AbstractCondition is an abstract implementation of an
Condition providing the boiler plate when implementing the
Condition interface.AbstractOperand is an abstract implementation of an
Operand providing the boiler plate when implementing the
Operand interface.Operand with the given arguments.AbstractOption is an abstract implementation of an Option
providing the boiler plate when implementing the Option interface.Option with the given arguments.Option with the given arguments.AndCondition contains (represents) a list of Condition
(Syntaxable) instances (nested by the AndCondition) of which
all are to be parsed successfully as of invoking the
Syntaxable.parseArgs(String[], String[]) methods.ArgsParser provides means for parsing command line arguments and
constructing a command line utility's help output.ArgsParser property.ArgsParser property returning the
builder for applying multiple build operations.ArgsParser property.ArgsParser property.ArgsParser interface.ArgsParser instance without any restrictions to
the parsed arguments.ArgsParser instance with the given root
Condition and the default SyntaxNotation.REFCODES.ArgsParser instance with the given root
Option and the default SyntaxNotation.REFCODES.Operand.ArrayOperand by encapsulating the given
Operand and providing its definition as array definition to the
CLI.ArrayOperand by encapsulating the given
Operand and providing its definition as array definition to the
CLI.ArrayOperand by encapsulating the given
Operand and providing its definition as array definition to the
CLI.Option.ArrayOption by encapsulating the given
Option and providing its definition as array definition to the
CLI.ArrayOption by encapsulating the given
Option and providing its definition as array definition to the
CLI.ArrayOption by encapsulating the given
Option and providing its definition as array definition to the
CLI.Operand.Operand.Operand.Option.Option.Option.Condition interface represents a node in the command line
arguments syntax tree; simply extending the Syntaxable interface and
adding the functionality of providing access to the added Operands
(leafs).ArgsParser.withConsoleWidth(int) method.ArgsParser.withConsoleWidth(int) method.Condition.Condition.ArgsParser.evalArgs(String[]) with the difference that the elements
representing the arguments are passed as a list instead of an array.FileOption for getting a File instance from a
path.Flag class implements the Option interface for
representing either a true or a false state: When a
flag is provided to your command line arguments, then it is considered to be
true, when it is omitted, then it is considered to be
false as of Flag.isEnabled().Flag.Flag.Flag.ArgsParser property.ExampleUsage instances as addeed using
ArgsParser.addExampleUsage(String, Operand...).ExampleUsage instances as addeed using
ArgsParser.addExampleUsage(String, Operand...).Option instance.Option instance.Option instance.Operand.Syntaxable
hierarchy to be traversed when determining the syntax for command line
arguments or when evaluating the command line arguments.Syntaxable
hierarchy to be traversed when determining the syntax for command line
arguments or when evaluating the command line arguments.ArgsParser.printSeparatorLn() method.ArgsParser.printSeparatorLn() method.Option instance.Option instance.Option instance.Syntaxable.parseArgs(String[], String[]) method,
use this method to determine whether the Operand.getValue() method
contains parsed value.String array
(setter) as of ArgsAccessor.ArgsMutator.setArgs(String[]) and returns the very same
value (getter).ArgsParser
(setter) as of ArgsParserAccessor.ArgsParserMutator.setArgsParser(ArgsParser) and returns the
very same value (getter).Condition
(setter) as of RootConditionAccessor.RootConditionMutator.setRootCondition(Condition) and returns the
very same value (getter).Operand represents a value parsed from command line arguments.Operation with the given arguments.Operation with the given arguments.Operation is an argument representing a function or a method and
is either provided or not provided as of Operation.isEnabled().Operation with the given arguments.Operation with the given arguments.Option represents a command line option with the according
option's value.OptionalCondition can nested by an AndCondition and
encapsulates a Condition which may be provided but does not
necessarily needs to be provided in order for the AndCondition to
successfully parse the nested Condition items including the
OptionalCondition.OrCondition represents a list of Condition
(Syntaxable) instances of which at least one must be parsed
successfully when the Syntaxable s'
Syntaxable.parseArgs(String[], String[]) methods are invoked.Syntaxable instance or, in case of
being a node in the syntax tree (such as a Condition, traversing
the child Syntaxable instances'
Syntaxable.parseArgs(String[], String[]) methods.Syntaxable instance or, in case of
being a node in the syntax tree (such as a Condition, traversing
the child Syntaxable instances'
Syntaxable.parseArgs(String[], String[]) methods.Syntaxable instance or, in case of
being a node in the syntax tree (such as a Condition, traversing
the child Syntaxable instances'
Syntaxable.parseArgs(String[], String[]) methods.Syntaxable instance or, in case of
being a node in the syntax tree (such as a Condition, traversing
the child Syntaxable instances'
Syntaxable.parseArgs(String[], String[]) methods.Syntaxable instance or, in case of
being a node in the syntax tree (such as a Condition, traversing
the child Syntaxable instances'
Syntaxable.parseArgs(String[], String[]) methods.Syntaxable instance or, in case of
being a node in the syntax tree (such as a Condition, traversing
the child Syntaxable instances'
Syntaxable.parseArgs(String[], String[]) methods.Syntaxable instance or, in case of
being a node in the syntax tree (such as a Condition, traversing
the child Syntaxable instances'
Syntaxable.parseArgs(String[], String[]) methods.ArgsParser.printHelp() without the banner.ArgsParser.withCopyrightNote(String) method; with regards to to the console
width as specified by the ArgsParser.withConsoleWidth(int) method.ArgsParser.withCopyrightNote(String) method; with regards to to the console
width as specified by the ArgsParser.withConsoleWidth(int) method.ArgsParser.withDescription(String)
method with regards to the console width as specified by the
ArgsParser.withConsoleWidth(int) method.ArgsParser.withDescription(String)
method with regards to the console width as specified by the
ArgsParser.withConsoleWidth(int) method.ArgsParser.addExampleUsage(String, Operand...) method with regards to the
console width as specified by the ArgsParser.withConsoleWidth(int) method.ArgsParser.addExampleUsage(String, Operand...) method with regards to the
console width as specified by the ArgsParser.withConsoleWidth(int) method.ArgsParser.withStandardOut(PrintStream) method.ArgsParser.withLicenseNote(String) method; with regards to to the console
width as specified by the ArgsParser.withConsoleWidth(int) method.ArgsParser.withLicenseNote(String) method; with regards to to the console
width as specified by the ArgsParser.withConsoleWidth(int) method.ArgsParser.withConsoleWidth(int) method.ArgsParser.withConsoleWidth(int) method.Options (short- and the long-options), the
Flages and the Operand and their description with regards
to the console width as specified by the ArgsParser.withConsoleWidth(int)
method.Options (short- and the long-options), the
Flages and the Operand and their description with regards
to the console width as specified by the ArgsParser.withConsoleWidth(int)
method.ArgsParser.withSeparatorLnChar(char) method; with regards to to the console
width as specified by the ArgsParser.withConsoleWidth(int) method.ArgsParser.withSeparatorLnChar(char) method; with regards to to the console
width as specified by the ArgsParser.withConsoleWidth(int) method.Condition with regards
to the SyntaxNotation set by the
ArgsParser.withSyntaxNotation(SyntaxNotation) method; making use of the
usage label as passed by the ArgsParser.withUsageLabel(String) method.Condition with regards
to the SyntaxNotation set by the
ArgsParser.withSyntaxNotation(SyntaxNotation) method; making use of the
usage label as passed by the ArgsParser.withUsageLabel(String) method.refcodes-cli artifact.Operand and
its value as parsed by the AbstractOperand.parseArgs(String[], String[]) method.Operand and
its value as parsed by the AbstractOperand.parseArgs(String[], String[]) method.ArgsParser property.ArgsParser.printHelp() method when
writing out the copyright claim and make other adjustments with the
result (with regards to the Builder-Pattern).ArgsParser.printHelp() method when
writing out the copyright claim and make other adjustments with the
result (with regards to the Builder-Pattern).PrintStream and make other adjustments with the
result (with regards to the Builder-Pattern).PrintStream and make other adjustments with the
result (with regards to the Builder-Pattern).ArgsParser.printHelp() method when writing
out the licensing conditions.ArgsParser.printHelp() method when writing
out the licensing conditions.ArgsParser.printSeparatorLn() method.ArgsParser.printSeparatorLn() method.PrintStream and make other adjustments with
the result (with regards to the Builder-Pattern).PrintStream and make other adjustments with
the result (with regards to the Builder-Pattern).SyntaxNotation.SyntaxNotation.ArgsParser.printHelp() method when writing
out the syntax.ArgsParser.printHelp() method when writing
out the syntax.Operand as parsed by the
AbstractOperand.parseArgs(String[], String[]) method.Operand as parsed by the
AbstractOperand.parseArgs(String[], String[]) method.Syntaxable defines the methods at least required when building a
command line arguments syntax tree for traversing the syntax tree; either for
parsing command line arguments or for constructing the command line arguments
syntax.SyntaxNotation is used by a the
Syntaxable.toSyntax(SyntaxNotation, String, String) method to
determine which notation to be used for the generated syntax.SyntaxUsage interface defines those methods required to create a
human readable usage String from the implementing instance.Operand instances found in the provided Lists
and adds all therein found argument arrays (as of
Operand.getArgs()) to the result.Lists therein found argument arrays subset (as of
Operand.getArgs()).Operand;.Operand.Operand.Operand consisting of the
options specification (if any) as of CliUtility.toOptionsSpec(Operand) and
the parameter specification (if any) as of
CliUtility.toParameterSpec(Operand).Syntaxable.toState() method might be used by the
Object.toString() method and prints out the state of the
syntaxable and (if any) its children.Syntaxable.toState() method might be used by the
Object.toString() method and prints out the state of the
syntaxable and (if any) its children.Syntaxable.toState() method might be used by the
Object.toString() method and prints out the state of the
syntaxable and (if any) its children.Syntaxable.toState() method might be used by the
Object.toString() method and prints out the state of the
syntaxable and (if any) its children.Syntaxable.toState() method might be used by the
Object.toString() method and prints out the state of the
syntaxable and (if any) its children.Syntaxable.toState() method might be used by the
Object.toString() method and prints out the state of the
syntaxable and (if any) its children.Syntaxable.toState() method might be used by the
Object.toString() method and prints out the state of the
syntaxable and (if any) its children.Syntaxable.toState() method might be used by the
Object.toString() method and prints out the state of the
syntaxable and (if any) its children.Syntaxable.toState() method might be used by the
Object.toString() method and prints out the state of the
syntaxable and (if any) its children.Syntaxable.toState() method might be used by the
Object.toString() method and prints out the state of the
syntaxable and (if any) its children.Syntaxable hierarchy;
use the method SyntaxUsage.toUsage(SyntaxNotation) in case you invoke syntax
retrieval from the root Syntaxable.Syntaxable hierarchy;
use the method SyntaxUsage.toUsage(SyntaxNotation) in case you invoke syntax
retrieval from the root Syntaxable.Syntaxable hierarchy;
use the method SyntaxUsage.toUsage(SyntaxNotation) in case you invoke syntax
retrieval from the root Syntaxable.Syntaxable hierarchy;
use the method SyntaxUsage.toUsage(SyntaxNotation) in case you invoke syntax
retrieval from the root Syntaxable.Syntaxable hierarchy;
use the method SyntaxUsage.toUsage(SyntaxNotation) in case you invoke syntax
retrieval from the root Syntaxable.Syntaxable hierarchy;
use the method SyntaxUsage.toUsage(SyntaxNotation) in case you invoke syntax
retrieval from the root Syntaxable.Syntaxable hierarchy;
use the method SyntaxUsage.toUsage(SyntaxNotation) in case you invoke syntax
retrieval from the root Syntaxable.Syntaxable hierarchy;
use the method SyntaxUsage.toUsage(SyntaxNotation) in case you invoke syntax
retrieval from the root Syntaxable.Syntaxable hierarchy;
use the method SyntaxUsage.toUsage(SyntaxNotation) in case you invoke syntax
retrieval from the root Syntaxable.Syntaxable and the child Syntaxables,
the method Syntaxable.toSyntax(SyntaxNotation, String, String) is
called from inside a Syntaxable hierarchy.Syntaxable and the child Syntaxables,
the method Syntaxable.toSyntax(SyntaxNotation, String, String) is
called from inside a Syntaxable hierarchy.Syntaxable and the child Syntaxables,
the method Syntaxable.toSyntax(SyntaxNotation, String, String) is
called from inside a Syntaxable hierarchy.Syntaxable and the child Syntaxables,
the method Syntaxable.toSyntax(SyntaxNotation, String, String) is
called from inside a Syntaxable hierarchy.Syntaxable and the child Syntaxables,
the method Syntaxable.toSyntax(SyntaxNotation, String, String) is
called from inside a Syntaxable hierarchy.Syntaxable and the child Syntaxables,
the method Syntaxable.toSyntax(SyntaxNotation, String, String) is
called from inside a Syntaxable hierarchy.Syntaxable and the child Syntaxables,
the method Syntaxable.toSyntax(SyntaxNotation, String, String) is
called from inside a Syntaxable hierarchy.AbstractOperand for converting a command line argument to the
required Operand's type.AbstractOperand for converting a command line argument to the
required Operand's type.AbstractOperand for converting a command line argument to the
required Operand's type.AbstractOperand for converting a command line argument to the
required Operand's type.AbstractOperand for converting a command line argument to the
required Operand's type.AbstractOperand for converting a command line argument to the
required Operand's type.AbstractOperand for converting a command line argument to the
required Operand's type.AbstractOperand for converting a command line argument to the
required Operand's type.AbstractOperand for converting a command line argument to the
required Operand's type.AbstractOperand for converting a command line argument to the
required Operand's type.AbstractOperand for converting a command line argument to the
required Operand's type.ArgsParser property.ArgsParser.printHelp() method when
writing out the copyright claim and make other adjustments with the
result (with regards to the Builder-Pattern).PrintStream and make other adjustments with the
result (with regards to the Builder-Pattern).ArgsParser.evalArgs(String[]) with the difference that this class's
instance being invoked is returned as of the builder pattern.ArgsParser.evalArgs(List) with the difference that this class's
instance being invoked is returned as of the builder pattern.ArgsParser.printHelp() method when writing
out the licensing conditions and make other adjustments with the result
(with regards to the Builder-Pattern).ArgsParser.printSeparatorLn() method.PrintStream and make other adjustments with
the result (with regards to the Builder-Pattern).SyntaxNotation and make other adjustments with the result
(with regards to the Builder-Pattern).ArgsParser.printHelp() method when writing
out the syntax and make other adjustments with the result (with regards
to the Builder-Pattern).XorCondition represents a list of Condition
(Syntaxable) instances of which only one is allowed to be parsed
successfully when the Syntaxable.parseArgs(String[], String[]) methods
are invoked.Copyright © 2021. All rights reserved.