Class AbstractProperty<T>

Type Parameters:
T - The generic type of the AbstractProperty's value.
All Implemented Interfaces:
Cloneable, Comparable<Operand<?>>, MatchCountAccessor, Operand<T>, Option<T>, ParsedArgsAccessor, Property<T>, Synopsisable, Term, ExceptionAccessor<ArgsSyntaxException>, VisibleAccessor, VisibleAccessor.VisibleBuilder<Term>, VisibleAccessor.VisibleMutator, VisibleAccessor.VisibleProperty, AliasAccessor, Clonable, DescriptionAccessor, Resetable, TypeAccessor<T>, ValueAccessor<T>, Diagnosable, Schemable<DiagnosticOptions>
Direct Known Subclasses:
BooleanProperty, CharProperty, DoubleProperty, EnumProperty, FileProperty, FloatProperty, IntProperty, LongProperty, StringProperty

public abstract class AbstractProperty<T> extends AbstractOption<T> implements Property<T>
The AbstractProperty is an abstract implementation of a Property providing the boiler plate when implementing the Property interface. A Property is a key=value pair passed as a single argument (e.g. "--file=someFile").