Class AnyCondition
- All Implemented Interfaces:
Condition, MatchCountAccessor, Synopsisable, Term, ExceptionAccessor<ArgsSyntaxException>, VisibleAccessor, VisibleAccessor.VisibleBuilder<Term>, VisibleAccessor.VisibleMutator, VisibleAccessor.VisibleProperty, ChildrenAccessor<Term[]>, DescriptionAccessor, Resetable, Diagnosable, Schemable<DiagnosticOptions>
Condition conditions may match for the
AnyCondition to match, e.g. all of the nested conditions are
optional. The AnyCondition can nested by an AndCondition and
encapsulates a Condition which may be provided but does not
necessarily needs to be provided in order for the AndCondition to
successfully parse the nested Condition items including the
AnyCondition.-
Nested Class Summary
Nested classes/interfaces inherited from interface ChildrenAccessor
ChildrenAccessor.ChildrenBuilder<T,B>, ChildrenAccessor.ChildrenMutator<T>, ChildrenAccessor.ChildrenProperty<T> Nested classes/interfaces inherited from interface DescriptionAccessor
DescriptionAccessor.DescriptionBuilder<B>, DescriptionAccessor.DescriptionMutator, DescriptionAccessor.DescriptionPropertyNested classes/interfaces inherited from interface ExceptionAccessor
ExceptionAccessor.ExceptionBuilder<EXC,B>, ExceptionAccessor.ExceptionMutator<EXC>, ExceptionAccessor.ExceptionProperty<EXC> Nested classes/interfaces inherited from interface MatchCountAccessor
MatchCountAccessor.MatchCountBuilder<B>, MatchCountAccessor.MatchCountMutator, MatchCountAccessor.MatchCountPropertyNested classes/interfaces inherited from interface VisibleAccessor
VisibleAccessor.VisibleBuilder<B>, VisibleAccessor.VisibleMutator, VisibleAccessor.VisibleProperty -
Field Summary
FieldsModifier and TypeFieldDescriptionprotected Stringprotected ArgsSyntaxExceptionprotected booleanFields inherited from class AbstractCondition
_children -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionRetrieves theArgsSyntaxExceptionexception caught while invoking theTerm.parseArgs(String[], CliContext)method.Operand<?>[]parseArgs(String[] aArgs, String[] aKeywords, CliContext aCliCtx) Parses the given command line arguments using the provided keyword set and CLI context.voidreset()voidsetVisible(boolean isVisible) protected static String[]toArgsDiff(String[] aArgs, String[] aArgsSubset) Creates the difference between the provided set and the provided subset.protected static String[]toArgsDiff(String[] aArgs, List<? extends Operand<?>> aArgsSubset) Creates the difference between the provided set and the providedLists therein found argument arrays subset (as ofOperand.getParsedArgs()).protected static String[]toArgsDiff(String[] aArgs, Operand<?>[] aArgsSubset) Creates the difference between the provided set and the providedLists therein found argument arrays subset (as ofOperand.getParsedArgs()).protected static String[]toParsedArgs(Operand<?>[]... aOperands) Takes allOperandinstances found in the providedLists and adds all therein found argument arrays (as ofOperand.getParsedArgs()) to the result.toSyntax(CliContext aCliCtx) Creates a syntax including its arguments.withVisible(boolean isVisible) Methods inherited from class AbstractCondition
getChildren, getMatchCount, isVisible, toOperand, toOperands, toSchema, toString, toValueMethods inherited from class Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface Condition
hasChild, isChild, toConditions, toOperand, toOperand, toOperandsMethods inherited from interface DescriptionAccessor
getDescriptionMethods inherited from interface Synopsisable
toSynopsis, toSynopsis, toSynopsis, toSynopsisMethods inherited from interface Term
argsParser, parseArgs, setVisible, toSynopsis, toSyntax, toSyntax, toSyntax, toSyntaxMethods inherited from interface VisibleAccessor
isHiddenMethods inherited from interface VisibleAccessor.VisibleBuilder
withHide, withShowMethods inherited from interface VisibleAccessor.VisibleMutator
hide, showMethods inherited from interface VisibleAccessor.VisibleProperty
letVisible
-
Field Details
-
_description
-
_exception
-
_isVisible
protected boolean _isVisible
-
-
Constructor Details
-
AnyCondition
-
-
Method Details
-
parseArgs
public Operand<?>[] parseArgs(String[] aArgs, String[] aKeywords, CliContext aCliCtx) throws ArgsSyntaxException Parses the given command line arguments using the provided keyword set and CLI context.This method represents the core parsing operation. It evaluates this
Termor, if this term is an inner node, delegates parsing to its child terms.The
aKeywordsparameter defines reserved tokens such as option names that must not be interpreted as operand values.This method does not validate whether all arguments have been consumed. Superfluous arguments must be handled by the caller.
- Parameters:
aArgs- The command line arguments to parseaKeywords- Reserved option and keyword tokensaCliCtx- TheCliContextcontrolling parsing and rendering- Returns:
- The evaluated operands
- Throws:
ArgsSyntaxException- If the arguments do not match the syntax
-
reset
public void reset()- Specified by:
resetin interfaceResetable- Overrides:
resetin classAbstractCondition
-
toSyntax
Creates a syntax including its arguments.A specification differs from a syntax in that the specification provides the full definition not omitting any choices whereas the syntax only provides a syntactically correct variant. For example, having an option with a short option and a long option, the specification will show the short option and the long option whereas the syntax will only show either the short option or, if no short option is set, the long option.
- Specified by:
toSyntaxin interfaceTerm- Overrides:
toSyntaxin classAbstractCondition- Parameters:
aCliCtx- The CLI context controlling notation and formatting- Returns:
- The human readable command line syntax
-
getException
Retrieves theArgsSyntaxExceptionexception caught while invoking theTerm.parseArgs(String[], CliContext)method. The exception (and the according suppressed ones alongside the causes) is not thrown by theTerm.parseArgs(String[], CliContext)method as of the semantics of thisAnyCondition! Nevertheless, the exception can be used to analyze argument parsing failure (e.g. for better error messages).- Specified by:
getExceptionin interfaceExceptionAccessor<ArgsSyntaxException>- Specified by:
getExceptionin interfaceTerm- Returns:
- The
ArgsSyntaxExceptionexception occurring while parsing the arguments.
-
withVisible
Visibility in this context means displaying or hiding this
Term's existence to the user (defaults totrue). -
getDescription
- Specified by:
getDescriptionin interfaceDescriptionAccessor
-
setVisible
public void setVisible(boolean isVisible) Visibility in this context means displaying or hiding this
Term's existence to the user (defaults totrue).- Specified by:
setVisiblein interfaceTerm- Specified by:
setVisiblein interfaceVisibleAccessor.VisibleMutator
-
toArgsDiff
Creates the difference between the provided set and the providedLists therein found argument arrays subset (as ofOperand.getParsedArgs()).- Parameters:
aArgs- The set to be used for the diff operation.aArgsSubset- The subset to be used for the diff operation being the lists containing theOperandinstances whose command line arguments are to be diffed.- Returns:
- The difference between the set and the subset.
-
toArgsDiff
Creates the difference between the provided set and the providedLists therein found argument arrays subset (as ofOperand.getParsedArgs()).- Parameters:
aArgs- The set to be used for the diff operation.aArgsSubset- The subset to be used for the diff operation being the lists containing theOperandinstances whose command line arguments are to be diffed.- Returns:
- The difference between the set and the subset.
-
toArgsDiff
Creates the difference between the provided set and the provided subset.- Parameters:
aArgs- The set to be used for the diff operation.aArgsSubset- The subset to be used for the diff operation.- Returns:
- The difference between the set and the subset.
-
toParsedArgs
Takes allOperandinstances found in the providedLists and adds all therein found argument arrays (as ofOperand.getParsedArgs()) to the result.
-