Interface ArgsAccessor
- All Known Subinterfaces:
ArgsAccessor.ArgsProperty
- All Known Implementing Classes:
AmbiguousArgsException,ArgsSyntaxException,CliException.CliArgsException,ParseArgsException,ParseDirectiveArgsException,ParseOptionArgsException,SuperfluousArgsException,UnknownArgsException,UnknownOperationArgsException,UnknownOptionArgsException
public interface ArgsAccessor
Provides an accessor for a command line arguments (short "args") array.
-
Nested Class Summary
Nested ClassesModifier and TypeInterfaceDescriptionstatic interfaceProvides a mutator for a args property.static interfaceProvides a args property. -
Method Summary
-
Method Details
-
getArgs
String[] getArgs()Retrieves the command line arguments from the args property.- Returns:
- The command line arguments stored by the args property.
-