-
- All Known Subinterfaces:
ArgsAccessor.ArgsProperty
- Enclosing interface:
- ArgsAccessor
public static interface ArgsAccessor.ArgsMutatorProvides a mutator for a args property.
-
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description voidsetArgs(String[] aArgs)Sets the command line arguments for the args property.
-
-
-
Method Detail
-
setArgs
void setArgs(String[] aArgs)
Sets the command line arguments for the args property.- Parameters:
aArgs- The command line arguments to be stored by the args property.
-
-