Interface ArgsParser
- All Superinterfaces:
ArgsParserBuilder<ArgsParser>, ArgsProcessorBuilder<ArgsParser>, ArgsSyntaxAccessor, ArgsSyntaxAccessor.ArgsSyntaxBuilder<ArgsParser>, ArgsSyntaxAccessor.ArgsSyntaxMutator, ArgsSyntaxAccessor.ArgsSyntaxProperty, ArgumentEscapeCodeAccessor, ArgumentEscapeCodeAccessor.ArgumentEscapeCodeBuilder<ArgsParser>, ArgumentEscapeCodeAccessor.ArgumentEscapeCodeMutator, ArgumentEscapeCodeAccessor.ArgumentEscapeCodeProperty, BannerBorderEscapeCodeAccessor, BannerBorderEscapeCodeAccessor.BannerBorderEscapeCodeBuilder<ArgsParser>, BannerBorderEscapeCodeAccessor.BannerBorderEscapeCodeMutator, BannerBorderEscapeCodeAccessor.BannerBorderEscapeCodeProperty, BannerEscapeCodeAccessor, BannerEscapeCodeAccessor.BannerEscapeCodeBuilder<ArgsParser>, BannerEscapeCodeAccessor.BannerEscapeCodeMutator, BannerEscapeCodeAccessor.BannerEscapeCodeProperty, BannerFontAccessor, BannerFontAccessor.BannerFontBuilder<ArgsParser>, BannerFontAccessor.BannerFontMutator, BannerFontAccessor.BannerFontProperty, BannerFontPaletteAccessor, BannerFontPaletteAccessor.BannerFontPaletteBuilder<ArgsParser>, BannerFontPaletteAccessor.BannerFontPaletteMutator, BannerFontPaletteAccessor.BannerFontPaletteProperty, CliMetrics, CommandEscapeCodeAccessor, CommandEscapeCodeAccessor.CommandEscapeCodeBuilder<ArgsParser>, CommandEscapeCodeAccessor.CommandEscapeCodeMutator, CommandEscapeCodeAccessor.CommandEscapeCodeProperty, ConsoleWidthAccessor, ConsoleWidthAccessor.ConsoleWidthBuilder<ArgsParser>, ConsoleWidthAccessor.ConsoleWidthMutator, ConsoleWidthAccessor.ConsoleWidthProperty, CopyrightAccessor, CopyrightAccessor.CopyrightBuilder<ArgsParser>, CopyrightAccessor.CopyrightMutator, CopyrightAccessor.CopyrightProperty, DescriptionAccessor, DescriptionAccessor.DescriptionBuilder<ArgsParser>, DescriptionAccessor.DescriptionMutator, DescriptionAccessor.DescriptionProperty, DescriptionEscapeCodeAccessor, DescriptionEscapeCodeAccessor.DescriptionEscapeCodeBuilder<ArgsParser>, DescriptionEscapeCodeAccessor.DescriptionEscapeCodeMutator, DescriptionEscapeCodeAccessor.DescriptionEscapeCodeProperty, Diagnosable, EscapeCodesStatusAccessor, EscapeCodesStatusAccessor.EscapeCodeStatusBuilder<ArgsParser>, EscapeCodesStatusAccessor.EscapeCodeStatusMutator, EscapeCodesStatusAccessor.EscapeCodeStatusProperty, ExamplesAccessor, ExamplesAccessor.ExamplesBuilder<ArgsParser>, ExamplesAccessor.ExamplesMutator, ExamplesAccessor.ExamplesProperty, KeywordEscapeCodeAccessor, KeywordEscapeCodeAccessor.KeywordEscapeCodeBuilder<ArgsParser>, KeywordEscapeCodeAccessor.KeywordEscapeCodeMutator, KeywordEscapeCodeAccessor.KeywordEscapeCodeProperty, LicenseAccessor, LicenseAccessor.LicenseBuilder<ArgsParser>, LicenseAccessor.LicenseMutator, LicenseAccessor.LicenseProperty, LineBreakAccessor, LineBreakAccessor.LineBreakBuilder<ArgsParser>, LineBreakAccessor.LineBreakMutator, LineBreakAccessor.LineBreakProperty, LineSeparatorEscapeCodeAccessor, LineSeparatorEscapeCodeAccessor.LineSeparatorEscapeCodeBuilder<ArgsParser>, LineSeparatorEscapeCodeAccessor.LineSeparatorEscapeCodeMutator, LineSeparatorEscapeCodeAccessor.LineSeparatorEscapeCodeProperty, LongOptionPrefixAccessor, LongOptionPrefixAccessor.LongOptionPrefixBuilder<ArgsParser>, LongOptionPrefixAccessor.LongOptionPrefixMutator, LongOptionPrefixAccessor.LongOptionPrefixProperty, MaxConsoleWidthAccessor, MaxConsoleWidthAccessor.MaxConsoleWidthBuilder<ArgsParser>, MaxConsoleWidthAccessor.MaxConsoleWidthMutator, MaxConsoleWidthAccessor.MaxConsoleWidthProperty, NameAccessor, NameAccessor.NameBuilder<ArgsParser>, NameAccessor.NameMutator, NameAccessor.NameProperty, Optionable, Resetable, ResetEscapeCodeAccessor, ResetEscapeCodeAccessor.ResetEscapeCodeBuilder<ArgsParser>, ResetEscapeCodeAccessor.ResetEscapeCodeMutator, ResetEscapeCodeAccessor.ResetEscapeCodeProperty, Schemable<DiagnosticOptions>, ShortOptionPrefixAccessor, ShortOptionPrefixAccessor.ShortOptionPrefixBuilder<ArgsParser>, ShortOptionPrefixAccessor.ShortOptionPrefixMutator, ShortOptionPrefixAccessor.ShortOptionPrefixProperty, SyntaxMetricsAccessor, SyntaxMetricsAccessor.SyntaxMetricsBuilder<ArgsParser>, SyntaxMetricsAccessor.SyntaxMetricsMutator, SyntaxMetricsAccessor.SyntaxMetricsProperty, TextBoxGridAccessor, TextBoxGridAccessor.TextBoxGridBuilder<ArgsParser>, TextBoxGridAccessor.TextBoxGridMutator, TextBoxGridAccessor.TextBoxGridProperty, TitleAccessor, TitleAccessor.TitleBuilder<ArgsParser>, TitleAccessor.TitleMutator, TitleAccessor.TitleProperty
- All Known Implementing Classes:
CliArgsParser
public interface ArgsParser
extends Optionable, CliMetrics, LineBreakAccessor.LineBreakProperty, LineSeparatorEscapeCodeAccessor.LineSeparatorEscapeCodeProperty, DescriptionEscapeCodeAccessor.DescriptionEscapeCodeProperty, LicenseAccessor.LicenseProperty, CopyrightAccessor.CopyrightProperty, ConsoleWidthAccessor.ConsoleWidthProperty, MaxConsoleWidthAccessor.MaxConsoleWidthProperty, BannerFontPaletteAccessor.BannerFontPaletteProperty, BannerFontAccessor.BannerFontProperty, CommandEscapeCodeAccessor.CommandEscapeCodeProperty, BannerEscapeCodeAccessor.BannerEscapeCodeProperty, BannerBorderEscapeCodeAccessor.BannerBorderEscapeCodeProperty, ExamplesAccessor.ExamplesProperty, TitleAccessor.TitleProperty, NameAccessor.NameProperty, DescriptionAccessor.DescriptionProperty, EscapeCodesStatusAccessor.EscapeCodeStatusProperty, ResetEscapeCodeAccessor.ResetEscapeCodeProperty, KeywordEscapeCodeAccessor.KeywordEscapeCodeProperty, ArgumentEscapeCodeAccessor.ArgumentEscapeCodeProperty, SyntaxMetricsAccessor.SyntaxMetricsProperty, ShortOptionPrefixAccessor.ShortOptionPrefixProperty, LongOptionPrefixAccessor.LongOptionPrefixProperty, TextBoxGridAccessor.TextBoxGridProperty, ArgsSyntaxAccessor.ArgsSyntaxProperty, ArgsProcessorBuilder<ArgsParser>, ArgsParserBuilder<ArgsParser>, Resetable, Diagnosable
The
ArgsParser provides means for parsing command line arguments and
constructing a command line utility's help output.-
Nested Class Summary
Nested classes/interfaces inherited from interface ArgsSyntaxAccessor
ArgsSyntaxAccessor.ArgsSyntaxBuilder<B>, ArgsSyntaxAccessor.ArgsSyntaxMutator, ArgsSyntaxAccessor.ArgsSyntaxPropertyNested classes/interfaces inherited from interface ArgumentEscapeCodeAccessor
ArgumentEscapeCodeAccessor.ArgumentEscapeCodeBuilder<B>, ArgumentEscapeCodeAccessor.ArgumentEscapeCodeMutator, ArgumentEscapeCodeAccessor.ArgumentEscapeCodePropertyNested classes/interfaces inherited from interface BannerBorderEscapeCodeAccessor
BannerBorderEscapeCodeAccessor.BannerBorderEscapeCodeBuilder<B>, BannerBorderEscapeCodeAccessor.BannerBorderEscapeCodeMutator, BannerBorderEscapeCodeAccessor.BannerBorderEscapeCodePropertyNested classes/interfaces inherited from interface BannerEscapeCodeAccessor
BannerEscapeCodeAccessor.BannerEscapeCodeBuilder<B>, BannerEscapeCodeAccessor.BannerEscapeCodeMutator, BannerEscapeCodeAccessor.BannerEscapeCodePropertyNested classes/interfaces inherited from interface BannerFontAccessor
BannerFontAccessor.BannerFontBuilder<B>, BannerFontAccessor.BannerFontMutator, BannerFontAccessor.BannerFontPropertyNested classes/interfaces inherited from interface BannerFontPaletteAccessor
BannerFontPaletteAccessor.BannerFontPaletteBuilder<B>, BannerFontPaletteAccessor.BannerFontPaletteMutator, BannerFontPaletteAccessor.BannerFontPalettePropertyNested classes/interfaces inherited from interface CommandEscapeCodeAccessor
CommandEscapeCodeAccessor.CommandEscapeCodeBuilder<B>, CommandEscapeCodeAccessor.CommandEscapeCodeMutator, CommandEscapeCodeAccessor.CommandEscapeCodePropertyNested classes/interfaces inherited from interface ConsoleWidthAccessor
ConsoleWidthAccessor.ConsoleWidthBuilder<B>, ConsoleWidthAccessor.ConsoleWidthMutator, ConsoleWidthAccessor.ConsoleWidthPropertyNested classes/interfaces inherited from interface CopyrightAccessor
CopyrightAccessor.CopyrightBuilder<B>, CopyrightAccessor.CopyrightMutator, CopyrightAccessor.CopyrightPropertyNested classes/interfaces inherited from interface DescriptionAccessor
DescriptionAccessor.DescriptionBuilder<B>, DescriptionAccessor.DescriptionMutator, DescriptionAccessor.DescriptionPropertyNested classes/interfaces inherited from interface DescriptionEscapeCodeAccessor
DescriptionEscapeCodeAccessor.DescriptionEscapeCodeBuilder<B>, DescriptionEscapeCodeAccessor.DescriptionEscapeCodeMutator, DescriptionEscapeCodeAccessor.DescriptionEscapeCodePropertyNested classes/interfaces inherited from interface EscapeCodesStatusAccessor
EscapeCodesStatusAccessor.EscapeCodeStatusBuilder<B>, EscapeCodesStatusAccessor.EscapeCodeStatusMutator, EscapeCodesStatusAccessor.EscapeCodeStatusPropertyNested classes/interfaces inherited from interface ExamplesAccessor
ExamplesAccessor.ExamplesBuilder<B>, ExamplesAccessor.ExamplesMutator, ExamplesAccessor.ExamplesPropertyNested classes/interfaces inherited from interface KeywordEscapeCodeAccessor
KeywordEscapeCodeAccessor.KeywordEscapeCodeBuilder<B>, KeywordEscapeCodeAccessor.KeywordEscapeCodeMutator, KeywordEscapeCodeAccessor.KeywordEscapeCodePropertyNested classes/interfaces inherited from interface LicenseAccessor
LicenseAccessor.LicenseBuilder<B>, LicenseAccessor.LicenseMutator, LicenseAccessor.LicensePropertyNested classes/interfaces inherited from interface LineBreakAccessor
LineBreakAccessor.LineBreakBuilder<B>, LineBreakAccessor.LineBreakMutator, LineBreakAccessor.LineBreakPropertyNested classes/interfaces inherited from interface LineSeparatorEscapeCodeAccessor
LineSeparatorEscapeCodeAccessor.LineSeparatorEscapeCodeBuilder<B>, LineSeparatorEscapeCodeAccessor.LineSeparatorEscapeCodeMutator, LineSeparatorEscapeCodeAccessor.LineSeparatorEscapeCodePropertyNested classes/interfaces inherited from interface LongOptionPrefixAccessor
LongOptionPrefixAccessor.LongOptionPrefixBuilder<B>, LongOptionPrefixAccessor.LongOptionPrefixMutator, LongOptionPrefixAccessor.LongOptionPrefixPropertyNested classes/interfaces inherited from interface MaxConsoleWidthAccessor
MaxConsoleWidthAccessor.MaxConsoleWidthBuilder<B>, MaxConsoleWidthAccessor.MaxConsoleWidthMutator, MaxConsoleWidthAccessor.MaxConsoleWidthPropertyNested classes/interfaces inherited from interface NameAccessor
NameAccessor.NameBuilder<B>, NameAccessor.NameMutator, NameAccessor.NamePropertyNested classes/interfaces inherited from interface ResetEscapeCodeAccessor
ResetEscapeCodeAccessor.ResetEscapeCodeBuilder<B>, ResetEscapeCodeAccessor.ResetEscapeCodeMutator, ResetEscapeCodeAccessor.ResetEscapeCodePropertyNested classes/interfaces inherited from interface ShortOptionPrefixAccessor
ShortOptionPrefixAccessor.ShortOptionPrefixBuilder<B>, ShortOptionPrefixAccessor.ShortOptionPrefixMutator, ShortOptionPrefixAccessor.ShortOptionPrefixPropertyNested classes/interfaces inherited from interface SyntaxMetricsAccessor
SyntaxMetricsAccessor.SyntaxMetricsBuilder<B>, SyntaxMetricsAccessor.SyntaxMetricsMutator, SyntaxMetricsAccessor.SyntaxMetricsPropertyNested classes/interfaces inherited from interface TextBoxGridAccessor
TextBoxGridAccessor.TextBoxGridBuilder<B>, TextBoxGridAccessor.TextBoxGridMutator, TextBoxGridAccessor.TextBoxGridPropertyNested classes/interfaces inherited from interface TitleAccessor
TitleAccessor.TitleBuilder<B>, TitleAccessor.TitleMutator, TitleAccessor.TitleProperty -
Method Summary
Modifier and TypeMethodDescriptiondefault voidaddExample(String aDescription, Operand<?>... aOperands) Adds an usage example by providing a description of the example and the command line arguments required by the example.voidaddExample(Example aExample) Adds an usage example by providing a description of the example and the command line arguments required by the example.voidPrints the given line to standard error with regards to the console width as specified by thewithConsoleWidth(int)method.Operand<?>[]Evaluates the provided command line arguments and determines the according values by evaluating the rootCondition.default Operand<?>[]Evaluates the provided command line arguments as ofevalArgs(String[]), additionally filtering (excluding) the arguments matching the providedPattern.default Operand<?>[]evalArgs(String[] aArgs, ArgsFilter aArgsFilter) Evaluates the provided command line arguments as ofevalArgs(String[]), additionally filtering (excluding) the arguments matching the providedArgsFilter.default Operand<?>[]Same asevalArgs(String[])with the difference that the elements representing the arguments are passed as a list instead of an array.default Operand<?>[]Evaluates the provided command line arguments as ofevalArgs(String[]), additionally filtering (excluding) the arguments matching the providedPattern.default Operand<?>[]evalArgs(List<String> aArgs, ArgsFilter aArgsFilter) Evaluates the provided command line arguments as ofevalArgs(String[]), additionally filtering (excluding) the arguments matching the providedArgsFilter.Retrieves the argument Escape-Code from the argument Escape-Code property.Retrieves the banner border Escape-Code from the banner border Escape-Code property.Retrieves the banner Escape-Code from the banner Escape-Code property.Retrieves the command Escape-Code from the command Escape-Code property.Retrieves the copyright from the copyright property.Retrieves the description Escape-Code from the description Escape-Code property.Example[]Retrieves the keyword (e.g. short- and long-options) Escape-Code from the option Escape-Code property.Retrieves the license from the license property.Retrieves the line separator Escape-Code from the line separator Escape-Code property.charGets the character to be used when printing a separator line with theprintSeparatorLn()method.voidPrints the banner; the banner most probably is an ASCII_HEADER_ASCII_BODY art text block which's look depends strongly on the taste of the author implementing this interface.default voidPrints the help as ofprintHelp()without the banner.voidPrints the copyright note as specified by thewithCopyright(String)method; with regards to the console width as specified by thewithConsoleWidth(int)method.voidPrints the description as set by thewithDescription(String)method with regards to the console width as specified by thewithConsoleWidth(int)method.voidPrints example usages as as added by theaddExample(String, Operand...)method with regards to the console width as specified by thewithConsoleWidth(int)method.voidPrints the header, which might be a simplified banner: Can be used when overriding methods such asprintHelp()orprintBanner().default voidPrints the help to the standard output specified by thewithStandardOut(PrintStream)method.voidPrints the license note as specified by thewithLicense(String)method; with regards to the console width as specified by thewithConsoleWidth(int)method.voidprintLn()Prints an empty line / a line break.voidPrints the given line to standard out with regards to the console width as specified by thewithConsoleWidth(int)method.voidPrints theOptions (short- and the long-options), theFlages and theOperandand their description with regards to the console width as specified by thewithConsoleWidth(int)method.voidPrints a separator line using the separator character as specified by thewithSeparatorLnChar(char)method; with regards to the console width as specified by thewithConsoleWidth(int)method.voidPrints the syntax as retrieved by the rootConditionelement as ofSynopsisable.toSynopsis(SyntaxNotation)with regards to theSyntaxNotationset by thewithSyntaxMetrics(SyntaxMetrics)method.voidsetErrorOut(PrintStream aErrorOut) Set the error outPrintStreamand make other adjustments with the result (with regards to the Builder-Pattern).voidsetLineSeparatorEscapeCode(String aLineSeparatorEscCode) Sets the line separator Escape-Code for the line separator Escape-Code property.voidsetSeparatorLnChar(char aSeparatorLnChar) Set the character to be used when printing a separator line with theprintSeparatorLn()method.voidsetStandardOut(PrintStream aStandardOut) Set the standard outPrintStreamand make other adjustments with the result (with regards to the Builder-Pattern).voidsetSyntaxMetrics(SyntaxMetrics aSyntaxMetrics) Sets theSyntaxMetricsfor theSyntaxMetricsproperty.default String[]Retrieves an array of the context specific options being configured for the givenOptioninstance, being the long option (when set) and the short option (when set), by prepending the according runtime specific short option and long option prefix (if applicable).default SchematoSchema()default ArgsParserwithAddExample(String aDescription, Operand<?>... aOperands) Builder method adding an application'sExampleelement.default ArgsParserwithAddExample(Example aExample) Builder method adding an application'sExampleelement.default ArgsParserwithArgumentEscapeCode(String aParamEscCode) Sets the argument Escape-Code for the argument Escape-Code property.default ArgsParserwithBannerBorderEscapeCode(String aBannerBorderEscCode) Sets the banner border Escape-Code for the banner border Escape-Code property.default ArgsParserwithBannerEscapeCode(String aBannerEscCode) Sets the banner Escape-Code for the banner Escape-Code property.default ArgsParserwithBannerFont(Font aBannerFont) default ArgsParserwithBannerFontPalette(char[] aColorPalette) Sets the banner font palette for the banner font palette property.default ArgsParserwithCommandEscapeCode(String aCommandEscCode) Sets the command Escape-Code for the command Escape-Code property.default ArgsParserwithConsoleWidth(int aConsoleWidth) default ArgsParserwithCopyright(String aCopyright) Sets the copyright for the copyright property.default ArgsParserwithDescription(String aDescription) default ArgsParserwithDescriptionEscapeCode(String aDescriptionEscCode) Sets the description Escape-Code for the description Escape-Code property.default ArgsParserwithErrorOut(PrintStream aErrorOut) Set the error outPrintStreamand make other adjustments with the result (with regards to the Builder-Pattern).default ArgsParserwithEscapeCodesEnabled(boolean isEscCodeEnabled) default ArgsParserwithEvalArgs(String[] aArgs) Evaluates the provided command line arguments.default ArgsParserwithEvalArgs(List<String> aArgs) Evaluates the provided command line arguments .default ArgsParserwithExamples(Collection<Example> aExamples) Builder method providing the application'sExampleelements.default ArgsParserwithExamples(Example[] aExamples) default ArgsParserwithKeywordEscapeCode(String aOptEscCode) Sets the keyword (e.g. short- and long-options) Escape-Code for the keyword Escape-Code property.default ArgsParserwithLicense(String aLicense) Sets the license for the license property.default ArgsParserwithLineBreak(String aLineBreak) default ArgsParserwithLineSeparatorEscapeCode(String aLineSeparatorEscCode) Sets the line separator Escape-Code for the line separator Escape-Code property.default ArgsParserwithLongOptionPrefix(String aLongOptionPrefix) Sets the long option prefix for the long option prefix property.default ArgsParserwithMaxConsoleWidth(int aMaxConsoleWidth) default ArgsParserdefault ArgsParserwithResetEscapeCode(String aResetEscCode) default ArgsParserwithSeparatorLnChar(char aSeparatorLnChar) Builder method adding an separator line char.default ArgsParserwithShortOptionPrefix(Character aShortOptionPrefix) Sets the short option prefix for the short option prefix property.default ArgsParserwithStandardOut(PrintStream aStandardOut) Set the standard outPrintStreamand make other adjustments with the result (with regards to the Builder-Pattern).default ArgsParserwithSyntaxMetrics(SyntaxMetrics aSyntaxMetrics) Sets theSyntaxMetricsfor theSyntaxMetricsproperty.default ArgsParserwithTextBoxGrid(TextBoxGrid aTextBoxGrid) default ArgsParserwithTextBoxGrid(TextBoxStyle aTextBoxStyle) default ArgsParserMethods inherited from interface ArgsParserBuilder
withEvalArgs, withEvalArgs, withEvalArgs, withEvalArgsMethods inherited from interface ArgsSyntaxAccessor.ArgsSyntaxBuilder
withArgsSyntaxMethods inherited from interface ArgsSyntaxAccessor.ArgsSyntaxMutator
setArgsSyntaxMethods inherited from interface ArgsSyntaxAccessor.ArgsSyntaxProperty
letArgsSyntaxMethods inherited from interface ArgumentEscapeCodeAccessor.ArgumentEscapeCodeMutator
setArgumentEscapeCodeMethods inherited from interface ArgumentEscapeCodeAccessor.ArgumentEscapeCodeProperty
letArgumentEscapeCodeMethods inherited from interface BannerBorderEscapeCodeAccessor.BannerBorderEscapeCodeMutator
setBannerBorderEscapeCodeMethods inherited from interface BannerBorderEscapeCodeAccessor.BannerBorderEscapeCodeProperty
letBannerBorderEscapeCodeMethods inherited from interface BannerEscapeCodeAccessor.BannerEscapeCodeMutator
setBannerEscapeCodeMethods inherited from interface BannerEscapeCodeAccessor.BannerEscapeCodeProperty
letBannerEscapeCodeMethods inherited from interface BannerFontAccessor
getBannerFontMethods inherited from interface BannerFontAccessor.BannerFontMutator
setBannerFontMethods inherited from interface BannerFontAccessor.BannerFontProperty
letBannerFontMethods inherited from interface BannerFontPaletteAccessor
getBannerFontPaletteMethods inherited from interface BannerFontPaletteAccessor.BannerFontPaletteBuilder
withBannerFontPaletteMethods inherited from interface BannerFontPaletteAccessor.BannerFontPaletteMutator
setBannerFontPalette, setBannerFontPaletteMethods inherited from interface BannerFontPaletteAccessor.BannerFontPaletteProperty
letBannerFontPaletteMethods inherited from interface CommandEscapeCodeAccessor.CommandEscapeCodeMutator
setCommandEscapeCodeMethods inherited from interface CommandEscapeCodeAccessor.CommandEscapeCodeProperty
letCommandEscapeCodeMethods inherited from interface ConsoleWidthAccessor
getConsoleWidthMethods inherited from interface ConsoleWidthAccessor.ConsoleWidthMutator
setConsoleWidthMethods inherited from interface ConsoleWidthAccessor.ConsoleWidthProperty
letConsoleWidthMethods inherited from interface CopyrightAccessor.CopyrightMutator
setCopyrightMethods inherited from interface CopyrightAccessor.CopyrightProperty
letCopyrightMethods inherited from interface DescriptionAccessor.DescriptionMutator
setDescriptionMethods inherited from interface DescriptionAccessor.DescriptionProperty
letDescriptionMethods inherited from interface DescriptionEscapeCodeAccessor.DescriptionEscapeCodeMutator
setDescriptionEscapeCodeMethods inherited from interface DescriptionEscapeCodeAccessor.DescriptionEscapeCodeProperty
letDescriptionEscapeCodeMethods inherited from interface EscapeCodesStatusAccessor
isEscapeCodesEnabledMethods inherited from interface EscapeCodesStatusAccessor.EscapeCodeStatusMutator
setEscapeCodesEnabledMethods inherited from interface EscapeCodesStatusAccessor.EscapeCodeStatusProperty
letEscapeCodesEnabledMethods inherited from interface ExamplesAccessor.ExamplesMutator
setExamples, setExamplesMethods inherited from interface ExamplesAccessor.ExamplesProperty
letExamplesMethods inherited from interface KeywordEscapeCodeAccessor.KeywordEscapeCodeMutator
setKeywordEscapeCodeMethods inherited from interface KeywordEscapeCodeAccessor.KeywordEscapeCodeProperty
letKeywordEscapeCodeMethods inherited from interface LicenseAccessor.LicenseMutator
setLicenseMethods inherited from interface LicenseAccessor.LicenseProperty
letLicenseMethods inherited from interface LineBreakAccessor
getLineBreakMethods inherited from interface LineBreakAccessor.LineBreakMutator
setLineBreakMethods inherited from interface LineBreakAccessor.LineBreakProperty
letLineBreakMethods inherited from interface LineSeparatorEscapeCodeAccessor.LineSeparatorEscapeCodeProperty
letLineSeparatorEscapeCodeMethods inherited from interface LongOptionPrefixAccessor
getLongOptionPrefixMethods inherited from interface LongOptionPrefixAccessor.LongOptionPrefixMutator
setLongOptionPrefixMethods inherited from interface LongOptionPrefixAccessor.LongOptionPrefixProperty
letLongOptionPrefixMethods inherited from interface MaxConsoleWidthAccessor
getMaxConsoleWidthMethods inherited from interface MaxConsoleWidthAccessor.MaxConsoleWidthMutator
setMaxConsoleWidthMethods inherited from interface MaxConsoleWidthAccessor.MaxConsoleWidthProperty
letMaxConsoleWidthMethods inherited from interface NameAccessor
getNameMethods inherited from interface NameAccessor.NameMutator
setNameMethods inherited from interface NameAccessor.NameProperty
letNameMethods inherited from interface ResetEscapeCodeAccessor
getResetEscapeCodeMethods inherited from interface ResetEscapeCodeAccessor.ResetEscapeCodeMutator
setResetEscapeCodeMethods inherited from interface ResetEscapeCodeAccessor.ResetEscapeCodeProperty
letResetEscapeCodeMethods inherited from interface ShortOptionPrefixAccessor
getShortOptionPrefixMethods inherited from interface ShortOptionPrefixAccessor.ShortOptionPrefixMutator
setShortOptionPrefixMethods inherited from interface ShortOptionPrefixAccessor.ShortOptionPrefixProperty
letShortOptionPrefixMethods inherited from interface SyntaxMetricsAccessor
getSyntaxMetricsMethods inherited from interface SyntaxMetricsAccessor.SyntaxMetricsBuilder
withSyntaxMetricsMethods inherited from interface SyntaxMetricsAccessor.SyntaxMetricsMutator
setSyntaxMetricsMethods inherited from interface SyntaxMetricsAccessor.SyntaxMetricsProperty
letSyntaxMetrics, letSyntaxMetricsMethods inherited from interface TextBoxGridAccessor
getTextBoxGridMethods inherited from interface TextBoxGridAccessor.TextBoxGridMutator
setTextBoxGrid, setTextBoxGridMethods inherited from interface TextBoxGridAccessor.TextBoxGridProperty
letTextBoxGrid, letTextBoxGridMethods inherited from interface TitleAccessor
getTitleMethods inherited from interface TitleAccessor.TitleMutator
setTitleMethods inherited from interface TitleAccessor.TitleProperty
letTitle
-
Method Details
-
addExample
Adds an usage example by providing a description of the example and the command line arguments required by the example.- Parameters:
aExample- The description as well as the command line arguments used by the example.
-
addExample
Adds an usage example by providing a description of the example and the command line arguments required by the example.- Parameters:
aDescription- The description of the example.aOperands- The command line arguments used by the example.
-
errorLn
Prints the given line to standard error with regards to the console width as specified by thewithConsoleWidth(int)method.- Parameters:
aLine- The line to be printed.
-
evalArgs
Same asevalArgs(String[])with the difference that the elements representing the arguments are passed as a list instead of an array.- Parameters:
aArgs- The command line arguments to be evaluated.- Returns:
- The list of evaluated command line arguments being instances of
the
Operandinterfaces or its sub-types. In case anOperandimplements theApprovableinterface or inherits from theAbstractOperandtype, then theOperandis also approved by invokingApprovable.approve()orAbstractOperand.approve()(which may trigger a registered lambda expression). - Throws:
ArgsSyntaxException- thrown in case of a command line arguments mismatch regarding provided and expected args.
-
evalArgs
default Operand<?>[] evalArgs(List<String> aArgs, ArgsFilter aArgsFilter) throws ArgsSyntaxException Evaluates the provided command line arguments as ofevalArgs(String[]), additionally filtering (excluding) the arguments matching the providedArgsFilter.- Parameters:
aArgs- The command line arguments to be evaluated.aArgsFilter- TheArgsFilterused to filter (exclude) any "unwanted" or otherwise evaluated arguments.- Returns:
- The list of evaluated command line arguments being instances of
the
Operandinterfaces or its sub-types. In case anOperandimplements theApprovableinterface or inherits from theAbstractOperandtype, then theOperandis also approved by invokingApprovable.approve()orAbstractOperand.approve()(which may trigger a registered lambda expression). - Throws:
ArgsSyntaxException- thrown in case of a command line arguments mismatch regarding provided and expected args.
-
evalArgs
Evaluates the provided command line arguments as ofevalArgs(String[]), additionally filtering (excluding) the arguments matching the providedPattern.- Parameters:
aArgs- The command line arguments to be evaluated.aFilterExp- ThePatternused to filter (exclude) any "unwanted" or otherwise evaluated arguments.- Returns:
- The list of evaluated command line arguments being instances of
the
Operandinterfaces or its sub-types. In case anOperandimplements theApprovableinterface or inherits from theAbstractOperandtype, then theOperandis also approved by invokingApprovable.approve()orAbstractOperand.approve()(which may trigger a registered lambda expression). - Throws:
ArgsSyntaxException- thrown in case of a command line arguments mismatch regarding provided and expected args.
-
evalArgs
Evaluates the provided command line arguments and determines the according values by evaluating the rootCondition. In case of parsing failure, an according exception is thrown. ATTENTION: This method tests(!) for superfluous command line arguments being passed; e.g. command line arguments not being evaluated by any of theTerminstance being traversed starting at the rootConditionwill be reported. Business logic therefore should invoke this root node'sevalArgs(String[])method instead of aCondition'sTerm.parseArgs(String[], String[], CliContext)method; as ignoring superfluous command line arguments will aCause unexpected behavior from the point of view of the invoker.- Parameters:
aArgs- The command line arguments to be evaluated.- Returns:
- The list of evaluated command line arguments being instances of
the
Operandinterfaces or its sub-types. In case anOperandimplements theApprovableinterface or inherits from theAbstractOperandtype, then theOperandis also approved by invokingApprovable.approve()orAbstractOperand.approve()(which may trigger a registered lambda expression). - Throws:
ArgsSyntaxException- thrown in case of a command line arguments mismatch regarding provided and expected args.
-
evalArgs
Evaluates the provided command line arguments as ofevalArgs(String[]), additionally filtering (excluding) the arguments matching the providedArgsFilter.- Parameters:
aArgs- The command line arguments to be evaluated.aArgsFilter- TheArgsFilterused to filter (exclude) any "unwanted" or otherwise evaluated arguments.- Returns:
- The list of evaluated command line arguments being instances of
the
Operandinterfaces or its sub-types. In case anOperandimplements theApprovableinterface or inherits from theAbstractOperandtype, then theOperandis also approved by invokingApprovable.approve()orAbstractOperand.approve()(which may trigger a registered lambda expression). - Throws:
ArgsSyntaxException- thrown in case of a command line arguments mismatch regarding provided and expected args.
-
evalArgs
Evaluates the provided command line arguments as ofevalArgs(String[]), additionally filtering (excluding) the arguments matching the providedPattern.- Parameters:
aArgs- The command line arguments to be evaluated.aFilterExp- ThePatternused to filter (exclude) any "unwanted" or otherwise evaluated arguments.- Returns:
- The list of evaluated command line arguments being instances of
the
Operandinterfaces or its sub-types. In case anOperandimplements theApprovableinterface or inherits from theAbstractOperandtype, then theOperandis also approved by invokingApprovable.approve()orAbstractOperand.approve()(which may trigger a registered lambda expression). - Throws:
ArgsSyntaxException- thrown in case of a command line arguments mismatch regarding provided and expected args.
-
getArgsSyntax
Term getArgsSyntax()- Specified by:
getArgsSyntaxin interfaceArgsSyntaxAccessor- Returns:
- The (root)
Termstored by the (root)Termproperty.
-
getArgumentEscapeCode
String getArgumentEscapeCode()Retrieves the argument Escape-Code from the argument Escape-Code property.- Specified by:
getArgumentEscapeCodein interfaceArgumentEscapeCodeAccessor- Returns:
- The argument Escape-Code stored by the argument Escape-Code property.
-
getBannerBorderEscapeCode
String getBannerBorderEscapeCode()Retrieves the banner border Escape-Code from the banner border Escape-Code property.- Specified by:
getBannerBorderEscapeCodein interfaceBannerBorderEscapeCodeAccessor- Returns:
- The banner border Escape-Code stored by the banner border Escape-Code property.
-
getBannerEscapeCode
String getBannerEscapeCode()Retrieves the banner Escape-Code from the banner Escape-Code property.- Specified by:
getBannerEscapeCodein interfaceBannerEscapeCodeAccessor- Returns:
- The banner Escape-Code stored by the banner Escape-Code property.
-
getCommandEscapeCode
String getCommandEscapeCode()Retrieves the command Escape-Code from the command Escape-Code property.- Specified by:
getCommandEscapeCodein interfaceCommandEscapeCodeAccessor- Returns:
- The command Escape-Code stored by the command Escape-Code property.
-
getCopyright
String getCopyright()Retrieves the copyright from the copyright property.- Specified by:
getCopyrightin interfaceCopyrightAccessor- Returns:
- The copyright stored by the copyright property.
-
getDescription
String getDescription()- Specified by:
getDescriptionin interfaceDescriptionAccessor
-
getDescriptionEscapeCode
String getDescriptionEscapeCode()Retrieves the description Escape-Code from the description Escape-Code property.- Specified by:
getDescriptionEscapeCodein interfaceDescriptionEscapeCodeAccessor- Returns:
- The description Escape-Code stored by the description Escape-Code property.
-
getExamples
Example[] getExamples()- Specified by:
getExamplesin interfaceExamplesAccessor- Returns:
- The
Exampleinstances stored by theExampleinstances property.
-
getLicense
String getLicense()Retrieves the license from the license property.- Specified by:
getLicensein interfaceLicenseAccessor- Returns:
- The license stored by the license property.
-
getLineSeparatorEscapeCode
String getLineSeparatorEscapeCode()Retrieves the line separator Escape-Code from the line separator Escape-Code property.- Specified by:
getLineSeparatorEscapeCodein interfaceLineSeparatorEscapeCodeAccessor- Returns:
- The line separator Escape-Code stored by the line separator Escape-Code property.
-
getKeywordEscapeCode
String getKeywordEscapeCode()Retrieves the keyword (e.g. short- and long-options) Escape-Code from the option Escape-Code property.- Specified by:
getKeywordEscapeCodein interfaceKeywordEscapeCodeAccessor- Returns:
- The keyword (e.g. short- and long-options) Escape-Code stored by the option Escape-Code property.
-
getSeparatorLnChar
char getSeparatorLnChar()Gets the character to be used when printing a separator line with theprintSeparatorLn()method.- Returns:
- aSeparatorChar The character used by the
printSeparatorLn()method when printing out the line of characters..
-
printBanner
void printBanner()Prints the banner; the banner most probably is an ASCII_HEADER_ASCII_BODY art text block which's look depends strongly on the taste of the author implementing this interface. -
printBody
default void printBody()Prints the help as ofprintHelp()without the banner. -
printCopyright
void printCopyright()Prints the copyright note as specified by thewithCopyright(String)method; with regards to the console width as specified by thewithConsoleWidth(int)method. -
printDescription
void printDescription()Prints the description as set by thewithDescription(String)method with regards to the console width as specified by thewithConsoleWidth(int)method. -
printExamples
void printExamples()Prints example usages as as added by theaddExample(String, Operand...)method with regards to the console width as specified by thewithConsoleWidth(int)method. -
printHeader
void printHeader()Prints the header, which might be a simplified banner: Can be used when overriding methods such asprintHelp()orprintBanner(). -
printHelp
default void printHelp()Prints the help to the standard output specified by thewithStandardOut(PrintStream)method. This method can make use of the more atomic methodsprintBanner(),printSynopsis(),printDescription(),printOptions()orprintSeparatorLn()to print a help text which's look depends strongly on the taste of the author implementing this interface. In case you dislike the implementing author's taste, feel free to overwrite this method and compose your own help text from the building blocks such asprintBanner(),printSynopsis(),printDescription(),printOptions()orprintSeparatorLn() -
printLicense
void printLicense()Prints the license note as specified by thewithLicense(String)method; with regards to the console width as specified by thewithConsoleWidth(int)method. -
printLn
void printLn()Prints an empty line / a line break. -
printLn
Prints the given line to standard out with regards to the console width as specified by thewithConsoleWidth(int)method.- Parameters:
aLine- The line to be printed.
-
printOptions
void printOptions()Prints theOptions (short- and the long-options), theFlages and theOperandand their description with regards to the console width as specified by thewithConsoleWidth(int)method. -
printSeparatorLn
void printSeparatorLn()Prints a separator line using the separator character as specified by thewithSeparatorLnChar(char)method; with regards to the console width as specified by thewithConsoleWidth(int)method. -
printSynopsis
void printSynopsis()Prints the syntax as retrieved by the rootConditionelement as ofSynopsisable.toSynopsis(SyntaxNotation)with regards to theSyntaxNotationset by thewithSyntaxMetrics(SyntaxMetrics)method. -
setErrorOut
Set the error outPrintStreamand make other adjustments with the result (with regards to the Builder-Pattern).- Parameters:
aErrorOut- The error outPrintStreamto set.
-
setLineSeparatorEscapeCode
Sets the line separator Escape-Code for the line separator Escape-Code property.- Specified by:
setLineSeparatorEscapeCodein interfaceLineSeparatorEscapeCodeAccessor.LineSeparatorEscapeCodeMutator- Parameters:
aLineSeparatorEscCode- The line separator Escape-Code to be stored by the line separator Escape-Code property.
-
setSeparatorLnChar
void setSeparatorLnChar(char aSeparatorLnChar) Set the character to be used when printing a separator line with theprintSeparatorLn()method.- Parameters:
aSeparatorLnChar- The character used by theprintSeparatorLn()method when printing out the line of characters..
-
setStandardOut
Set the standard outPrintStreamand make other adjustments with the result (with regards to the Builder-Pattern).- Parameters:
aStandardOut- The standard outPrintStreamto set.
-
setSyntaxMetrics
Sets theSyntaxMetricsfor theSyntaxMetricsproperty.- Specified by:
setSyntaxMetricsin interfaceSyntaxMetricsAccessor.SyntaxMetricsMutator- Parameters:
aSyntaxMetrics- TheSyntaxMetricsto be stored by theSyntaxMetricsproperty.
-
toOptions
Retrieves an array of the context specific options being configured for the givenOptioninstance, being the long option (when set) and the short option (when set), by prepending the according runtime specific short option and long option prefix (if applicable).- Specified by:
toOptionsin interfaceOptionable- Parameters:
aOption- TheOptioninstance for which to get the configured short and long options.- Returns:
- The array of options being the long option (if not null) and the short option (if not null) with the according context specific prefixes.
-
toSchema
- Specified by:
toSchemain interfaceSchemable<DiagnosticOptions>
-
withAddExample
Builder method adding an application'sExampleelement.- Specified by:
withAddExamplein interfaceArgsProcessorBuilder<ArgsParser>- Parameters:
aExample- The application'sExampleelement to be added.- Returns:
- This builder as of the builder pattern.
-
withAddExample
Builder method adding an application'sExampleelement.- Specified by:
withAddExamplein interfaceArgsProcessorBuilder<ArgsParser>- Parameters:
aDescription- The example's description.aOperands- The command line arguments required by the example.- Returns:
- This builder as of the builder pattern.
-
withArgumentEscapeCode
Sets the argument Escape-Code for the argument Escape-Code property.- Specified by:
withArgumentEscapeCodein interfaceArgumentEscapeCodeAccessor.ArgumentEscapeCodeBuilder<ArgsParser>- Parameters:
aParamEscCode- The argument Escape-Code to be stored by the argument Escape-Code property.- Returns:
- The builder for applying multiple build operations.
-
withBannerBorderEscapeCode
Sets the banner border Escape-Code for the banner border Escape-Code property.- Specified by:
withBannerBorderEscapeCodein interfaceBannerBorderEscapeCodeAccessor.BannerBorderEscapeCodeBuilder<ArgsParser>- Parameters:
aBannerBorderEscCode- The banner border Escape-Code to be stored by the banner border Escape-Code property.- Returns:
- The builder for applying multiple build operations.
-
withBannerEscapeCode
Sets the banner Escape-Code for the banner Escape-Code property.- Specified by:
withBannerEscapeCodein interfaceBannerEscapeCodeAccessor.BannerEscapeCodeBuilder<ArgsParser>- Parameters:
aBannerEscCode- The banner Escape-Code to be stored by the banner Escape-Code property.- Returns:
- The builder for applying multiple build operations.
-
withBannerFont
- Specified by:
withBannerFontin interfaceBannerFontAccessor.BannerFontBuilder<ArgsParser>- Parameters:
aBannerFont- The bannerFontto be stored by the bannerFontproperty.- Returns:
- The builder for applying multiple build operations.
-
withBannerFontPalette
Sets the banner font palette for the banner font palette property.- Specified by:
withBannerFontPalettein interfaceBannerFontPaletteAccessor.BannerFontPaletteBuilder<ArgsParser>- Parameters:
aColorPalette- The banner font palette to be stored by the banner palette property.- Returns:
- The builder for applying multiple build operations.
-
withCommandEscapeCode
Sets the command Escape-Code for the command Escape-Code property.- Specified by:
withCommandEscapeCodein interfaceCommandEscapeCodeAccessor.CommandEscapeCodeBuilder<ArgsParser>- Parameters:
aCommandEscCode- The command Escape-Code to be stored by the command Escape-Code property.- Returns:
- The builder for applying multiple build operations.
-
withConsoleWidth
- Specified by:
withConsoleWidthin interfaceConsoleWidthAccessor.ConsoleWidthBuilder<ArgsParser>
-
withCopyright
Sets the copyright for the copyright property.- Specified by:
withCopyrightin interfaceCopyrightAccessor.CopyrightBuilder<ArgsParser>- Parameters:
aCopyright- The copyright to be stored by the console width property.- Returns:
- The builder for applying multiple build operations.
-
withDescription
- Specified by:
withDescriptionin interfaceDescriptionAccessor.DescriptionBuilder<ArgsParser>
-
withDescriptionEscapeCode
Sets the description Escape-Code for the description Escape-Code property.- Specified by:
withDescriptionEscapeCodein interfaceDescriptionEscapeCodeAccessor.DescriptionEscapeCodeBuilder<ArgsParser>- Parameters:
aDescriptionEscCode- The description Escape-Code to be stored by the description Escape-Code property.- Returns:
- The builder for applying multiple build operations.
-
withErrorOut
Set the error outPrintStreamand make other adjustments with the result (with regards to the Builder-Pattern).- Specified by:
withErrorOutin interfaceArgsProcessorBuilder<ArgsParser>- Parameters:
aErrorOut- The error outPrintStreamto set.- Returns:
- This instance with regard to the builder pattern.
-
withEscapeCodesEnabled
- Specified by:
withEscapeCodesEnabledin interfaceEscapeCodesStatusAccessor.EscapeCodeStatusBuilder<ArgsParser>
-
withEvalArgs
Evaluates the provided command line arguments .- Specified by:
withEvalArgsin interfaceArgsParserBuilder<ArgsParser>- Parameters:
aArgs- The command line arguments to be evaluated.- Returns:
- This instance as of the builder pattern to chain further method calls.
- Throws:
ArgsSyntaxException- thrown in case of a command line arguments mismatch regarding provided and expected args.
-
withEvalArgs
Evaluates the provided command line arguments.- Specified by:
withEvalArgsin interfaceArgsParserBuilder<ArgsParser>- Parameters:
aArgs- The command line arguments to be evaluated.- Returns:
- This instance as of the builder pattern to chain further method calls.
- Throws:
ArgsSyntaxException- thrown in case of a command line arguments mismatch regarding provided and expected args.
-
withExamples
Builder method providing the application'sExampleelements.- Specified by:
withExamplesin interfaceExamplesAccessor.ExamplesBuilder<ArgsParser>- Parameters:
aExamples- The application'sExampleelements to use.- Returns:
- This builder as of the builder pattern.
-
withExamples
- Specified by:
withExamplesin interfaceExamplesAccessor.ExamplesBuilder<ArgsParser>- Parameters:
aExamples- TheExampleinstances to be stored.- Returns:
- The builder for applying multiple build operations.
-
withLicense
Sets the license for the license property.- Specified by:
withLicensein interfaceLicenseAccessor.LicenseBuilder<ArgsParser>- Parameters:
aLicense- The license to be stored by the console width property.- Returns:
- The builder for applying multiple build operations.
-
withLineBreak
- Specified by:
withLineBreakin interfaceLineBreakAccessor.LineBreakBuilder<ArgsParser>
-
withLineSeparatorEscapeCode
Sets the line separator Escape-Code for the line separator Escape-Code property.- Specified by:
withLineSeparatorEscapeCodein interfaceLineSeparatorEscapeCodeAccessor.LineSeparatorEscapeCodeBuilder<ArgsParser>- Parameters:
aLineSeparatorEscCode- The line separator Escape-Code to be stored by the line separator Escape-Code property.- Returns:
- The builder for applying multiple build operations.
-
withLongOptionPrefix
Sets the long option prefix for the long option prefix property.- Specified by:
withLongOptionPrefixin interfaceLongOptionPrefixAccessor.LongOptionPrefixBuilder<ArgsParser>- Parameters:
aLongOptionPrefix- The long option prefix to be stored by the long option prefix property.- Returns:
- The builder for applying multiple build operations.
-
withMaxConsoleWidth
- Specified by:
withMaxConsoleWidthin interfaceMaxConsoleWidthAccessor.MaxConsoleWidthBuilder<ArgsParser>
-
withName
- Specified by:
withNamein interfaceNameAccessor.NameBuilder<ArgsParser>
-
withKeywordEscapeCode
Sets the keyword (e.g. short- and long-options) Escape-Code for the keyword Escape-Code property.- Specified by:
withKeywordEscapeCodein interfaceKeywordEscapeCodeAccessor.KeywordEscapeCodeBuilder<ArgsParser>- Parameters:
aOptEscCode- The keyword (e.g. short- and long-options) Escape-Code to be stored by the option Escape-Code property.- Returns:
- The builder for applying multiple build operations.
-
withResetEscapeCode
- Specified by:
withResetEscapeCodein interfaceResetEscapeCodeAccessor.ResetEscapeCodeBuilder<ArgsParser>
-
withSeparatorLnChar
Builder method adding an separator line char.- Specified by:
withSeparatorLnCharin interfaceArgsProcessorBuilder<ArgsParser>- Parameters:
aSeparatorLnChar- THe according separator line char to use.- Returns:
- This builder as of the builder pattern.
-
withShortOptionPrefix
Sets the short option prefix for the short option prefix property.- Specified by:
withShortOptionPrefixin interfaceShortOptionPrefixAccessor.ShortOptionPrefixBuilder<ArgsParser>- Parameters:
aShortOptionPrefix- The short option prefix to be stored by the short option prefix property.- Returns:
- The builder for applying multiple build operations.
-
withStandardOut
Set the standard outPrintStreamand make other adjustments with the result (with regards to the Builder-Pattern).- Specified by:
withStandardOutin interfaceArgsProcessorBuilder<ArgsParser>- Parameters:
aStandardOut- The standard outPrintStreamto set.- Returns:
- This instance with regard to the builder pattern.
-
withSyntaxMetrics
Sets theSyntaxMetricsfor theSyntaxMetricsproperty.- Specified by:
withSyntaxMetricsin interfaceSyntaxMetricsAccessor.SyntaxMetricsBuilder<ArgsParser>- Parameters:
aSyntaxMetrics- TheSyntaxMetricsto be stored by theSyntaxMetricsproperty.- Returns:
- The builder for applying multiple build operations.
-
withTextBoxGrid
- Specified by:
withTextBoxGridin interfaceTextBoxGridAccessor.TextBoxGridBuilder<ArgsParser>
-
withTextBoxGrid
- Specified by:
withTextBoxGridin interfaceTextBoxGridAccessor.TextBoxGridBuilder<ArgsParser>
-
withTitle
- Specified by:
withTitlein interfaceTitleAccessor.TitleBuilder<ArgsParser>
-