- All Known Subinterfaces:
ArgsParserAccessor.ArgsParserProperty
public interface ArgsParserAccessor
Provides an accessor for a
ArgsParser property.-
Nested Class Summary
Nested Classes Modifier and Type Interface Description static interfaceArgsParserAccessor.ArgsParserBuilder<B extends ArgsParserAccessor.ArgsParserBuilder<B>>Provides a builder method for aArgsParserproperty returning the builder for applying multiple build operations.static interfaceArgsParserAccessor.ArgsParserMutatorProvides a mutator for aArgsParserproperty.static interfaceArgsParserAccessor.ArgsParserPropertyProvides aArgsParserproperty. -
Method Summary
Modifier and Type Method Description ArgsParsergetArgsParser()Retrieves the args-parser from theArgsParserproperty.
-
Method Details
-
getArgsParser
ArgsParser getArgsParser()Retrieves the args-parser from theArgsParserproperty.- Returns:
- The args-parser stored by the
ArgsParserproperty.
-