Module org.refcodes.cli
Package org.refcodes.cli
Interface ArgsParserAccessor.ArgsParserBuilder<B extends ArgsParserAccessor.ArgsParserBuilder<B>>
-
- Type Parameters:
B- The builder to return in order to be able to apply multiple build operations.
- Enclosing interface:
- ArgsParserAccessor
public static interface ArgsParserAccessor.ArgsParserBuilder<B extends ArgsParserAccessor.ArgsParserBuilder<B>>Provides a builder method for aArgsParserproperty returning the builder for applying multiple build operations.
-
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description BwithArgsParser(ArgsParser aProperties)Sets the args-parser for theArgsParserproperty.
-
-
-
Method Detail
-
withArgsParser
B withArgsParser(ArgsParser aProperties)
Sets the args-parser for theArgsParserproperty.- Parameters:
aProperties- The args-parser to be stored by theArgsParserproperty.- Returns:
- The builder for applying multiple build operations.
-
-