Module org.refcodes.cli
Package org.refcodes.cli
Interface ArgsParserBuilder<B extends ArgsParserBuilder<B>>
- Type Parameters:
B- the generic type
- All Known Subinterfaces:
ParseArgs
- All Known Implementing Classes:
ArgsParser
public interface ArgsParserBuilder<B extends ArgsParserBuilder<B>>
This mixin provides builder additions (as of the builder pattern for chained
configuring method calls) for parsing command line arguments.
-
Method Summary
Modifier and TypeMethodDescriptionwithEvalArgs(String[] aArgs) Evaluates the provided command line arguments.default BwithEvalArgs(String[] aArgs, Pattern aFilterExp) Evaluates the provided command line arguments, filtering (excluding) the arguments matching the providedPattern.default BwithEvalArgs(String[] aArgs, ArgsFilter aArgsFilter) Evaluates the provided command line arguments, filtering (excluding) the arguments matching the providedArgsFilter.default BwithEvalArgs(List<String> aArgs) Evaluates the provided command line arguments .default BwithEvalArgs(List<String> aArgs, Pattern aFilterExp) Evaluates the provided command line arguments, filtering (excluding) the arguments matching the providedPattern.default BwithEvalArgs(List<String> aArgs, ArgsFilter aArgsFilter) Evaluates the provided command line arguments, filtering (excluding) the arguments matching the providedArgsFilter.
-
Method Details
-
withEvalArgs
Evaluates the provided command line arguments .- Parameters:
aArgs- The command line arguments to be evaluated.- Returns:
- This instance as of the builder pattern to chain further method calls.
- Throws:
ArgsSyntaxException- thrown in case of a command line arguments mismatch regarding provided and expected args.
-
withEvalArgs
Evaluates the provided command line arguments, filtering (excluding) the arguments matching the providedArgsFilter.- Parameters:
aArgs- The command line arguments to be evaluated.aArgsFilter- TheArgsFilterused to filter (exclude) any "unwanted" or otherwise evaluated arguments.- Returns:
- This instance as of the builder pattern to chain further method calls.
- Throws:
ArgsSyntaxException- thrown in case of a command line arguments mismatch regarding provided and expected args.
-
withEvalArgs
Evaluates the provided command line arguments, filtering (excluding) the arguments matching the providedPattern.- Parameters:
aArgs- The command line arguments to be evaluated.aFilterExp- ThePatternused to filter (exclude) any "unwanted" or otherwise evaluated arguments.- Returns:
- This instance as of the builder pattern to chain further method calls.
- Throws:
ArgsSyntaxException- thrown in case of a command line arguments mismatch regarding provided and expected args.
-
withEvalArgs
Evaluates the provided command line arguments.- Parameters:
aArgs- The command line arguments to be evaluated.- Returns:
- This instance as of the builder pattern to chain further method calls.
- Throws:
ArgsSyntaxException- thrown in case of a command line arguments mismatch regarding provided and expected args.
-
withEvalArgs
Evaluates the provided command line arguments, filtering (excluding) the arguments matching the providedArgsFilter.- Parameters:
aArgs- The command line arguments to be evaluated.aArgsFilter- TheArgsFilterused to filter (exclude) any "unwanted" or otherwise evaluated arguments.- Returns:
- This instance as of the builder pattern to chain further method calls.
- Throws:
ArgsSyntaxException- thrown in case of a command line arguments mismatch regarding provided and expected args.
-
withEvalArgs
Evaluates the provided command line arguments, filtering (excluding) the arguments matching the providedPattern.- Parameters:
aArgs- The command line arguments to be evaluated.aFilterExp- ThePatternused to filter (exclude) any "unwanted" or otherwise evaluated arguments.- Returns:
- This instance as of the builder pattern to chain further method calls.
- Throws:
ArgsSyntaxException- thrown in case of a command line arguments mismatch regarding provided and expected args.
-