Module org.refcodes.cli
Package org.refcodes.cli
Interface ArgsProvidierBuilder<B extends ArgsProvidierBuilder<B>>
- Type Parameters:
B- The builder type for chaining builder methods.
public interface ArgsProvidierBuilder<B extends ArgsProvidierBuilder<B>>
The
ArgsProvidierBuilder interface provides builder methods for
feeding command line arguments.-
Method Summary
Modifier and TypeMethodDescriptionBuilder method providing the application's command line arguments.default BBuilder method providing the application's command line arguments, filtering (excluding) the arguments matching the providedPattern.default BwithArgs(String[] aArgs, ArgsFilter aArgsFilter) Builder method providing the application's command line arguments, filtering (excluding) the arguments matching the providedArgsFilter.Builder method providing the application's command line arguments.default BBuilder method providing the application's command line arguments, filtering (excluding) the arguments matching the providedPattern.default BwithArgs(List<String> aArgs, ArgsFilter aArgsFilter) Builder method providing the application's command line arguments, filtering (excluding) the arguments matching the providedArgsFilter.
-
Method Details
-
withArgs
Builder method providing the application's command line arguments.- Parameters:
aArgs- The application's command line arguments.- Returns:
- This builder as of the builder pattern.
-
withArgs
Builder method providing the application's command line arguments, filtering (excluding) the arguments matching the providedArgsFilter.- Parameters:
aArgs- The application's command line arguments.aArgsFilter- TheArgsFilterused to filter (exclude) any "unwanted" or otherwise evaluated arguments.- Returns:
- This instance as of the builder pattern to chain further method calls.
-
withArgs
Builder method providing the application's command line arguments, filtering (excluding) the arguments matching the providedPattern.- Parameters:
aArgs- The application's command line arguments.aFilterExp- ThePatternused to filter (exclude) any "unwanted" or otherwise evaluated arguments.- Returns:
- This instance as of the builder pattern to chain further method calls.
-
withArgs
Builder method providing the application's command line arguments.- Parameters:
aArgs- The application's command line arguments.- Returns:
- This builder as of the builder pattern.
-
withArgs
Builder method providing the application's command line arguments, filtering (excluding) the arguments matching the providedArgsFilter.- Parameters:
aArgs- The application's command line arguments.aArgsFilter- TheArgsFilterused to filter (exclude) any "unwanted" or otherwise evaluated arguments.- Returns:
- This instance as of the builder pattern to chain further method calls.
-
withArgs
Builder method providing the application's command line arguments, filtering (excluding) the arguments matching the providedPattern.- Parameters:
aArgs- The application's command line arguments.aFilterExp- ThePatternused to filter (exclude) any "unwanted" or otherwise evaluated arguments.- Returns:
- This instance as of the builder pattern to chain further method calls.
-