- All Known Subinterfaces:
ArgumentSuffixAccessor.ArgumentSuffixProperty,SyntaxMetrics
- All Known Implementing Classes:
SyntaxMetricsImpl,SyntaxNotation
public interface ArgumentSuffixAccessor
Provides an accessor for an argument suffix property.
-
Nested Class Summary
Nested ClassesModifier and TypeInterfaceDescriptionstatic interfaceArgumentSuffixAccessor.ArgumentSuffixBuilder<B extends ArgumentSuffixAccessor.ArgumentSuffixBuilder<B>>Provides a builder method for an argument suffix property returning the builder for applying multiple build operations.static interfaceProvides a mutator for an argument suffix property.static interfaceProvides an argument suffix property. -
Method Summary
Modifier and TypeMethodDescriptionRetrieves the argument suffix from the argument suffix property.
-
Method Details
-
getArgumentSuffix
String getArgumentSuffix()Retrieves the argument suffix from the argument suffix property.- Returns:
- The argument suffix stored by the argument suffix property.
-