Interface BannerFontAccessor.BannerFontProperty
- All Superinterfaces:
BannerFontAccessor, BannerFontAccessor.BannerFontMutator
- All Known Subinterfaces:
ArgsParser
- All Known Implementing Classes:
CliArgsParser
- Enclosing interface:
BannerFontAccessor
public static interface BannerFontAccessor.BannerFontProperty
extends BannerFontAccessor, BannerFontAccessor.BannerFontMutator
Provides a banner
Font property.-
Nested Class Summary
Nested classes/interfaces inherited from interface BannerFontAccessor
BannerFontAccessor.BannerFontBuilder<B>, BannerFontAccessor.BannerFontMutator, BannerFontAccessor.BannerFontProperty -
Method Summary
Modifier and TypeMethodDescriptiondefault FontletBannerFont(Font aBannerFont) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenFont(setter) as ofBannerFontAccessor.BannerFontMutator.setBannerFont(Font)and returns the very same value (getter).Methods inherited from interface BannerFontAccessor
getBannerFontMethods inherited from interface BannerFontAccessor.BannerFontMutator
setBannerFont
-
Method Details
-
letBannerFont
This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenFont(setter) as ofBannerFontAccessor.BannerFontMutator.setBannerFont(Font)and returns the very same value (getter).- Parameters:
aBannerFont- TheFontto set (viaBannerFontAccessor.BannerFontMutator.setBannerFont(Font)).- Returns:
- Returns the value passed for it to be used in conclusive processing steps.
-