Interface BannerFontPaletteAccessor.BannerFontPaletteMutator
- All Known Subinterfaces:
ArgsParser, BannerFontPaletteAccessor.BannerFontPaletteProperty
- All Known Implementing Classes:
CliArgsParser
- Enclosing interface:
BannerFontPaletteAccessor
public static interface BannerFontPaletteAccessor.BannerFontPaletteMutator
Provides a mutator for a banner font palette property.
-
Method Summary
Modifier and TypeMethodDescriptionvoidsetBannerFontPalette(char[] aBannerFontPalette) Sets the banner font palette for the banner font palette property.voidsetBannerFontPalette(AsciiColorPalette aBannerFontPalette) Sets the banner font palette for the banner font palette property.
-
Method Details
-
setBannerFontPalette
Sets the banner font palette for the banner font palette property.- Parameters:
aBannerFontPalette- The banner font palette to be stored by the banner palette property.
-
setBannerFontPalette
void setBannerFontPalette(char[] aBannerFontPalette) Sets the banner font palette for the banner font palette property.- Parameters:
aBannerFontPalette- The banner font palette to be stored by the banner palette property.
-