Class CharDirective
- All Implemented Interfaces:
Cloneable, Comparable<Operand<?>>, Directive<Character>, MatchCountAccessor, Operand<Character>, OperationAccessor, ParsedArgsAccessor, Synopsisable, Term, ExceptionAccessor<ArgsSyntaxException>, VisibleAccessor, VisibleAccessor.VisibleBuilder<Term>, VisibleAccessor.VisibleMutator, VisibleAccessor.VisibleProperty, AliasAccessor, Clonable, DescriptionAccessor, Resetable, TypeAccessor<Character>, ValueAccessor<Character>, Diagnosable, Schemable<DiagnosticOptions>
-
Nested Class Summary
Nested classes/interfaces inherited from interface AliasAccessor
AliasAccessor.AliasBuilder<B>, AliasAccessor.AliasMutator, AliasAccessor.AliasPropertyNested classes/interfaces inherited from interface DescriptionAccessor
DescriptionAccessor.DescriptionBuilder<B>, DescriptionAccessor.DescriptionMutator, DescriptionAccessor.DescriptionPropertyNested classes/interfaces inherited from interface ExceptionAccessor
ExceptionAccessor.ExceptionBuilder<EXC,B>, ExceptionAccessor.ExceptionMutator<EXC>, ExceptionAccessor.ExceptionProperty<EXC> Nested classes/interfaces inherited from interface MatchCountAccessor
MatchCountAccessor.MatchCountBuilder<B>, MatchCountAccessor.MatchCountMutator, MatchCountAccessor.MatchCountPropertyNested classes/interfaces inherited from interface OperationAccessor
OperationAccessor.OperationBuilder<B>, OperationAccessor.OperationMutator, OperationAccessor.OperationPropertyNested classes/interfaces inherited from interface ParsedArgsAccessor
ParsedArgsAccessor.ParsedArgsMutator, ParsedArgsAccessor.ParsedArgsPropertyNested classes/interfaces inherited from interface TypeAccessor
TypeAccessor.TypeBuilder<T,B>, TypeAccessor.TypeMutator<T>, TypeAccessor.TypeProperty<T> Nested classes/interfaces inherited from interface ValueAccessor
ValueAccessor.ValueBuilder<V,B>, ValueAccessor.ValueMutator<V>, ValueAccessor.ValueProperty<V> Nested classes/interfaces inherited from interface VisibleAccessor
VisibleAccessor.VisibleBuilder<B>, VisibleAccessor.VisibleMutator, VisibleAccessor.VisibleProperty -
Field Summary
FieldsModifier and TypeFieldDescriptionprotected Stringprotected ArgsSyntaxExceptionprotected booleanFields inherited from class AbstractOperand
_matchCount -
Constructor Summary
ConstructorsConstructorDescriptionCharDirective(String aOperation, String aDescription) Instantiates a newCharDirectivewith the given arguments.CharDirective(String aOperation, String aAlias, String aDescription) Instantiates a newCharDirectivewith the given arguments.CharDirective(String aOperation, String aAlias, String aDescription, Consumer<CharDirective> aConsumer) Instantiates a newCharDirectivewith the given arguments.CharDirective(String aOperation, String aDescription, Consumer<CharDirective> aConsumer) Instantiates a newCharDirectivewith the given arguments.CharDirective(Relation<String, Character> aProperty) Instantiates a newCharDirectivewith the alias being the proerty's key and the value being the property's value.CharDirective(Relation<String, Character> aProperty, Consumer<CharDirective> aConsumer) Instantiates a newCharDirectivewith the alias being the proerty's key and the value being the property's value. -
Method Summary
Modifier and TypeMethodDescriptionRetrieves theArgsSyntaxExceptionexception in case invokingTerm.parseArgs(String[], CliContext)failed.booleanvoidsetVisible(boolean isVisible) protected static String[]toArgsDiff(String[] aArgs, String[] aArgsSubset) Creates the difference between the provided set and the provided subset.protected static String[]toArgsDiff(String[] aArgs, List<? extends Operand<?>> aArgsSubset) Creates the difference between the provided set and the providedLists therein found argument arrays subset (as ofOperand.getParsedArgs()).protected static String[]toArgsDiff(String[] aArgs, Operand<?>[] aArgsSubset) Creates the difference between the provided set and the providedLists therein found argument arrays subset (as ofOperand.getParsedArgs()).protected static String[]toParsedArgs(Operand<?>[]... aOperands) Takes allOperandinstances found in the providedLists and adds all therein found argument arrays (as ofOperand.getParsedArgs()) to the result.protected CharacterDouble dispatch hook to be implemented by subclasses of theAbstractOperandfor converting a command line argument to the requiredOperand's type.withVisible(boolean isVisible) Methods inherited from class AbstractDirective
clone, contains, getOperation, parseArgs, setParsedArgs, setValue, toSchema, toStringMethods inherited from class AbstractOperand
approve, compareTo, getAlias, getMatchCount, getParsedArgs, getType, getValue, resetMethods inherited from class Object
equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface Comparable
compareToMethods inherited from interface DescriptionAccessor
getDescriptionMethods inherited from interface Directive
toKeywords, toSpec, toSyntax, toUsageMethods inherited from interface Operand
getAlias, getParsedArgs, getValue, hasValue, toSpec, toSpec, toSpec, toSpec, toUsage, toValueMethods inherited from interface Synopsisable
toSynopsis, toSynopsis, toSynopsis, toSynopsisMethods inherited from interface Term
argsParser, getException, getMatchCount, isVisible, parseArgs, setVisible, toSynopsis, toSyntax, toSyntax, toSyntax, toSyntaxMethods inherited from interface TypeAccessor
getTypeMethods inherited from interface ValueAccessor
getValueOrMethods inherited from interface VisibleAccessor
isHiddenMethods inherited from interface VisibleAccessor.VisibleBuilder
withHide, withShowMethods inherited from interface VisibleAccessor.VisibleMutator
hide, showMethods inherited from interface VisibleAccessor.VisibleProperty
letVisible
-
Field Details
-
_description
-
_exception
-
_isVisible
protected boolean _isVisible
-
-
Constructor Details
-
CharDirective
Instantiates a newCharDirectivewith the given arguments. In case a long option is provided, the intance's alias will automatically be set with the long option, else the short option is used as alias.- Parameters:
aOperation- The operation identifying thisCharDirective.aDescription- The description of theCharDirective
-
CharDirective
Instantiates a newCharDirectivewith the given arguments. In case a long option is provided, the intance's alias will automatically be set with the long option, else the short option is used as alias.- Parameters:
aOperation- The operation identifying thisCharDirective.aDescription- The description of theCharDirective.aConsumer- TheConsumerbeing invoked in case thisCharDirectiveparticipated in successfully parsing the command line arguments.
-
CharDirective
Instantiates a newCharDirectivewith the given arguments.- Parameters:
aOperation- The operation identifying thisCharDirective.aAlias- The alias to be used for naming purposes.aDescription- The description of theCharDirective
-
CharDirective
public CharDirective(String aOperation, String aAlias, String aDescription, Consumer<CharDirective> aConsumer) Instantiates a newCharDirectivewith the given arguments.- Parameters:
aOperation- The operation identifying thisCharDirective.aAlias- The alias to be used for naming purposes.aDescription- The description of theCharDirective.aConsumer- TheConsumerbeing invoked in case thisCharDirectiveparticipated in successfully parsing the command line arguments.
-
CharDirective
Instantiates a newCharDirectivewith the alias being the proerty's key and the value being the property's value. Depending on the provided property's key, the key is either used for the short option or the long option.- Parameters:
aProperty- The key (=alias) and the value for the operand.
-
CharDirective
Instantiates a newCharDirectivewith the alias being the proerty's key and the value being the property's value. Depending on the provided property's key, the key is either used for the short option or the long option.- Parameters:
aProperty- The key (=alias) and the value for the operand.aConsumer- TheConsumerbeing invoked in case thisCharDirectiveparticipated in successfully parsing the command line arguments.
-
-
Method Details
-
withVisible
Visibility in this context means displaying or hiding this
Term's existence to the user (defaults totrue). -
toType
Double dispatch hook to be implemented by subclasses of theAbstractOperandfor converting a command line argument to the requiredOperand's type. In case conversion failed, then an according exception is to be thrown.- Specified by:
toTypein classAbstractOperand<Character>- Parameters:
aArg- The command line argument to be converted to an instance of the given type T.- Returns:
- An instance of type T from the provided command line argument.
- Throws:
ParseArgsException- Thrown in case the provided command line arguments do not respect the required syntax or cannot be converted to the required type.
-
getDescription
- Specified by:
getDescriptionin interfaceDescriptionAccessor
-
getException
Retrieves theArgsSyntaxExceptionexception in case invokingTerm.parseArgs(String[], CliContext)failed. The exception (and the according suppressed ones alongside the causes) does not necessarily have been thrown by theTerm.parseArgs(String[], CliContext)method depending on the semantics of theTermhanding the exception (theAnyConditionprovides any exceptions it caught even though it did not throw them as of its semantics).- Specified by:
getExceptionin interfaceExceptionAccessor<ArgsSyntaxException>- Specified by:
getExceptionin interfaceTerm- Returns:
- The
ArgsSyntaxExceptionexception occurring while parsing the arguments.
-
setVisible
public void setVisible(boolean isVisible) Visibility in this context means displaying or hiding this
Term's existence to the user (defaults totrue).- Specified by:
setVisiblein interfaceTerm- Specified by:
setVisiblein interfaceVisibleAccessor.VisibleMutator
-
isVisible
public boolean isVisible()Visibility in this context means displaying or hiding this
Term's existence to the user (defaults totrue).- Specified by:
isVisiblein interfaceTerm- Specified by:
isVisiblein interfaceVisibleAccessor
-
toArgsDiff
Creates the difference between the provided set and the providedLists therein found argument arrays subset (as ofOperand.getParsedArgs()).- Parameters:
aArgs- The set to be used for the diff operation.aArgsSubset- The subset to be used for the diff operation being the lists containing theOperandinstances whose command line arguments are to be diffed.- Returns:
- The difference between the set and the subset.
-
toArgsDiff
Creates the difference between the provided set and the providedLists therein found argument arrays subset (as ofOperand.getParsedArgs()).- Parameters:
aArgs- The set to be used for the diff operation.aArgsSubset- The subset to be used for the diff operation being the lists containing theOperandinstances whose command line arguments are to be diffed.- Returns:
- The difference between the set and the subset.
-
toArgsDiff
Creates the difference between the provided set and the provided subset.- Parameters:
aArgs- The set to be used for the diff operation.aArgsSubset- The subset to be used for the diff operation.- Returns:
- The difference between the set and the subset.
-
toParsedArgs
Takes allOperandinstances found in the providedLists and adds all therein found argument arrays (as ofOperand.getParsedArgs()) to the result.
-