- All Superinterfaces:
CliContextAccessor,CliContextAccessor.RootConditionMutator
- Enclosing interface:
- CliContextAccessor
public static interface CliContextAccessor.RootConditionProperty
extends CliContextAccessor, CliContextAccessor.RootConditionMutator
Provides a
CliContext property.-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.cli.CliContextAccessor
CliContextAccessor.RootConditionBuilder<B extends CliContextAccessor.RootConditionBuilder<B>>, CliContextAccessor.RootConditionMutator, CliContextAccessor.RootConditionProperty -
Method Summary
Modifier and TypeMethodDescriptiondefault CliContextletCliContext(CliContext aCliContext) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenCliContext(setter) as ofCliContextAccessor.RootConditionMutator.setCliContext(CliContext)and returns the very same value (getter).Methods inherited from interface org.refcodes.cli.CliContextAccessor
getCliContextMethods inherited from interface org.refcodes.cli.CliContextAccessor.RootConditionMutator
setCliContext
-
Method Details
-
letCliContext
This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenCliContext(setter) as ofCliContextAccessor.RootConditionMutator.setCliContext(CliContext)and returns the very same value (getter).- Parameters:
aCliContext- TheCliContextto set (viaCliContextAccessor.RootConditionMutator.setCliContext(CliContext)).- Returns:
- Returns the value passed for it to be used in conclusive processing steps.
-