- java.lang.Object
-
- java.lang.Throwable
-
- java.lang.Exception
-
- org.refcodes.exception.AbstractException
-
- org.refcodes.cli.CliException
-
- All Implemented Interfaces:
Serializable,org.refcodes.exception.ErrorCodeAccessor,org.refcodes.exception.Trap
- Direct Known Subclasses:
CliException.ConsoleArgsException,CliException.ConsoleCliException
public abstract class CliException extends org.refcodes.exception.AbstractExceptionBase exception for the console artifact.- Author:
- steiner
- See Also:
- Serialized Form
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classCliException.ConsoleArgsExceptionThis abstract exception is the base exception for all command line argument related exceptions.static classCliException.ConsoleCliExceptionThe Class ConsoleCliException.-
Nested classes/interfaces inherited from interface org.refcodes.exception.ErrorCodeAccessor
org.refcodes.exception.ErrorCodeAccessor.ErrorCodeBuilder<B extends org.refcodes.exception.ErrorCodeAccessor.ErrorCodeBuilder<B>>, org.refcodes.exception.ErrorCodeAccessor.ErrorCodeMutator, org.refcodes.exception.ErrorCodeAccessor.ErrorCodeProperty
-
-
Constructor Summary
Constructors Constructor Description CliException(String message)Instantiates a new console exception.CliException(String aMessage, String aErrorCode)Instantiates a new console exception.CliException(String message, Throwable cause)Instantiates a new console exception.CliException(String aMessage, Throwable aCause, String aErrorCode)Instantiates a new console exception.CliException(Throwable cause)Instantiates a new console exception.CliException(Throwable aCause, String aErrorCode)Instantiates a new console exception.
-
Method Summary
-
Methods inherited from class java.lang.Throwable
addSuppressed, fillInStackTrace, getCause, getLocalizedMessage, getMessage, getStackTrace, getSuppressed, initCause, printStackTrace, printStackTrace, printStackTrace, setStackTrace, toString
-
-
-
-
Constructor Detail
-
CliException
public CliException(String aMessage, String aErrorCode)
Instantiates a new console exception.- Parameters:
aMessage- the messageaErrorCode- the error code
-
CliException
public CliException(String aMessage, Throwable aCause, String aErrorCode)
Instantiates a new console exception.- Parameters:
aMessage- the messageaCause- the causeaErrorCode- the error code
-
CliException
public CliException(String message, Throwable cause)
Instantiates a new console exception.- Parameters:
message- the messagecause- the cause
-
CliException
public CliException(String message)
Instantiates a new console exception.- Parameters:
message- the message
-
CliException
public CliException(Throwable aCause, String aErrorCode)
Instantiates a new console exception.- Parameters:
aCause- the causeaErrorCode- the error code
-
CliException
public CliException(Throwable cause)
Instantiates a new console exception.- Parameters:
cause- the cause
-
-