- java.lang.Object
-
- java.lang.Throwable
-
- java.lang.Exception
-
- org.refcodes.exception.AbstractException
-
- org.refcodes.cli.CliException
-
- org.refcodes.cli.CliException.ConsoleArgsException
-
- All Implemented Interfaces:
Serializable,ArgsAccessor,org.refcodes.exception.ErrorCodeAccessor,org.refcodes.exception.Trap
- Direct Known Subclasses:
ArgsMismatchException
- Enclosing class:
- CliException
public abstract static class CliException.ConsoleArgsException extends CliException implements ArgsAccessor
This abstract exception is the base exception for all command line argument related exceptions.- Author:
- steiner
- See Also:
- Serialized Form
-
-
Nested Class Summary
-
Nested classes/interfaces inherited from class org.refcodes.cli.CliException
CliException.ConsoleArgsException, CliException.ConsoleCliException
-
Nested classes/interfaces inherited from interface org.refcodes.cli.ArgsAccessor
ArgsAccessor.ArgsMutator, ArgsAccessor.ArgsProperty
-
Nested classes/interfaces inherited from interface org.refcodes.exception.ErrorCodeAccessor
org.refcodes.exception.ErrorCodeAccessor.ErrorCodeBuilder<B extends org.refcodes.exception.ErrorCodeAccessor.ErrorCodeBuilder<B>>, org.refcodes.exception.ErrorCodeAccessor.ErrorCodeMutator, org.refcodes.exception.ErrorCodeAccessor.ErrorCodeProperty
-
-
Constructor Summary
Constructors Constructor Description ConsoleArgsException(String[] aArgs, String message)Instantiates a new console args exception.ConsoleArgsException(String[] aArgs, String aMessage, String aErrorCode)Instantiates a new console args exception.ConsoleArgsException(String[] aArgs, String message, Throwable cause)Instantiates a new console args exception.ConsoleArgsException(String[] aArgs, String aMessage, Throwable aCause, String aErrorCode)Instantiates a new console args exception.ConsoleArgsException(String[] aArgs, Throwable cause)Instantiates a new console args exception.ConsoleArgsException(String[] aArgs, Throwable aCause, String aErrorCode)Instantiates a new console args exception.
-
Method Summary
All Methods Instance Methods Concrete Methods Modifier and Type Method Description String[]getArgs()Gets the args.-
Methods inherited from class java.lang.Throwable
addSuppressed, fillInStackTrace, getCause, getLocalizedMessage, getMessage, getStackTrace, getSuppressed, initCause, printStackTrace, printStackTrace, printStackTrace, setStackTrace, toString
-
-
-
-
Constructor Detail
-
ConsoleArgsException
public ConsoleArgsException(String[] aArgs, String aMessage, String aErrorCode)
Instantiates a new console args exception.- Parameters:
aArgs- the argsaMessage- the messageaErrorCode- the error code
-
ConsoleArgsException
public ConsoleArgsException(String[] aArgs, String aMessage, Throwable aCause, String aErrorCode)
Instantiates a new console args exception.- Parameters:
aArgs- the argsaMessage- the messageaCause- the causeaErrorCode- the error code
-
ConsoleArgsException
public ConsoleArgsException(String[] aArgs, String message, Throwable cause)
Instantiates a new console args exception.- Parameters:
aArgs- the argsmessage- the messagecause- the cause
-
ConsoleArgsException
public ConsoleArgsException(String[] aArgs, String message)
Instantiates a new console args exception.- Parameters:
aArgs- the argsmessage- the message
-
ConsoleArgsException
public ConsoleArgsException(String[] aArgs, Throwable aCause, String aErrorCode)
Instantiates a new console args exception.- Parameters:
aArgs- the argsaCause- the causeaErrorCode- the error code
-
-
Method Detail
-
getArgs
public String[] getArgs()
Gets the args.- Specified by:
getArgsin interfaceArgsAccessor- Returns:
- the args
-
-