Enum Class CliSchemaOntology

java.lang.Object
java.lang.Enum<CliSchemaOntology>
org.refcodes.cli.CliSchemaOntology
All Implemented Interfaces:
Serializable, Comparable<CliSchemaOntology>, Constable, DescriptionAccessor, NameAccessor, TypeAccessor, org.refcodes.ontology.EnumTerm, org.refcodes.ontology.Term, org.refcodes.ontology.UnsafeConcept

public enum CliSchemaOntology extends Enum<CliSchemaOntology> implements org.refcodes.ontology.UnsafeConcept
The CliSchemaOntology describes the terms used in the CLI for Schema generation.
  • Enum Constant Details

    • LONG_OPTION

      public static final CliSchemaOntology LONG_OPTION
      Denotes the long option name.
    • SHORT_OPTION

      public static final CliSchemaOntology SHORT_OPTION
      Denotes the short option name.
    • MATCH_COUNT

      public static final CliSchemaOntology MATCH_COUNT
      Denotes the number of matched arguments.
    • HAS_VALUE

      public static final CliSchemaOntology HAS_VALUE
      Denotes whether the operand has a value.
    • OPERATION

      public static final CliSchemaOntology OPERATION
      Denotes the operation.
    • MAX_LENGTH

      public static final CliSchemaOntology MAX_LENGTH
      Denotes the maximum number of array elements.
    • MIN_LENGTH

      public static final CliSchemaOntology MIN_LENGTH
      Denotes the minimum number of array elements.
  • Method Details

    • values

      public static CliSchemaOntology[] values()
      Returns an array containing the constants of this enum class, in the order they are declared.
      Returns:
      an array containing the constants of this enum class, in the order they are declared
    • valueOf

      public static CliSchemaOntology valueOf(String name)
      Returns the enum constant of this class with the specified name. The string must match exactly an identifier used to declare an enum constant in this class. (Extraneous whitespace characters are not permitted.)
      Parameters:
      name - the name of the enum constant to be returned.
      Returns:
      the enum constant with the specified name
      Throws:
      IllegalArgumentException - if this enum class has no constant with the specified name
      NullPointerException - if the argument is null
    • getType

      public Class getType()
      Specified by:
      getType in interface TypeAccessor
    • getDescription

      public String getDescription()
      Specified by:
      getDescription in interface DescriptionAccessor