java.lang.Object
org.refcodes.cli.CliSugar
-
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionstatic Conditionall(Constituent aArg) static Conditionand(Constituent... aArgs) static Conditionany(Constituent... aArgs) static <T> ArrayOperand<T>Creates an array representation facade for the encapsulatedOperand.static <T> ArrayOperand<T>Creates an array representation facade for the encapsulatedOperand.static <T> ArrayOperand<T>Creates an array representation facade for the encapsulatedOperand.static <T> ArrayOption<T>Creates an array representation facade for the encapsulatedOption.static <T> ArrayOption<T>Creates an array representation facade for the encapsulatedOption.static <T> ArrayOption<T>Creates an array representation facade for the encapsulatedOption.static Conditioncases(Constituent... aArgs) static CharOptioncharOption(Character aShortOption, String aLongOption, String aDescription) Instantiates a newCharOptionwith the given arguments.static CharOptioncharOption(Character aShortOption, String aLongOption, String aAlias, String aDescription) Instantiates a newCharOptionwith the given arguments.static CharOptioncharOption(String aLongOption, String aDescription) Instantiates a newCharOptionwith the given arguments.static CharOptioncharOption(String aLongOption, String aAlias, String aDescription) Instantiates a newCharOptionwith the given arguments.static CleanFlagConstructs the predefined cleanFlag.static CleanFlagcleanFlag(boolean hasShortOption) Constructs the predefined cleanFlag.static CleanFlagConstructs the predefined cleanFlag.static ConfigOptionCreates aConfigOptionrepresenting value specifying a configuration resource (file).static ConfigOptionconfigOption(String aDescription) Instantiates a new config (file)Option.static DaemonFlagConstructs the predefined daemonFlag.static DaemonFlagdaemonFlag(boolean hasShortOption) Constructs the predefined daemonFlag.static DaemonFlagdaemonFlag(String aDescription) Constructs the predefined daemonFlag.static DebugFlagConstructs the predefined debugFlag.static DebugFlagdebugFlag(boolean hasShortOption) Constructs the predefined debugFlag.static DebugFlagConstructs the predefined debugFlag.static DoubleOptiondoubleOption(Character aShortOption, String aDoubleOption, String aDescription) Instantiates a newDoubleOptionwith the given arguments.static DoubleOptiondoubleOption(Character aShortOption, String aDoubleOption, String aAlias, String aDescription) Instantiates a newDoubleOptionwith the given arguments.static DoubleOptiondoubleOption(String aDoubleOption, String aDescription) Instantiates a newDoubleOptionwith the given arguments.static DoubleOptiondoubleOption(String aDoubleOption, String aAlias, String aDescription) Instantiates a newDoubleOptionwith the given arguments.static <T extends Enum<T>>
EnumOption<T>enumOption(Character aShortOption, String aLongOption, Class<T> aType, String aDescription) Instantiates a newEnumOptionwith the given arguments.static <T extends Enum<T>>
EnumOption<T>enumOption(Character aShortOption, String aLongOption, Class<T> aType, String aAlias, String aDescription) Instantiates a newEnumOptionwith the given arguments.static <T extends Enum<T>>
EnumOption<T>enumOption(String aLongOption, Class<T> aType, String aDescription) Instantiates a newEnumOptionwith the given arguments.static <T extends Enum<T>>
EnumOption<T>enumOption(String aLongOption, Class<T> aType, String aAlias, String aDescription) Instantiates a newEnumOptionwith the given arguments.static Examplestatic Example[]Sugar for creating anExamplearray from a varargs argument.static FileOptionfileOption(Character aShortOption, String aLongOption, String aDescription) Instantiates a newFileOptionwith the given arguments.static FileOptionfileOption(Character aShortOption, String aLongOption, String aAlias, String aDescription) Instantiates a newFileOptionwith the given arguments.static FileOptionfileOption(String aLongOption, String aDescription) Instantiates a newFileOptionwith the given arguments.static FileOptionfileOption(String aLongOption, String aAlias, String aDescription) Instantiates a newFileOptionwith the given arguments.static FlagInstantiates a newFlagwith the given arguments.static FlagInstantiates a newFlagwith the given arguments.static FlagInstantiates a newFlagwith the given arguments.static FlagInstantiates a newFlagwith the given arguments.static FloatOptionfloatOption(Character aShortOption, String aFloatOption, String aDescription) Instantiates a newFloatOptionwith the given arguments.static FloatOptionfloatOption(Character aShortOption, String aFloatOption, String aAlias, String aDescription) Instantiates a newFloatOptionwith the given arguments.static FloatOptionfloatOption(String aFloatOption, String aDescription) Instantiates a newFloatOptionwith the given arguments.static FloatOptionfloatOption(String aFloatOption, String aAlias, String aDescription) Instantiates a newFloatOptionwith the given arguments.static ForceFlagConstructs the predefined forceFlag.static ForceFlagforceFlag(boolean hasShortOption) Constructs the predefined forceFlag.static ForceFlagConstructs the predefined forceFlag.static HelpFlaghelpFlag()Constructs the predefined helpFlag.static HelpFlaghelpFlag(boolean hasShortOption) Constructs the predefined helpFlag.static HelpFlagConstructs the predefined helpFlag.static InitFlaginitFlag()Constructs the predefined initFlag.static InitFlaginitFlag(boolean hasShortOption) Constructs the predefined initFlag.static InitFlagConstructs the predefined initFlag.static IntOptionInstantiates a newIntOptionwith the given arguments.static IntOptionInstantiates a newIntOptionwith the given arguments.static IntOptionInstantiates a newIntOptionwith the given arguments.static IntOptionInstantiates a newIntOptionwith the given arguments.static LongOptionlongOption(Character aShortOption, String aLongOption, String aDescription) Instantiates a newLongOptionwith the given arguments.static LongOptionlongOption(Character aShortOption, String aLongOption, String aAlias, String aDescription) Instantiates a newLongOptionwith the given arguments.static LongOptionlongOption(String aLongOption, String aDescription) Instantiates a newLongOptionwith the given arguments.static LongOptionlongOption(String aLongOption, String aAlias, String aDescription) Instantiates a newLongOptionwith the given arguments.static NoneOperandInstantiates a newNoneOperand.static NoneOperandInstantiates a newNoneOperand.static NoneOperandInstantiates a newNoneOperand.static OperationConstructs aOperationwith the given arguments.static OperationConstructs aOperationwith the given arguments.static Conditionoptional(Constituent... aArgs) Semantically identical synonym for theoptional(Constituent...)declaration.static Conditionor(Constituent... aArgs) static QuietFlagConstructs the predefined quietFlag.static QuietFlagquietFlag(boolean hasShortOption) Constructs the predefined quietFlag.static QuietFlagConstructs the predefined quietFlag.static StringOperandstringOperand(String aAlias, String aDescription) Instantiates a newStringOperand.static StringOptionstringOption(Character aShortOption, String aStringOption, String aDescription) Instantiates a newStringOptionwith the given arguments.static StringOptionstringOption(Character aShortOption, String aStringOption, String aAlias, String aDescription) Instantiates a newStringOptionwith the given arguments.static StringOptionstringOption(String aStringOption, String aDescription) Instantiates a newStringOptionwith the given arguments.static StringOptionstringOption(String aStringOption, String aAlias, String aDescription) Instantiates a newStringOptionwith the given arguments.static SysInfoFlagConstructs the predefined system infoFlag.static SysInfoFlagsysInfoFlag(boolean hasShortOption) Constructs the predefined system infoFlag.static SysInfoFlagsysInfoFlag(String aDescription) Constructs the predefined system infoFlag.static VerboseFlagConstructs the predefined verboseFlag.static VerboseFlagverboseFlag(boolean hasShortOption) Constructs the predefined verboseFlag.static VerboseFlagverboseFlag(String aDescription) Constructs the predefined verboseFlag.static Conditionxor(Constituent... aArgs)
-
Constructor Details
-
CliSugar
public CliSugar()
-
-
Method Details
-
examples
Sugar for creating anExamplearray from a varargs argument.- Parameters:
aExamples- theExamplevarargs argument.- Returns:
- The according array representation.
-
example
-
operation
Constructs aOperationwith the given arguments.- Parameters:
aOperation- The operation to declare.aDescription- The description to be used (without any line breaks).- Returns:
- The accordingly created
Operation.
-
operation
Constructs aOperationwith the given arguments.- Parameters:
aOperation- The operation to declare.aAlias- The operation's name to be used when constructing the syntax.aDescription- The description to be used (without any line breaks).- Returns:
- The accordingly created
Operation.
-
and
- Parameters:
aArgs- TheConstituent(Condition) instances to be nested.- Returns:
- The according AND condition.
- See Also:
-
all
- Parameters:
aArg- TheConstituent(Condition) instance to be nested.- Returns:
- The according ALL condition.
- See Also:
-
or
- Parameters:
aArgs- TheConstituent(Condition) instances to be nested.- Returns:
- The according OR condition.
- See Also:
-
xor
- Parameters:
aArgs- TheConstituent(Condition) instances to be nested.- Returns:
- The according XOR condition.
- See Also:
-
cases
- Parameters:
aArgs- TheConstituent(Condition) instances to be nested.- Returns:
- The according CasesCondition (https://www.metacodes.pro XOR) condition.
- See Also:
-
any
Instantiates a newAnyConditionwith theConstituent(Condition) instances to be nested. Any of the nestedConditionconditions may match for theAnyConditionto match, e.g. all of the nested conditions are optional.- Parameters:
aArgs- TheConstituent(Condition) instances to be nested- Returns:
- The according
AbstractCondition. - See Also:
-
optional
Semantically identical synonym for theoptional(Constituent...)declaration.- Parameters:
aArgs- TheConstituent(Condition) instances to be nested- Returns:
- The according
AbstractCondition. - See Also:
-
none
Instantiates a newNoneOperand.- Parameters:
aAlias- The identifier to be used when printing the syntax via theConstituent.toSyntax(CliContext)method.aDescription- The description to be used (without any line breaks).- Returns:
- the none operand
- See Also:
-
none
Instantiates a newNoneOperand.- Parameters:
aDescription- The description to be used (without any line breaks).- Returns:
- the none operand
- See Also:
-
none
Instantiates a newNoneOperand.- Parameters:
aProperty- The key (= alias) and the value for the operand.- Returns:
- the none operand
- See Also:
-
enumOption
public static <T extends Enum<T>> EnumOption<T> enumOption(Character aShortOption, String aLongOption, Class<T> aType, String aAlias, String aDescription) Instantiates a newEnumOptionwith the given arguments.- Type Parameters:
T- The generic type of the enumeration.- Parameters:
aShortOption- The short option to use.aLongOption- The long option to use.aType- The type of the enumeration to be used.aAlias- The alias to be used for naming purposes.aDescription- The description of theEnumOption- Returns:
- The accordingly created
EnumOptioninstance. - See Also:
-
enumOption
public static <T extends Enum<T>> EnumOption<T> enumOption(Character aShortOption, String aLongOption, Class<T> aType, String aDescription) Instantiates a newEnumOptionwith the given arguments. In case a long option is provided, the intance's alias will automatically be set with the long option, else the short option is used ass alias.- Type Parameters:
T- The generic type of the enumeration.- Parameters:
aShortOption- The short option to use.aLongOption- The long option to use.aType- The type of the enumeration to be used.aDescription- The description of theEnumOption- Returns:
- The accordingly created
EnumOptioninstance. - See Also:
-
enumOption
public static <T extends Enum<T>> EnumOption<T> enumOption(String aLongOption, Class<T> aType, String aAlias, String aDescription) Instantiates a newEnumOptionwith the given arguments.- Type Parameters:
T- The generic type of the enumeration.- Parameters:
aLongOption- The long option to use.aType- The type of the enumeration to be used.aAlias- The alias to be used for naming purposes.aDescription- The description of theEnumOption- Returns:
- The accordingly created
EnumOptioninstance. - See Also:
-
enumOption
public static <T extends Enum<T>> EnumOption<T> enumOption(String aLongOption, Class<T> aType, String aDescription) Instantiates a newEnumOptionwith the given arguments. In case a long option is provided, the intance's alias will automatically be set with the long option.- Type Parameters:
T- The generic type of the enumeration.- Parameters:
aLongOption- The long option to use.aType- The type of the enumeration to be used.aDescription- The description of theEnumOption- Returns:
- The accordingly created
EnumOptioninstance. - See Also:
-
flag
Instantiates a newFlagwith the given arguments. -
flag
Instantiates a newFlagwith the given arguments. In case a long option is provided, the intance's alias will automatically be set with the long option. -
flag
public static Flag flag(Character aShortOption, String aLongOption, String aAlias, String aDescription) Instantiates a newFlagwith the given arguments. -
flag
Instantiates a newFlagwith the given arguments. In case a long option is provided, the intance's alias will automatically be set with the long option, else the short option is used ass alias. -
daemonFlag
Constructs the predefined daemonFlag.- Parameters:
aDescription- The description to be used (without any line breaks).- Returns:
- The accordingly created
Flaginstance. - See Also:
-
daemonFlag
Constructs the predefined daemonFlag.- Returns:
- The accordingly created
Flaginstance. - See Also:
-
daemonFlag
Constructs the predefined daemonFlag.- Parameters:
hasShortOption- True in case to also enable the short option, else only the long option takes effect.- Returns:
- The accordingly created
Flaginstance. - See Also:
-
forceFlag
Constructs the predefined forceFlag. -
forceFlag
Constructs the predefined forceFlag. -
forceFlag
Constructs the predefined forceFlag. -
helpFlag
Constructs the predefined helpFlag. -
helpFlag
Constructs the predefined helpFlag. -
helpFlag
Constructs the predefined helpFlag. -
initFlag
Constructs the predefined initFlag. -
initFlag
Constructs the predefined initFlag. -
initFlag
Constructs the predefined initFlag. -
cleanFlag
Constructs the predefined cleanFlag. -
cleanFlag
Constructs the predefined cleanFlag. -
cleanFlag
Constructs the predefined cleanFlag. -
sysInfoFlag
Constructs the predefined system infoFlag.- Parameters:
aDescription- The description to use when printing out the help text.- Returns:
- The accordingly created
Flaginstance. - See Also:
-
sysInfoFlag
Constructs the predefined system infoFlag.- Returns:
- The accordingly created
Flaginstance. - See Also:
-
sysInfoFlag
Constructs the predefined system infoFlag.- Parameters:
hasShortOption- True in case to also enable the short option, else only the long option takes effect.- Returns:
- The accordingly created
Flaginstance. - See Also:
-
quietFlag
Constructs the predefined quietFlag. -
quietFlag
Constructs the predefined quietFlag. -
quietFlag
Constructs the predefined quietFlag. -
verboseFlag
Constructs the predefined verboseFlag.- Parameters:
aDescription- The description to use when printing out the help text.- Returns:
- The accordingly created
Flaginstance. - See Also:
-
verboseFlag
Constructs the predefined verboseFlag.- Returns:
- The accordingly created
Flaginstance. - See Also:
-
verboseFlag
Constructs the predefined verboseFlag.- Parameters:
hasShortOption- True in case to also enable the short option, else only the long option takes effect.- Returns:
- The accordingly created
Flaginstance. - See Also:
-
debugFlag
Constructs the predefined debugFlag. -
debugFlag
Constructs the predefined debugFlag. -
debugFlag
Constructs the predefined debugFlag. -
intOption
Instantiates a newIntOptionwith the given arguments. -
intOption
Instantiates a newIntOptionwith the given arguments. In case a long option is provided, the intance's alias will automatically be set with the long option. -
intOption
public static IntOption intOption(Character aShortOption, String aLongOption, String aAlias, String aDescription) Instantiates a newIntOptionwith the given arguments. -
intOption
Instantiates a newIntOptionwith the given arguments. In case a long option is provided, the intance's alias will automatically be set with the long option, else the short option is used ass alias. -
longOption
Instantiates a newLongOptionwith the given arguments.- Parameters:
aLongOption- The long option to use.aAlias- The alias to be used for naming purposes.aDescription- The description of theLongOption- Returns:
- The accordingly created
LongOptioninstance. - See Also:
-
longOption
Instantiates a newLongOptionwith the given arguments. In case a long option is provided, the intance's alias will automatically be set with the long option.- Parameters:
aLongOption- The long option to use.aDescription- The description of theLongOption- Returns:
- The accordingly created
LongOptioninstance. - See Also:
-
longOption
public static LongOption longOption(Character aShortOption, String aLongOption, String aAlias, String aDescription) Instantiates a newLongOptionwith the given arguments.- Parameters:
aShortOption- The short option to use.aLongOption- The long option to use.aAlias- The alias to be used for naming purposes.aDescription- The description of theLongOption- Returns:
- The accordingly created
LongOptioninstance. - See Also:
-
longOption
public static LongOption longOption(Character aShortOption, String aLongOption, String aDescription) Instantiates a newLongOptionwith the given arguments. In case a long option is provided, the intance's alias will automatically be set with the long option, else the short option is used ass alias.- Parameters:
aShortOption- The short option to use.aLongOption- The long option to use.aDescription- The description of theLongOption- Returns:
- The accordingly created
LongOptioninstance. - See Also:
-
floatOption
Instantiates a newFloatOptionwith the given arguments.- Parameters:
aFloatOption- The long option to use.aAlias- The alias to be used for naming purposes.aDescription- The description of theFloatOption- Returns:
- The accordingly created
FloatOptioninstance. - See Also:
-
floatOption
Instantiates a newFloatOptionwith the given arguments. In case a long option is provided, the intance's alias will automatically be set with the long option.- Parameters:
aFloatOption- The long option to use.aDescription- The description of theFloatOption- Returns:
- The accordingly created
FloatOptioninstance. - See Also:
-
floatOption
public static FloatOption floatOption(Character aShortOption, String aFloatOption, String aAlias, String aDescription) Instantiates a newFloatOptionwith the given arguments.- Parameters:
aShortOption- The short option to use.aFloatOption- The long option to use.aAlias- The alias to be used for naming purposes.aDescription- The description of theFloatOption- Returns:
- The accordingly created
FloatOptioninstance. - See Also:
-
floatOption
public static FloatOption floatOption(Character aShortOption, String aFloatOption, String aDescription) Instantiates a newFloatOptionwith the given arguments. In case a long option is provided, the intance's alias will automatically be set with the long option, else the short option is used ass alias.- Parameters:
aShortOption- The short option to use.aFloatOption- the float optionaDescription- The description of theFloatOption- Returns:
- The accordingly created
FloatOptioninstance. - See Also:
-
doubleOption
Instantiates a newDoubleOptionwith the given arguments.- Parameters:
aDoubleOption- The long option to use.aAlias- The alias to be used for naming purposes.aDescription- The description of theDoubleOption- Returns:
- The accordingly created
DoubleOptioninstance. - See Also:
-
doubleOption
Instantiates a newDoubleOptionwith the given arguments. In case a long option is provided, the intance's alias will automatically be set with the long option.- Parameters:
aDoubleOption- The long option to use.aDescription- The description of theDoubleOption- Returns:
- The accordingly created
DoubleOptioninstance. - See Also:
-
doubleOption
public static DoubleOption doubleOption(Character aShortOption, String aDoubleOption, String aAlias, String aDescription) Instantiates a newDoubleOptionwith the given arguments.- Parameters:
aShortOption- The short option to use.aDoubleOption- The long option to use.aAlias- The alias to be used for naming purposes.aDescription- The description of theDoubleOption- Returns:
- The accordingly created
DoubleOptioninstance. - See Also:
-
doubleOption
public static DoubleOption doubleOption(Character aShortOption, String aDoubleOption, String aDescription) Instantiates a newDoubleOptionwith the given arguments. In case a long option is provided, the intance's alias will automatically be set with the long option, else the short option is used ass alias.- Parameters:
aShortOption- The short option to use.aDoubleOption- the double optionaDescription- The description of theDoubleOption- Returns:
- The accordingly created
DoubleOptioninstance. - See Also:
-
stringOption
Instantiates a newStringOptionwith the given arguments.- Parameters:
aStringOption- The long option to use.aAlias- The alias to be used for naming purposes.aDescription- The description of theStringOption- Returns:
- The accordingly created
StringOptioninstance. - See Also:
-
stringOption
Instantiates a newStringOptionwith the given arguments. In case a long option is provided, the intance's alias will automatically be set with the long option.- Parameters:
aStringOption- The long option to use.aDescription- The description of theStringOption- Returns:
- The accordingly created
StringOptioninstance. - See Also:
-
stringOption
public static StringOption stringOption(Character aShortOption, String aStringOption, String aAlias, String aDescription) Instantiates a newStringOptionwith the given arguments.- Parameters:
aShortOption- The short option to use.aStringOption- The long option to use.aAlias- The alias to be used for naming purposes.aDescription- The description of theStringOption- Returns:
- The accordingly created
StringOptioninstance. - See Also:
-
stringOption
public static StringOption stringOption(Character aShortOption, String aStringOption, String aDescription) Instantiates a newStringOptionwith the given arguments. In case a long option is provided, the intance's alias will automatically be set with the long option, else the short option is used ass alias.- Parameters:
aShortOption- The short option to use.aStringOption- the string optionaDescription- The description of theStringOption- Returns:
- The accordingly created
StringOptioninstance. - See Also:
-
charOption
Instantiates a newCharOptionwith the given arguments.- Parameters:
aLongOption- The long option to use.aAlias- The alias to be used for naming purposes.aDescription- The description of theCharOption- Returns:
- The accordingly created
CharOptioninstance. - See Also:
-
charOption
Instantiates a newCharOptionwith the given arguments. In case a long option is provided, the intance's alias will automatically be set with the long option.- Parameters:
aLongOption- The long option to use.aDescription- The description of theCharOption- Returns:
- The accordingly created
CharOptioninstance. - See Also:
-
charOption
public static CharOption charOption(Character aShortOption, String aLongOption, String aAlias, String aDescription) Instantiates a newCharOptionwith the given arguments.- Parameters:
aShortOption- The short option to use.aLongOption- The long option to use.aAlias- The alias to be used for naming purposes.aDescription- The description of theCharOption- Returns:
- The accordingly created
EnumOptioninstance. - See Also:
-
charOption
public static CharOption charOption(Character aShortOption, String aLongOption, String aDescription) Instantiates a newCharOptionwith the given arguments. In case a long option is provided, the intance's alias will automatically be set with the long option, else the short option is used ass alias.- Parameters:
aShortOption- The short option to use.aLongOption- The long option to use.aDescription- The description of theCharOption- Returns:
- The accordingly created
EnumOptioninstance. - See Also:
-
configOption
Creates aConfigOptionrepresenting value specifying a configuration resource (file).- Returns:
- the according
ConfigOption. - See Also:
-
configOption
Instantiates a new config (file)Option.- Parameters:
aDescription- The description to use.- Returns:
- the according
ConfigOption. - See Also:
-
fileOption
Instantiates a newFileOptionwith the given arguments.- Parameters:
aLongOption- The long option to use.aAlias- The alias to be used for naming purposes.aDescription- The description of theFileOption- Returns:
- The according
FileOption. - See Also:
-
fileOption
Instantiates a newFileOptionwith the given arguments. In case a long option is provided, the intance's alias will automatically be set with the long option.- Parameters:
aLongOption- The long option to use.aDescription- the description- Returns:
- The according
FileOption. - See Also:
-
fileOption
public static FileOption fileOption(Character aShortOption, String aLongOption, String aAlias, String aDescription) Instantiates a newFileOptionwith the given arguments.- Parameters:
aShortOption- The short option to use.aLongOption- The long option to use.aAlias- The alias to be used for naming purposes.aDescription- The description of theFileOption- Returns:
- The according
FileOption. - See Also:
-
fileOption
public static FileOption fileOption(Character aShortOption, String aLongOption, String aDescription) Instantiates a newFileOptionwith the given arguments. In case a long option is provided, the intance's alias will automatically be set with the long option, else the short option is used ass alias.- Parameters:
aShortOption- The short option to use.aLongOption- The long option to use.aDescription- The description of theFileOption- Returns:
- The according
FileOption. - See Also:
-
stringOperand
Instantiates a newStringOperand.- Parameters:
aAlias- The alias to be used for naming purposes.aDescription- The description to be used (without any line breaks).- Returns:
- The according
StringOperand. - See Also:
-
asArray
Creates an array representation facade for the encapsulatedOption. This way anyOptioncan also be used as an arrayOption, e.g. it can be provided multiple times in the command line arguments.- Type Parameters:
T- The type of theOptionfor which to create anArrayOption.- Parameters:
aOption- TheOptionwhich's array counterpart is to be defined.- Returns:
- The according
ArrayOption.
-
asArray
Creates an array representation facade for the encapsulatedOption. This way anyOptioncan also be used as an arrayOption, e.g. it can by provided multiple times in the command line arguments.- Type Parameters:
T- The type of theOptionfor which to create anArrayOption.- Parameters:
aOption- TheOptionwhich's array counterpart is to be defined.aLength- The number of array elements, or -1 if there is no limit.- Returns:
- The according
ArrayOption.
-
asArray
Creates an array representation facade for the encapsulatedOption. This way anyOptioncan also be used as an arrayOption, e.g. it can by provided multiple times in the command line arguments.- Type Parameters:
T- The type of theOptionfor which to create anArrayOption.- Parameters:
aOption- TheOptionwhich's array counterpart is to be defined.aMinLength- The minimum number of array elements, or -1 if there is no limit.aMaxLength- The maximum number of array elements, or -1 if there is no limit.- Returns:
- The according
ArrayOption.
-
asArray
Creates an array representation facade for the encapsulatedOperand. This way anyOperandcan also be used as an arrayOperand, e.g. it can be provided multiple times in the command line arguments.- Type Parameters:
T- The type of theOperandfor which to create anArrayOperand.- Parameters:
aOperand- TheOperandwhich's array counterpart is to be defined.- Returns:
- The according
ArrayOperand.
-
asArray
Creates an array representation facade for the encapsulatedOperand. This way anyOperandcan also be used as an arrayOperand, e.g. it can by provided multiple times in the command line arguments.- Type Parameters:
T- The type of theOperandfor which to create anArrayOperand.- Parameters:
aOperand- TheOperandwhich's array counterpart is to be defined.aLength- The number of array elements, or -1 if there is no limit.- Returns:
- The according
ArrayOperand.
-
asArray
Creates an array representation facade for the encapsulatedOperand. This way anyOperandcan also be used as an arrayOperand, e.g. it can by provided multiple times in the command line arguments.- Type Parameters:
T- The type of theOperandfor which to create anArrayOperand.- Parameters:
aOperand- TheOperandwhich's array counterpart is to be defined.aMinLength- The minimum number of array elements, or -1 if there is no limit.aMaxLength- The maximum number of array elements, or -1 if there is no limit.- Returns:
- The according
ArrayOperand.
-