java.lang.Object
org.refcodes.cli.AbstractOperand<T>
org.refcodes.cli.AbstractOption<T>
org.refcodes.cli.EnumOption<T>
- Type Parameters:
T- The generic type of the enumeration.
- All Implemented Interfaces:
Cloneable,Comparable<Operand<?>>,ArgsAccessor,Constituent,Operand<T>,Option<T>,Synopsisable,org.refcodes.mixin.AliasAccessor,org.refcodes.mixin.Clonable,org.refcodes.mixin.DescriptionAccessor,org.refcodes.mixin.Resetable,org.refcodes.mixin.Schemable<CliSchema>,org.refcodes.mixin.TypeAccessor<T>,org.refcodes.mixin.ValueAccessor<T>
The
EnumOption represents an Option of enumeration types.-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.mixin.AliasAccessor
org.refcodes.mixin.AliasAccessor.AliasBuilder<B extends org.refcodes.mixin.AliasAccessor.AliasBuilder<B>>, org.refcodes.mixin.AliasAccessor.AliasMutator, org.refcodes.mixin.AliasAccessor.AliasPropertyNested classes/interfaces inherited from interface org.refcodes.cli.ArgsAccessor
ArgsAccessor.ArgsMutator, ArgsAccessor.ArgsPropertyNested classes/interfaces inherited from interface org.refcodes.mixin.DescriptionAccessor
org.refcodes.mixin.DescriptionAccessor.DescriptionBuilder<B extends org.refcodes.mixin.DescriptionAccessor.DescriptionBuilder<B>>, org.refcodes.mixin.DescriptionAccessor.DescriptionMutator, org.refcodes.mixin.DescriptionAccessor.DescriptionPropertyNested classes/interfaces inherited from interface org.refcodes.mixin.TypeAccessor
org.refcodes.mixin.TypeAccessor.TypeBuilder<T extends Object,B extends org.refcodes.mixin.TypeAccessor.TypeBuilder<T, B>>, org.refcodes.mixin.TypeAccessor.TypeMutator<T extends Object>, org.refcodes.mixin.TypeAccessor.TypeProperty<T extends Object> Nested classes/interfaces inherited from interface org.refcodes.mixin.ValueAccessor
org.refcodes.mixin.ValueAccessor.ValueBuilder<V extends Object,B extends org.refcodes.mixin.ValueAccessor.ValueBuilder<V, B>>, org.refcodes.mixin.ValueAccessor.ValueMutator<V extends Object>, org.refcodes.mixin.ValueAccessor.ValueProperty<V extends Object> -
Field Summary
FieldsFields inherited from class org.refcodes.cli.AbstractOperand
_value -
Constructor Summary
ConstructorsConstructorDescriptionInstantiates a newEnumOptionwith the given arguments.EnumOption(Character aShortOption, String aLongOption, Class<T> aType, String aAlias, String aDescription) Instantiates a newEnumOptionwith the given arguments.EnumOption(String aLongOption, Class<T> aType, String aDescription) Instantiates a newEnumOptionwith the given arguments.Instantiates a newEnumOptionwith the given arguments.EnumOption(org.refcodes.struct.Relation<String, T> aProperty, Class<T> aType) Instantiates a newEnumOptionwith the alias being the proerty's key and the value being the property's value. -
Method Summary
Modifier and TypeMethodDescriptionprotected TDouble dispatch hook to be implemented by subclasses of theAbstractOperandfor converting a command line argument to the requiredOperand's type.Methods inherited from class org.refcodes.cli.AbstractOption
clone, contains, getLongOption, getShortOption, parseArgs, setParsedArgs, setValue, toOptionArgument, toOptionArgument, toSchema, toSyntaxMethods inherited from class org.refcodes.cli.AbstractOperand
compareTo, getAlias, getType, getValue, reset, toParsedArgs, toStringMethods inherited from class java.lang.Object
equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface java.lang.Comparable
compareToMethods inherited from interface org.refcodes.cli.Constituent
parseArgs, toSynopsis, toSyntax, toSyntax, toSyntax, toSyntaxMethods inherited from interface org.refcodes.mixin.DescriptionAccessor
getDescriptionMethods inherited from interface org.refcodes.cli.Operand
getAlias, getValue, hasValue, toParsedArgs, toSpec, toValueMethods inherited from interface org.refcodes.mixin.Resetable
resetMethods inherited from interface org.refcodes.cli.Synopsisable
toSynopsis, toSynopsis, toSynopsis, toSynopsisMethods inherited from interface org.refcodes.mixin.TypeAccessor
getTypeMethods inherited from interface org.refcodes.mixin.ValueAccessor
getValueOr
-
Field Details
-
_description
-
-
Constructor Details
-
EnumOption
public EnumOption(Character aShortOption, String aLongOption, Class<T> aType, String aAlias, String aDescription) Instantiates a newEnumOptionwith the given arguments.- Parameters:
aShortOption- The short option to use.aLongOption- The long option to use.aType- The type of the enumeration to be used.aAlias- The alias to be used for naming purposes.aDescription- The description of theEnumOption
-
EnumOption
Instantiates a newEnumOptionwith the given arguments. In case a long option is provided, the intance's alias will automatically be set with the long option, else the short option is used ass alias.- Parameters:
aShortOption- The short option to use.aLongOption- The long option to use.aType- The type of the enumeration to be used.aDescription- The description of theEnumOption
-
EnumOption
Instantiates a newEnumOptionwith the given arguments.- Parameters:
aLongOption- The long option to use.aType- The type of the enumeration to be used.aAlias- The alias to be used for naming purposes.aDescription- The description of theEnumOption
-
EnumOption
Instantiates a newEnumOptionwith the given arguments. In case a long option is provided, the intance's alias will automatically be set with the long option.- Parameters:
aLongOption- The long option to use.aType- The type of the enumeration to be used.aDescription- The description of theEnumOption
-
EnumOption
Instantiates a newEnumOptionwith the alias being the proerty's key and the value being the property's value. Depending on the provided property's key, the key is either used for the short option or the long option.- Parameters:
aProperty- The key (=alias) and the value for the operand.aType- The type of the enumeration to be used.
-
-
Method Details
-
toType
Double dispatch hook to be implemented by subclasses of theAbstractOperandfor converting a command line argument to the requiredOperand's type. In case conversion failed, then an according exception is to be thrown.- Specified by:
toTypein classAbstractOperand<T extends Enum<T>>- Parameters:
aArg- The command line argument to be converted to an instance of the given type T.- Returns:
- An instance of type T from the provided command line argument.
- Throws:
ParseArgsException- Thrown in case the provided command line arguments do not respect the required syntax or cannot be converted to the required type.
-
getDescription
- Specified by:
getDescriptionin interfaceorg.refcodes.mixin.DescriptionAccessor
-