Enum ExitCode

java.lang.Object
java.lang.Enum<ExitCode>
org.refcodes.cli.ExitCode
All Implemented Interfaces:
Serializable, Comparable<ExitCode>, java.lang.constant.Constable, org.refcodes.mixin.StatusCodeAccessor<Integer>

public enum ExitCode
extends Enum<ExitCode>
implements org.refcodes.mixin.StatusCodeAccessor<Integer>
Some default exit codes defined for CLI applications.
Author:
steiner
  • Enum Constant Details

    • SUCCESS

      public static final ExitCode SUCCESS
    • FAIL

      public static final ExitCode FAIL
    • ARGS_ERROR

      public static final ExitCode ARGS_ERROR
    • IO_ERROR

      public static final ExitCode IO_ERROR
  • Method Details

    • values

      public static ExitCode[] values()
      Returns an array containing the constants of this enum type, in the order they are declared.
      Returns:
      an array containing the constants of this enum type, in the order they are declared
    • valueOf

      public static ExitCode valueOf​(String name)
      Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
      Parameters:
      name - the name of the enum constant to be returned.
      Returns:
      the enum constant with the specified name
      Throws:
      IllegalArgumentException - if this enum type has no constant with the specified name
      NullPointerException - if the argument is null
    • getStatusCode

      public Integer getStatusCode()
      Gets the status code.
      Specified by:
      getStatusCode in interface org.refcodes.mixin.StatusCodeAccessor<Integer>
      Returns:
      the status code