- All Implemented Interfaces:
Cloneable,Comparable<Operand<?>>,MatchCountAccessor,Operand<File>,Option<File>,ParsedArgsAccessor,Synopsisable,Term,org.refcodes.exception.ExceptionAccessor<ArgsSyntaxException>,org.refcodes.graphical.VisibleAccessor,org.refcodes.graphical.VisibleAccessor.VisibleBuilder<Term>,org.refcodes.graphical.VisibleAccessor.VisibleMutator,org.refcodes.graphical.VisibleAccessor.VisibleProperty,org.refcodes.mixin.AliasAccessor,org.refcodes.mixin.Clonable,org.refcodes.mixin.DescriptionAccessor,org.refcodes.mixin.Resetable,org.refcodes.mixin.TypeAccessor<File>,org.refcodes.mixin.ValueAccessor<File>,org.refcodes.schema.Schemable
-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.mixin.AliasAccessor
org.refcodes.mixin.AliasAccessor.AliasBuilder<B extends org.refcodes.mixin.AliasAccessor.AliasBuilder<B>>, org.refcodes.mixin.AliasAccessor.AliasMutator, org.refcodes.mixin.AliasAccessor.AliasPropertyNested classes/interfaces inherited from interface org.refcodes.mixin.DescriptionAccessor
org.refcodes.mixin.DescriptionAccessor.DescriptionBuilder<B extends org.refcodes.mixin.DescriptionAccessor.DescriptionBuilder<B>>, org.refcodes.mixin.DescriptionAccessor.DescriptionMutator, org.refcodes.mixin.DescriptionAccessor.DescriptionPropertyNested classes/interfaces inherited from interface org.refcodes.exception.ExceptionAccessor
org.refcodes.exception.ExceptionAccessor.ExceptionBuilder<EXC extends Throwable,B extends org.refcodes.exception.ExceptionAccessor.ExceptionBuilder<EXC, B>>, org.refcodes.exception.ExceptionAccessor.ExceptionMutator<EXC extends Throwable>, org.refcodes.exception.ExceptionAccessor.ExceptionProperty<EXC extends Throwable> Nested classes/interfaces inherited from interface org.refcodes.cli.MatchCountAccessor
MatchCountAccessor.MatchCountBuilder<B extends MatchCountAccessor.MatchCountBuilder<B>>, MatchCountAccessor.MatchCountMutator, MatchCountAccessor.MatchCountPropertyNested classes/interfaces inherited from interface org.refcodes.cli.ParsedArgsAccessor
ParsedArgsAccessor.ParsedArgsMutator, ParsedArgsAccessor.ParsedArgsPropertyNested classes/interfaces inherited from interface org.refcodes.mixin.TypeAccessor
org.refcodes.mixin.TypeAccessor.TypeBuilder<T,B extends org.refcodes.mixin.TypeAccessor.TypeBuilder<T, B>>, org.refcodes.mixin.TypeAccessor.TypeMutator<T>, org.refcodes.mixin.TypeAccessor.TypeProperty<T> Nested classes/interfaces inherited from interface org.refcodes.mixin.ValueAccessor
org.refcodes.mixin.ValueAccessor.ValueBuilder<V,B extends org.refcodes.mixin.ValueAccessor.ValueBuilder<V, B>>, org.refcodes.mixin.ValueAccessor.ValueMutator<V>, org.refcodes.mixin.ValueAccessor.ValueProperty<V> Nested classes/interfaces inherited from interface org.refcodes.graphical.VisibleAccessor
org.refcodes.graphical.VisibleAccessor.VisibleBuilder<B extends org.refcodes.graphical.VisibleAccessor.VisibleBuilder<B>>, org.refcodes.graphical.VisibleAccessor.VisibleMutator, org.refcodes.graphical.VisibleAccessor.VisibleProperty -
Field Summary
FieldsModifier and TypeFieldDescriptionprotected Stringprotected ArgsSyntaxExceptionprotected booleanFields inherited from class org.refcodes.cli.AbstractOperand
_matchCount -
Constructor Summary
ConstructorsConstructorDescriptionFileOption(Character aShortOption, String aLongOption, String aDescription) Instantiates a newFileOptionwith the given arguments.FileOption(Character aShortOption, String aLongOption, String aAlias, String aDescription) Instantiates a newFileOptionwith the given arguments.FileOption(Character aShortOption, String aLongOption, String aAlias, String aDescription, Consumer<FileOption> aConsumer) Instantiates a newFileOptionwith the given arguments.FileOption(Character aShortOption, String aLongOption, String aDescription, Consumer<FileOption> aConsumer) Instantiates a newFileOptionwith the given arguments.FileOption(String aLongOption, String aDescription) Instantiates a newFileOptionwith the given arguments.FileOption(String aLongOption, String aAlias, String aDescription) Instantiates a newFileOptionwith the given arguments.FileOption(String aLongOption, String aAlias, String aDescription, Consumer<FileOption> aConsumer) Instantiates a newFileOptionwith the given arguments.FileOption(String aLongOption, String aDescription, Consumer<FileOption> aConsumer) Instantiates a newFileOptionwith the given arguments.FileOption(org.refcodes.struct.Relation<String, File> aProperty) Instantiates a newFileOptionwith the alias being the proerty's key and the value being the property's value.FileOption(org.refcodes.struct.Relation<String, File> aProperty, Consumer<FileOption> aConsumer) Instantiates a newFileOptionwith the alias being the proerty's key and the value being the property's value. -
Method Summary
Modifier and TypeMethodDescriptionRetrieves theArgsSyntaxExceptionexception in case invokingTerm.parseArgs(String[], CliContext)failed.booleanVisibility in this context means displaying or hiding thisTerm's existence to the user (defaults totrue).voidsetVisible(boolean isVisible) Visibility in this context means displaying or hiding thisTerm's existence to the user (defaults totrue).protected static String[]toArgsDiff(String[] aArgs, String[] aArgsSubset) Creates the difference between the provided set and the provided subset.protected static String[]toArgsDiff(String[] aArgs, List<? extends Operand<?>> aArgsSubset) Creates the difference between the provided set and the providedLists therein found argument arrays subset (as ofOperand.getParsedArgs()).protected static String[]toArgsDiff(String[] aArgs, Operand<?>[] aArgsSubset) Creates the difference between the provided set and the providedLists therein found argument arrays subset (as ofOperand.getParsedArgs()).protected static String[]toParsedArgs(Operand<?>[]... aOperands) Takes allOperandinstances found in the providedLists and adds all therein found argument arrays (as ofOperand.getParsedArgs()) to the result.protected FileDouble dispatch hook to be implemented by subclasses of theAbstractOperandfor converting a command line argument to the requiredOperand's type.withVisible(boolean isVisible) Visibility in this context means displaying or hiding thisTerm's existence to the user (defaults totrue).Methods inherited from class org.refcodes.cli.AbstractOption
clone, contains, getLongOption, getShortOption, parseArgs, setParsedArgs, setValue, toException, toSchema, toString, toSyntaxMethods inherited from class org.refcodes.cli.AbstractOperand
approve, compareTo, getAlias, getMatchCount, getParsedArgs, getType, getValue, resetMethods inherited from class java.lang.Object
equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface java.lang.Comparable
compareToMethods inherited from interface org.refcodes.mixin.DescriptionAccessor
getDescriptionMethods inherited from interface org.refcodes.cli.Operand
getAlias, getParsedArgs, getValue, hasValue, toSpec, toSpec, toUsage, toUsage, toValueMethods inherited from interface org.refcodes.mixin.Resetable
resetMethods inherited from interface org.refcodes.cli.Synopsisable
toSynopsis, toSynopsis, toSynopsis, toSynopsisMethods inherited from interface org.refcodes.cli.Term
getException, getMatchCount, isVisible, parseArgs, setVisible, toSynopsis, toSyntax, toSyntax, toSyntax, toSyntaxMethods inherited from interface org.refcodes.mixin.TypeAccessor
getTypeMethods inherited from interface org.refcodes.mixin.ValueAccessor
getValueOrMethods inherited from interface org.refcodes.graphical.VisibleAccessor.VisibleBuilder
withHide, withShowMethods inherited from interface org.refcodes.graphical.VisibleAccessor.VisibleMutator
hide, showMethods inherited from interface org.refcodes.graphical.VisibleAccessor.VisibleProperty
letVisible
-
Field Details
-
_description
-
_exception
-
_isVisible
protected boolean _isVisible
-
-
Constructor Details
-
FileOption
Instantiates a newFileOptionwith the given arguments. In case a long option is provided, the intance's alias will automatically be set with the long option, else the short option is used ass alias.- Parameters:
aShortOption- The short option to use.aLongOption- The long option to use.aDescription- The description of theFileOption
-
FileOption
public FileOption(Character aShortOption, String aLongOption, String aDescription, Consumer<FileOption> aConsumer) Instantiates a newFileOptionwith the given arguments. In case a long option is provided, the intance's alias will automatically be set with the long option, else the short option is used ass alias.- Parameters:
aShortOption- The short option to use.aLongOption- The long option to use.aDescription- The description of theFileOptionaConsumer- TheConsumerbeing invoked in case thisFileOptionparticipated in successfully parsing the command line arguments.
-
FileOption
Instantiates a newFileOptionwith the given arguments.- Parameters:
aShortOption- The short option to use.aLongOption- The long option to use.aAlias- The alias to be used for naming purposes.aDescription- The description of theFileOption
-
FileOption
public FileOption(Character aShortOption, String aLongOption, String aAlias, String aDescription, Consumer<FileOption> aConsumer) Instantiates a newFileOptionwith the given arguments.- Parameters:
aShortOption- The short option to use.aLongOption- The long option to use.aAlias- The alias to be used for naming purposes.aDescription- The description of theFileOptionaConsumer- TheConsumerbeing invoked in case thisFileOptionparticipated in successfully parsing the command line arguments.
-
FileOption
Instantiates a newFileOptionwith the alias being the proerty's key and the value being the property's value. Depending on the provided property's key, the key is either used for the short option or the long option.- Parameters:
aProperty- The key (=alias) and the value for the operand.
-
FileOption
public FileOption(org.refcodes.struct.Relation<String, File> aProperty, Consumer<FileOption> aConsumer) Instantiates a newFileOptionwith the alias being the proerty's key and the value being the property's value. Depending on the provided property's key, the key is either used for the short option or the long option.- Parameters:
aProperty- The key (=alias) and the value for the operand.aConsumer- TheConsumerbeing invoked in case thisFileOptionparticipated in successfully parsing the command line arguments.
-
FileOption
Instantiates a newFileOptionwith the given arguments. In case a long option is provided, the intance's alias will automatically be set with the long option.- Parameters:
aLongOption- The long option to use.aDescription- The description of theFileOption
-
FileOption
Instantiates a newFileOptionwith the given arguments. In case a long option is provided, the intance's alias will automatically be set with the long option.- Parameters:
aLongOption- The long option to use.aDescription- The description of theFileOptionaConsumer- TheConsumerbeing invoked in case thisFileOptionparticipated in successfully parsing the command line arguments.
-
FileOption
Instantiates a newFileOptionwith the given arguments.- Parameters:
aLongOption- The long option to use.aAlias- The alias to be used for naming purposes.aDescription- The description of theFileOption
-
FileOption
public FileOption(String aLongOption, String aAlias, String aDescription, Consumer<FileOption> aConsumer) Instantiates a newFileOptionwith the given arguments.- Parameters:
aLongOption- The long option to use.aAlias- The alias to be used for naming purposes.aDescription- The description of theFileOptionaConsumer- TheConsumerbeing invoked in case thisFileOptionparticipated in successfully parsing the command line arguments.
-
-
Method Details
-
withVisible
Visibility in this context means displaying or hiding thisTerm's existence to the user (defaults totrue). -
toType
Double dispatch hook to be implemented by subclasses of theAbstractOperandfor converting a command line argument to the requiredOperand's type. In case conversion failed, then an according exception is to be thrown.- Specified by:
toTypein classAbstractOperand<File>- Parameters:
aArg- The command line argument to be converted to an instance of the given type T.- Returns:
- An instance of type T from the provided command line argument.
- Throws:
ParseArgsException- Thrown in case the provided command line arguments do not respect the required syntax or cannot be converted to the required type.
-
getDescription
- Specified by:
getDescriptionin interfaceorg.refcodes.mixin.DescriptionAccessor
-
getException
Retrieves theArgsSyntaxExceptionexception in case invokingTerm.parseArgs(String[], CliContext)failed. The exception (and the according suppressed ones alongside the causes) does not necessarily have been thrown by theTerm.parseArgs(String[], CliContext)method depending on the semantics of theTermhanding the exception (theAnyConditionprovides any exceptions it caught even though it did not throw them as of its semantics).- Specified by:
getExceptionin interfaceorg.refcodes.exception.ExceptionAccessor<ArgsSyntaxException>- Specified by:
getExceptionin interfaceTerm- Returns:
- The
ArgsSyntaxExceptionexception occurring while parsing the arguments.
-
setVisible
public void setVisible(boolean isVisible) Visibility in this context means displaying or hiding thisTerm's existence to the user (defaults totrue).- Specified by:
setVisiblein interfaceTerm- Specified by:
setVisiblein interfaceorg.refcodes.graphical.VisibleAccessor.VisibleMutator
-
isVisible
-
toArgsDiff
Creates the difference between the provided set and the providedLists therein found argument arrays subset (as ofOperand.getParsedArgs()).- Parameters:
aArgs- The set to be used for the diff operation.aArgsSubset- The subset to be used for the diff operation being the lists containing theOperandinstances whose command line arguments are to be diffed.- Returns:
- The difference between the set and the subset.
-
toArgsDiff
Creates the difference between the provided set and the providedLists therein found argument arrays subset (as ofOperand.getParsedArgs()).- Parameters:
aArgs- The set to be used for the diff operation.aArgsSubset- The subset to be used for the diff operation being the lists containing theOperandinstances whose command line arguments are to be diffed.- Returns:
- The difference between the set and the subset.
-
toArgsDiff
Creates the difference between the provided set and the provided subset.- Parameters:
aArgs- The set to be used for the diff operation.aArgsSubset- The subset to be used for the diff operation.- Returns:
- The difference between the set and the subset.
-
toParsedArgs
Takes allOperandinstances found in the providedLists and adds all therein found argument arrays (as ofOperand.getParsedArgs()) to the result.
-