Class Flag
- All Implemented Interfaces:
Cloneable, Comparable<Operand<?>>, MatchCountAccessor, Operand<Boolean>, Option<Boolean>, ParsedArgsAccessor, Synopsisable, Term, ExceptionAccessor<ArgsSyntaxException>, VisibleAccessor, VisibleAccessor.VisibleBuilder<Term>, VisibleAccessor.VisibleMutator, VisibleAccessor.VisibleProperty, AliasAccessor, Clonable, DescriptionAccessor, EnabledAccessor, Resetable, TypeAccessor<Boolean>, ValueAccessor<Boolean>, Diagnosable, Schemable<DiagnosticOptions>
- Direct Known Subclasses:
CleanFlag, DaemonFlag, DebugFlag, ForceFlag, HelpFlag, InitFlag, QuietFlag, SysInfoFlag, VerboseFlag
Flag class implements the Option interface for
representing either a true or a false state: When a
flag is provided to your command line arguments, then it is considered to be
true, when it is omitted, then it is considered to be
false as of isEnabled().-
Nested Class Summary
Nested classes/interfaces inherited from interface AliasAccessor
AliasAccessor.AliasBuilder<B>, AliasAccessor.AliasMutator, AliasAccessor.AliasPropertyNested classes/interfaces inherited from interface DescriptionAccessor
DescriptionAccessor.DescriptionBuilder<B>, DescriptionAccessor.DescriptionMutator, DescriptionAccessor.DescriptionPropertyNested classes/interfaces inherited from interface EnabledAccessor
EnabledAccessor.EnabledBuilder<B>, EnabledAccessor.EnabledMutator, EnabledAccessor.EnabledPropertyNested classes/interfaces inherited from interface ExceptionAccessor
ExceptionAccessor.ExceptionBuilder<EXC,B>, ExceptionAccessor.ExceptionMutator<EXC>, ExceptionAccessor.ExceptionProperty<EXC> Nested classes/interfaces inherited from interface MatchCountAccessor
MatchCountAccessor.MatchCountBuilder<B>, MatchCountAccessor.MatchCountMutator, MatchCountAccessor.MatchCountPropertyNested classes/interfaces inherited from interface ParsedArgsAccessor
ParsedArgsAccessor.ParsedArgsMutator, ParsedArgsAccessor.ParsedArgsPropertyNested classes/interfaces inherited from interface TypeAccessor
TypeAccessor.TypeBuilder<T,B>, TypeAccessor.TypeMutator<T>, TypeAccessor.TypeProperty<T> Nested classes/interfaces inherited from interface ValueAccessor
ValueAccessor.ValueBuilder<V,B>, ValueAccessor.ValueMutator<V>, ValueAccessor.ValueProperty<V> Nested classes/interfaces inherited from interface VisibleAccessor
VisibleAccessor.VisibleBuilder<B>, VisibleAccessor.VisibleMutator, VisibleAccessor.VisibleProperty -
Field Summary
FieldsModifier and TypeFieldDescriptionprotected Stringprotected ArgsSyntaxExceptionprotected booleanFields inherited from class AbstractOperand
_matchCount -
Constructor Summary
ConstructorsConstructorDescriptionInstantiates a newFlagwith the given arguments.Instantiates the classFlag.Flag(Character aShortOption, String aLongOption, String aAlias, String aDescription, Consumer<Flag> aConsumer) Instantiates the classFlag.Instantiates a newFlagwith the given arguments.Instantiates a newFlagwith the given arguments.Instantiates the classFlag.Instantiates the classFlag.Instantiates a newFlagwith the given arguments.Instantiates a newFlagwith the alias being the proerty's key and the value being the property's value.Instantiates a newFlagwith the alias being the proerty's key and the value being the property's value. -
Method Summary
Modifier and TypeMethodDescriptionRetrieves theArgsSyntaxExceptionexception in case invokingTerm.parseArgs(String[], CliContext)failed.booleanReturns true if the switch has been set (enabled).booleanparseArgs(String[] aArgs, String[] aKeywords, CliContext aCliCtx) Parses the given command line arguments using the provided keyword set and CLI context.voidreset()voidsetVisible(boolean isVisible) protected static String[]toArgsDiff(String[] aArgs, String[] aArgsSubset) Creates the difference between the provided set and the provided subset.protected static String[]toArgsDiff(String[] aArgs, List<? extends Operand<?>> aArgsSubset) Creates the difference between the provided set and the providedLists therein found argument arrays subset (as ofOperand.getParsedArgs()).protected static String[]toArgsDiff(String[] aArgs, Operand<?>[] aArgsSubset) Creates the difference between the provided set and the providedLists therein found argument arrays subset (as ofOperand.getParsedArgs()).protected static String[]toParsedArgs(Operand<?>[]... aOperands) Takes allOperandinstances found in the providedLists and adds all therein found argument arrays (as ofOperand.getParsedArgs()) to the result.toSpec(CliContext aCliCtx) Creates a specification including its arguments.toSyntax(CliContext aCliCtx) Creates a syntax including its arguments.protected BooleanDouble dispatch hook to be implemented by subclasses of theAbstractOperandfor converting a command line argument to the requiredOperand's type.withVisible(boolean isVisible) Methods inherited from class AbstractOption
clone, contains, getLongOption, getShortOption, setParsedArgs, setValue, toException, toSchema, toStringMethods inherited from class AbstractOperand
approve, compareTo, getAlias, getMatchCount, getParsedArgs, getType, getValueMethods inherited from class Object
equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface Comparable
compareToMethods inherited from interface DescriptionAccessor
getDescriptionMethods inherited from interface Operand
getAlias, getParsedArgs, getValue, hasValue, toSpec, toSpec, toSpec, toSpec, toUsage, toValueMethods inherited from interface Option
toKeywords, toLongOption, toShortOption, toUsageMethods inherited from interface Synopsisable
toSynopsis, toSynopsis, toSynopsis, toSynopsisMethods inherited from interface Term
argsParser, getException, getMatchCount, isVisible, parseArgs, setVisible, toSynopsis, toSyntax, toSyntax, toSyntax, toSyntaxMethods inherited from interface TypeAccessor
getTypeMethods inherited from interface ValueAccessor
getValueOrMethods inherited from interface VisibleAccessor
isHiddenMethods inherited from interface VisibleAccessor.VisibleBuilder
withHide, withShowMethods inherited from interface VisibleAccessor.VisibleMutator
hide, showMethods inherited from interface VisibleAccessor.VisibleProperty
letVisible
-
Field Details
-
_description
-
_exception
-
_isVisible
protected boolean _isVisible
-
-
Constructor Details
-
Flag
Instantiates a newFlagwith the given arguments. In case a long option is provided, the intance's alias will automatically be set with the long option, else the short option is used as alias.- Parameters:
aShortOption- The short option to use.aLongOption- The long option to use.aDescription- The description of theFlag
-
Flag
-
Flag
-
Flag
-
Flag
Instantiates a newFlagwith the alias being the proerty's key and the value being the property's value. Depending on the provided property's key, the key is either used for the short option or the long option.- Parameters:
aProperty- The key (=alias) and the value for the operand.
-
Flag
Instantiates a newFlagwith the alias being the proerty's key and the value being the property's value. Depending on the provided property's key, the key is either used for the short option or the long option. -
Flag
-
Flag
Instantiates a newFlagwith the given arguments. In case a long option is provided, the intance's alias will automatically be set with the long option. -
Flag
-
Flag
-
-
Method Details
-
isEnabled
public boolean isEnabled()Returns true if the switch has been set (enabled).- Specified by:
isEnabledin interfaceEnabledAccessor- Returns:
- True in case the
Flaghas been provided (set), else false.
-
parseArgs
public Operand<Boolean>[] parseArgs(String[] aArgs, String[] aKeywords, CliContext aCliCtx) throws ArgsSyntaxException Parses the given command line arguments using the provided keyword set and CLI context.This method represents the core parsing operation. It evaluates this
Termor, if this term is an inner node, delegates parsing to its child terms.The
aKeywordsparameter defines reserved tokens such as option names that must not be interpreted as operand values.This method does not validate whether all arguments have been consumed. Superfluous arguments must be handled by the caller.
- Specified by:
parseArgsin interfaceTerm- Overrides:
parseArgsin classAbstractOption<Boolean>- Parameters:
aArgs- The command line arguments to parseaKeywords- Reserved option and keyword tokensaCliCtx- TheCliContextcontrolling parsing and rendering- Returns:
- The evaluated operands
- Throws:
ArgsSyntaxException- If the arguments do not match the syntax
-
reset
public void reset()- Specified by:
resetin interfaceResetable- Overrides:
resetin classAbstractOperand<Boolean>
-
withVisible
Visibility in this context means displaying or hiding this
Term's existence to the user (defaults totrue).- Specified by:
withVisiblein interfaceVisibleAccessor.VisibleBuilder<Term>
-
toSpec
Creates a specification including its arguments.A specification differs from a syntax in that the specification provides the full definition not omitting any choices whereas the syntax only provides a syntactically correct variant. For example, having an option with a short option and a long option, the specification will show the short option and the long option whereas the syntax will only show either the short option or, if no short option is set, the long option.
-
toSyntax
Creates a syntax including its arguments.A specification differs from a syntax in that the specification provides the full definition not omitting any choices whereas the syntax only provides a syntactically correct variant. For example, having an option with a short option and a long option, the specification will show the short option and the long option whereas the syntax will only show either the short option or, if no short option is set, the long option.
-
toType
Double dispatch hook to be implemented by subclasses of theAbstractOperandfor converting a command line argument to the requiredOperand's type. In case conversion failed, then an according exception is to be thrown.- Specified by:
toTypein classAbstractOperand<Boolean>- Parameters:
aArg- The command line argument to be converted to an instance of the given type T.- Returns:
- An instance of type T from the provided command line argument.
- Throws:
ParseArgsException- Thrown in case the provided command line arguments do not respect the required syntax or cannot be converted to the required type.
-
getDescription
- Specified by:
getDescriptionin interfaceDescriptionAccessor
-
getException
Retrieves theArgsSyntaxExceptionexception in case invokingTerm.parseArgs(String[], CliContext)failed. The exception (and the according suppressed ones alongside the causes) does not necessarily have been thrown by theTerm.parseArgs(String[], CliContext)method depending on the semantics of theTermhanding the exception (theAnyConditionprovides any exceptions it caught even though it did not throw them as of its semantics).- Specified by:
getExceptionin interfaceExceptionAccessor<ArgsSyntaxException>- Specified by:
getExceptionin interfaceTerm- Returns:
- The
ArgsSyntaxExceptionexception occurring while parsing the arguments.
-
setVisible
public void setVisible(boolean isVisible) Visibility in this context means displaying or hiding this
Term's existence to the user (defaults totrue).- Specified by:
setVisiblein interfaceTerm- Specified by:
setVisiblein interfaceVisibleAccessor.VisibleMutator
-
isVisible
public boolean isVisible()Visibility in this context means displaying or hiding this
Term's existence to the user (defaults totrue).- Specified by:
isVisiblein interfaceTerm- Specified by:
isVisiblein interfaceVisibleAccessor
-
toArgsDiff
Creates the difference between the provided set and the providedLists therein found argument arrays subset (as ofOperand.getParsedArgs()).- Parameters:
aArgs- The set to be used for the diff operation.aArgsSubset- The subset to be used for the diff operation being the lists containing theOperandinstances whose command line arguments are to be diffed.- Returns:
- The difference between the set and the subset.
-
toArgsDiff
Creates the difference between the provided set and the providedLists therein found argument arrays subset (as ofOperand.getParsedArgs()).- Parameters:
aArgs- The set to be used for the diff operation.aArgsSubset- The subset to be used for the diff operation being the lists containing theOperandinstances whose command line arguments are to be diffed.- Returns:
- The difference between the set and the subset.
-
toArgsDiff
Creates the difference between the provided set and the provided subset.- Parameters:
aArgs- The set to be used for the diff operation.aArgsSubset- The subset to be used for the diff operation.- Returns:
- The difference between the set and the subset.
-
toParsedArgs
Takes allOperandinstances found in the providedLists and adds all therein found argument arrays (as ofOperand.getParsedArgs()) to the result.
-