Class ForceFlag

All Implemented Interfaces:
Cloneable, Comparable<Operand<?>>, ArgsAccessor, Operand<Boolean>, Option<Boolean>, Syntaxable, SyntaxUsage, org.refcodes.component.Resetable, org.refcodes.mixin.AliasAccessor, org.refcodes.mixin.Clonable, org.refcodes.mixin.DescriptionAccessor, org.refcodes.mixin.EnabledAccessor, org.refcodes.mixin.TypeAccessor<Boolean>, org.refcodes.mixin.ValueAccessor<Boolean>

public class ForceFlag
extends Flag
A predefined force switch.
  • Nested Class Summary

    Nested classes/interfaces inherited from interface org.refcodes.mixin.AliasAccessor

    org.refcodes.mixin.AliasAccessor.AliasBuilder<B extends org.refcodes.mixin.AliasAccessor.AliasBuilder<B>>, org.refcodes.mixin.AliasAccessor.AliasMutator, org.refcodes.mixin.AliasAccessor.AliasProperty

    Nested classes/interfaces inherited from interface org.refcodes.cli.ArgsAccessor

    ArgsAccessor.ArgsMutator, ArgsAccessor.ArgsProperty

    Nested classes/interfaces inherited from interface org.refcodes.mixin.DescriptionAccessor

    org.refcodes.mixin.DescriptionAccessor.DescriptionBuilder<B extends org.refcodes.mixin.DescriptionAccessor.DescriptionBuilder<B>>, org.refcodes.mixin.DescriptionAccessor.DescriptionMutator, org.refcodes.mixin.DescriptionAccessor.DescriptionProperty

    Nested classes/interfaces inherited from interface org.refcodes.mixin.EnabledAccessor

    org.refcodes.mixin.EnabledAccessor.EnabledBuilder<B extends org.refcodes.mixin.EnabledAccessor.EnabledBuilder<B>>, org.refcodes.mixin.EnabledAccessor.EnabledMutator, org.refcodes.mixin.EnabledAccessor.EnabledProperty

    Nested classes/interfaces inherited from interface org.refcodes.mixin.TypeAccessor

    org.refcodes.mixin.TypeAccessor.TypeBuilder<T extends Object,​B extends org.refcodes.mixin.TypeAccessor.TypeBuilder<T,​B>>, org.refcodes.mixin.TypeAccessor.TypeMutator<T extends Object>, org.refcodes.mixin.TypeAccessor.TypeProperty<T extends Object>

    Nested classes/interfaces inherited from interface org.refcodes.mixin.ValueAccessor

    org.refcodes.mixin.ValueAccessor.ValueBuilder<V extends Object,​B extends org.refcodes.mixin.ValueAccessor.ValueBuilder<V,​B>>, org.refcodes.mixin.ValueAccessor.ValueMutator<V extends Object>, org.refcodes.mixin.ValueAccessor.ValueProperty<V extends Object>
  • Field Summary

    Fields
    Modifier and Type Field Description
    static String ALIAS  
    static String LONG_OPTION  
    static String SHORT_OPTION  

    Fields inherited from class org.refcodes.cli.AbstractOperand

    _value
  • Constructor Summary

    Constructors
    Constructor Description
    ForceFlag()
    Constructs the predefined force switch.
    ForceFlag​(String aDescription)
    Constructs the predefined force switch.
  • Method Summary

    Modifier and Type Method Description
    String toUsage​(SyntaxNotation aSyntaxNotation, String aOptionEscCode, String aResetEscCode)
    Returns the human readable (verbose) syntax of implementing class ATTENTION: As of different parenthesis settings for some notations regarding the root Syntaxable and the child Syntaxables, the method Syntaxable.toSyntax(SyntaxNotation, String, String) is called from inside a Syntaxable hierarchy.

    Methods inherited from class org.refcodes.cli.Flag

    isEnabled, parseArgs, reset, toValue

    Methods inherited from class org.refcodes.cli.AbstractOption

    clone, getLongOption, getOptionPrefixes, getShortOption, setArgs, setValue, toState, toSyntax

    Methods inherited from class org.refcodes.cli.AbstractOperand

    compareTo, getAlias, getArgs, getDescription, getType, getValue, toString

    Methods inherited from class java.lang.Object

    equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, wait

    Methods inherited from interface org.refcodes.mixin.Clonable

    clone

    Methods inherited from interface java.lang.Comparable

    compareTo

    Methods inherited from interface org.refcodes.mixin.DescriptionAccessor

    getDescription

    Methods inherited from interface org.refcodes.cli.Operand

    get, getAlias, getArgs, getValue, hasValue

    Methods inherited from interface org.refcodes.cli.Option

    getLongOption, getOptions, getShortOption

    Methods inherited from interface org.refcodes.cli.Syntaxable

    parseArgs, toState, toSyntax, toSyntax

    Methods inherited from interface org.refcodes.cli.SyntaxUsage

    toUsage, toUsage, toUsage

    Methods inherited from interface org.refcodes.mixin.TypeAccessor

    getType

    Methods inherited from interface org.refcodes.mixin.ValueAccessor

    getValueOr
  • Field Details

  • Constructor Details

    • ForceFlag

      public ForceFlag​(String aDescription)
      Constructs the predefined force switch.
      Parameters:
      aDescription - A description without any line breaks.
    • ForceFlag

      public ForceFlag()
      Constructs the predefined force switch.
  • Method Details

    • toUsage

      public String toUsage​(SyntaxNotation aSyntaxNotation, String aOptionEscCode, String aResetEscCode)
      Returns the human readable (verbose) syntax of implementing class ATTENTION: As of different parenthesis settings for some notations regarding the root Syntaxable and the child Syntaxables, the method Syntaxable.toSyntax(SyntaxNotation, String, String) is called from inside a Syntaxable hierarchy. In case the syntax is to be retrieved from the root Syntaxable or an encapsulating and different type, then the applicable method to be called is SyntaxUsage.toUsage(SyntaxNotation), as for some notations it will for example not create the most outer braces.
      Specified by:
      toUsage in interface SyntaxUsage
      Parameters:
      aSyntaxNotation - The syntax notation used for generating the command line arguments syntax.
      aOptionEscCode - The escape code to be used when processing an option, e.g. this can be an ANSI Escape-Code to highlight the option parameters (for example "--help", "-q" and so on).
      aResetEscCode - The escape code to close (reset) any Escape-Code being set before.
      Returns:
      The human readable (verbose) command line arguments syntax.