- All Superinterfaces:
LicenseAccessor,LicenseAccessor.LicenseMutator
- All Known Subinterfaces:
ArgsParser
- All Known Implementing Classes:
ArgsParserImpl
- Enclosing interface:
- LicenseAccessor
public static interface LicenseAccessor.LicenseProperty
extends LicenseAccessor, LicenseAccessor.LicenseMutator
Provides a license property.
-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.cli.LicenseAccessor
LicenseAccessor.LicenseBuilder<B extends LicenseAccessor.LicenseBuilder<B>>, LicenseAccessor.LicenseMutator, LicenseAccessor.LicenseProperty -
Method Summary
Modifier and TypeMethodDescriptiondefault StringletLicense(String aLicense) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the given width (setter) as ofLicenseAccessor.LicenseMutator.setLicense(String)and returns the very same value (getter).Methods inherited from interface org.refcodes.cli.LicenseAccessor
getLicenseMethods inherited from interface org.refcodes.cli.LicenseAccessor.LicenseMutator
setLicense
-
Method Details
-
letLicense
This method stores and passes through the given argument, which is very useful for builder APIs: Sets the given width (setter) as ofLicenseAccessor.LicenseMutator.setLicense(String)and returns the very same value (getter).- Parameters:
aLicense- The width to set (viaLicenseAccessor.LicenseMutator.setLicense(String)).- Returns:
- Returns the value passed for it to be used in conclusive processing steps.
-