Interface LongOptionAccessor
- All Known Subinterfaces:
LongOptionAccessor.LongOptionProperty
- All Known Implementing Classes:
ParseOptionArgsException,UnknownOptionArgsException
public interface LongOptionAccessor
Provides an accessor for a long option property.
-
Nested Class Summary
Nested ClassesModifier and TypeInterfaceDescriptionstatic interfaceProvides a builder method for a long option property returning the builder for applying multiple build operations.static interfaceProvides a mutator for a long option property.static interfaceProvides a long option property. -
Method Summary
Modifier and TypeMethodDescriptionRetrieves the long option from the long option property.
-
Method Details
-
getLongOption
String getLongOption()Retrieves the long option from the long option property.- Returns:
- The long option stored by the long option property.
-