- All Known Subinterfaces:
LongOptionAccessor.LongOptionProperty
- Enclosing interface:
- LongOptionAccessor
public static interface LongOptionAccessor.LongOptionMutator
Provides a mutator for a long option property.
-
Method Summary
Modifier and TypeMethodDescriptionvoidsetLongOption(String aLongOption) Sets the long option for the long option property.
-
Method Details
-
setLongOption
Sets the long option for the long option property.- Parameters:
aLongOption- The long option to be stored by the long option property.
-