- All Known Subinterfaces:
LongOptionPrefixAccessor.LongOptionPrefixProperty,ParseArgs,SyntaxMetrics
- All Known Implementing Classes:
ArgsParser,SyntaxMetricsImpl,SyntaxNotation
public interface LongOptionPrefixAccessor
Provides an accessor for a long option prefix property.
-
Nested Class Summary
Nested ClassesModifier and TypeInterfaceDescriptionstatic interfaceLongOptionPrefixAccessor.LongOptionPrefixBuilder<B extends LongOptionPrefixAccessor.LongOptionPrefixBuilder<B>>Provides a builder method for a long option prefix property returning the builder for applying multiple build operations.static interfaceProvides a mutator for a long option prefix property.static interfaceProvides a long option prefix property. -
Method Summary
Modifier and TypeMethodDescriptionRetrieves the long option prefix from the long option prefix property.
-
Method Details
-
getLongOptionPrefix
String getLongOptionPrefix()Retrieves the long option prefix from the long option prefix property.- Returns:
- The long option prefix stored by the long option prefix property.
-