Interface LongOptionPrefixAccessor.LongOptionPrefixBuilder<B extends LongOptionPrefixAccessor.LongOptionPrefixBuilder<B>>
- Type Parameters:
B- The builder to return in order to be able to apply multiple build operations.
- All Known Subinterfaces:
ArgsParser,ArgsProcessorBuilder<B>
- All Known Implementing Classes:
CliArgsParser,SyntaxMetricsBuilder.Builder
- Enclosing interface:
LongOptionPrefixAccessor
public static interface LongOptionPrefixAccessor.LongOptionPrefixBuilder<B extends LongOptionPrefixAccessor.LongOptionPrefixBuilder<B>>
Provides a builder method for a long option prefix property returning the
builder for applying multiple build operations.
-
Method Summary
Modifier and TypeMethodDescriptionwithLongOptionPrefix(String aLongOptionPrefix) Sets the long option prefix for the long option prefix property.
-
Method Details
-
withLongOptionPrefix
-