Interface MatchCountAccessor.MatchCountBuilder<B extends MatchCountAccessor.MatchCountBuilder<B>>

Type Parameters:
B - The builder to return in order to be able to apply multiple build operations.
Enclosing interface:
MatchCountAccessor

public static interface MatchCountAccessor.MatchCountBuilder<B extends MatchCountAccessor.MatchCountBuilder<B>>
Provides a builder method for a match-count property returning the builder for applying multiple build operations.