Class NoneOperand
- All Implemented Interfaces:
Cloneable, Comparable<Operand<?>>, MatchCountAccessor, Operand<Boolean>, ParsedArgsAccessor, Synopsisable, Term, ExceptionAccessor<ArgsSyntaxException>, VisibleAccessor, VisibleAccessor.VisibleBuilder<Term>, VisibleAccessor.VisibleMutator, VisibleAccessor.VisibleProperty, AliasAccessor, Clonable, DescriptionAccessor, EnabledAccessor, Resetable, TypeAccessor<Boolean>, ValueAccessor<Boolean>, Diagnosable, Schemable<DiagnosticOptions>
NoneOperand represents an empty set of arguments, e.g. no command
line argument is being passed. Usually only makes sense near the root of a
Term tree (e.g. inside the main XorCondition) to test ALL
arguments passed to an application and one invocation may have neither
optional (as of AnyCondition) nor mandatory arguments allowed.-
Nested Class Summary
Nested classes/interfaces inherited from interface AliasAccessor
AliasAccessor.AliasBuilder<B>, AliasAccessor.AliasMutator, AliasAccessor.AliasPropertyNested classes/interfaces inherited from interface DescriptionAccessor
DescriptionAccessor.DescriptionBuilder<B>, DescriptionAccessor.DescriptionMutator, DescriptionAccessor.DescriptionPropertyNested classes/interfaces inherited from interface EnabledAccessor
EnabledAccessor.EnabledBuilder<B>, EnabledAccessor.EnabledMutator, EnabledAccessor.EnabledPropertyNested classes/interfaces inherited from interface ExceptionAccessor
ExceptionAccessor.ExceptionBuilder<EXC,B>, ExceptionAccessor.ExceptionMutator<EXC>, ExceptionAccessor.ExceptionProperty<EXC> Nested classes/interfaces inherited from interface MatchCountAccessor
MatchCountAccessor.MatchCountBuilder<B>, MatchCountAccessor.MatchCountMutator, MatchCountAccessor.MatchCountPropertyNested classes/interfaces inherited from interface ParsedArgsAccessor
ParsedArgsAccessor.ParsedArgsMutator, ParsedArgsAccessor.ParsedArgsPropertyNested classes/interfaces inherited from interface TypeAccessor
TypeAccessor.TypeBuilder<T,B>, TypeAccessor.TypeMutator<T>, TypeAccessor.TypeProperty<T> Nested classes/interfaces inherited from interface ValueAccessor
ValueAccessor.ValueBuilder<V,B>, ValueAccessor.ValueMutator<V>, ValueAccessor.ValueProperty<V> Nested classes/interfaces inherited from interface VisibleAccessor
VisibleAccessor.VisibleBuilder<B>, VisibleAccessor.VisibleMutator, VisibleAccessor.VisibleProperty -
Field Summary
FieldsModifier and TypeFieldDescriptionprotected Stringprotected ArgsSyntaxExceptionprotected booleanstatic final StringFields inherited from class AbstractOperand
_matchCount -
Constructor Summary
ConstructorsConstructorDescriptionNoneOperand(String aDescription) Instantiates the classNoneOperand.NoneOperand(String aAlias, String aDescription) Instantiates the classNoneOperand.NoneOperand(String aAlias, String aDescription, Consumer<NoneOperand> aConsumer) Instantiates the classNoneOperand.NoneOperand(String aDescription, Consumer<NoneOperand> aConsumer) Instantiates the classNoneOperand.NoneOperand(Relation<String, Boolean> aProperty) Instantiates the classNoneOperand.NoneOperand(Relation<String, Boolean> aProperty, Consumer<NoneOperand> aConsumer) Instantiates the classNoneOperand. -
Method Summary
Modifier and TypeMethodDescriptionRetrieves theArgsSyntaxExceptionexception in case invokingTerm.parseArgs(String[], CliContext)failed.booleanDetermines whether none arguments have been passed.booleanOperand<?>[]parseArgs(String[] aArgs, String[] aKeywords, CliContext aCliCtx) Parses the given command line arguments using the provided keyword set and CLI context.voidsetVisible(boolean isVisible) protected static String[]toArgsDiff(String[] aArgs, String[] aArgsSubset) Creates the difference between the provided set and the provided subset.protected static String[]toArgsDiff(String[] aArgs, List<? extends Operand<?>> aArgsSubset) Creates the difference between the provided set and the providedLists therein found argument arrays subset (as ofOperand.getParsedArgs()).protected static String[]toArgsDiff(String[] aArgs, Operand<?>[] aArgsSubset) Creates the difference between the provided set and the providedLists therein found argument arrays subset (as ofOperand.getParsedArgs()).protected static String[]toParsedArgs(Operand<?>[]... aOperands) Takes allOperandinstances found in the providedLists and adds all therein found argument arrays (as ofOperand.getParsedArgs()) to the result.toSpec(CliContext aCliCtx) Creates a specification including its arguments.toSyntax(CliContext aCliCtx) Creates a syntax including its arguments.protected BooleanTo value.toUsage(CliContext aCliCtx) Creates a plain usage specification without any escape codes, helpful e.g. in human readable messages.withVisible(boolean isVisible) Methods inherited from class AbstractOperand
approve, clone, compareTo, getAlias, getMatchCount, getParsedArgs, getType, getValue, reset, setParsedArgs, setValue, toSchema, toStringMethods inherited from class Object
equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface DescriptionAccessor
getDescriptionMethods inherited from interface Operand
hasValue, toKeywords, toSpec, toSpec, toSpec, toSpec, toUsage, toValueMethods inherited from interface Synopsisable
toSynopsis, toSynopsis, toSynopsis, toSynopsisMethods inherited from interface Term
argsParser, getException, isVisible, parseArgs, setVisible, toSynopsis, toSyntax, toSyntax, toSyntax, toSyntaxMethods inherited from interface ValueAccessor
getValueOrMethods inherited from interface VisibleAccessor
isHiddenMethods inherited from interface VisibleAccessor.VisibleBuilder
withHide, withShowMethods inherited from interface VisibleAccessor.VisibleMutator
hide, showMethods inherited from interface VisibleAccessor.VisibleProperty
letVisible
-
Field Details
-
ALIAS
- See Also:
-
_description
-
_exception
-
_isVisible
protected boolean _isVisible
-
-
Constructor Details
-
NoneOperand
Instantiates the classNoneOperand.- See Also:
-
NoneOperand
-
NoneOperand
Instantiates the classNoneOperand.- See Also:
-
NoneOperand
Instantiates the classNoneOperand.- See Also:
-
NoneOperand
Instantiates the classNoneOperand.- See Also:
-
NoneOperand
Instantiates the classNoneOperand.- See Also:
-
-
Method Details
-
isEnabled
public boolean isEnabled()Determines whether none arguments have been passed.- Specified by:
isEnabledin interfaceEnabledAccessor- Returns:
- True in case none arguments have been passed.
-
parseArgs
public Operand<?>[] parseArgs(String[] aArgs, String[] aKeywords, CliContext aCliCtx) throws ArgsSyntaxException Parses the given command line arguments using the provided keyword set and CLI context.This method represents the core parsing operation. It evaluates this
Termor, if this term is an inner node, delegates parsing to its child terms.The
aKeywordsparameter defines reserved tokens such as option names that must not be interpreted as operand values.This method does not validate whether all arguments have been consumed. Superfluous arguments must be handled by the caller.
- Specified by:
parseArgsin interfaceTerm- Overrides:
parseArgsin classAbstractOperand<Boolean>- Parameters:
aArgs- The command line arguments to parseaKeywords- Reserved option and keyword tokensaCliCtx- TheCliContextcontrolling parsing and rendering- Returns:
- The evaluated operands
- Throws:
ArgsSyntaxException- If the arguments do not match the syntax
-
withVisible
Visibility in this context means displaying or hiding this
Term's existence to the user (defaults totrue).- Specified by:
withVisiblein interfaceVisibleAccessor.VisibleBuilder<Term>
-
toSyntax
Creates a syntax including its arguments.A specification differs from a syntax in that the specification provides the full definition not omitting any choices whereas the syntax only provides a syntactically correct variant. For example, having an option with a short option and a long option, the specification will show the short option and the long option whereas the syntax will only show either the short option or, if no short option is set, the long option.
-
toUsage
Creates a plain usage specification without any escape codes, helpful e.g. in human readable messages.- Specified by:
toUsagein interfaceOperand<Boolean>- Parameters:
aCliCtx- TheCliContextto use when creating a beautiful usage text.- Returns:
- The according usage text.
-
toSpec
Creates a specification including its arguments.A specification differs from a syntax in that the specification provides the full definition not omitting any choices whereas the syntax only provides a syntactically correct variant. For example, having an option with a short option and a long option, the specification will show the short option and the long option whereas the syntax will only show either the short option or, if no short option is set, the long option.
- Specified by:
toSpecin interfaceOperand<Boolean>- Parameters:
aCliCtx- TheCliContextto use when creating a beautiful specification text.- Returns:
- The according specification text.
-
toType
To value.- Specified by:
toTypein classAbstractOperand<Boolean>- Parameters:
aArg- the arg- Returns:
- the string
-
getDescription
- Specified by:
getDescriptionin interfaceDescriptionAccessor
-
getException
Retrieves theArgsSyntaxExceptionexception in case invokingTerm.parseArgs(String[], CliContext)failed. The exception (and the according suppressed ones alongside the causes) does not necessarily have been thrown by theTerm.parseArgs(String[], CliContext)method depending on the semantics of theTermhanding the exception (theAnyConditionprovides any exceptions it caught even though it did not throw them as of its semantics).- Specified by:
getExceptionin interfaceExceptionAccessor<ArgsSyntaxException>- Specified by:
getExceptionin interfaceTerm- Returns:
- The
ArgsSyntaxExceptionexception occurring while parsing the arguments.
-
setVisible
public void setVisible(boolean isVisible) Visibility in this context means displaying or hiding this
Term's existence to the user (defaults totrue).- Specified by:
setVisiblein interfaceTerm- Specified by:
setVisiblein interfaceVisibleAccessor.VisibleMutator
-
isVisible
public boolean isVisible()Visibility in this context means displaying or hiding this
Term's existence to the user (defaults totrue).- Specified by:
isVisiblein interfaceTerm- Specified by:
isVisiblein interfaceVisibleAccessor
-
toArgsDiff
Creates the difference between the provided set and the providedLists therein found argument arrays subset (as ofOperand.getParsedArgs()).- Parameters:
aArgs- The set to be used for the diff operation.aArgsSubset- The subset to be used for the diff operation being the lists containing theOperandinstances whose command line arguments are to be diffed.- Returns:
- The difference between the set and the subset.
-
toArgsDiff
Creates the difference between the provided set and the providedLists therein found argument arrays subset (as ofOperand.getParsedArgs()).- Parameters:
aArgs- The set to be used for the diff operation.aArgsSubset- The subset to be used for the diff operation being the lists containing theOperandinstances whose command line arguments are to be diffed.- Returns:
- The difference between the set and the subset.
-
toArgsDiff
Creates the difference between the provided set and the provided subset.- Parameters:
aArgs- The set to be used for the diff operation.aArgsSubset- The subset to be used for the diff operation.- Returns:
- The difference between the set and the subset.
-
toParsedArgs
Takes allOperandinstances found in the providedLists and adds all therein found argument arrays (as ofOperand.getParsedArgs()) to the result.
-