Interface OperationAccessor.OperationBuilder<B extends OperationAccessor.OperationBuilder<B>>

Type Parameters:
B - The builder to return in order to be able to apply multiple build operations.
Enclosing interface:
OperationAccessor

public static interface OperationAccessor.OperationBuilder<B extends OperationAccessor.OperationBuilder<B>>
Provides a builder method for a operation property returning the builder for applying multiple build operations.
  • Method Summary

    Modifier and Type
    Method
    Description
    withOperation(String aOperation)
    Sets the operation for the operation property.
  • Method Details

    • withOperation

      B withOperation(String aOperation)
      Sets the operation for the operation property.
      Parameters:
      aOperation - The operation to be stored by the operation property.
      Returns:
      The builder for applying multiple build operations.