- All Superinterfaces:
ArgsParserBuilder<ParseArgs>,ArgsProcessorBuilder<ParseArgs>,ArgsSyntaxAccessor,ArgsSyntaxAccessor.ArgsSyntaxBuilder<ParseArgs>,ArgsSyntaxAccessor.ArgsSyntaxMutator,ArgsSyntaxAccessor.ArgsSyntaxProperty,ArgumentEscapeCodeAccessor,ArgumentEscapeCodeAccessor.ArgumentEscapeCodeBuilder<ParseArgs>,ArgumentEscapeCodeAccessor.ArgumentEscapeCodeMutator,ArgumentEscapeCodeAccessor.ArgumentEscapeCodeProperty,BannerBorderEscapeCodeAccessor,BannerBorderEscapeCodeAccessor.BannerBorderEscapeCodeBuilder<ParseArgs>,BannerBorderEscapeCodeAccessor.BannerBorderEscapeCodeMutator,BannerBorderEscapeCodeAccessor.BannerBorderEscapeCodeProperty,BannerEscapeCodeAccessor,BannerEscapeCodeAccessor.BannerEscapeCodeBuilder<ParseArgs>,BannerEscapeCodeAccessor.BannerEscapeCodeMutator,BannerEscapeCodeAccessor.BannerEscapeCodeProperty,BannerFontAccessor,BannerFontAccessor.BannerFontBuilder<ParseArgs>,BannerFontAccessor.BannerFontMutator,BannerFontAccessor.BannerFontProperty,BannerFontPaletteAccessor,BannerFontPaletteAccessor.BannerFontPaletteBuilder<ParseArgs>,BannerFontPaletteAccessor.BannerFontPaletteMutator,BannerFontPaletteAccessor.BannerFontPaletteProperty,CliMetrics,CommandEscapeCodeAccessor,CommandEscapeCodeAccessor.CommandEscapeCodeBuilder<ParseArgs>,CommandEscapeCodeAccessor.CommandEscapeCodeMutator,CommandEscapeCodeAccessor.CommandEscapeCodeProperty,org.refcodes.mixin.ConsoleWidthAccessor,org.refcodes.mixin.ConsoleWidthAccessor.ConsoleWidthBuilder<ParseArgs>,org.refcodes.mixin.ConsoleWidthAccessor.ConsoleWidthMutator,org.refcodes.mixin.ConsoleWidthAccessor.ConsoleWidthProperty,CopyrightAccessor,CopyrightAccessor.CopyrightBuilder<ParseArgs>,CopyrightAccessor.CopyrightMutator,CopyrightAccessor.CopyrightProperty,org.refcodes.mixin.DescriptionAccessor,org.refcodes.mixin.DescriptionAccessor.DescriptionBuilder<ParseArgs>,org.refcodes.mixin.DescriptionAccessor.DescriptionMutator,org.refcodes.mixin.DescriptionAccessor.DescriptionProperty,DescriptionEscapeCodeAccessor,DescriptionEscapeCodeAccessor.DescriptionEscapeCodeBuilder<ParseArgs>,DescriptionEscapeCodeAccessor.DescriptionEscapeCodeMutator,DescriptionEscapeCodeAccessor.DescriptionEscapeCodeProperty,org.refcodes.mixin.EscapeCodesStatusAccessor,org.refcodes.mixin.EscapeCodesStatusAccessor.EscapeCodeStatusBuilder<ParseArgs>,org.refcodes.mixin.EscapeCodesStatusAccessor.EscapeCodeStatusMutator,org.refcodes.mixin.EscapeCodesStatusAccessor.EscapeCodeStatusProperty,ExamplesAccessor,ExamplesAccessor.ExamplesBuilder<ParseArgs>,ExamplesAccessor.ExamplesMutator,ExamplesAccessor.ExamplesProperty,LicenseAccessor,LicenseAccessor.LicenseBuilder<ParseArgs>,LicenseAccessor.LicenseMutator,LicenseAccessor.LicenseProperty,org.refcodes.mixin.LineBreakAccessor,org.refcodes.mixin.LineBreakAccessor.LineBreakBuilder<ParseArgs>,org.refcodes.mixin.LineBreakAccessor.LineBreakMutator,org.refcodes.mixin.LineBreakAccessor.LineBreakProperty,LineSeparatorEscapeCodeAccessor,LineSeparatorEscapeCodeAccessor.LineSeparatorEscapeCodeBuilder<ParseArgs>,LineSeparatorEscapeCodeAccessor.LineSeparatorEscapeCodeMutator,LineSeparatorEscapeCodeAccessor.LineSeparatorEscapeCodeProperty,LongOptionPrefixAccessor,LongOptionPrefixAccessor.LongOptionPrefixBuilder<ParseArgs>,LongOptionPrefixAccessor.LongOptionPrefixMutator,LongOptionPrefixAccessor.LongOptionPrefixProperty,org.refcodes.mixin.MaxConsoleWidthAccessor,org.refcodes.mixin.MaxConsoleWidthAccessor.MaxConsoleWidthBuilder<ParseArgs>,org.refcodes.mixin.MaxConsoleWidthAccessor.MaxConsoleWidthMutator,org.refcodes.mixin.MaxConsoleWidthAccessor.MaxConsoleWidthProperty,org.refcodes.mixin.NameAccessor,org.refcodes.mixin.NameAccessor.NameBuilder<ParseArgs>,org.refcodes.mixin.NameAccessor.NameMutator,org.refcodes.mixin.NameAccessor.NameProperty,Optionable,OptionEscapeCodeAccessor,OptionEscapeCodeAccessor.OptionEscapeCodeBuilder<ParseArgs>,OptionEscapeCodeAccessor.OptionEscapeCodeMutator,OptionEscapeCodeAccessor.OptionEscapeCodeProperty,org.refcodes.mixin.Resetable,org.refcodes.mixin.ResetEscapeCodeAccessor,org.refcodes.mixin.ResetEscapeCodeAccessor.ResetEscapeCodeBuilder<ParseArgs>,org.refcodes.mixin.ResetEscapeCodeAccessor.ResetEscapeCodeMutator,org.refcodes.mixin.ResetEscapeCodeAccessor.ResetEscapeCodeProperty,org.refcodes.mixin.Schemable,ShortOptionPrefixAccessor,ShortOptionPrefixAccessor.ShortOptionPrefixBuilder<ParseArgs>,ShortOptionPrefixAccessor.ShortOptionPrefixMutator,ShortOptionPrefixAccessor.ShortOptionPrefixProperty,SyntaxMetricsAccessor,SyntaxMetricsAccessor.SyntaxMetricsBuilder<ParseArgs>,SyntaxMetricsAccessor.SyntaxMetricsMutator,SyntaxMetricsAccessor.SyntaxMetricsProperty,org.refcodes.textual.TextBoxGridAccessor,org.refcodes.textual.TextBoxGridAccessor.TextBoxGridBuilder<ParseArgs>,org.refcodes.textual.TextBoxGridAccessor.TextBoxGridMutator,org.refcodes.textual.TextBoxGridAccessor.TextBoxGridProperty,org.refcodes.mixin.TitleAccessor,org.refcodes.mixin.TitleAccessor.TitleBuilder<ParseArgs>,org.refcodes.mixin.TitleAccessor.TitleMutator,org.refcodes.mixin.TitleAccessor.TitleProperty
- All Known Implementing Classes:
ArgsParser
public interface ParseArgs
extends org.refcodes.mixin.Schemable, Optionable, CliMetrics, org.refcodes.mixin.LineBreakAccessor.LineBreakProperty, LineSeparatorEscapeCodeAccessor.LineSeparatorEscapeCodeProperty, DescriptionEscapeCodeAccessor.DescriptionEscapeCodeProperty, LicenseAccessor.LicenseProperty, CopyrightAccessor.CopyrightProperty, org.refcodes.mixin.ConsoleWidthAccessor.ConsoleWidthProperty, org.refcodes.mixin.MaxConsoleWidthAccessor.MaxConsoleWidthProperty, BannerFontPaletteAccessor.BannerFontPaletteProperty, BannerFontAccessor.BannerFontProperty, CommandEscapeCodeAccessor.CommandEscapeCodeProperty, BannerEscapeCodeAccessor.BannerEscapeCodeProperty, BannerBorderEscapeCodeAccessor.BannerBorderEscapeCodeProperty, ExamplesAccessor.ExamplesProperty, org.refcodes.mixin.TitleAccessor.TitleProperty, org.refcodes.mixin.NameAccessor.NameProperty, org.refcodes.mixin.DescriptionAccessor.DescriptionProperty, org.refcodes.mixin.EscapeCodesStatusAccessor.EscapeCodeStatusProperty, org.refcodes.mixin.ResetEscapeCodeAccessor.ResetEscapeCodeProperty, OptionEscapeCodeAccessor.OptionEscapeCodeProperty, ArgumentEscapeCodeAccessor.ArgumentEscapeCodeProperty, SyntaxMetricsAccessor.SyntaxMetricsProperty, ShortOptionPrefixAccessor.ShortOptionPrefixProperty, LongOptionPrefixAccessor.LongOptionPrefixProperty, org.refcodes.textual.TextBoxGridAccessor.TextBoxGridProperty, ArgsSyntaxAccessor.ArgsSyntaxProperty, ArgsProcessorBuilder<ParseArgs>, ArgsParserBuilder<ParseArgs>, org.refcodes.mixin.Resetable
The
ParseArgs provides means for parsing command line arguments and
constructing a command line utility's help output.-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.cli.ArgsSyntaxAccessor
ArgsSyntaxAccessor.ArgsSyntaxBuilder<B extends ArgsSyntaxAccessor.ArgsSyntaxBuilder<B>>, ArgsSyntaxAccessor.ArgsSyntaxMutator, ArgsSyntaxAccessor.ArgsSyntaxPropertyNested classes/interfaces inherited from interface org.refcodes.cli.ArgumentEscapeCodeAccessor
ArgumentEscapeCodeAccessor.ArgumentEscapeCodeBuilder<B extends ArgumentEscapeCodeAccessor.ArgumentEscapeCodeBuilder<B>>, ArgumentEscapeCodeAccessor.ArgumentEscapeCodeMutator, ArgumentEscapeCodeAccessor.ArgumentEscapeCodePropertyNested classes/interfaces inherited from interface org.refcodes.cli.BannerBorderEscapeCodeAccessor
BannerBorderEscapeCodeAccessor.BannerBorderEscapeCodeBuilder<B extends BannerBorderEscapeCodeAccessor.BannerBorderEscapeCodeBuilder<B>>, BannerBorderEscapeCodeAccessor.BannerBorderEscapeCodeMutator, BannerBorderEscapeCodeAccessor.BannerBorderEscapeCodePropertyNested classes/interfaces inherited from interface org.refcodes.cli.BannerEscapeCodeAccessor
BannerEscapeCodeAccessor.BannerEscapeCodeBuilder<B extends BannerEscapeCodeAccessor.BannerEscapeCodeBuilder<B>>, BannerEscapeCodeAccessor.BannerEscapeCodeMutator, BannerEscapeCodeAccessor.BannerEscapeCodePropertyNested classes/interfaces inherited from interface org.refcodes.cli.BannerFontAccessor
BannerFontAccessor.BannerFontBuilder<B extends BannerFontAccessor.BannerFontBuilder<B>>, BannerFontAccessor.BannerFontMutator, BannerFontAccessor.BannerFontPropertyNested classes/interfaces inherited from interface org.refcodes.cli.BannerFontPaletteAccessor
BannerFontPaletteAccessor.BannerFontPaletteBuilder<B extends BannerFontPaletteAccessor.BannerFontPaletteBuilder<B>>, BannerFontPaletteAccessor.BannerFontPaletteMutator, BannerFontPaletteAccessor.BannerFontPalettePropertyNested classes/interfaces inherited from interface org.refcodes.cli.CommandEscapeCodeAccessor
CommandEscapeCodeAccessor.CommandEscapeCodeBuilder<B extends CommandEscapeCodeAccessor.CommandEscapeCodeBuilder<B>>, CommandEscapeCodeAccessor.CommandEscapeCodeMutator, CommandEscapeCodeAccessor.CommandEscapeCodePropertyNested classes/interfaces inherited from interface org.refcodes.mixin.ConsoleWidthAccessor
org.refcodes.mixin.ConsoleWidthAccessor.ConsoleWidthBuilder<B extends org.refcodes.mixin.ConsoleWidthAccessor.ConsoleWidthBuilder<B>>, org.refcodes.mixin.ConsoleWidthAccessor.ConsoleWidthMutator, org.refcodes.mixin.ConsoleWidthAccessor.ConsoleWidthPropertyNested classes/interfaces inherited from interface org.refcodes.cli.CopyrightAccessor
CopyrightAccessor.CopyrightBuilder<B extends CopyrightAccessor.CopyrightBuilder<B>>, CopyrightAccessor.CopyrightMutator, CopyrightAccessor.CopyrightPropertyNested classes/interfaces inherited from interface org.refcodes.mixin.DescriptionAccessor
org.refcodes.mixin.DescriptionAccessor.DescriptionBuilder<B extends org.refcodes.mixin.DescriptionAccessor.DescriptionBuilder<B>>, org.refcodes.mixin.DescriptionAccessor.DescriptionMutator, org.refcodes.mixin.DescriptionAccessor.DescriptionPropertyNested classes/interfaces inherited from interface org.refcodes.cli.DescriptionEscapeCodeAccessor
DescriptionEscapeCodeAccessor.DescriptionEscapeCodeBuilder<B extends DescriptionEscapeCodeAccessor.DescriptionEscapeCodeBuilder<B>>, DescriptionEscapeCodeAccessor.DescriptionEscapeCodeMutator, DescriptionEscapeCodeAccessor.DescriptionEscapeCodePropertyNested classes/interfaces inherited from interface org.refcodes.mixin.EscapeCodesStatusAccessor
org.refcodes.mixin.EscapeCodesStatusAccessor.EscapeCodeStatusBuilder<B extends org.refcodes.mixin.EscapeCodesStatusAccessor.EscapeCodeStatusBuilder<B>>, org.refcodes.mixin.EscapeCodesStatusAccessor.EscapeCodeStatusMutator, org.refcodes.mixin.EscapeCodesStatusAccessor.EscapeCodeStatusPropertyNested classes/interfaces inherited from interface org.refcodes.cli.ExamplesAccessor
ExamplesAccessor.ExamplesBuilder<B extends ExamplesAccessor.ExamplesBuilder<B>>, ExamplesAccessor.ExamplesMutator, ExamplesAccessor.ExamplesPropertyNested classes/interfaces inherited from interface org.refcodes.cli.LicenseAccessor
LicenseAccessor.LicenseBuilder<B extends LicenseAccessor.LicenseBuilder<B>>, LicenseAccessor.LicenseMutator, LicenseAccessor.LicensePropertyNested classes/interfaces inherited from interface org.refcodes.mixin.LineBreakAccessor
org.refcodes.mixin.LineBreakAccessor.LineBreakBuilder<B extends org.refcodes.mixin.LineBreakAccessor.LineBreakBuilder<B>>, org.refcodes.mixin.LineBreakAccessor.LineBreakMutator, org.refcodes.mixin.LineBreakAccessor.LineBreakPropertyNested classes/interfaces inherited from interface org.refcodes.cli.LineSeparatorEscapeCodeAccessor
LineSeparatorEscapeCodeAccessor.LineSeparatorEscapeCodeBuilder<B extends LineSeparatorEscapeCodeAccessor.LineSeparatorEscapeCodeBuilder<B>>, LineSeparatorEscapeCodeAccessor.LineSeparatorEscapeCodeMutator, LineSeparatorEscapeCodeAccessor.LineSeparatorEscapeCodePropertyNested classes/interfaces inherited from interface org.refcodes.cli.LongOptionPrefixAccessor
LongOptionPrefixAccessor.LongOptionPrefixBuilder<B extends LongOptionPrefixAccessor.LongOptionPrefixBuilder<B>>, LongOptionPrefixAccessor.LongOptionPrefixMutator, LongOptionPrefixAccessor.LongOptionPrefixPropertyNested classes/interfaces inherited from interface org.refcodes.mixin.MaxConsoleWidthAccessor
org.refcodes.mixin.MaxConsoleWidthAccessor.MaxConsoleWidthBuilder<B extends org.refcodes.mixin.MaxConsoleWidthAccessor.MaxConsoleWidthBuilder<B>>, org.refcodes.mixin.MaxConsoleWidthAccessor.MaxConsoleWidthMutator, org.refcodes.mixin.MaxConsoleWidthAccessor.MaxConsoleWidthPropertyNested classes/interfaces inherited from interface org.refcodes.mixin.NameAccessor
org.refcodes.mixin.NameAccessor.NameBuilder<B extends org.refcodes.mixin.NameAccessor.NameBuilder<B>>, org.refcodes.mixin.NameAccessor.NameMutator, org.refcodes.mixin.NameAccessor.NamePropertyNested classes/interfaces inherited from interface org.refcodes.cli.OptionEscapeCodeAccessor
OptionEscapeCodeAccessor.OptionEscapeCodeBuilder<B extends OptionEscapeCodeAccessor.OptionEscapeCodeBuilder<B>>, OptionEscapeCodeAccessor.OptionEscapeCodeMutator, OptionEscapeCodeAccessor.OptionEscapeCodePropertyNested classes/interfaces inherited from interface org.refcodes.mixin.ResetEscapeCodeAccessor
org.refcodes.mixin.ResetEscapeCodeAccessor.ResetEscapeCodeBuilder<B extends org.refcodes.mixin.ResetEscapeCodeAccessor.ResetEscapeCodeBuilder<B>>, org.refcodes.mixin.ResetEscapeCodeAccessor.ResetEscapeCodeMutator, org.refcodes.mixin.ResetEscapeCodeAccessor.ResetEscapeCodePropertyNested classes/interfaces inherited from interface org.refcodes.cli.ShortOptionPrefixAccessor
ShortOptionPrefixAccessor.ShortOptionPrefixBuilder<B extends ShortOptionPrefixAccessor.ShortOptionPrefixBuilder<B>>, ShortOptionPrefixAccessor.ShortOptionPrefixMutator, ShortOptionPrefixAccessor.ShortOptionPrefixPropertyNested classes/interfaces inherited from interface org.refcodes.cli.SyntaxMetricsAccessor
SyntaxMetricsAccessor.SyntaxMetricsBuilder<B extends SyntaxMetricsAccessor.SyntaxMetricsBuilder<B>>, SyntaxMetricsAccessor.SyntaxMetricsMutator, SyntaxMetricsAccessor.SyntaxMetricsPropertyNested classes/interfaces inherited from interface org.refcodes.textual.TextBoxGridAccessor
org.refcodes.textual.TextBoxGridAccessor.TextBoxGridBuilder<B extends org.refcodes.textual.TextBoxGridAccessor.TextBoxGridBuilder<?>>, org.refcodes.textual.TextBoxGridAccessor.TextBoxGridMutator, org.refcodes.textual.TextBoxGridAccessor.TextBoxGridPropertyNested classes/interfaces inherited from interface org.refcodes.mixin.TitleAccessor
org.refcodes.mixin.TitleAccessor.TitleBuilder<B extends org.refcodes.mixin.TitleAccessor.TitleBuilder<B>>, org.refcodes.mixin.TitleAccessor.TitleMutator, org.refcodes.mixin.TitleAccessor.TitleProperty -
Method Summary
Modifier and TypeMethodDescriptiondefault voidaddExample(String aDescription, Operand<?>... aOperands) Adds a usage example by providing a description of the example and the command line arguments required by the example.voidaddExample(Example aExample) Adds a usage example by providing a description of the example and the command line arguments required by the example.voidPrints the given line to standard error with regards to the console width as specified by thewithConsoleWidth(int)method.Operand<?>[]Evaluates the provided command line arguments and determines the according values by evaluating the rootCondition.default Operand<?>[]Evaluates the provided command line arguments as ofevalArgs(String[]), additionally filtering (excluding) the arguments matching the providedPattern.default Operand<?>[]evalArgs(String[] aArgs, ArgsFilter aArgsFilter) Evaluates the provided command line arguments as ofevalArgs(String[]), additionally filtering (excluding) the arguments matching the providedArgsFilter.default Operand<?>[]Same asevalArgs(String[])with the difference that the elements representing the arguments are passed as a list instead of an array.default Operand<?>[]Evaluates the provided command line arguments as ofevalArgs(String[]), additionally filtering (excluding) the arguments matching the providedPattern.default Operand<?>[]evalArgs(List<String> aArgs, ArgsFilter aArgsFilter) Evaluates the provided command line arguments as ofevalArgs(String[]), additionally filtering (excluding) the arguments matching the providedArgsFilter.Retrieves the argument Escape-Code from the argument Escape-Code property.Retrieves the banner border Escape-Code from the banner border Escape-Code property.Retrieves the banner Escape-Code from the banner Escape-Code property.Retrieves the command Escape-Code from the command Escape-Code property.Retrieves the copyright from the copyright property.Retrieves the description Escape-Code from the description Escape-Code property.Example[]Retrieves the license from the license property.Retrieves the line separator Escape-Code from the line separator Escape-Code property.Retrieves the option Escape-Code from the option Escape-Code property.charGets the character to be used when printing a separator line with theprintSeparatorLn()method.voidPrints the banner; the banner most probably is an ASCII_HEADER_ASCII_BODY art text block which's look depends strongly on the taste of the author implementing this interface.default voidPrints the help as ofprintHelp()without the banner.voidPrints the copyright note as specified by thewithCopyright(String)method; with regards to the console width as specified by thewithConsoleWidth(int)method.voidPrints the description as set by thewithDescription(String)method with regards to the console width as specified by thewithConsoleWidth(int)method.voidPrints example usages as as added by theaddExample(String, Operand...)method with regards to the console width as specified by thewithConsoleWidth(int)method.voidPrints the header, which might be a simplified banner: Can be used when overriding methods such asprintHelp()orprintBanner().default voidPrints the help to the standard output specified by thewithStandardOut(PrintStream)method.voidPrints the license note as specified by thewithLicense(String)method; with regards to the console width as specified by thewithConsoleWidth(int)method.voidprintLn()Prints an empty line / a line break.voidPrints the given line to standard out with regards to the console width as specified by thewithConsoleWidth(int)method.voidPrints theOptions (short- and the long-options), theFlages and theOperandand their description with regards to the console width as specified by thewithConsoleWidth(int)method.voidPrints a separator line using the separator character as specified by thewithSeparatorLnChar(char)method; with regards to the console width as specified by thewithConsoleWidth(int)method.voidPrints the syntax as retrieved by the rootConditionelement as ofSynopsisable.toSynopsis(SyntaxNotation)with regards to theSyntaxNotationset by thewithSyntaxMetrics(SyntaxMetrics)method.voidsetErrorOut(PrintStream aErrorOut) Set the error outPrintStreamand make other adjustments with the result (with regards to the Builder-Pattern).voidsetLineSeparatorEscapeCode(String aLineSeparatorEscCode) Sets the line separator Escape-Code for the line separator Escape-Code property.voidsetSeparatorLnChar(char aSeparatorLnChar) Set the character to be used when printing a separator line with theprintSeparatorLn()method.voidsetStandardOut(PrintStream aStandardOut) Set the standard outPrintStreamand make other adjustments with the result (with regards to the Builder-Pattern).voidsetSyntaxMetrics(SyntaxMetrics aSyntaxMetrics) Sets theSyntaxMetricsfor theSyntaxMetricsproperty.default String[]Retrieves an array of the context specific options being configured for the givenOptioninstance, being the long option (when set) and the short option (when set), by prepending the according runtime specific short option and long option prefix (if applicable).default CliSchematoSchema()default ParseArgswithAddExample(String aDescription, Operand<?>... aOperands) Builder method adding an application'sExampleelement.default ParseArgswithAddExample(Example aExample) Builder method adding an application'sExampleelement.default ParseArgswithArgumentEscapeCode(String aParamEscCode) Sets the argument Escape-Code for the argument Escape-Code property.default ParseArgswithBannerBorderEscapeCode(String aBannerBorderEscCode) Sets the banner border Escape-Code for the banner border Escape-Code property.default ParseArgswithBannerEscapeCode(String aBannerEscCode) Sets the banner Escape-Code for the banner Escape-Code property.default ParseArgswithBannerFont(org.refcodes.textual.Font aBannerFont) Sets the bannerFontfor the bannerFontproperty.default ParseArgswithBannerFontPalette(char[] aColorPalette) Sets the banner font palette for the banner font palette property.default ParseArgswithCommandEscapeCode(String aCommandEscCode) Sets the command Escape-Code for the command Escape-Code property.default ParseArgswithConsoleWidth(int aConsoleWidth) default ParseArgswithCopyright(String aCopyright) Sets the copyright for the copyright property.default ParseArgswithDescription(String aDescription) default ParseArgswithDescriptionEscapeCode(String aDescriptionEscCode) Sets the description Escape-Code for the description Escape-Code property.default ParseArgswithErrorOut(PrintStream aErrorOut) Set the error outPrintStreamand make other adjustments with the result (with regards to the Builder-Pattern).default ParseArgswithEscapeCodesEnabled(boolean isEscCodeEnabled) default ParseArgswithEvalArgs(String[] aArgs) Evaluates the provided command line arguments.default ParseArgswithEvalArgs(List<String> aArgs) Evaluates the provided command line arguments .default ParseArgswithExamples(Collection<Example> aExamples) Builder method providing the application'sExampleelements.default ParseArgswithExamples(Example[] aExamples) default ParseArgswithLicense(String aLicense) Sets the license for the license property.default ParseArgswithLineBreak(String aLineBreak) default ParseArgswithLineSeparatorEscapeCode(String aLineSeparatorEscCode) Sets the line separator Escape-Code for the line separator Escape-Code property.default ParseArgswithLongOptionPrefix(String aLongOptionPrefix) Sets the long option prefix for the long option prefix property.default ParseArgswithMaxConsoleWidth(int aMaxConsoleWidth) default ParseArgsdefault ParseArgswithOptionEscapeCode(String aOptEscCode) Sets the option Escape-Code for the option Escape-Code property.default ParseArgswithResetEscapeCode(String aResetEscCode) default ParseArgswithSeparatorLnChar(char aSeparatorLnChar) Builder method adding an separator line char.default ParseArgswithShortOptionPrefix(Character aShortOptionPrefix) Sets the short option prefix for the short option prefix property.default ParseArgswithStandardOut(PrintStream aStandardOut) Set the standard outPrintStreamand make other adjustments with the result (with regards to the Builder-Pattern).default ParseArgswithSyntaxMetrics(SyntaxMetrics aSyntaxMetrics) Sets theSyntaxMetricsfor theSyntaxMetricsproperty.default ParseArgswithTextBoxGrid(org.refcodes.textual.TextBoxGrid aTextBoxGrid) default ParseArgswithTextBoxGrid(org.refcodes.textual.TextBoxStyle aTextBoxStyle) default ParseArgsMethods inherited from interface org.refcodes.cli.ArgsParserBuilder
withEvalArgs, withEvalArgs, withEvalArgs, withEvalArgsMethods inherited from interface org.refcodes.cli.ArgsSyntaxAccessor.ArgsSyntaxBuilder
withArgsSyntaxMethods inherited from interface org.refcodes.cli.ArgsSyntaxAccessor.ArgsSyntaxMutator
setArgsSyntaxMethods inherited from interface org.refcodes.cli.ArgsSyntaxAccessor.ArgsSyntaxProperty
letArgsSyntaxMethods inherited from interface org.refcodes.cli.ArgumentEscapeCodeAccessor.ArgumentEscapeCodeMutator
setArgumentEscapeCodeMethods inherited from interface org.refcodes.cli.ArgumentEscapeCodeAccessor.ArgumentEscapeCodeProperty
letArgumentEscapeCodeMethods inherited from interface org.refcodes.cli.BannerBorderEscapeCodeAccessor.BannerBorderEscapeCodeMutator
setBannerBorderEscapeCodeMethods inherited from interface org.refcodes.cli.BannerBorderEscapeCodeAccessor.BannerBorderEscapeCodeProperty
letBannerBorderEscapeCodeMethods inherited from interface org.refcodes.cli.BannerEscapeCodeAccessor.BannerEscapeCodeMutator
setBannerEscapeCodeMethods inherited from interface org.refcodes.cli.BannerEscapeCodeAccessor.BannerEscapeCodeProperty
letBannerEscapeCodeMethods inherited from interface org.refcodes.cli.BannerFontAccessor
getBannerFontMethods inherited from interface org.refcodes.cli.BannerFontAccessor.BannerFontMutator
setBannerFontMethods inherited from interface org.refcodes.cli.BannerFontAccessor.BannerFontProperty
letBannerFontMethods inherited from interface org.refcodes.cli.BannerFontPaletteAccessor
getBannerFontPaletteMethods inherited from interface org.refcodes.cli.BannerFontPaletteAccessor.BannerFontPaletteBuilder
withBannerFontPaletteMethods inherited from interface org.refcodes.cli.BannerFontPaletteAccessor.BannerFontPaletteMutator
setBannerFontPalette, setBannerFontPaletteMethods inherited from interface org.refcodes.cli.BannerFontPaletteAccessor.BannerFontPaletteProperty
letBannerFontPaletteMethods inherited from interface org.refcodes.cli.CommandEscapeCodeAccessor.CommandEscapeCodeMutator
setCommandEscapeCodeMethods inherited from interface org.refcodes.cli.CommandEscapeCodeAccessor.CommandEscapeCodeProperty
letCommandEscapeCodeMethods inherited from interface org.refcodes.mixin.ConsoleWidthAccessor
getConsoleWidthMethods inherited from interface org.refcodes.mixin.ConsoleWidthAccessor.ConsoleWidthMutator
setConsoleWidthMethods inherited from interface org.refcodes.mixin.ConsoleWidthAccessor.ConsoleWidthProperty
letConsoleWidthMethods inherited from interface org.refcodes.cli.CopyrightAccessor.CopyrightMutator
setCopyrightMethods inherited from interface org.refcodes.cli.CopyrightAccessor.CopyrightProperty
letCopyrightMethods inherited from interface org.refcodes.mixin.DescriptionAccessor.DescriptionMutator
setDescriptionMethods inherited from interface org.refcodes.mixin.DescriptionAccessor.DescriptionProperty
letDescriptionMethods inherited from interface org.refcodes.cli.DescriptionEscapeCodeAccessor.DescriptionEscapeCodeMutator
setDescriptionEscapeCodeMethods inherited from interface org.refcodes.cli.DescriptionEscapeCodeAccessor.DescriptionEscapeCodeProperty
letDescriptionEscapeCodeMethods inherited from interface org.refcodes.mixin.EscapeCodesStatusAccessor
isEscapeCodesEnabledMethods inherited from interface org.refcodes.mixin.EscapeCodesStatusAccessor.EscapeCodeStatusMutator
setEscapeCodesEnabledMethods inherited from interface org.refcodes.mixin.EscapeCodesStatusAccessor.EscapeCodeStatusProperty
letEscapeCodesEnabledMethods inherited from interface org.refcodes.cli.ExamplesAccessor.ExamplesMutator
setExamples, setExamplesMethods inherited from interface org.refcodes.cli.ExamplesAccessor.ExamplesProperty
letExamplesMethods inherited from interface org.refcodes.cli.LicenseAccessor.LicenseMutator
setLicenseMethods inherited from interface org.refcodes.cli.LicenseAccessor.LicenseProperty
letLicenseMethods inherited from interface org.refcodes.mixin.LineBreakAccessor
getLineBreakMethods inherited from interface org.refcodes.mixin.LineBreakAccessor.LineBreakMutator
setLineBreakMethods inherited from interface org.refcodes.mixin.LineBreakAccessor.LineBreakProperty
letLineBreakMethods inherited from interface org.refcodes.cli.LineSeparatorEscapeCodeAccessor.LineSeparatorEscapeCodeProperty
letLineSeparatorEscapeCodeMethods inherited from interface org.refcodes.cli.LongOptionPrefixAccessor
getLongOptionPrefixMethods inherited from interface org.refcodes.cli.LongOptionPrefixAccessor.LongOptionPrefixMutator
setLongOptionPrefixMethods inherited from interface org.refcodes.cli.LongOptionPrefixAccessor.LongOptionPrefixProperty
letLongOptionPrefixMethods inherited from interface org.refcodes.mixin.MaxConsoleWidthAccessor
getMaxConsoleWidthMethods inherited from interface org.refcodes.mixin.MaxConsoleWidthAccessor.MaxConsoleWidthMutator
setMaxConsoleWidthMethods inherited from interface org.refcodes.mixin.MaxConsoleWidthAccessor.MaxConsoleWidthProperty
letMaxConsoleWidthMethods inherited from interface org.refcodes.mixin.NameAccessor
getNameMethods inherited from interface org.refcodes.mixin.NameAccessor.NameMutator
setNameMethods inherited from interface org.refcodes.mixin.NameAccessor.NameProperty
letNameMethods inherited from interface org.refcodes.cli.OptionEscapeCodeAccessor.OptionEscapeCodeMutator
setOptionEscapeCodeMethods inherited from interface org.refcodes.cli.OptionEscapeCodeAccessor.OptionEscapeCodeProperty
letOptionEscapeCodeMethods inherited from interface org.refcodes.mixin.Resetable
resetMethods inherited from interface org.refcodes.mixin.ResetEscapeCodeAccessor
getResetEscapeCodeMethods inherited from interface org.refcodes.mixin.ResetEscapeCodeAccessor.ResetEscapeCodeMutator
setResetEscapeCodeMethods inherited from interface org.refcodes.mixin.ResetEscapeCodeAccessor.ResetEscapeCodeProperty
letResetEscapeCodeMethods inherited from interface org.refcodes.cli.ShortOptionPrefixAccessor
getShortOptionPrefixMethods inherited from interface org.refcodes.cli.ShortOptionPrefixAccessor.ShortOptionPrefixMutator
setShortOptionPrefixMethods inherited from interface org.refcodes.cli.ShortOptionPrefixAccessor.ShortOptionPrefixProperty
letShortOptionPrefixMethods inherited from interface org.refcodes.cli.SyntaxMetricsAccessor
getSyntaxMetricsMethods inherited from interface org.refcodes.cli.SyntaxMetricsAccessor.SyntaxMetricsBuilder
withSyntaxMetricsMethods inherited from interface org.refcodes.cli.SyntaxMetricsAccessor.SyntaxMetricsMutator
setSyntaxMetricsMethods inherited from interface org.refcodes.cli.SyntaxMetricsAccessor.SyntaxMetricsProperty
letSyntaxMetrics, letSyntaxMetricsMethods inherited from interface org.refcodes.textual.TextBoxGridAccessor
getTextBoxGridMethods inherited from interface org.refcodes.textual.TextBoxGridAccessor.TextBoxGridMutator
setTextBoxGrid, setTextBoxGridMethods inherited from interface org.refcodes.textual.TextBoxGridAccessor.TextBoxGridProperty
letTextBoxGrid, letTextBoxGridMethods inherited from interface org.refcodes.mixin.TitleAccessor
getTitleMethods inherited from interface org.refcodes.mixin.TitleAccessor.TitleMutator
setTitleMethods inherited from interface org.refcodes.mixin.TitleAccessor.TitleProperty
letTitle
-
Method Details
-
addExample
Adds a usage example by providing a description of the example and the command line arguments required by the example.- Parameters:
aExample- The description as well as the command line arguments used by the example.
-
addExample
Adds a usage example by providing a description of the example and the command line arguments required by the example.- Parameters:
aDescription- The description of the example.aOperands- The command line arguments used by the example.
-
errorLn
Prints the given line to standard error with regards to the console width as specified by thewithConsoleWidth(int)method.- Parameters:
aLine- The line to be printed.
-
evalArgs
Same asevalArgs(String[])with the difference that the elements representing the arguments are passed as a list instead of an array.- Parameters:
aArgs- The command line arguments to be evaluated.- Returns:
- The list of evaluated command line arguments being instances of
the
Operandinterfaces or its sub-types. In case anOperandimplements theApprovableinterface or inherits from theAbstractOperandtype, then theOperandis also approved by invokingApprovable.approve()orAbstractOperand.approve()(which may trigger a registered lambda expression). - Throws:
ArgsSyntaxException- thrown in case of a command line arguments mismatch regarding provided and expected args.
-
evalArgs
default Operand<?>[] evalArgs(List<String> aArgs, ArgsFilter aArgsFilter) throws ArgsSyntaxException Evaluates the provided command line arguments as ofevalArgs(String[]), additionally filtering (excluding) the arguments matching the providedArgsFilter.- Parameters:
aArgs- The command line arguments to be evaluated.aArgsFilter- TheArgsFilterused to filter (exclude) any "unwanted" or otherwise evaluated arguments.- Returns:
- The list of evaluated command line arguments being instances of
the
Operandinterfaces or its sub-types. In case anOperandimplements theApprovableinterface or inherits from theAbstractOperandtype, then theOperandis also approved by invokingApprovable.approve()orAbstractOperand.approve()(which may trigger a registered lambda expression). - Throws:
ArgsSyntaxException- thrown in case of a command line arguments mismatch regarding provided and expected args.
-
evalArgs
Evaluates the provided command line arguments as ofevalArgs(String[]), additionally filtering (excluding) the arguments matching the providedPattern.- Parameters:
aArgs- The command line arguments to be evaluated.aFilterExp- ThePatternused to filter (exclude) any "unwanted" or otherwise evaluated arguments.- Returns:
- The list of evaluated command line arguments being instances of
the
Operandinterfaces or its sub-types. In case anOperandimplements theApprovableinterface or inherits from theAbstractOperandtype, then theOperandis also approved by invokingApprovable.approve()orAbstractOperand.approve()(which may trigger a registered lambda expression). - Throws:
ArgsSyntaxException- thrown in case of a command line arguments mismatch regarding provided and expected args.
-
evalArgs
Evaluates the provided command line arguments and determines the according values by evaluating the rootCondition. In case of parsing failure, an according exception is thrown. ATTENTION: This method tests(!) for superfluous command line arguments being passed; e.g. command line arguments not being evaluated by any of theTerminstance being traversed starting at the rootConditionwill be reported. Business logic therefore should invoke this root node'sevalArgs(String[])method instead of aCondition'sTerm.parseArgs(String[], String[], CliContext)method; as ignoring superfluous command line arguments will aCause unexpected behavior from the point of view of the invoker.- Parameters:
aArgs- The command line arguments to be evaluated.- Returns:
- The list of evaluated command line arguments being instances of
the
Operandinterfaces or its sub-types. In case anOperandimplements theApprovableinterface or inherits from theAbstractOperandtype, then theOperandis also approved by invokingApprovable.approve()orAbstractOperand.approve()(which may trigger a registered lambda expression). - Throws:
ArgsSyntaxException- thrown in case of a command line arguments mismatch regarding provided and expected args.
-
evalArgs
Evaluates the provided command line arguments as ofevalArgs(String[]), additionally filtering (excluding) the arguments matching the providedArgsFilter.- Parameters:
aArgs- The command line arguments to be evaluated.aArgsFilter- TheArgsFilterused to filter (exclude) any "unwanted" or otherwise evaluated arguments.- Returns:
- The list of evaluated command line arguments being instances of
the
Operandinterfaces or its sub-types. In case anOperandimplements theApprovableinterface or inherits from theAbstractOperandtype, then theOperandis also approved by invokingApprovable.approve()orAbstractOperand.approve()(which may trigger a registered lambda expression). - Throws:
ArgsSyntaxException- thrown in case of a command line arguments mismatch regarding provided and expected args.
-
evalArgs
Evaluates the provided command line arguments as ofevalArgs(String[]), additionally filtering (excluding) the arguments matching the providedPattern.- Parameters:
aArgs- The command line arguments to be evaluated.aFilterExp- ThePatternused to filter (exclude) any "unwanted" or otherwise evaluated arguments.- Returns:
- The list of evaluated command line arguments being instances of
the
Operandinterfaces or its sub-types. In case anOperandimplements theApprovableinterface or inherits from theAbstractOperandtype, then theOperandis also approved by invokingApprovable.approve()orAbstractOperand.approve()(which may trigger a registered lambda expression). - Throws:
ArgsSyntaxException- thrown in case of a command line arguments mismatch regarding provided and expected args.
-
getArgsSyntax
Term getArgsSyntax()- Specified by:
getArgsSyntaxin interfaceArgsSyntaxAccessor- Returns:
- The (root)
Termstored by the (root)Termproperty.
-
getArgumentEscapeCode
String getArgumentEscapeCode()Retrieves the argument Escape-Code from the argument Escape-Code property.- Specified by:
getArgumentEscapeCodein interfaceArgumentEscapeCodeAccessor- Returns:
- The argument Escape-Code stored by the argument Escape-Code property.
-
getBannerBorderEscapeCode
String getBannerBorderEscapeCode()Retrieves the banner border Escape-Code from the banner border Escape-Code property.- Specified by:
getBannerBorderEscapeCodein interfaceBannerBorderEscapeCodeAccessor- Returns:
- The banner border Escape-Code stored by the banner border Escape-Code property.
-
getBannerEscapeCode
String getBannerEscapeCode()Retrieves the banner Escape-Code from the banner Escape-Code property.- Specified by:
getBannerEscapeCodein interfaceBannerEscapeCodeAccessor- Returns:
- The banner Escape-Code stored by the banner Escape-Code property.
-
getCommandEscapeCode
String getCommandEscapeCode()Retrieves the command Escape-Code from the command Escape-Code property.- Specified by:
getCommandEscapeCodein interfaceCommandEscapeCodeAccessor- Returns:
- The command Escape-Code stored by the command Escape-Code property.
-
getCopyright
String getCopyright()Retrieves the copyright from the copyright property.- Specified by:
getCopyrightin interfaceCopyrightAccessor- Returns:
- The copyright stored by the copyright property.
-
getDescription
String getDescription()- Specified by:
getDescriptionin interfaceorg.refcodes.mixin.DescriptionAccessor
-
getDescriptionEscapeCode
String getDescriptionEscapeCode()Retrieves the description Escape-Code from the description Escape-Code property.- Specified by:
getDescriptionEscapeCodein interfaceDescriptionEscapeCodeAccessor- Returns:
- The description Escape-Code stored by the description Escape-Code property.
-
getExamples
Example[] getExamples()- Specified by:
getExamplesin interfaceExamplesAccessor- Returns:
- The
Exampleinstances stored by theExampleinstances property.
-
getLicense
String getLicense()Retrieves the license from the license property.- Specified by:
getLicensein interfaceLicenseAccessor- Returns:
- The license stored by the license property.
-
getLineSeparatorEscapeCode
String getLineSeparatorEscapeCode()Retrieves the line separator Escape-Code from the line separator Escape-Code property.- Specified by:
getLineSeparatorEscapeCodein interfaceLineSeparatorEscapeCodeAccessor- Returns:
- The line separator Escape-Code stored by the line separator Escape-Code property.
-
getOptionEscapeCode
String getOptionEscapeCode()Retrieves the option Escape-Code from the option Escape-Code property.- Specified by:
getOptionEscapeCodein interfaceOptionEscapeCodeAccessor- Returns:
- The option Escape-Code stored by the option Escape-Code property.
-
getSeparatorLnChar
char getSeparatorLnChar()Gets the character to be used when printing a separator line with theprintSeparatorLn()method.- Returns:
- aSeparatorChar The character used by the
printSeparatorLn()method when printing out the line of characters..
-
printBanner
void printBanner()Prints the banner; the banner most probably is an ASCII_HEADER_ASCII_BODY art text block which's look depends strongly on the taste of the author implementing this interface. -
printBody
default void printBody()Prints the help as ofprintHelp()without the banner. -
printCopyright
void printCopyright()Prints the copyright note as specified by thewithCopyright(String)method; with regards to the console width as specified by thewithConsoleWidth(int)method. -
printDescription
void printDescription()Prints the description as set by thewithDescription(String)method with regards to the console width as specified by thewithConsoleWidth(int)method. -
printExamples
void printExamples()Prints example usages as as added by theaddExample(String, Operand...)method with regards to the console width as specified by thewithConsoleWidth(int)method. -
printHeader
void printHeader()Prints the header, which might be a simplified banner: Can be used when overriding methods such asprintHelp()orprintBanner(). -
printHelp
default void printHelp()Prints the help to the standard output specified by thewithStandardOut(PrintStream)method. This method can make use of the more atomic methodsprintBanner(),printSynopsis(),printDescription(),printOptions()orprintSeparatorLn()to print a help text which's look depends strongly on the taste of the author implementing this interface. In case you dislike the implementing author's taste, feel free to overwrite this method and compose your own help text from the building blocks such asprintBanner(),printSynopsis(),printDescription(),printOptions()orprintSeparatorLn() -
printLicense
void printLicense()Prints the license note as specified by thewithLicense(String)method; with regards to the console width as specified by thewithConsoleWidth(int)method. -
printLn
void printLn()Prints an empty line / a line break. -
printLn
Prints the given line to standard out with regards to the console width as specified by thewithConsoleWidth(int)method.- Parameters:
aLine- The line to be printed.
-
printOptions
void printOptions()Prints theOptions (short- and the long-options), theFlages and theOperandand their description with regards to the console width as specified by thewithConsoleWidth(int)method. -
printSeparatorLn
void printSeparatorLn()Prints a separator line using the separator character as specified by thewithSeparatorLnChar(char)method; with regards to the console width as specified by thewithConsoleWidth(int)method. -
printSynopsis
void printSynopsis()Prints the syntax as retrieved by the rootConditionelement as ofSynopsisable.toSynopsis(SyntaxNotation)with regards to theSyntaxNotationset by thewithSyntaxMetrics(SyntaxMetrics)method. -
setErrorOut
Set the error outPrintStreamand make other adjustments with the result (with regards to the Builder-Pattern).- Parameters:
aErrorOut- The error outPrintStreamto set.
-
setLineSeparatorEscapeCode
Sets the line separator Escape-Code for the line separator Escape-Code property.- Specified by:
setLineSeparatorEscapeCodein interfaceLineSeparatorEscapeCodeAccessor.LineSeparatorEscapeCodeMutator- Parameters:
aLineSeparatorEscCode- The line separator Escape-Code to be stored by the line separator Escape-Code property.
-
setSeparatorLnChar
void setSeparatorLnChar(char aSeparatorLnChar) Set the character to be used when printing a separator line with theprintSeparatorLn()method.- Parameters:
aSeparatorLnChar- The character used by theprintSeparatorLn()method when printing out the line of characters..
-
setStandardOut
Set the standard outPrintStreamand make other adjustments with the result (with regards to the Builder-Pattern).- Parameters:
aStandardOut- The standard outPrintStreamto set.
-
setSyntaxMetrics
Sets theSyntaxMetricsfor theSyntaxMetricsproperty.- Specified by:
setSyntaxMetricsin interfaceSyntaxMetricsAccessor.SyntaxMetricsMutator- Parameters:
aSyntaxMetrics- TheSyntaxMetricsto be stored by theSyntaxMetricsproperty.
-
toOptions
Retrieves an array of the context specific options being configured for the givenOptioninstance, being the long option (when set) and the short option (when set), by prepending the according runtime specific short option and long option prefix (if applicable).- Specified by:
toOptionsin interfaceOptionable- Parameters:
aOption- TheOptioninstance for which to get the configured short and long options.- Returns:
- The array of options being the long option (if not null) and the short option (if not null) with the according context specific prefixes.
-
toSchema
- Specified by:
toSchemain interfaceorg.refcodes.mixin.Schemable
-
withAddExample
Builder method adding an application'sExampleelement.- Specified by:
withAddExamplein interfaceArgsProcessorBuilder<ParseArgs>- Parameters:
aExample- The application'sExampleelement to be added.- Returns:
- This builder as of the builder pattern.
-
withAddExample
Builder method adding an application'sExampleelement.- Specified by:
withAddExamplein interfaceArgsProcessorBuilder<ParseArgs>- Parameters:
aDescription- The example's description.aOperands- The command line arguments required by the example.- Returns:
- This builder as of the builder pattern.
-
withArgumentEscapeCode
Sets the argument Escape-Code for the argument Escape-Code property.- Specified by:
withArgumentEscapeCodein interfaceArgumentEscapeCodeAccessor.ArgumentEscapeCodeBuilder<ParseArgs>- Parameters:
aParamEscCode- The argument Escape-Code to be stored by the argument Escape-Code property.- Returns:
- The builder for applying multiple build operations.
-
withBannerBorderEscapeCode
Sets the banner border Escape-Code for the banner border Escape-Code property.- Specified by:
withBannerBorderEscapeCodein interfaceBannerBorderEscapeCodeAccessor.BannerBorderEscapeCodeBuilder<ParseArgs>- Parameters:
aBannerBorderEscCode- The banner border Escape-Code to be stored by the banner border Escape-Code property.- Returns:
- The builder for applying multiple build operations.
-
withBannerEscapeCode
Sets the banner Escape-Code for the banner Escape-Code property.- Specified by:
withBannerEscapeCodein interfaceBannerEscapeCodeAccessor.BannerEscapeCodeBuilder<ParseArgs>- Parameters:
aBannerEscCode- The banner Escape-Code to be stored by the banner Escape-Code property.- Returns:
- The builder for applying multiple build operations.
-
withBannerFont
Sets the bannerFontfor the bannerFontproperty.- Specified by:
withBannerFontin interfaceBannerFontAccessor.BannerFontBuilder<ParseArgs>- Parameters:
aBannerFont- The bannerFontto be stored by the bannerFontproperty.- Returns:
- The builder for applying multiple build operations.
-
withBannerFontPalette
Sets the banner font palette for the banner font palette property.- Specified by:
withBannerFontPalettein interfaceBannerFontPaletteAccessor.BannerFontPaletteBuilder<ParseArgs>- Parameters:
aColorPalette- The banner font palette to be stored by the banner palette property.- Returns:
- The builder for applying multiple build operations.
-
withCommandEscapeCode
Sets the command Escape-Code for the command Escape-Code property.- Specified by:
withCommandEscapeCodein interfaceCommandEscapeCodeAccessor.CommandEscapeCodeBuilder<ParseArgs>- Parameters:
aCommandEscCode- The command Escape-Code to be stored by the command Escape-Code property.- Returns:
- The builder for applying multiple build operations.
-
withConsoleWidth
- Specified by:
withConsoleWidthin interfaceorg.refcodes.mixin.ConsoleWidthAccessor.ConsoleWidthBuilder<ParseArgs>
-
withCopyright
Sets the copyright for the copyright property.- Specified by:
withCopyrightin interfaceCopyrightAccessor.CopyrightBuilder<ParseArgs>- Parameters:
aCopyright- The copyright to be stored by the console width property.- Returns:
- The builder for applying multiple build operations.
-
withDescription
- Specified by:
withDescriptionin interfaceorg.refcodes.mixin.DescriptionAccessor.DescriptionBuilder<ParseArgs>
-
withDescriptionEscapeCode
Sets the description Escape-Code for the description Escape-Code property.- Specified by:
withDescriptionEscapeCodein interfaceDescriptionEscapeCodeAccessor.DescriptionEscapeCodeBuilder<ParseArgs>- Parameters:
aDescriptionEscCode- The description Escape-Code to be stored by the description Escape-Code property.- Returns:
- The builder for applying multiple build operations.
-
withErrorOut
Set the error outPrintStreamand make other adjustments with the result (with regards to the Builder-Pattern).- Specified by:
withErrorOutin interfaceArgsProcessorBuilder<ParseArgs>- Parameters:
aErrorOut- The error outPrintStreamto set.- Returns:
- This instance with regard to the builder pattern.
-
withEscapeCodesEnabled
- Specified by:
withEscapeCodesEnabledin interfaceorg.refcodes.mixin.EscapeCodesStatusAccessor.EscapeCodeStatusBuilder<ParseArgs>
-
withEvalArgs
Evaluates the provided command line arguments .- Specified by:
withEvalArgsin interfaceArgsParserBuilder<ParseArgs>- Parameters:
aArgs- The command line arguments to be evaluated.- Returns:
- This instance as of the builder pattern to chain further method calls.
- Throws:
ArgsSyntaxException- thrown in case of a command line arguments mismatch regarding provided and expected args.
-
withEvalArgs
Evaluates the provided command line arguments.- Specified by:
withEvalArgsin interfaceArgsParserBuilder<ParseArgs>- Parameters:
aArgs- The command line arguments to be evaluated.- Returns:
- This instance as of the builder pattern to chain further method calls.
- Throws:
ArgsSyntaxException- thrown in case of a command line arguments mismatch regarding provided and expected args.
-
withExamples
Builder method providing the application'sExampleelements.- Specified by:
withExamplesin interfaceExamplesAccessor.ExamplesBuilder<ParseArgs>- Parameters:
aExamples- The application'sExampleelements to use.- Returns:
- This builder as of the builder pattern.
-
withExamples
- Specified by:
withExamplesin interfaceExamplesAccessor.ExamplesBuilder<ParseArgs>- Parameters:
aExamples- TheExampleinstances to be stored.- Returns:
- The builder for applying multiple build operations.
-
withLicense
Sets the license for the license property.- Specified by:
withLicensein interfaceLicenseAccessor.LicenseBuilder<ParseArgs>- Parameters:
aLicense- The license to be stored by the console width property.- Returns:
- The builder for applying multiple build operations.
-
withLineBreak
- Specified by:
withLineBreakin interfaceorg.refcodes.mixin.LineBreakAccessor.LineBreakBuilder<ParseArgs>
-
withLineSeparatorEscapeCode
Sets the line separator Escape-Code for the line separator Escape-Code property.- Specified by:
withLineSeparatorEscapeCodein interfaceLineSeparatorEscapeCodeAccessor.LineSeparatorEscapeCodeBuilder<ParseArgs>- Parameters:
aLineSeparatorEscCode- The line separator Escape-Code to be stored by the line separator Escape-Code property.- Returns:
- The builder for applying multiple build operations.
-
withLongOptionPrefix
Sets the long option prefix for the long option prefix property.- Specified by:
withLongOptionPrefixin interfaceLongOptionPrefixAccessor.LongOptionPrefixBuilder<ParseArgs>- Parameters:
aLongOptionPrefix- The long option prefix to be stored by the long option prefix property.- Returns:
- The builder for applying multiple build operations.
-
withMaxConsoleWidth
- Specified by:
withMaxConsoleWidthin interfaceorg.refcodes.mixin.MaxConsoleWidthAccessor.MaxConsoleWidthBuilder<ParseArgs>
-
withName
- Specified by:
withNamein interfaceorg.refcodes.mixin.NameAccessor.NameBuilder<ParseArgs>
-
withOptionEscapeCode
Sets the option Escape-Code for the option Escape-Code property.- Specified by:
withOptionEscapeCodein interfaceOptionEscapeCodeAccessor.OptionEscapeCodeBuilder<ParseArgs>- Parameters:
aOptEscCode- The option Escape-Code to be stored by the option Escape-Code property.- Returns:
- The builder for applying multiple build operations.
-
withResetEscapeCode
- Specified by:
withResetEscapeCodein interfaceorg.refcodes.mixin.ResetEscapeCodeAccessor.ResetEscapeCodeBuilder<ParseArgs>
-
withSeparatorLnChar
Builder method adding an separator line char.- Specified by:
withSeparatorLnCharin interfaceArgsProcessorBuilder<ParseArgs>- Parameters:
aSeparatorLnChar- THe according separator line char to use.- Returns:
- This builder as of the builder pattern.
-
withShortOptionPrefix
Sets the short option prefix for the short option prefix property.- Specified by:
withShortOptionPrefixin interfaceShortOptionPrefixAccessor.ShortOptionPrefixBuilder<ParseArgs>- Parameters:
aShortOptionPrefix- The short option prefix to be stored by the short option prefix property.- Returns:
- The builder for applying multiple build operations.
-
withStandardOut
Set the standard outPrintStreamand make other adjustments with the result (with regards to the Builder-Pattern).- Specified by:
withStandardOutin interfaceArgsProcessorBuilder<ParseArgs>- Parameters:
aStandardOut- The standard outPrintStreamto set.- Returns:
- This instance with regard to the builder pattern.
-
withSyntaxMetrics
Sets theSyntaxMetricsfor theSyntaxMetricsproperty.- Specified by:
withSyntaxMetricsin interfaceSyntaxMetricsAccessor.SyntaxMetricsBuilder<ParseArgs>- Parameters:
aSyntaxMetrics- TheSyntaxMetricsto be stored by theSyntaxMetricsproperty.- Returns:
- The builder for applying multiple build operations.
-
withTextBoxGrid
- Specified by:
withTextBoxGridin interfaceorg.refcodes.textual.TextBoxGridAccessor.TextBoxGridBuilder<ParseArgs>
-
withTextBoxGrid
- Specified by:
withTextBoxGridin interfaceorg.refcodes.textual.TextBoxGridAccessor.TextBoxGridBuilder<ParseArgs>
-
withTitle
- Specified by:
withTitlein interfaceorg.refcodes.mixin.TitleAccessor.TitleBuilder<ParseArgs>
-