Class ParseArgsException
- All Implemented Interfaces:
Serializable, ArgsAccessor, MatchCountAccessor, ErrorCodeAccessor, Trap, SourceAccessor<Term>
- Direct Known Subclasses:
ParseDirectiveArgsException, ParseOptionArgsException
Thrown in case the provided command line arguments do not respect the
required semantics or cannot be converted to the required type.
- See Also:
-
Nested Class Summary
Nested classes/interfaces inherited from class CliException
CliException.CliArgsExceptionNested classes/interfaces inherited from interface ArgsAccessor
ArgsAccessor.ArgsMutator, ArgsAccessor.ArgsPropertyNested classes/interfaces inherited from interface ErrorCodeAccessor
ErrorCodeAccessor.ErrorCodeBuilder<B>, ErrorCodeAccessor.ErrorCodeMutator, ErrorCodeAccessor.ErrorCodePropertyNested classes/interfaces inherited from interface MatchCountAccessor
MatchCountAccessor.MatchCountBuilder<B>, MatchCountAccessor.MatchCountMutator, MatchCountAccessor.MatchCountPropertyNested classes/interfaces inherited from interface SourceAccessor
SourceAccessor.SourceBuilder<SRC,B>, SourceAccessor.SourceMutator<SRC>, SourceAccessor.SourceProperty<SRC> -
Field Summary
Fields inherited from class ArgsSyntaxException
_matchCount, _sourceFields inherited from class CliException.CliArgsException
_args -
Constructor Summary
ConstructorsConstructorDescriptionParseArgsException(String[] aArgs, Throwable aCause) Instantiates the classParseArgsException.ParseArgsException(String[] aArgs, Throwable aCause, String aErrorCode) Instantiates the classParseArgsException.ParseArgsException(String[] aArgs, Term aSource, Throwable aCause) Instantiates the classParseArgsException.ParseArgsException(String[] aArgs, Term aSource, Throwable aCause, String aErrorCode) Instantiates the classParseArgsException.ParseArgsException(String aMessage, String[] aArgs) Instantiates the classParseArgsException.ParseArgsException(String aMessage, String[] aArgs, String aErrorCode) Instantiates the classParseArgsException.ParseArgsException(String aMessage, String[] aArgs, Throwable aCause) Instantiates the classParseArgsException.ParseArgsException(String aMessage, String[] aArgs, Throwable aCause, String aErrorCode) Instantiates the classParseArgsException.ParseArgsException(String aMessage, String[] aArgs, Term aSource) Instantiates the classParseArgsException.ParseArgsException(String aMessage, String[] aArgs, Term aSource, String aErrorCode) Instantiates the classParseArgsException.ParseArgsException(String aMessage, String[] aArgs, Term aSource, Throwable aCause) Instantiates the classParseArgsException.ParseArgsException(String aMessage, String[] aArgs, Term aSource, Throwable aCause, String aErrorCode) Instantiates the classParseArgsException. -
Method Summary
Methods inherited from class ArgsSyntaxException
getMatchCount, getPatternArguments, getSource, toHeuristicMessage, toRootMatchCauseMethods inherited from class CliException.CliArgsException
getArgsMethods inherited from class AbstractException
getErrorCode, getMessageMethods inherited from class Throwable
addSuppressed, fillInStackTrace, getCause, getLocalizedMessage, getStackTrace, getSuppressed, initCause, printStackTrace, printStackTrace, printStackTrace, setStackTrace, toStringMethods inherited from class Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface Trap
toLocalizedMessage, toMessage, toMessage, toMessage, toShortLocalizedMessage, toShortMessage
-
Constructor Details
-
ParseArgsException
Instantiates the classParseArgsException.- See Also:
-
ParseArgsException
Instantiates the classParseArgsException.- See Also:
-
ParseArgsException
Instantiates the classParseArgsException.- See Also:
-
ParseArgsException
-
ParseArgsException
Instantiates the classParseArgsException.- See Also:
-
ParseArgsException
Instantiates the classParseArgsException.- See Also:
-
ParseArgsException
Instantiates the classParseArgsException.- See Also:
-
ParseArgsException
Instantiates the classParseArgsException.- See Also:
-
ParseArgsException
Instantiates the classParseArgsException.- See Also:
-
ParseArgsException
Instantiates the classParseArgsException.- See Also:
-
ParseArgsException
Instantiates the classParseArgsException.- See Also:
-
ParseArgsException
Instantiates the classParseArgsException.- See Also:
-