Interface ParsedArgsAccessor

  • Method Details

    • getParsedArgs

      String[] getParsedArgs()
      Retrieves the command line arguments from the parsed args property.
      Returns:
      The command line arguments stored by the parsed args property.