- All Known Subinterfaces:
ParsedArgsAccessor.ParsedArgsProperty
- Enclosing interface:
ParsedArgsAccessor
public static interface ParsedArgsAccessor.ParsedArgsMutator
Provides a mutator for a parsed args property.
-
Method Summary
Modifier and TypeMethodDescriptionvoidsetParsedArgs(String[] aParsedArgs) Sets the command line arguments for the parsed args property.
-
Method Details
-
setParsedArgs
Sets the command line arguments for the parsed args property.- Parameters:
aParsedArgs- The command line arguments to be stored by the args property.
-