Interface Property<T>

Type Parameters:
T - The generic type of the Property's value.
All Superinterfaces:
AliasAccessor, Clonable, Cloneable, Comparable<Operand<?>>, DescriptionAccessor, Diagnosable, ExceptionAccessor<ArgsSyntaxException>, MatchCountAccessor, Operand<T>, Option<T>, ParsedArgsAccessor, Resetable, Schemable<DiagnosticOptions>, Synopsisable, Term, TypeAccessor<T>, ValueAccessor<T>, VisibleAccessor, VisibleAccessor.VisibleBuilder<Term>, VisibleAccessor.VisibleMutator, VisibleAccessor.VisibleProperty
All Known Implementing Classes:
AbstractProperty, BooleanProperty, CharProperty, ConfigProperty, DoubleProperty, EnumProperty, FileProperty, FloatProperty, IntProperty, LongProperty, StringProperty

public interface Property<T> extends Option<T>
An Property represents an option property with the according porperty's key and value separated by a = (and no whitespace inbetween). A Property can be seen as a key=value pair and is passed in a single argument as such (e.g. "--file=someFile"). A Property has a state which changes with each invocation of the Term.parseArgs(String[], String[], CliContext) method.
  • Method Details

    • toSpec

      default String toSpec(CliContext aCliCtx)
      Creates a specification including its arguments.

      A specification differs from a syntax in that the specification provides the full definition not omitting any choices whereas the syntax only provides a syntactically correct variant. For example, having an option with a short option and a long option, the specification will show the short option and the long option whereas the syntax will only show either the short option or, if no short option is set, the long option.

      Specified by:
      toSpec in interface Operand<T>
      Specified by:
      toSpec in interface Option<T>
      Parameters:
      aCliCtx - The CliContext to use when creating a beautiful specification text.
      Returns:
      The according specification text.
    • toSyntax

      default String toSyntax(CliContext aCliCtx)
      Creates a syntax including its arguments.

      A specification differs from a syntax in that the specification provides the full definition not omitting any choices whereas the syntax only provides a syntactically correct variant. For example, having an option with a short option and a long option, the specification will show the short option and the long option whereas the syntax will only show either the short option or, if no short option is set, the long option.

      Specified by:
      toSyntax in interface Operand<T>
      Specified by:
      toSyntax in interface Option<T>
      Specified by:
      toSyntax in interface Term
      Parameters:
      aCliCtx - The CLI context controlling notation and formatting
      Returns:
      The human readable command line syntax