Class QuietFlag
- All Implemented Interfaces:
Cloneable, Comparable<Operand<?>>, MatchCountAccessor, Operand<Boolean>, Option<Boolean>, ParsedArgsAccessor, Synopsisable, Term, ExceptionAccessor<ArgsSyntaxException>, VisibleAccessor, VisibleAccessor.VisibleBuilder<Term>, VisibleAccessor.VisibleMutator, VisibleAccessor.VisibleProperty, AliasAccessor, Clonable, DescriptionAccessor, EnabledAccessor, Resetable, TypeAccessor<Boolean>, ValueAccessor<Boolean>, Diagnosable, Schemable<DiagnosticOptions>
A predefined "be quiet"
Flag: A predefined Flag gives its
SHORT_OPTION, its LONG_OPTION as well as its ALIAS
an according semantics regarded by other subsystems.-
Nested Class Summary
Nested classes/interfaces inherited from interface AliasAccessor
AliasAccessor.AliasBuilder<B>, AliasAccessor.AliasMutator, AliasAccessor.AliasPropertyNested classes/interfaces inherited from interface DescriptionAccessor
DescriptionAccessor.DescriptionBuilder<B>, DescriptionAccessor.DescriptionMutator, DescriptionAccessor.DescriptionPropertyNested classes/interfaces inherited from interface EnabledAccessor
EnabledAccessor.EnabledBuilder<B>, EnabledAccessor.EnabledMutator, EnabledAccessor.EnabledPropertyNested classes/interfaces inherited from interface ExceptionAccessor
ExceptionAccessor.ExceptionBuilder<EXC,B>, ExceptionAccessor.ExceptionMutator<EXC>, ExceptionAccessor.ExceptionProperty<EXC> Nested classes/interfaces inherited from interface MatchCountAccessor
MatchCountAccessor.MatchCountBuilder<B>, MatchCountAccessor.MatchCountMutator, MatchCountAccessor.MatchCountPropertyNested classes/interfaces inherited from interface ParsedArgsAccessor
ParsedArgsAccessor.ParsedArgsMutator, ParsedArgsAccessor.ParsedArgsPropertyNested classes/interfaces inherited from interface TypeAccessor
TypeAccessor.TypeBuilder<T,B>, TypeAccessor.TypeMutator<T>, TypeAccessor.TypeProperty<T> Nested classes/interfaces inherited from interface ValueAccessor
ValueAccessor.ValueBuilder<V,B>, ValueAccessor.ValueMutator<V>, ValueAccessor.ValueProperty<V> Nested classes/interfaces inherited from interface VisibleAccessor
VisibleAccessor.VisibleBuilder<B>, VisibleAccessor.VisibleMutator, VisibleAccessor.VisibleProperty -
Field Summary
FieldsModifier and TypeFieldDescriptionprotected Stringprotected ArgsSyntaxExceptionprotected booleanstatic final Stringstatic final Stringstatic final CharacterFields inherited from class AbstractOperand
_matchCount -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionRetrieves theArgsSyntaxExceptionexception in case invokingTerm.parseArgs(String[], CliContext)failed.booleanvoidsetVisible(boolean isVisible) protected static String[]toArgsDiff(String[] aArgs, String[] aArgsSubset) Creates the difference between the provided set and the provided subset.protected static String[]toArgsDiff(String[] aArgs, List<? extends Operand<?>> aArgsSubset) Creates the difference between the provided set and the providedLists therein found argument arrays subset (as ofOperand.getParsedArgs()).protected static String[]toArgsDiff(String[] aArgs, Operand<?>[] aArgsSubset) Creates the difference between the provided set and the providedLists therein found argument arrays subset (as ofOperand.getParsedArgs()).protected static String[]toParsedArgs(Operand<?>[]... aOperands) Takes allOperandinstances found in the providedLists and adds all therein found argument arrays (as ofOperand.getParsedArgs()) to the result.Methods inherited from class Flag
isEnabled, parseArgs, reset, toSpec, toSyntax, toType, withVisibleMethods inherited from class AbstractOption
clone, contains, getLongOption, getShortOption, setParsedArgs, setValue, toException, toSchema, toStringMethods inherited from class AbstractOperand
approve, compareTo, getAlias, getMatchCount, getParsedArgs, getType, getValueMethods inherited from class Object
equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface Comparable
compareToMethods inherited from interface DescriptionAccessor
getDescriptionMethods inherited from interface Operand
getAlias, getParsedArgs, getValue, hasValue, toSpec, toSpec, toSpec, toSpec, toUsage, toValueMethods inherited from interface Option
toKeywords, toLongOption, toShortOption, toUsageMethods inherited from interface Synopsisable
toSynopsis, toSynopsis, toSynopsis, toSynopsisMethods inherited from interface Term
argsParser, getException, getMatchCount, isVisible, parseArgs, setVisible, toSynopsis, toSyntax, toSyntax, toSyntax, toSyntaxMethods inherited from interface TypeAccessor
getTypeMethods inherited from interface ValueAccessor
getValueOrMethods inherited from interface VisibleAccessor
isHiddenMethods inherited from interface VisibleAccessor.VisibleBuilder
withHide, withShowMethods inherited from interface VisibleAccessor.VisibleMutator
hide, showMethods inherited from interface VisibleAccessor.VisibleProperty
letVisible
-
Field Details
-
ALIAS
- See Also:
-
LONG_OPTION
- See Also:
-
SHORT_OPTION
-
_description
-
_exception
-
_isVisible
protected boolean _isVisible
-
-
Constructor Details
-
Method Details
-
getDescription
- Specified by:
getDescriptionin interfaceDescriptionAccessor
-
getException
Retrieves theArgsSyntaxExceptionexception in case invokingTerm.parseArgs(String[], CliContext)failed. The exception (and the according suppressed ones alongside the causes) does not necessarily have been thrown by theTerm.parseArgs(String[], CliContext)method depending on the semantics of theTermhanding the exception (theAnyConditionprovides any exceptions it caught even though it did not throw them as of its semantics).- Specified by:
getExceptionin interfaceExceptionAccessor<ArgsSyntaxException>- Specified by:
getExceptionin interfaceTerm- Returns:
- The
ArgsSyntaxExceptionexception occurring while parsing the arguments.
-
setVisible
public void setVisible(boolean isVisible) Visibility in this context means displaying or hiding this
Term's existence to the user (defaults totrue).- Specified by:
setVisiblein interfaceTerm- Specified by:
setVisiblein interfaceVisibleAccessor.VisibleMutator
-
isVisible
public boolean isVisible()Visibility in this context means displaying or hiding this
Term's existence to the user (defaults totrue).- Specified by:
isVisiblein interfaceTerm- Specified by:
isVisiblein interfaceVisibleAccessor
-
toArgsDiff
Creates the difference between the provided set and the providedLists therein found argument arrays subset (as ofOperand.getParsedArgs()).- Parameters:
aArgs- The set to be used for the diff operation.aArgsSubset- The subset to be used for the diff operation being the lists containing theOperandinstances whose command line arguments are to be diffed.- Returns:
- The difference between the set and the subset.
-
toArgsDiff
Creates the difference between the provided set and the providedLists therein found argument arrays subset (as ofOperand.getParsedArgs()).- Parameters:
aArgs- The set to be used for the diff operation.aArgsSubset- The subset to be used for the diff operation being the lists containing theOperandinstances whose command line arguments are to be diffed.- Returns:
- The difference between the set and the subset.
-
toArgsDiff
Creates the difference between the provided set and the provided subset.- Parameters:
aArgs- The set to be used for the diff operation.aArgsSubset- The subset to be used for the diff operation.- Returns:
- The difference between the set and the subset.
-
toParsedArgs
Takes allOperandinstances found in the providedLists and adds all therein found argument arrays (as ofOperand.getParsedArgs()) to the result.
-