- All Known Subinterfaces:
ArgsParser,RootConditionAccessor.RootConditionProperty
- All Known Implementing Classes:
ArgsParserImpl
public interface RootConditionAccessor
Provides an accessor for a root condition property.
-
Nested Class Summary
Nested ClassesModifier and TypeInterfaceDescriptionstatic interfaceProvides a builder method for a root condition property returning the builder for applying multiple build operations.static interfaceProvides a mutator for a root condition property.static interfaceProvides a root condition property. -
Method Summary
Modifier and TypeMethodDescriptionRetrieves the root condition from the root condition property.
-
Method Details
-
getArgsSyntax
ArgsSyntax getArgsSyntax()Retrieves the root condition from the root condition property.- Returns:
- The root condition stored by the root condition property.
-