Module org.refcodes.cli
Package org.refcodes.cli
Interface RootConditionAccessor.RootConditionBuilder<B extends RootConditionAccessor.RootConditionBuilder<B>>
-
- Type Parameters:
B- The builder to return in order to be able to apply multiple build operations.
- Enclosing interface:
- RootConditionAccessor
public static interface RootConditionAccessor.RootConditionBuilder<B extends RootConditionAccessor.RootConditionBuilder<B>>Provides a builder method for a root condition property returning the builder for applying multiple build operations.
-
-
Method Summary
All Methods Instance Methods Abstract Methods Default Methods Modifier and Type Method Description BwithRootArgsSyntax(ArgsSyntax aRootArgsSyntax)Sets the root condition for the root condition property.default BwithRootOption(Option<?> aRootOption)Sets the root option for the root condition property.
-
-
-
Method Detail
-
withRootArgsSyntax
B withRootArgsSyntax(ArgsSyntax aRootArgsSyntax)
Sets the root condition for the root condition property.- Parameters:
aRootArgsSyntax- The root condition to be stored by the root condition property.- Returns:
- The builder for applying multiple build operations.
-
withRootOption
default B withRootOption(Option<?> aRootOption)
Sets the root option for the root condition property. Convenience method wrapping anOptioninto aOptionConditionand passing it to thewithRootArgsSyntax(ArgsSyntax)method.- Parameters:
aRootOption- The root condition to be stored by the root condition property.- Returns:
- The builder for applying multiple build operations.
-
-