Module org.refcodes.cli
Package org.refcodes.cli
Interface RootConditionAccessor.RootConditionMutator
- All Known Subinterfaces:
RootConditionAccessor.RootConditionProperty
- Enclosing interface:
RootConditionAccessor
public static interface RootConditionAccessor.RootConditionMutator
Provides a mutator for a root condition property.
-
Method Summary
Modifier and TypeMethodDescriptionvoidsetRootArgsSyntax(ArgsSyntax aRootArgsSyntax) Sets the root condition for the root condition property.default voidsetRootOption(Option<?> aRootOption) Sets the root option for the root condition property.
-
Method Details
-
setRootArgsSyntax
Sets the root condition for the root condition property.- Parameters:
aRootArgsSyntax- The root condition to be stored by the root condition property.
-
setRootOption
Sets the root option for the root condition property. Convenience method wrapping anOptioninto aOptionConditionand passing it to thesetRootArgsSyntax(ArgsSyntax)method.- Parameters:
aRootOption- The root option to be stored by the root condition property.
-