Module org.refcodes.cli
Package org.refcodes.cli
Interface RootConditionAccessor.RootConditionProperty
- All Superinterfaces:
RootConditionAccessor,RootConditionAccessor.RootConditionMutator
- Enclosing interface:
RootConditionAccessor
public static interface RootConditionAccessor.RootConditionProperty
extends RootConditionAccessor, RootConditionAccessor.RootConditionMutator
Provides a root condition property.
-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.cli.RootConditionAccessor
RootConditionAccessor.RootConditionBuilder<B extends RootConditionAccessor.RootConditionBuilder<B>>, RootConditionAccessor.RootConditionMutator, RootConditionAccessor.RootConditionProperty -
Method Summary
Modifier and TypeMethodDescriptiondefault ArgsSyntaxletRootArgsSyntax(ArgsSyntax aRootArgsSyntax) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenArgsSyntax(setter) as ofRootConditionAccessor.RootConditionMutator.setRootArgsSyntax(ArgsSyntax)and returns the very same value (getter).Methods inherited from interface org.refcodes.cli.RootConditionAccessor
getArgsSyntaxMethods inherited from interface org.refcodes.cli.RootConditionAccessor.RootConditionMutator
setRootArgsSyntax, setRootOption
-
Method Details
-
letRootArgsSyntax
This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenArgsSyntax(setter) as ofRootConditionAccessor.RootConditionMutator.setRootArgsSyntax(ArgsSyntax)and returns the very same value (getter).- Parameters:
aRootArgsSyntax- TheArgsSyntaxto set (viaRootConditionAccessor.RootConditionMutator.setRootArgsSyntax(ArgsSyntax)).- Returns:
- Returns the value passed for it to be used in conclusive processing steps.
-