- All Known Subinterfaces:
ShortOptionAccessor.ShortOptionProperty
- All Known Implementing Classes:
ParseOptionArgsException,UnknownOptionArgsException
public interface ShortOptionAccessor
Provides an accessor for a short option property.
-
Nested Class Summary
Nested ClassesModifier and TypeInterfaceDescriptionstatic interfaceProvides a builder method for a short option property returning the builder for applying multiple build operations.static interfaceProvides a mutator for a short option property.static interfaceProvides a short option property. -
Method Summary
Modifier and TypeMethodDescriptionRetrieves the short option from the short option property.
-
Method Details
-
getShortOption
String getShortOption()Retrieves the short option from the short option property.- Returns:
- The short option stored by the short option property.
-