Interface SyntaxMetrics
- All Superinterfaces:
ArgumentPrefixAccessor,ArgumentSuffixAccessor,LongOptionPrefixAccessor,ShortOptionPrefixAccessor
- All Known Implementing Classes:
SyntaxMetricsBuilder,SyntaxNotation
public interface SyntaxMetrics
extends ShortOptionPrefixAccessor, LongOptionPrefixAccessor, ArgumentPrefixAccessor, ArgumentSuffixAccessor
The
SyntaxMetrics provides properties specific to a specific command
line syntax notation.-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.cli.ArgumentPrefixAccessor
ArgumentPrefixAccessor.ArgumentPrefixBuilder<B extends ArgumentPrefixAccessor.ArgumentPrefixBuilder<B>>, ArgumentPrefixAccessor.ArgumentPrefixMutator, ArgumentPrefixAccessor.ArgumentPrefixPropertyNested classes/interfaces inherited from interface org.refcodes.cli.ArgumentSuffixAccessor
ArgumentSuffixAccessor.ArgumentSuffixBuilder<B extends ArgumentSuffixAccessor.ArgumentSuffixBuilder<B>>, ArgumentSuffixAccessor.ArgumentSuffixMutator, ArgumentSuffixAccessor.ArgumentSuffixPropertyNested classes/interfaces inherited from interface org.refcodes.cli.LongOptionPrefixAccessor
LongOptionPrefixAccessor.LongOptionPrefixBuilder<B extends LongOptionPrefixAccessor.LongOptionPrefixBuilder<B>>, LongOptionPrefixAccessor.LongOptionPrefixMutator, LongOptionPrefixAccessor.LongOptionPrefixPropertyNested classes/interfaces inherited from interface org.refcodes.cli.ShortOptionPrefixAccessor
ShortOptionPrefixAccessor.ShortOptionPrefixBuilder<B extends ShortOptionPrefixAccessor.ShortOptionPrefixBuilder<B>>, ShortOptionPrefixAccessor.ShortOptionPrefixMutator, ShortOptionPrefixAccessor.ShortOptionPrefixProperty -
Method Summary
Modifier and TypeMethodDescriptionstatic SyntaxMetricsBuilder.Builderbuilder()Creates aSyntaxMetricsBuilder.Builderused to fluently constructSyntaxMetricsinstances.Retrieves the symbol for representing an ALL condition.Retrieves the symbol for representing an AND condition.Retrieves the symbol for representing an OPTIONAL condition.The assignment operator to be used in the syntax for separating a name from a value.Retrieves the symbol representing the beginning of an array, e.g. an opening square brace.Retrieves the symbol representing the beginning of a list, e.g. an opening brace.Retrieves the symbol representing the beginning of optional elements, e.g. an opening square brace.Retrieves the symbol representing the beginning of a range, e.g. an opening curly brace.Retrieves the symbol for representing an EMPTY condition (no args).Retrieves the symbol representing the end of an array, e.g. a closing square brace.Retrieves the symbol representing the end of a list, e.g. a closing brace.Retrieves the symbol representing the end of optional elements, e.g. a closing square brace.Retrieves the symbol representing the end of a range, e.g. a closing curly brace.Retrieves the symbol representing an interval, e.g. "..." or "-".Retrieves the symbol for representing an OR condition.In case of unknowingly (name, alias, value), the provided symbol should be usedRetrieves the symbol for representing an XOR condition.default String[]Returns an array of the prefixes configured by thisSyntaxMetricsinstance, omitting any null or empty prefixes as well as any duplicates.Methods inherited from interface org.refcodes.cli.ArgumentPrefixAccessor
getArgumentPrefixMethods inherited from interface org.refcodes.cli.ArgumentSuffixAccessor
getArgumentSuffixMethods inherited from interface org.refcodes.cli.LongOptionPrefixAccessor
getLongOptionPrefixMethods inherited from interface org.refcodes.cli.ShortOptionPrefixAccessor
getShortOptionPrefix
-
Method Details
-
getAllSymbol
String getAllSymbol()Retrieves the symbol for representing an ALL condition.- Returns:
- The according ALL symbol.
-
getAndSymbol
String getAndSymbol()Retrieves the symbol for representing an AND condition.- Returns:
- The according AND symbol.
-
getAnySymbol
String getAnySymbol()Retrieves the symbol for representing an OPTIONAL condition.- Returns:
- The according OPTIONAL symbol.
-
getBeginArraySymbol
String getBeginArraySymbol()Retrieves the symbol representing the beginning of an array, e.g. an opening square brace.- Returns:
- The symbol representing the beginning of an array.
-
getBeginListSymbol
String getBeginListSymbol()Retrieves the symbol representing the beginning of a list, e.g. an opening brace.- Returns:
- The symbol representing the beginning of a list.
-
getBeginOptionalSymbol
String getBeginOptionalSymbol()Retrieves the symbol representing the beginning of optional elements, e.g. an opening square brace.- Returns:
- The symbol representing the beginning of optional elements.
-
getBeginRangeSymbol
String getBeginRangeSymbol()Retrieves the symbol representing the beginning of a range, e.g. an opening curly brace.- Returns:
- The symbol representing the beginning of a range.
-
getEmptySymbol
String getEmptySymbol()Retrieves the symbol for representing an EMPTY condition (no args).- Returns:
- The according EMPTY symbol.
-
getEndArraySymbol
String getEndArraySymbol()Retrieves the symbol representing the end of an array, e.g. a closing square brace.- Returns:
- The symbol representing the end of an array.
-
getEndListSymbol
String getEndListSymbol()Retrieves the symbol representing the end of a list, e.g. a closing brace.- Returns:
- The symbol representing the end of a list.
-
getEndOptionalSymbol
String getEndOptionalSymbol()Retrieves the symbol representing the end of optional elements, e.g. a closing square brace.- Returns:
- The symbol representing the end of a optional elements.
-
getEndRangeSymbol
String getEndRangeSymbol()Retrieves the symbol representing the end of a range, e.g. a closing curly brace.- Returns:
- The symbol representing the end of a range.
-
getIntervalSymbol
String getIntervalSymbol()Retrieves the symbol representing an interval, e.g. "..." or "-".- Returns:
- The symbol representing an interval.
-
getOrSymbol
String getOrSymbol()Retrieves the symbol for representing an OR condition.- Returns:
- The according OR symbol.
-
getXorSymbol
String getXorSymbol()Retrieves the symbol for representing an XOR condition.- Returns:
- The according XOR symbol.
-
getUndefinedSymbol
String getUndefinedSymbol()In case of unknowingly (name, alias, value), the provided symbol should be used- Returns:
- The symbol to be used for unknown things.
-
getAssignmentOperator
String getAssignmentOperator()The assignment operator to be used in the syntax for separating a name from a value.- Returns:
- The assignment operator.
-
toOptionPrefixes
Returns an array of the prefixes configured by thisSyntaxMetricsinstance, omitting any null or empty prefixes as well as any duplicates.- Returns:
- The array containing the configured options' prefixes.
-
builder
Creates aSyntaxMetricsBuilder.Builderused to fluently constructSyntaxMetricsinstances.- Returns:
- The
SyntaxMetricsBuilder.Builderfor constructingSyntaxMetricsinstances.
-