Module org.refcodes.cli
Package org.refcodes.cli
Interface SyntaxMetricsAccessor.SyntaxMetricsProperty
- All Superinterfaces:
SyntaxMetricsAccessor,SyntaxMetricsAccessor.SyntaxMetricsMutator
- All Known Subinterfaces:
ParseArgs
- All Known Implementing Classes:
ArgsParser
- Enclosing interface:
- SyntaxMetricsAccessor
public static interface SyntaxMetricsAccessor.SyntaxMetricsProperty
extends SyntaxMetricsAccessor, SyntaxMetricsAccessor.SyntaxMetricsMutator
Provides a
SyntaxMetrics property.-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.cli.SyntaxMetricsAccessor
SyntaxMetricsAccessor.SyntaxMetricsBuilder<B extends SyntaxMetricsAccessor.SyntaxMetricsBuilder<B>>, SyntaxMetricsAccessor.SyntaxMetricsMutator, SyntaxMetricsAccessor.SyntaxMetricsProperty -
Method Summary
Modifier and TypeMethodDescriptiondefault SyntaxMetricsletSyntaxMetrics(SyntaxMetrics aSyntaxMetrics) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenSyntaxMetrics(setter) as ofSyntaxMetricsAccessor.SyntaxMetricsMutator.setSyntaxMetrics(SyntaxMetrics)and returns the very same value (getter).default SyntaxNotationletSyntaxMetrics(SyntaxNotation aSyntaxNotation) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenSyntaxNotation(setter) as ofSyntaxMetricsAccessor.SyntaxMetricsMutator.setSyntaxMetrics(SyntaxNotation)and returns the very same value (getter).Methods inherited from interface org.refcodes.cli.SyntaxMetricsAccessor
getSyntaxMetricsMethods inherited from interface org.refcodes.cli.SyntaxMetricsAccessor.SyntaxMetricsMutator
setSyntaxMetrics, setSyntaxMetrics
-
Method Details
-
letSyntaxMetrics
This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenSyntaxMetrics(setter) as ofSyntaxMetricsAccessor.SyntaxMetricsMutator.setSyntaxMetrics(SyntaxMetrics)and returns the very same value (getter).- Parameters:
aSyntaxMetrics- TheSyntaxMetricsto set (viaSyntaxMetricsAccessor.SyntaxMetricsMutator.setSyntaxMetrics(SyntaxMetrics)).- Returns:
- Returns the value passed for it to be used in conclusive processing steps.
-
letSyntaxMetrics
This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenSyntaxNotation(setter) as ofSyntaxMetricsAccessor.SyntaxMetricsMutator.setSyntaxMetrics(SyntaxNotation)and returns the very same value (getter).- Parameters:
aSyntaxNotation- TheSyntaxNotationto set (viaSyntaxMetricsAccessor.SyntaxMetricsMutator.setSyntaxMetrics(SyntaxNotation)).- Returns:
- Returns the value passed for it to be used in conclusive processing steps.
-