- All Superinterfaces:
org.refcodes.mixin.Resetable,org.refcodes.mixin.Schemable<CliSchema>,Synopsisable
- All Known Subinterfaces:
ArgsSyntax,Condition,Operand<T>,Option<T>
- All Known Implementing Classes:
AbstractCondition,AbstractOperand,AbstractOption,AllCondition,AndCondition,AnyCondition,ArrayOperand,ArrayOption,CasesCondition,CharOption,CleanFlag,ConfigOption,DaemonFlag,DebugFlag,DoubleOption,EnumOption,FileOption,Flag,FloatOption,ForceFlag,HelpFlag,InitFlag,IntOption,LongOption,NoneOperand,Operation,OptionCondition,OrCondition,QuietFlag,StringOperand,StringOption,SysInfoFlag,VerboseFlag,XorCondition
public interface Syntaxable
extends org.refcodes.mixin.Resetable, Synopsisable, org.refcodes.mixin.Schemable<CliSchema>
A
Syntaxable defines the methods at least required when building a
command line arguments syntax tree for traversing the syntax tree; either for
parsing command line arguments or for constructing the command line arguments
syntax. By providing various implementations of the Syntaxable's
subclasses such as Operand, Option or ArgsSyntax, a
command line arguments syntax tree can be constructed. This syntax tree can
be use to create a human readable (verbose) command line arguments syntax and
to parse an array of command line arguments for determining the
Operands', the Flages' or the Options' values.-
Method Summary
Modifier and TypeMethodDescriptionParses the provided command line arguments and determines the according values by evaluating thisSyntaxableinstance or, in case of being a node in the syntax tree (such as aArgsSyntax, traversing the childSyntaxableinstances'parseArgs(String[], String[])methods.Parses the provided command line arguments and determines the according values by evaluating thisSyntaxableinstance or, in case of being a node in the syntax tree (such as aArgsSyntax, traversing the childSyntaxableinstances'parseArgs(String[], String[])methods.toState()ThetoState()method might be used by theObject.toString()method and prints out the state of the syntaxable and (if any) its children.default StringtoSyntax()This method is to be called from inside theSyntaxablehierarchy; use the methodSynopsisable.toSynopsis(SyntaxNotation)in case you invoke syntax retrieval from the rootSyntaxable.default StringThis method is to be called from inside theSyntaxablehierarchy; use the methodSynopsisable.toSynopsis(SyntaxNotation)in case you invoke syntax retrieval from the rootSyntaxable.default StringtoSyntax(SyntaxNotation aSyntaxNotation) This method is to be called from inside theSyntaxablehierarchy; use the methodSynopsisable.toSynopsis(SyntaxNotation)in case you invoke syntax retrieval from the rootSyntaxable.toSyntax(SyntaxNotation aSyntaxNotation, String aOptEscCode, String aParamEscCode, String aResetEscCode) This method is to be called from inside theSyntaxablehierarchy; use the methodSynopsisable.toSynopsis(SyntaxNotation)in case you invoke syntax retrieval from the rootSyntaxable.<V> VSearches for a value being set for the given for given alias in the syntax tree parsing the command line arguments; if a node in the syntax tree has a value for the given alias, then this value is returned.Methods inherited from interface org.refcodes.mixin.Resetable
resetMethods inherited from interface org.refcodes.mixin.Schemable
toSchemaMethods inherited from interface org.refcodes.cli.Synopsisable
toSynopsis, toSynopsis, toSynopsis, toSynopsis
-
Method Details
-
toSyntax
This method is to be called from inside theSyntaxablehierarchy; use the methodSynopsisable.toSynopsis(SyntaxNotation)in case you invoke syntax retrieval from the rootSyntaxable. Returns the human readable (verbose) syntax of thisSyntaxableinstance including, in case of being a node in the syntax tree (such as aArgsSyntax, the syntax of the childSyntaxableinstances. ATTENTION: As of different parenthesis settings for some notations regarding the rootSyntaxableand the childSyntaxables, the methodtoSyntax(SyntaxNotation, String, String, String)is called from inside theSyntaxablehierarchy. In case the syntax is to be retrieved from the rootSyntaxable, then the applicable method to be called isSynopsisable.toSynopsis(SyntaxNotation), as for some notations it will for example not create the most outer braces.- Parameters:
aSyntaxNotation- The syntax notation used for generating the command line arguments syntax.- Returns:
- The human readable (verbose) command line arguments syntax.
-
toSyntax
This method is to be called from inside theSyntaxablehierarchy; use the methodSynopsisable.toSynopsis(SyntaxNotation)in case you invoke syntax retrieval from the rootSyntaxable. Returns the human readable (verbose) syntax of thisSyntaxableinstance including, in case of being a node in the syntax tree (such as aArgsSyntax, the syntax of the childSyntaxableinstances. ATTENTION: As of different parenthesis settings for some notations regarding the rootSyntaxableand the childSyntaxables, the methodtoSyntax(SyntaxNotation, String, String, String)is called from inside theSyntaxablehierarchy. In case the syntax is to be retrieved from the rootSyntaxable, then the applicable method to be called isSynopsisable.toSynopsis(SyntaxNotation), as for some notations it will for example not create the most outer braces. This method uses theSyntaxNotation.REFCODESbe default!- Returns:
- The human readable (verbose) command line arguments syntax.
-
toSyntax
This method is to be called from inside theSyntaxablehierarchy; use the methodSynopsisable.toSynopsis(SyntaxNotation)in case you invoke syntax retrieval from the rootSyntaxable. Returns the human readable (verbose) syntax of thisSyntaxableinstance including, in case of being a node in the syntax tree (such as aArgsSyntax, the syntax of the childSyntaxableinstances. ATTENTION: As of different parenthesis settings for some notations regarding the rootSyntaxableand the childSyntaxables, the methodtoSyntax(SyntaxNotation, String, String, String)is called from inside theSyntaxablehierarchy. In case the syntax is to be retrieved from the rootSyntaxable, then the applicable method to be called isSynopsisable.toSynopsis(SyntaxNotation), as for some notations it will for example not create the most outer braces. This method uses theSyntaxNotation.REFCODESbe default!- Parameters:
aOptEscCode- The escape code to be used when processing an option, e.g. this can be an ANSI Escape-Code to highlight the option.aParamEscCode- The escape code to be used when processing a keyword, e.g. this can be an ANSI Escape-Code to highlight the option and/or parameters.aResetEscCode- The escape code to close (reset) any Escape-Code being set before.- Returns:
- The human readable (verbose) command line arguments syntax.
-
toSyntax
String toSyntax(SyntaxNotation aSyntaxNotation, String aOptEscCode, String aParamEscCode, String aResetEscCode) This method is to be called from inside theSyntaxablehierarchy; use the methodSynopsisable.toSynopsis(SyntaxNotation)in case you invoke syntax retrieval from the rootSyntaxable. Returns the human readable (verbose) syntax of thisSyntaxableinstance including, in case of being a node in the syntax tree (such as aArgsSyntax, the syntax of the childSyntaxableinstances. ATTENTION: As of different parenthesis settings for some notations regarding the rootSyntaxableand the childSyntaxables, the methodtoSyntax(SyntaxNotation, String, String, String)is called from inside theSyntaxablehierarchy. In case the syntax is to be retrieved from the rootSyntaxable, then the applicable method to be called isSynopsisable.toSynopsis(SyntaxNotation), as for some notations it will for example not create the most outer braces.- Parameters:
aSyntaxNotation- The syntax notation used for generating the command line arguments syntax.aOptEscCode- The escape code to be used when processing an option, e.g. this can be an ANSI Escape-Code to highlight the option.aParamEscCode- The escape code to be used when processing a keyword, e.g. this can be an ANSI Escape-Code to highlight the option and/or parameters.aResetEscCode- The escape code to close (reset) any Escape-Code being set before.- Returns:
- The human readable (verbose) command line arguments syntax.
-
parseArgs
Parses the provided command line arguments and determines the according values by evaluating thisSyntaxableinstance or, in case of being a node in the syntax tree (such as aArgsSyntax, traversing the childSyntaxableinstances'parseArgs(String[], String[])methods. In case of successfully parsing thisSyntaxableand / or the childSyntaxableinstances, the evaluated command line arguments are returned: Depending on theSyntaxablesubclasses representing the evaluated command line arguments, instances ofFlagclasses,Optionclasses orOperandclasses may be found in the result. In case of parsing failure, an according exception is thrown. ATTENTION: This method does not test for superfluous command line arguments being passed; e.g. command line arguments not being evaluated by any of theSyntaxableinstance being traversed. This method is commonly used by a rootSyntaxable'sArgsParser.evalArgs(String[])method, which delegates to theparseArgs(String[], String[])method and after which it determines whether there are superfluous arguments to be taken care of (by throwing an according exception). Business logic therefore should invoke the root node'sparseArgs(String[], String[])method as ignoring superfluous command line arguments will cause unexpected behavior from the point of view of the invoker.- Parameters:
aArgs- The command line arguments to be parsed.- Returns:
- The list of evaluated command line arguments being instances of
the
Operandinterfaces or its sub-types. - Throws:
ArgsSyntaxException- thrown in case of a command line arguments mismatch regarding provided and expected args.
-
parseArgs
Parses the provided command line arguments and determines the according values by evaluating thisSyntaxableinstance or, in case of being a node in the syntax tree (such as aArgsSyntax, traversing the childSyntaxableinstances'parseArgs(String[], String[])methods. In case of successfully parsing thisSyntaxableand / or the childSyntaxableinstances, the evaluated command line arguments are returned: Depending on theSyntaxablesubclasses representing the evaluated command line arguments, instances ofFlagclasses,Optionclasses orOperandclasses may be found in the result. In case of parsing failure, an according exception is thrown. ATTENTION: This method does not test for superfluous command line arguments being passed; e.g. command line arguments not being evaluated by any of theSyntaxableinstance being traversed. This method is commonly used by a rootSyntaxable'sArgsParser.evalArgs(String[])method, which delegates to theparseArgs(String[], String[])method and after which it determines whether there are superfluous arguments to be taken care of (by throwing an according exception). Business logic therefore should invoke the root node'sparseArgs(String[], String[])method as ignoring superfluous command line arguments will cause unexpected behavior from the point of view of the invoker.- Parameters:
aArgs- The command line arguments to be parsed.aOptions- The list of options (short and as well as long) which are reserved and cannot be used as value.- Returns:
- The list of evaluated command line arguments being instances of
the
Operandinterfaces or its sub-types. - Throws:
ArgsSyntaxException- thrown in case of a command line arguments mismatch regarding provided and expected args.
-
toValue
Searches for a value being set for the given for given alias in the syntax tree parsing the command line arguments; if a node in the syntax tree has a value for the given alias, then this value is returned.- Type Parameters:
V- The type of the value being expected.- Parameters:
aAlias- The alias for which to seek for a value being set.- Returns:
- The according value or null if none has been set for the given alias.
-
toState
String toState()ThetoState()method might be used by theObject.toString()method and prints out the state of the syntaxable and (if any) its children. Even in case parsing command line arguments failed, the state till failure can be inspected with this method.- Returns:
- The state of this
Syntaxableinstance and (if any) its children.
-