- All Implemented Interfaces:
Cloneable,Comparable<Operand<?>>,ArgsAccessor,MatchCountAccessor,Operand<Boolean>,Option<Boolean>,Synopsisable,Term,org.refcodes.exception.ExceptionAccessor<ArgsSyntaxException>,org.refcodes.mixin.AliasAccessor,org.refcodes.mixin.Clonable,org.refcodes.mixin.DescriptionAccessor,org.refcodes.mixin.EnabledAccessor,org.refcodes.mixin.Resetable,org.refcodes.mixin.Schemable,org.refcodes.mixin.TypeAccessor<Boolean>,org.refcodes.mixin.ValueAccessor<Boolean>
A predefined system information
Flag: A predefined Flag gives
its SHORT_OPTION, its LONG_OPTION as well as its
ALIAS an according semantics regarded by other subsystems..-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.mixin.AliasAccessor
org.refcodes.mixin.AliasAccessor.AliasBuilder<B extends org.refcodes.mixin.AliasAccessor.AliasBuilder<B>>, org.refcodes.mixin.AliasAccessor.AliasMutator, org.refcodes.mixin.AliasAccessor.AliasPropertyNested classes/interfaces inherited from interface org.refcodes.cli.ArgsAccessor
ArgsAccessor.ArgsMutator, ArgsAccessor.ArgsPropertyNested classes/interfaces inherited from interface org.refcodes.mixin.DescriptionAccessor
org.refcodes.mixin.DescriptionAccessor.DescriptionBuilder<B extends org.refcodes.mixin.DescriptionAccessor.DescriptionBuilder<B>>, org.refcodes.mixin.DescriptionAccessor.DescriptionMutator, org.refcodes.mixin.DescriptionAccessor.DescriptionPropertyNested classes/interfaces inherited from interface org.refcodes.mixin.EnabledAccessor
org.refcodes.mixin.EnabledAccessor.EnabledBuilder<B extends org.refcodes.mixin.EnabledAccessor.EnabledBuilder<B>>, org.refcodes.mixin.EnabledAccessor.EnabledMutator, org.refcodes.mixin.EnabledAccessor.EnabledPropertyNested classes/interfaces inherited from interface org.refcodes.exception.ExceptionAccessor
org.refcodes.exception.ExceptionAccessor.ExceptionBuilder<EXC extends Throwable,B extends org.refcodes.exception.ExceptionAccessor.ExceptionBuilder<EXC, B>>, org.refcodes.exception.ExceptionAccessor.ExceptionMutator<EXC extends Throwable>, org.refcodes.exception.ExceptionAccessor.ExceptionProperty<EXC extends Throwable> Nested classes/interfaces inherited from interface org.refcodes.cli.MatchCountAccessor
MatchCountAccessor.MatchCountBuilder<B extends MatchCountAccessor.MatchCountBuilder<B>>, MatchCountAccessor.MatchCountMutator, MatchCountAccessor.MatchCountPropertyNested classes/interfaces inherited from interface org.refcodes.mixin.TypeAccessor
org.refcodes.mixin.TypeAccessor.TypeBuilder<T extends Object,B extends org.refcodes.mixin.TypeAccessor.TypeBuilder<T, B>>, org.refcodes.mixin.TypeAccessor.TypeMutator<T extends Object>, org.refcodes.mixin.TypeAccessor.TypeProperty<T extends Object> Nested classes/interfaces inherited from interface org.refcodes.mixin.ValueAccessor
org.refcodes.mixin.ValueAccessor.ValueBuilder<V extends Object,B extends org.refcodes.mixin.ValueAccessor.ValueBuilder<V, B>>, org.refcodes.mixin.ValueAccessor.ValueMutator<V extends Object>, org.refcodes.mixin.ValueAccessor.ValueProperty<V extends Object> -
Field Summary
FieldsModifier and TypeFieldDescriptionprotected Stringprotected ArgsSyntaxExceptionstatic final Stringstatic final Stringstatic final CharacterFields inherited from class org.refcodes.cli.AbstractOperand
_matchCount -
Constructor Summary
ConstructorsConstructorDescriptionConstructs the predefined system informationFlag.SysInfoFlag(boolean hasShortOption) Constructs the predefined system informationFlag.SysInfoFlag(String aDescription) Constructs the predefined system informationFlag.SysInfoFlag(String aDescription, boolean hasShortOption) Constructs the predefined system informationFlag. -
Method Summary
Modifier and TypeMethodDescriptionRetrieves theArgsSyntaxExceptionexception in case invokingTerm.parseArgs(String[], CliContext)failed.protected static String[]toArgsDiff(String[] aArgs, String[] aArgsSubset) Creates the difference between the provided set and the provided subset.protected static String[]toArgsDiff(String[] aArgs, List<? extends Operand<?>> aArgsSubset) Creates the difference between the provided set and the providedLists therein found argument arrays subset (as ofOperand.getArgs()).protected static String[]toArgsDiff(String[] aArgs, Operand<?>[] aArgsSubset) Creates the difference between the provided set and the providedLists therein found argument arrays subset (as ofOperand.getArgs()).protected static String[]toParsedArgs(Operand<?>[]... aOperands) Takes allOperandinstances found in the providedLists and adds all therein found argument arrays (as ofOperand.getArgs()) to the result.Methods inherited from class org.refcodes.cli.AbstractOption
clone, contains, getLongOption, getShortOption, setParsedArgs, setValue, toException, toSchemaMethods inherited from class org.refcodes.cli.AbstractOperand
approve, compareTo, getAlias, getArgs, getMatchCount, getType, getValue, toStringMethods inherited from class java.lang.Object
equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface java.lang.Comparable
compareToMethods inherited from interface org.refcodes.mixin.DescriptionAccessor
getDescriptionMethods inherited from interface org.refcodes.cli.Operand
getAlias, getArgs, getValue, hasValue, toSpec, toSpec, toValueMethods inherited from interface org.refcodes.cli.Synopsisable
toSynopsis, toSynopsis, toSynopsis, toSynopsisMethods inherited from interface org.refcodes.cli.Term
getException, getMatchCount, parseArgs, toSynopsis, toSyntax, toSyntax, toSyntax, toSyntaxMethods inherited from interface org.refcodes.mixin.TypeAccessor
getTypeMethods inherited from interface org.refcodes.mixin.ValueAccessor
getValueOr
-
Field Details
-
ALIAS
- See Also:
-
LONG_OPTION
- See Also:
-
SHORT_OPTION
-
_description
-
_exception
-
-
Constructor Details
-
SysInfoFlag
public SysInfoFlag()Constructs the predefined system informationFlag. -
SysInfoFlag
public SysInfoFlag(boolean hasShortOption) Constructs the predefined system informationFlag.- Parameters:
hasShortOption- True in case to also enable the short option, else only the long option takes effect.
-
SysInfoFlag
Constructs the predefined system informationFlag.- Parameters:
aDescription- The description to be used (without any line breaks).
-
SysInfoFlag
Constructs the predefined system informationFlag.- Parameters:
aDescription- The description to be used (without any line breaks).hasShortOption- True in case to also enable the short option, else only the long option takes effect.
-
-
Method Details
-
getDescription
- Specified by:
getDescriptionin interfaceorg.refcodes.mixin.DescriptionAccessor
-
getException
Retrieves theArgsSyntaxExceptionexception in case invokingTerm.parseArgs(String[], CliContext)failed. The exception (and the according suppressed ones alongside the causes) does not necessarily have been thrown by theTerm.parseArgs(String[], CliContext)method depending on the semantics of theTermhanding the exception (theAnyConditionprovides any exceptions it caught even though it did not throw them as of its semantics).- Specified by:
getExceptionin interfaceorg.refcodes.exception.ExceptionAccessor<ArgsSyntaxException>- Specified by:
getExceptionin interfaceTerm- Returns:
- The
ArgsSyntaxExceptionexception occurring while parsing the arguments.
-
toArgsDiff
Creates the difference between the provided set and the providedLists therein found argument arrays subset (as ofOperand.getArgs()).- Parameters:
aArgs- The set to be used for the diff operation.aArgsSubset- The subset to be used for the diff operation being the lists containing theOperandinstances whose command line arguments are to be diffed.- Returns:
- The difference between the set and the subset.
-
toArgsDiff
Creates the difference between the provided set and the providedLists therein found argument arrays subset (as ofOperand.getArgs()).- Parameters:
aArgs- The set to be used for the diff operation.aArgsSubset- The subset to be used for the diff operation being the lists containing theOperandinstances whose command line arguments are to be diffed.- Returns:
- The difference between the set and the subset.
-
toArgsDiff
Creates the difference between the provided set and the provided subset.- Parameters:
aArgs- The set to be used for the diff operation.aArgsSubset- The subset to be used for the diff operation.- Returns:
- The difference between the set and the subset.
-
toParsedArgs
Takes allOperandinstances found in the providedLists and adds all therein found argument arrays (as ofOperand.getArgs()) to the result.
-