Class UnknownArgsException
- All Implemented Interfaces:
Serializable, ArgsAccessor, MatchCountAccessor, ErrorCodeAccessor, Trap, SourceAccessor<Term>
- Direct Known Subclasses:
UnknownOperationArgsException, UnknownOptionArgsException
Thrown in case command line arguments were not processed (did not match the
expected arguments), e.g. the arguments were rejected as them did not work
for the according syntax.
- See Also:
-
Nested Class Summary
Nested classes/interfaces inherited from class CliException
CliException.CliArgsExceptionNested classes/interfaces inherited from interface ArgsAccessor
ArgsAccessor.ArgsMutator, ArgsAccessor.ArgsPropertyNested classes/interfaces inherited from interface ErrorCodeAccessor
ErrorCodeAccessor.ErrorCodeBuilder<B>, ErrorCodeAccessor.ErrorCodeMutator, ErrorCodeAccessor.ErrorCodePropertyNested classes/interfaces inherited from interface MatchCountAccessor
MatchCountAccessor.MatchCountBuilder<B>, MatchCountAccessor.MatchCountMutator, MatchCountAccessor.MatchCountPropertyNested classes/interfaces inherited from interface SourceAccessor
SourceAccessor.SourceBuilder<SRC,B>, SourceAccessor.SourceMutator<SRC>, SourceAccessor.SourceProperty<SRC> -
Field Summary
Fields inherited from class ArgsSyntaxException
_matchCount, _sourceFields inherited from class CliException.CliArgsException
_args -
Constructor Summary
ConstructorsConstructorDescriptionUnknownArgsException(String[] aArgs, Throwable aCause) Instantiates the classUnknownArgsException.UnknownArgsException(String[] aArgs, Throwable aCause, String aErrorCode) Instantiates the classUnknownArgsException.UnknownArgsException(String[] aArgs, Term aSource, Throwable aCause) Instantiates the classUnknownArgsException.UnknownArgsException(String[] aArgs, Term aSource, Throwable aCause, String aErrorCode) Instantiates the classUnknownArgsException.UnknownArgsException(String aMessage, String[] aArgs) Instantiates the classUnknownArgsException.UnknownArgsException(String aMessage, String[] aArgs, String aErrorCode) Instantiates the classUnknownArgsException.UnknownArgsException(String aMessage, String[] aArgs, Throwable aCause) Instantiates the classUnknownArgsException.UnknownArgsException(String aMessage, String[] aArgs, Throwable aCause, String aErrorCode) Instantiates the classUnknownArgsException.UnknownArgsException(String aMessage, String[] aArgs, Term aSource) Instantiates the classUnknownArgsException.UnknownArgsException(String aMessage, String[] aArgs, Term aSource, String aErrorCode) Instantiates the classUnknownArgsException.UnknownArgsException(String aMessage, String[] aArgs, Term aSource, Throwable aCause) Instantiates the classUnknownArgsException.UnknownArgsException(String aMessage, String[] aArgs, Term aSource, Throwable aCause, String aErrorCode) Instantiates the classUnknownArgsException. -
Method Summary
Methods inherited from class ArgsSyntaxException
getMatchCount, getPatternArguments, getSource, toHeuristicMessage, toRootMatchCauseMethods inherited from class CliException.CliArgsException
getArgsMethods inherited from class AbstractException
getErrorCode, getMessageMethods inherited from class Throwable
addSuppressed, fillInStackTrace, getCause, getLocalizedMessage, getStackTrace, getSuppressed, initCause, printStackTrace, printStackTrace, printStackTrace, setStackTrace, toStringMethods inherited from class Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface Trap
toLocalizedMessage, toMessage, toMessage, toMessage, toShortLocalizedMessage, toShortMessage
-
Constructor Details
-
UnknownArgsException
Instantiates the classUnknownArgsException.- See Also:
-
UnknownArgsException
Instantiates the classUnknownArgsException.- See Also:
-
UnknownArgsException
Instantiates the classUnknownArgsException.- See Also:
-
UnknownArgsException
-
UnknownArgsException
Instantiates the classUnknownArgsException.- See Also:
-
UnknownArgsException
Instantiates the classUnknownArgsException.- See Also:
-
UnknownArgsException
Instantiates the classUnknownArgsException.- See Also:
-
UnknownArgsException
Instantiates the classUnknownArgsException.- See Also:
-
UnknownArgsException
Instantiates the classUnknownArgsException.- See Also:
-
UnknownArgsException
Instantiates the classUnknownArgsException.- See Also:
-
UnknownArgsException
Instantiates the classUnknownArgsException.- See Also:
-
UnknownArgsException
Instantiates the classUnknownArgsException.- See Also:
-