Class UnknownOperationArgsException
- All Implemented Interfaces:
Serializable, ArgsAccessor, MatchCountAccessor, OperationAccessor, ErrorCodeAccessor, Trap, SourceAccessor<Term>
public class UnknownOperationArgsException
extends UnknownArgsException
implements OperationAccessor
Thrown in case command line arguments were not processed (did not match the
expected arguments) by an
Option (having a short- and/or a
long-option), e.g. the arguments were rejected as them did not work for the
according syntax.- See Also:
-
Nested Class Summary
Nested classes/interfaces inherited from class CliException
CliException.CliArgsExceptionNested classes/interfaces inherited from interface ArgsAccessor
ArgsAccessor.ArgsMutator, ArgsAccessor.ArgsPropertyNested classes/interfaces inherited from interface ErrorCodeAccessor
ErrorCodeAccessor.ErrorCodeBuilder<B>, ErrorCodeAccessor.ErrorCodeMutator, ErrorCodeAccessor.ErrorCodePropertyNested classes/interfaces inherited from interface MatchCountAccessor
MatchCountAccessor.MatchCountBuilder<B>, MatchCountAccessor.MatchCountMutator, MatchCountAccessor.MatchCountPropertyNested classes/interfaces inherited from interface OperationAccessor
OperationAccessor.OperationBuilder<B>, OperationAccessor.OperationMutator, OperationAccessor.OperationPropertyNested classes/interfaces inherited from interface SourceAccessor
SourceAccessor.SourceBuilder<SRC,B>, SourceAccessor.SourceMutator<SRC>, SourceAccessor.SourceProperty<SRC> -
Field Summary
Fields inherited from class ArgsSyntaxException
_matchCount, _sourceFields inherited from class CliException.CliArgsException
_args -
Constructor Summary
ConstructorsConstructorDescriptionUnknownOperationArgsException(String aMessage, String[] aArgs, String aOperation) Instantiates the classUnknownOperationArgsException.UnknownOperationArgsException(String aMessage, String[] aArgs, String aOperation, String aErrorCode) Instantiates the classUnknownOperationArgsException.UnknownOperationArgsException(String aMessage, String[] aArgs, String aOperation, Throwable aCause) Instantiates the classUnknownOperationArgsException.UnknownOperationArgsException(String aMessage, String[] aArgs, String aOperation, Throwable aCause, String aErrorCode) Instantiates the classUnknownOperationArgsException.UnknownOperationArgsException(String aMessage, String[] aArgs, String aOperation, Throwable aCause, Term aSource) Instantiates the classUnknownOperationArgsException.UnknownOperationArgsException(String aMessage, String[] aArgs, String aOperation, Throwable aCause, Term aSource, String aErrorCode) Instantiates the classUnknownOperationArgsException.UnknownOperationArgsException(String aMessage, String[] aArgs, String aOperation, Term aSource) Instantiates the classUnknownOperationArgsException.UnknownOperationArgsException(String aMessage, String[] aArgs, String aOperation, Term aSource, String aErrorCode) Instantiates the classUnknownOperationArgsException.UnknownOperationArgsException(String aShortOption, String aOperation, String[] aArgs, Throwable aCause) Instantiates the classUnknownOperationArgsException.UnknownOperationArgsException(String aShortOption, String aOperation, String[] aArgs, Throwable aCause, String aErrorCode) Instantiates the classUnknownOperationArgsException.UnknownOperationArgsException(String aShortOption, String aOperation, String[] aArgs, Throwable aCause, Term aSource) Instantiates the classUnknownOperationArgsException.UnknownOperationArgsException(String aShortOption, String aOperation, String[] aArgs, Throwable aCause, Term aSource, String aErrorCode) Instantiates the classUnknownOperationArgsException. -
Method Summary
Methods inherited from class ArgsSyntaxException
getMatchCount, getSource, toHeuristicMessage, toRootMatchCauseMethods inherited from class CliException.CliArgsException
getArgsMethods inherited from class AbstractException
getErrorCode, getMessageMethods inherited from class Throwable
addSuppressed, fillInStackTrace, getCause, getLocalizedMessage, getStackTrace, getSuppressed, initCause, printStackTrace, printStackTrace, printStackTrace, setStackTrace, toStringMethods inherited from class Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface Trap
toLocalizedMessage, toMessage, toMessage, toMessage, toShortLocalizedMessage, toShortMessage
-
Constructor Details
-
UnknownOperationArgsException
public UnknownOperationArgsException(String aMessage, String[] aArgs, String aOperation, Term aSource) Instantiates the classUnknownOperationArgsException.- Parameters:
aOperation- The operation for which the arguments did not apply.- See Also:
-
UnknownOperationArgsException
-
UnknownOperationArgsException
-
UnknownOperationArgsException
-
UnknownOperationArgsException
-
UnknownOperationArgsException
-
UnknownOperationArgsException
Instantiates the classUnknownOperationArgsException.- Parameters:
aOperation- The operation for which the arguments did not apply.- See Also:
-
UnknownOperationArgsException
public UnknownOperationArgsException(String aMessage, String[] aArgs, String aOperation, String aErrorCode) Instantiates the classUnknownOperationArgsException.- Parameters:
aOperation- The operation for which the arguments did not apply.- See Also:
-
UnknownOperationArgsException
public UnknownOperationArgsException(String aMessage, String[] aArgs, String aOperation, Throwable aCause) Instantiates the classUnknownOperationArgsException.- Parameters:
aOperation- The operation for which the arguments did not apply.- See Also:
-
UnknownOperationArgsException
-
UnknownOperationArgsException
public UnknownOperationArgsException(String aShortOption, String aOperation, String[] aArgs, Throwable aCause) Instantiates the classUnknownOperationArgsException.- Parameters:
aOperation- The operation for which the arguments did not apply.- See Also:
-
UnknownOperationArgsException
-
-
Method Details
-
getOperation
Retrieves the operation from the operation property.- Specified by:
getOperationin interfaceOperationAccessor- Returns:
- The operation stored by the operation property.
-
getPatternArguments
- Specified by:
getPatternArgumentsin interfaceTrap- Overrides:
getPatternArgumentsin classArgsSyntaxException
-