Uses of Class
org.refcodes.cli.AbstractOperand
-
Uses of AbstractOperand in org.refcodes.cli
Subclasses of AbstractOperand in org.refcodes.cliModifier and TypeClassDescriptionclassTheAbstractDirectiveis an abstract implementation of anDirectiveproviding the boiler plate when implementing theDirectiveinterface.classTheAbstractOptionis an abstract implementation of anOptionproviding the boiler plate when implementing theOptioninterface.classTheAbstractPropertyis an abstract implementation of aPropertyproviding the boiler plate when implementing thePropertyinterface.classclassclassclassclassclassclassA predefined cleanFlag: A predefinedFlaggives itsCleanFlag.SHORT_OPTION, itsCleanFlag.LONG_OPTIONas well as itsCleanFlag.ALIASan according semantics regarded by other subsystems.classTheConfigOptionrepresents anOptionholding a value specifying a configuration resource (file).classTheConfigPropertyrepresents anPropertyholding a value specifying a configuration resource (file).classA predefined daemonFlag: A predefinedFlaggives itsDaemonFlag.SHORT_OPTION, itsDaemonFlag.LONG_OPTIONas well as itsDaemonFlag.ALIASan according semantics regarded by other subsystems.classA predefined debugFlag: A predefinedFlaggives itsDebugFlag.SHORT_OPTION, itsDebugFlag.LONG_OPTIONas well as itsDebugFlag.ALIASan according semantics regarded by other subsystems.classclassclassclassEnumDirective<T extends Enum<T>>TheEnumDirectiverepresents aDirectiveof enumeration types.classEnumOption<T extends Enum<T>>TheEnumOptionrepresents anOptionof enumeration types.classEnumProperty<T extends Enum<T>>TheEnumPropertyrepresents anPropertyof enumeration types.classclassclassclassTheFlagclass implements theOptioninterface for representing either atrueor afalsestate: When a flag is provided to your command line arguments, then it is considered to betrue, when it is omitted, then it is considered to befalseas ofFlag.isEnabled().classclassclassclassA predefined forceFlag: A predefinedFlaggives itsForceFlag.SHORT_OPTION, itsForceFlag.LONG_OPTIONas well as itsForceFlag.ALIASan according semantics regarded by other subsystems.classA predefined helpFlag: A predefinedFlaggives itsHelpFlag.SHORT_OPTION, itsHelpFlag.LONG_OPTIONas well as itsHelpFlag.ALIASan according semantics regarded by other subsystems.classA predefined initFlag: A predefinedFlaggives itsInitFlag.SHORT_OPTION, itsInitFlag.LONG_OPTIONas well as itsInitFlag.ALIASan according semantics regarded by other subsystems.classclassclassclassclassclassclassTheNoneOperandrepresents an empty set of arguments, e.g. no command line argument is being passed.classTheOperationis an argument representing an action of functioning or the fact of being active or in effect and is either provided (as command line argument) or not provided as ofOperation.isEnabled().classA predefined "be quiet"Flag: A predefinedFlaggives itsQuietFlag.SHORT_OPTION, itsQuietFlag.LONG_OPTIONas well as itsQuietFlag.ALIASan according semantics regarded by other subsystems.classclassclassclassclassA predefined system informationFlag: A predefinedFlaggives itsSysInfoFlag.SHORT_OPTION, itsSysInfoFlag.LONG_OPTIONas well as itsSysInfoFlag.ALIASan according semantics regarded by other subsystems..classA predefined verboseFlag: A predefinedFlaggives itsVerboseFlag.SHORT_OPTION, itsVerboseFlag.LONG_OPTIONas well as itsVerboseFlag.ALIASan according semantics regarded by other subsystems.