Uses of Class
org.refcodes.cli.AbstractOption
-
Uses of AbstractOption in org.refcodes.cli
Subclasses of AbstractOption in org.refcodes.cli Modifier and Type Class Description classCharOptionclassDebugFlagA predefined debug switch.classDoubleOptionclassEnumOption<T extends Enum<T>>The Class EnumOption.classFileOptionclassFlagTheFlagclass implements theOptioninterface for representing either atrueor afalsestate: When a flag is provided to your command line arguments, then it is considered to betrue, when it is omitted, then it is considered to befalseas ofFlag.isEnabled().classFloatOptionclassForceFlagA predefined force switch.classHelpFlagA predefined help switch.classIntOptionclassLongOptionclassQuietFlagA predefined "be quiet" switch.classStringOptionclassSysInfoFlagA predefined system information switch.classVerboseFlagA predefined verbose switch.