Uses of Class
org.refcodes.cli.AmbiguousArgsException
-
Uses of AmbiguousArgsException in org.refcodes.cli
Methods in org.refcodes.cli that throw AmbiguousArgsException Modifier and Type Method Description List<? extends Operand<?>>ArgsParser. evalArgs(String[] aArgs)Evaluates the provided command line arguments and determines the according values by evaluating the rootCondition.default List<? extends Operand<?>>ArgsParser. evalArgs(List<String> aArgs)Same asArgsParser.evalArgs(String[])with the difference that the elements representing the arguments are passed as a list instead of an array.List<? extends Operand<?>>ArgsParserImpl. evalArgs(String[] aArgs)Evaluates the provided command line arguments and determines the according values by evaluating the rootCondition.List<Operand<T>>AbstractOperand. parseArgs(String[] aArgs, String[] aOptions)Parses the provided command line arguments and determines the according values by evaluating thisSyntaxableinstance or, in case of being a node in the syntax tree (such as aCondition, traversing the childSyntaxableinstances'Syntaxable.parseArgs(String[], String[])methods.List<Operand<T>>AbstractOption. parseArgs(String[] aArgs, String[] aOptions)Parses the provided command line arguments and determines the according values by evaluating thisSyntaxableinstance or, in case of being a node in the syntax tree (such as aCondition, traversing the childSyntaxableinstances'Syntaxable.parseArgs(String[], String[])methods.List<? extends Operand<?>>AndCondition. parseArgs(String[] aArgs, String[] aOptions)List<Operand<?>>ArrayOperand. parseArgs(String[] aArgs, String[] aOperands)Parses the provided command line arguments and determines the according values by evaluating thisSyntaxableinstance or, in case of being a node in the syntax tree (such as aCondition, traversing the childSyntaxableinstances'Syntaxable.parseArgs(String[], String[])methods.List<Operand<Boolean>>Flag. parseArgs(String[] aArgs, String[] aOptions)Parses the provided command line arguments and determines the according values by evaluating thisSyntaxableinstance or, in case of being a node in the syntax tree (such as aCondition, traversing the childSyntaxableinstances'Syntaxable.parseArgs(String[], String[])methods.List<Operand<Boolean>>Operation. parseArgs(String[] aArgs, String[] aOptions)Parses the provided command line arguments and determines the according values by evaluating thisSyntaxableinstance or, in case of being a node in the syntax tree (such as aCondition, traversing the childSyntaxableinstances'Syntaxable.parseArgs(String[], String[])methods.List<? extends Operand<?>>OptionalCondition. parseArgs(String[] aArgs, String[] aOptions)List<? extends Operand<?>>OptionConditionFacade. parseArgs(String[] aArgs, String[] aOptions)List<? extends Operand<?>>OrCondition. parseArgs(String[] aArgs, String[] aOptions)default List<? extends Operand<?>>Syntaxable. parseArgs(String[] aArgs)Parses the provided command line arguments and determines the according values by evaluating thisSyntaxableinstance or, in case of being a node in the syntax tree (such as aCondition, traversing the childSyntaxableinstances'Syntaxable.parseArgs(String[], String[])methods.List<? extends Operand<?>>Syntaxable. parseArgs(String[] aArgs, String[] aOptions)Parses the provided command line arguments and determines the according values by evaluating thisSyntaxableinstance or, in case of being a node in the syntax tree (such as aCondition, traversing the childSyntaxableinstances'Syntaxable.parseArgs(String[], String[])methods.List<? extends Operand<?>>XorCondition. parseArgs(String[] aArgs, String[] aOptions)default ArgsParserArgsParser. withEvalArgs(String[] aArgs)Same asArgsParser.evalArgs(String[])with the difference that this class's instance being invoked is returned as of the builder pattern.default ArgsParserArgsParser. withEvalArgs(List<String> aArgs)Same asArgsParser.evalArgs(List)with the difference that this class's instance being invoked is returned as of the builder pattern.BArgsParserMixin. withEvalArgs(String[] aArgs)Evaluates the provided command line arguments.default BArgsParserMixin. withEvalArgs(List<String> aArgs)Evaluates the provided command line arguments .