Uses of Interface
org.refcodes.cli.ArgsAccessor
-
Uses of ArgsAccessor in org.refcodes.cli
Subinterfaces of ArgsAccessor in org.refcodes.cliModifier and TypeInterfaceDescriptionstatic interfaceProvides a args property.interfaceOperand<T>AnOperandrepresents a value parsed from command line arguments.interfaceOption<T>AnOptionrepresents a command line option with the according option's value.Classes in org.refcodes.cli that implement ArgsAccessorModifier and TypeClassDescriptionclassTheAbstractOperandis an abstract implementation of anOperandproviding the boiler plate when implementing theOperandinterface.classTheAbstractOptionis an abstract implementation of anOptionproviding the boiler plate when implementing theOptioninterface.classThrown in case the command line arguments do not match the required syntax.classThrown in case of a command line arguments mismatch regarding provided and expected args.classArrayOperand<T>Creates an array representation facade for the encapsulatedOperand.classArrayOption<T>Creates an array representation facade for the encapsulatedOption.classclassA predefined cleanFlag: A predefinedFlaggives itsCleanFlag.SHORT_OPTION, itsCleanFlag.LONG_OPTIONas well as itsCleanFlag.ALIASan according semantics regarded by other subsystems.static classThis abstract exception is the base exception for all command line argument related exceptions.classTheConfigOptionrepresents anOptionholding a value specifying a configuration resource (file).classA predefined daemonFlag: A predefinedFlaggives itsDaemonFlag.SHORT_OPTION, itsDaemonFlag.LONG_OPTIONas well as itsDaemonFlag.ALIASan according semantics regarded by other subsystems.classA predefined debugFlag: A predefinedFlaggives itsDebugFlag.SHORT_OPTION, itsDebugFlag.LONG_OPTIONas well as itsDebugFlag.ALIASan according semantics regarded by other subsystems.classclassEnumOption<T extends Enum<T>>TheEnumOptionrepresents anOptionof enumeration types.classclassTheFlagclass implements theOptioninterface for representing either atrueor afalsestate: When a flag is provided to your command line arguments, then it is considered to betrue, when it is omitted, then it is considered to befalseas ofFlag.isEnabled().classclassA predefined forceFlag: A predefinedFlaggives itsForceFlag.SHORT_OPTION, itsForceFlag.LONG_OPTIONas well as itsForceFlag.ALIASan according semantics regarded by other subsystems.classA predefined helpFlag: A predefinedFlaggives itsHelpFlag.SHORT_OPTION, itsHelpFlag.LONG_OPTIONas well as itsHelpFlag.ALIASan according semantics regarded by other subsystems.classA predefined initFlag: A predefinedFlaggives itsInitFlag.SHORT_OPTION, itsInitFlag.LONG_OPTIONas well as itsInitFlag.ALIASan according semantics regarded by other subsystems.classclassclassTheNoneOperandrepresents an empty set of arguments, e.g. no command line argument is being passed.classTheOperationis an argument representing a function or a method ("command") and is either provided or not provided as ofOperation.isEnabled().classThrown in case the provided command line arguments do not respect the required semantics or cannot be converted to the required type.classA predefined "be quiet"Flag: A predefinedFlaggives itsQuietFlag.SHORT_OPTION, itsQuietFlag.LONG_OPTIONas well as itsQuietFlag.ALIASan according semantics regarded by other subsystems.classclassclassThrown in case there were arguments found not being used (superfluous arguments).classA predefined system informationFlag: A predefinedFlaggives itsSysInfoFlag.SHORT_OPTION, itsSysInfoFlag.LONG_OPTIONas well as itsSysInfoFlag.ALIASan according semantics regarded by other subsystems..classThrown in case command line arguments were not processed (did not match the expected arguments), e.g. the arguments were rejected as them did not work for the according syntax.classA predefined verboseFlag: A predefinedFlaggives itsVerboseFlag.SHORT_OPTION, itsVerboseFlag.LONG_OPTIONas well as itsVerboseFlag.ALIASan according semantics regarded by other subsystems.