Uses of Class
org.refcodes.cli.ArgsMismatchException
-
-
Uses of ArgsMismatchException in org.refcodes.cli
Subclasses of ArgsMismatchException in org.refcodes.cli Modifier and Type Class Description classAmbiguousArgsExceptionThrown in case at least one command line argument is ambiguous regarding expected args vs. provided args.classParseArgsExceptionThrown in case the provided command line arguments do not respect the required syntax or cannot be converted to the required type.classSuperfluousArgsExceptionThrown in case there were arguments found not being used (superfluous arguments).classUnknownArgsExceptionThrown in case not one command line argument matched regarding the provided args vs. the expected args.
-