Uses of Interface
org.refcodes.cli.ArgsParser
-
Uses of ArgsParser in org.refcodes.cli
Classes in org.refcodes.cli that implement ArgsParserModifier and TypeClassDescriptionclassA straightforward implementation of theArgsParserinterface.Subinterfaces with type arguments of type ArgsParser in org.refcodes.cliModifier and TypeInterfaceDescriptioninterfaceTheArgsParserprovides means for parsing command line arguments and constructing a command line utility's help output.interfaceTheArgsParserprovides means for parsing command line arguments and constructing a command line utility's help output.Methods in org.refcodes.cli that return ArgsParserModifier and TypeMethodDescriptionArgsParserAccessor.getArgsParser()Retrieves the args-parser from theArgsParserproperty.default ArgsParserArgsParserAccessor.ArgsParserProperty.letArgsParser(ArgsParser aArgsParser) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenArgsParser(setter) as ofArgsParserAccessor.ArgsParserMutator.setArgsParser(ArgsParser)and returns the very same value (getter).default ArgsParserArgsParser.withAddExample(String aDescription, Operand<?>... aOperands) Builder method adding an application'sExampleelement.default ArgsParserArgsParser.withAddExample(Example aExample) Builder method adding an application'sExampleelement.default ArgsParserArgsParser.withArgumentEscapeCode(String aParamEscCode) Sets the argument Escape-Code for the argument Escape-Code property.default ArgsParserArgsParser.withBannerBorderEscapeCode(String aBannerBorderEscCode) Sets the banner border Escape-Code for the banner border Escape-Code property.default ArgsParserArgsParser.withBannerEscapeCode(String aBannerEscCode) Sets the banner Escape-Code for the banner Escape-Code property.default ArgsParserArgsParser.withBannerFont(org.refcodes.textual.Font aBannerFont) Sets the bannerFontfor the bannerFontproperty.default ArgsParserArgsParser.withBannerFontPalette(char[] aColorPalette) Sets the banner font palette for the banner font palette property.default ArgsParserArgsParser.withCommandEscapeCode(String aCommandEscCode) Sets the command Escape-Code for the command Escape-Code property.default ArgsParserArgsParser.withConsoleWidth(int aConsoleWidth) default ArgsParserArgsParser.withCopyright(String aCopyright) Sets the copyright for the copyright property.default ArgsParserArgsParser.withDescription(String aDescription) default ArgsParserArgsParser.withDescriptionEscapeCode(String aDescriptionEscCode) Sets the description Escape-Code for the description Escape-Code property.default ArgsParserArgsParser.withErrorOut(PrintStream aErrorOut) Set the error outPrintStreamand make other adjustments with the result (with regards to the Builder-Pattern).default ArgsParserArgsParser.withEscapeCodesEnabled(boolean isEscCodeEnabled) default ArgsParserArgsParser.withEvalArgs(String[] aArgs) Evaluates the provided command line arguments.default ArgsParserArgsParser.withEvalArgs(List<String> aArgs) Evaluates the provided command line arguments .default ArgsParserArgsParser.withExamples(Collection<Example> aExamples) Builder method providing the application'sExampleelements.default ArgsParserArgsParser.withExamples(Example[] aExamples) default ArgsParserArgsParser.withKeywordEscapeCode(String aOptEscCode) Sets the keyword (e.g. short- and long-options) Escape-Code for the keyword Escape-Code property.default ArgsParserArgsParser.withLicense(String aLicense) Sets the license for the license property.default ArgsParserArgsParser.withLineBreak(String aLineBreak) default ArgsParserArgsParser.withLineSeparatorEscapeCode(String aLineSeparatorEscCode) Sets the line separator Escape-Code for the line separator Escape-Code property.default ArgsParserArgsParser.withLongOptionPrefix(String aLongOptionPrefix) Sets the long option prefix for the long option prefix property.default ArgsParserArgsParser.withMaxConsoleWidth(int aMaxConsoleWidth) default ArgsParserdefault ArgsParserArgsParser.withResetEscapeCode(String aResetEscCode) default ArgsParserArgsParser.withSeparatorLnChar(char aSeparatorLnChar) Builder method adding an separator line char.default ArgsParserArgsParser.withShortOptionPrefix(Character aShortOptionPrefix) Sets the short option prefix for the short option prefix property.default ArgsParserArgsParser.withStandardOut(PrintStream aStandardOut) Set the standard outPrintStreamand make other adjustments with the result (with regards to the Builder-Pattern).default ArgsParserArgsParser.withSyntaxMetrics(SyntaxMetrics aSyntaxMetrics) Sets theSyntaxMetricsfor theSyntaxMetricsproperty.default ArgsParserArgsParser.withTextBoxGrid(org.refcodes.textual.TextBoxGrid aTextBoxGrid) default ArgsParserArgsParser.withTextBoxGrid(org.refcodes.textual.TextBoxStyle aTextBoxStyle) default ArgsParserMethods in org.refcodes.cli with parameters of type ArgsParserModifier and TypeMethodDescriptiondefault ArgsParserArgsParserAccessor.ArgsParserProperty.letArgsParser(ArgsParser aArgsParser) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenArgsParser(setter) as ofArgsParserAccessor.ArgsParserMutator.setArgsParser(ArgsParser)and returns the very same value (getter).voidArgsParserAccessor.ArgsParserMutator.setArgsParser(ArgsParser aArgsParser) Sets the args-parser for theArgsParserproperty.ArgsParserAccessor.ArgsParserBuilder.withArgsParser(ArgsParser aArgsParser) Sets the args-parser for theArgsParserproperty.