Uses of Interface
org.refcodes.cli.ArgsParserBuilder
-
Uses of ArgsParserBuilder in org.refcodes.cli
Classes in org.refcodes.cli with type parameters of type ArgsParserBuilderModifier and TypeInterfaceDescriptioninterfaceArgsParserBuilder<B extends ArgsParserBuilder<B>>This mixin provides builder additions (as of the builder pattern for chained configuring method calls) for parsing command line arguments.Subinterfaces of ArgsParserBuilder in org.refcodes.cliModifier and TypeInterfaceDescriptioninterfaceTheParseArgsprovides means for parsing command line arguments and constructing a command line utility's help output.Classes in org.refcodes.cli that implement ArgsParserBuilderModifier and TypeClassDescriptionclassA straightforward implementation of theParseArgsinterface.