Uses of Interface
org.refcodes.cli.ArgsParserMixin
-
Uses of ArgsParserMixin in org.refcodes.cli
Classes in org.refcodes.cli with type parameters of type ArgsParserMixinModifier and TypeInterfaceDescriptioninterfaceArgsParserMixin<B extends ArgsParserMixin<B>>This mixin provides builder additions (as of the builder pattern for chained configuring method calls) for parsing command line arguments.Subinterfaces of ArgsParserMixin in org.refcodes.cliModifier and TypeInterfaceDescriptioninterfaceTheArgsParserprovides means for parsing command line arguments and constructing a command line utility's help output.Classes in org.refcodes.cli that implement ArgsParserMixinModifier and TypeClassDescriptionclassA straightforward implementation of theArgsParserinterface.