Uses of Interface
org.refcodes.cli.ArgsSyntax
-
-
Uses of ArgsSyntax in org.refcodes.cli
Subinterfaces of ArgsSyntax in org.refcodes.cli Modifier and Type Interface Description interfaceConditionInterface indicating that theArgsSyntaxsemantically represents a condition which usally encapsulates otherSyntaxablechildren.Classes in org.refcodes.cli that implement ArgsSyntax Modifier and Type Class Description classAbstractConditionTheAbstractConditionis an abstract implementation of theArgsSyntaxinterface providing the boiler plate when implementing theArgsSyntaxinterface as done by theAbstractCondition's sub-classes.classAllConditionTheAllConditionenforces that the encapsulatedSyntaxableconsumes all arguments passed via invoking itsSyntaxable.parseArgs(String[]), else aSuperfluousArgsExceptionis thrown.classAndConditionAnAndConditioncontains (represents) a list ofArgsSyntax(Syntaxable) instances (nested by theAndCondition) of which all are to be parsed successfully as of invoking theSyntaxable.parseArgs(String[], String[])methods.classAnyConditionAny of the nestedArgsSyntaxconditions may match for theAnyConditionto match, e.g. all of the nested conditions are optional.classCasesConditionTheCasesConditionis anXorConditionmaking sure that all possible cases inside theXorConditionmust(!)classOptionConditionclassOrConditionAnOrConditionrepresents a list ofArgsSyntax(Syntaxable) instances of which at least one must be parsed successfully when theSyntaxables'Syntaxable.parseArgs(String[], String[])methods are invoked.classXorConditionAnXorConditionrepresents a list ofArgsSyntax(Syntaxable) instances of which only one is allowed to be parsed successfully when theSyntaxable.parseArgs(String[], String[])methods are invoked.Methods in org.refcodes.cli that return ArgsSyntax Modifier and Type Method Description static ArgsSyntaxCliSugar. all(Syntaxable aArg)static ArgsSyntaxCliSugar. and(Syntaxable... aArgs)static ArgsSyntaxCliSugar. any(Syntaxable... aArgs)static ArgsSyntaxCliSugar. cases(Syntaxable... aArgs)ArgsSyntaxArgsParser. getArgsSyntax()The root condition is the starting point node of aSyntaxablehierarchy to be traversed when determining the syntax for command line arguments or when evaluating the command line arguments.ArgsSyntaxArgsParserImpl. getArgsSyntax()The root condition is the starting point node of aSyntaxablehierarchy to be traversed when determining the syntax for command line arguments or when evaluating the command line arguments.ArgsSyntaxRootConditionAccessor. getArgsSyntax()Retrieves the root condition from the root condition property.default ArgsSyntaxRootConditionAccessor.RootConditionProperty. letRootArgsSyntax(ArgsSyntax aRootArgsSyntax)This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenArgsSyntax(setter) as ofRootConditionAccessor.RootConditionMutator.setRootArgsSyntax(ArgsSyntax)and returns the very same value (getter).static ArgsSyntaxCliSugar. optional(Syntaxable... aArgs)Semantically identical synonym for theCliSugar.optional(Syntaxable...)declaration.static ArgsSyntaxCliSugar. or(Syntaxable... aArgs)static ArgsSyntaxCliSugar. xor(Syntaxable... aArgs)Methods in org.refcodes.cli with parameters of type ArgsSyntax Modifier and Type Method Description default ArgsSyntaxRootConditionAccessor.RootConditionProperty. letRootArgsSyntax(ArgsSyntax aRootArgsSyntax)This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenArgsSyntax(setter) as ofRootConditionAccessor.RootConditionMutator.setRootArgsSyntax(ArgsSyntax)and returns the very same value (getter).voidRootConditionAccessor.RootConditionMutator. setRootArgsSyntax(ArgsSyntax aRootArgsSyntax)Sets the root condition for the root condition property.BRootConditionAccessor.RootConditionBuilder. withRootArgsSyntax(ArgsSyntax aRootArgsSyntax)Sets the root condition for the root condition property.Constructors in org.refcodes.cli with parameters of type ArgsSyntax Constructor Description ArgsParserImpl(ArgsSyntax aRootArgsSyntax)Constructs theArgsParserinstance with the given rootArgsSyntaxand the defaultSyntaxNotation.REFCODES.
-