Uses of Interface
org.refcodes.cli.ArgsSyntaxAccessor.ArgsSyntaxBuilder
-
Uses of ArgsSyntaxAccessor.ArgsSyntaxBuilder in org.refcodes.cli
Classes in org.refcodes.cli with type parameters of type ArgsSyntaxAccessor.ArgsSyntaxBuilderModifier and TypeInterfaceDescriptionstatic interfaceProvides a builder method for a (root)Termproperty returning the builder for applying multiple build operations.Subinterfaces of ArgsSyntaxAccessor.ArgsSyntaxBuilder in org.refcodes.cliModifier and TypeInterfaceDescriptioninterfaceArgsProcessorBuilder<B extends ArgsProcessorBuilder<B>>TheArgsProcessorBuilderprovides common minimum builder functionality required by to build an argument processing instance.interfaceTheParseArgsprovides means for parsing command line arguments and constructing a command line utility's help output.Classes in org.refcodes.cli that implement ArgsSyntaxAccessor.ArgsSyntaxBuilderModifier and TypeClassDescriptionclassA straightforward implementation of theParseArgsinterface.