Uses of Class
org.refcodes.cli.ArgsSyntaxException
-
Uses of ArgsSyntaxException in org.refcodes.cli
Subclasses of ArgsSyntaxException in org.refcodes.cliModifier and TypeClassDescriptionclassThrown in case the command line arguments do not match the required syntax.classThrown in case the provided command line arguments do not respect the required semantics or cannot be converted to the required type.classThrown in case the provided command line arguments do not respect the required semantics or cannot be converted to the required type by aDirective(having an operation alongside an expected operand), e.g.classThrown in case the provided command line arguments do not respect the required semantics or cannot be converted to the required type by anOption(having a short- and/or a long-option), e.g. the arguments were rejected as them did not work for the according syntax.classThrown in case there were arguments found not being used (superfluous arguments).classThrown in case command line arguments were not processed (did not match the expected arguments), e.g. the arguments were rejected as them did not work for the according syntax.classThrown in case command line arguments were not processed (did not match the expected arguments) by anOption(having a short- and/or a long-option), e.g. the arguments were rejected as them did not work for the according syntax.classThrown in case command line arguments were not processed (did not match the expected arguments) by anOption(having a short- and/or a long-option), e.g. the arguments were rejected as them did not work for the according syntax.Subinterfaces with type arguments of type ArgsSyntaxException in org.refcodes.cliModifier and TypeInterfaceDescriptioninterfaceATermrepresents a node within a command line argument syntax tree.Fields in org.refcodes.cli declared as ArgsSyntaxExceptionModifier and TypeFieldDescriptionprotected ArgsSyntaxExceptionAbstractTerm._exceptionprotected ArgsSyntaxExceptionAbstractTerm._exceptionprotected ArgsSyntaxExceptionAbstractTerm._exceptionprotected ArgsSyntaxExceptionAbstractTerm._exceptionprotected ArgsSyntaxExceptionAbstractTerm._exceptionprotected ArgsSyntaxExceptionAbstractTerm._exceptionprotected ArgsSyntaxExceptionAbstractTerm._exceptionprotected ArgsSyntaxExceptionAbstractTerm._exceptionprotected ArgsSyntaxExceptionAbstractTerm._exceptionprotected ArgsSyntaxExceptionAbstractTerm._exceptionprotected ArgsSyntaxExceptionAbstractTerm._exceptionprotected ArgsSyntaxExceptionAbstractTerm._exceptionprotected ArgsSyntaxExceptionAbstractTerm._exceptionprotected ArgsSyntaxExceptionAbstractTerm._exceptionprotected ArgsSyntaxExceptionAbstractTerm._exceptionprotected ArgsSyntaxExceptionAbstractTerm._exceptionprotected ArgsSyntaxExceptionAbstractTerm._exceptionprotected ArgsSyntaxExceptionAbstractTerm._exceptionprotected ArgsSyntaxExceptionAbstractTerm._exceptionprotected ArgsSyntaxExceptionAbstractTerm._exceptionprotected ArgsSyntaxExceptionAbstractTerm._exceptionprotected ArgsSyntaxExceptionAbstractTerm._exceptionprotected ArgsSyntaxExceptionAbstractTerm._exceptionprotected ArgsSyntaxExceptionAbstractTerm._exceptionprotected ArgsSyntaxExceptionAbstractTerm._exceptionprotected ArgsSyntaxExceptionAbstractTerm._exceptionprotected ArgsSyntaxExceptionAbstractTerm._exceptionprotected ArgsSyntaxExceptionAbstractTerm._exceptionprotected ArgsSyntaxExceptionAbstractTerm._exceptionprotected ArgsSyntaxExceptionAbstractTerm._exceptionprotected ArgsSyntaxExceptionAbstractTerm._exceptionprotected ArgsSyntaxExceptionAbstractTerm._exceptionprotected ArgsSyntaxExceptionAbstractTerm._exceptionprotected ArgsSyntaxExceptionAbstractTerm._exceptionprotected ArgsSyntaxExceptionAbstractTerm._exceptionprotected ArgsSyntaxExceptionAbstractTerm._exceptionprotected ArgsSyntaxExceptionAbstractTerm._exceptionprotected ArgsSyntaxExceptionAbstractTerm._exceptionprotected ArgsSyntaxExceptionAbstractTerm._exceptionprotected ArgsSyntaxExceptionAbstractTerm._exceptionprotected ArgsSyntaxExceptionAbstractTerm._exceptionprotected ArgsSyntaxExceptionAbstractTerm._exceptionprotected ArgsSyntaxExceptionAbstractTerm._exceptionprotected ArgsSyntaxExceptionAbstractTerm._exceptionprotected ArgsSyntaxExceptionAbstractTerm._exceptionprotected ArgsSyntaxExceptionAbstractTerm._exceptionprotected ArgsSyntaxExceptionAbstractTerm._exceptionprotected ArgsSyntaxExceptionAbstractTerm._exceptionprotected ArgsSyntaxExceptionAbstractTerm._exceptionprotected ArgsSyntaxExceptionAbstractTerm._exceptionprotected ArgsSyntaxExceptionAbstractTerm._exceptionprotected ArgsSyntaxExceptionAbstractTerm._exceptionprotected ArgsSyntaxExceptionAbstractTerm._exceptionprotected ArgsSyntaxExceptionAbstractTerm._exceptionprotected ArgsSyntaxExceptionAbstractTerm._exceptionprotected ArgsSyntaxExceptionAbstractTerm._exceptionMethods in org.refcodes.cli that return ArgsSyntaxExceptionModifier and TypeMethodDescriptionAnyCondition.getException()Retrieves theArgsSyntaxExceptionexception caught while invoking theTerm.parseArgs(String[], CliContext)method.Term.getException()Retrieves theArgsSyntaxExceptionexception in case invokingTerm.parseArgs(String[], CliContext)failed.ArgsSyntaxException.toRootMatchCause()Determines the root cause of this exception with the same match count (getMatchCount()) as this exception.Methods in org.refcodes.cli that throw ArgsSyntaxExceptionModifier and TypeMethodDescriptiondefault Operand<?>[]Term.argsParser(String[] aArgs) Parses the given command line arguments using thisTermas the root of the syntax tree.Operand<?>[]Evaluates the provided command line arguments and determines the according values by evaluating the rootCondition.default Operand<?>[]Evaluates the provided command line arguments as ofArgsParser.evalArgs(String[]), additionally filtering (excluding) the arguments matching the providedPattern.default Operand<?>[]ArgsParser.evalArgs(String[] aArgs, ArgsFilter aArgsFilter) Evaluates the provided command line arguments as ofArgsParser.evalArgs(String[]), additionally filtering (excluding) the arguments matching the providedArgsFilter.default Operand<?>[]Same asArgsParser.evalArgs(String[])with the difference that the elements representing the arguments are passed as a list instead of an array.default Operand<?>[]Evaluates the provided command line arguments as ofArgsParser.evalArgs(String[]), additionally filtering (excluding) the arguments matching the providedPattern.default Operand<?>[]ArgsParser.evalArgs(List<String> aArgs, ArgsFilter aArgsFilter) Evaluates the provided command line arguments as ofArgsParser.evalArgs(String[]), additionally filtering (excluding) the arguments matching the providedArgsFilter.Operand<?>[]Evaluates the provided command line arguments and determines the according values by evaluating the rootCondition.Operand<?>[]AbstractDirective.parseArgs(String[] aArgs, String[] aKeywords, CliContext aCliCtx) Parses the given command line arguments using the provided keyword set and CLI context.Operand<?>[]AbstractOperand.parseArgs(String[] aArgs, String[] aKeywords, CliContext aCliCtx) Parses the given command line arguments using the provided keyword set and CLI context.Operand<?>[]AbstractOption.parseArgs(String[] aArgs, String[] aKeywords, CliContext aCliCtx) Parses the given command line arguments using the provided keyword set and CLI context.Operand<?>[]AbstractProperty.parseArgs(String[] aArgs, String[] aKeywords, CliContext aCliCtx) Parses the given command line arguments using the provided keyword set and CLI context.Operand<?>[]AllCondition.parseArgs(String[] aArgs, String[] aKeywords, CliContext aCliCtx) Parses the given command line arguments using the provided keyword set and CLI context.Operand<?>[]AndCondition.parseArgs(String[] aArgs, String[] aKeywords, CliContext aCliCtx) Parses the given command line arguments using the provided keyword set and CLI context.Operand<?>[]AnyCondition.parseArgs(String[] aArgs, String[] aKeywords, CliContext aCliCtx) Parses the given command line arguments using the provided keyword set and CLI context.Operand<?>[]ArrayOperand.parseArgs(String[] aArgs, String[] aOperands, CliContext aCliCtx) Parses the given command line arguments using the provided keyword set and CLI context.Flag.parseArgs(String[] aArgs, String[] aKeywords, CliContext aCliCtx) Parses the given command line arguments using the provided keyword set and CLI context.Operand<?>[]NoneOperand.parseArgs(String[] aArgs, String[] aKeywords, CliContext aCliCtx) Parses the given command line arguments using the provided keyword set and CLI context.Operation.parseArgs(String[] aArgs, String[] aKeywords, CliContext aCliCtx) Parses the given command line arguments using the provided keyword set and CLI context.Operand<?>[]OrCondition.parseArgs(String[] aArgs, String[] aKeywords, CliContext aCliCtx) Parses the given command line arguments using the provided keyword set and CLI context.Operand<?>[]Term.parseArgs(String[] aArgs, String[] aKeywords, CliContext aCliCtx) Parses the given command line arguments using the provided keyword set and CLI context.default Operand<?>[]Term.parseArgs(String[] aArgs, CliContext aCliCtx) Parses the given command line arguments using the provided CLI context deriving its keyword.Operand<?>[]XorCondition.parseArgs(String[] aArgs, String[] aKeywords, CliContext aCliCtx) Parses the given command line arguments using the provided keyword set and CLI context.default ArgsParserArgsParser.withEvalArgs(String[] aArgs) Evaluates the provided command line arguments.default ArgsParserArgsParser.withEvalArgs(List<String> aArgs) Evaluates the provided command line arguments .ArgsParserBuilder.withEvalArgs(String[] aArgs) Evaluates the provided command line arguments.default BArgsParserBuilder.withEvalArgs(String[] aArgs, Pattern aFilterExp) Evaluates the provided command line arguments, filtering (excluding) the arguments matching the providedPattern.default BArgsParserBuilder.withEvalArgs(String[] aArgs, ArgsFilter aArgsFilter) Evaluates the provided command line arguments, filtering (excluding) the arguments matching the providedArgsFilter.default BArgsParserBuilder.withEvalArgs(List<String> aArgs) Evaluates the provided command line arguments .default BArgsParserBuilder.withEvalArgs(List<String> aArgs, Pattern aFilterExp) Evaluates the provided command line arguments, filtering (excluding) the arguments matching the providedPattern.default BArgsParserBuilder.withEvalArgs(List<String> aArgs, ArgsFilter aArgsFilter) Evaluates the provided command line arguments, filtering (excluding) the arguments matching the providedArgsFilter.CliArgsParser.withEvalArgs(String[] aArgs) Evaluates the provided command line arguments.CliArgsParser.withEvalArgs(String[] aArgs, Pattern aFilterExp) Evaluates the provided command line arguments, filtering (excluding) the arguments matching the providedPattern.CliArgsParser.withEvalArgs(String[] aArgs, ArgsFilter aArgsFilter) Evaluates the provided command line arguments, filtering (excluding) the arguments matching the providedArgsFilter.CliArgsParser.withEvalArgs(List<String> aArgs) Evaluates the provided command line arguments .CliArgsParser.withEvalArgs(List<String> aArgs, Pattern aFilterExp) Evaluates the provided command line arguments, filtering (excluding) the arguments matching the providedPattern.CliArgsParser.withEvalArgs(List<String> aArgs, ArgsFilter aArgsFilter) Evaluates the provided command line arguments, filtering (excluding) the arguments matching the providedArgsFilter.