Uses of Interface
org.refcodes.cli.ArgumentPrefixAccessor
-
Uses of ArgumentPrefixAccessor in org.refcodes.cli
Subinterfaces of ArgumentPrefixAccessor in org.refcodes.cliModifier and TypeInterfaceDescriptionstatic interfaceProvides an argument prefix property.interfaceTheSyntaxMetricsprovides properties specific to a specific command line syntax notation.Classes in org.refcodes.cli that implement ArgumentPrefixAccessorModifier and TypeClassDescriptionclassTheSyntaxMetricsBuilderclass implements theSyntaxMetricsinterface for building customSyntaxMetricsinstances.enumTheSyntaxNotationis used by a theTerm.toSyntax(CliContext)method to determine which notation to be used for the generated syntax.