Uses of Interface
org.refcodes.cli.ArgumentSuffixAccessor
-
Uses of ArgumentSuffixAccessor in org.refcodes.cli
Subinterfaces of ArgumentSuffixAccessor in org.refcodes.cliModifier and TypeInterfaceDescriptionstatic interfaceProvides an argument suffix property.interfaceTheSyntaxMetricsprovides properties specific to a specific command line syntax notation.Classes in org.refcodes.cli that implement ArgumentSuffixAccessorModifier and TypeClassDescriptionclassTheSyntaxMetricsImplclass implements theSyntaxMetricsinterface for building customSyntaxMetricsinstances.enumTheSyntaxNotationis used by a theConstituent.toSyntax(CliContext)method to determine which notation to be used for the generated syntax.