Uses of Interface
org.refcodes.cli.BannerFontAccessor.BannerFontBuilder
-
Uses of BannerFontAccessor.BannerFontBuilder in org.refcodes.cli
Classes in org.refcodes.cli with type parameters of type BannerFontAccessor.BannerFontBuilderModifier and TypeInterfaceDescriptionstatic interfaceProvides a builder method for a bannerFontproperty returning the builder for applying multiple build operations.Subinterfaces of BannerFontAccessor.BannerFontBuilder in org.refcodes.cliModifier and TypeInterfaceDescriptioninterfaceTheArgsParserprovides means for parsing command line arguments and constructing a command line utility's help output.interfaceArgsProcessorBuilder<B extends ArgsProcessorBuilder<B>>TheArgsProcessorBuilderprovides common minimum builder functionality required by to build an argument processing instance.Classes in org.refcodes.cli that implement BannerFontAccessor.BannerFontBuilderModifier and TypeClassDescriptionclassA straightforward implementation of theArgsParserinterface.