Uses of Class
org.refcodes.cli.CliContext
-
Uses of CliContext in org.refcodes.cli
Methods in org.refcodes.cli that return CliContextModifier and TypeMethodDescriptionCliContext.Builder.build()CliContext.Builderfor fluently building aCliContextinstances.CliContextAccessor.getCliContext()Retrieves theCliContextfrom theCliContextproperty.default CliContextCliContextAccessor.CliContextProperty.letCliContext(CliContext aCliCtx) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenCliContext(setter) as ofCliContextAccessor.CliContextMutator.setCliContext(CliContext)and returns the very same value (getter).Methods in org.refcodes.cli with parameters of type CliContextModifier and TypeMethodDescriptiondefault CliContextCliContextAccessor.CliContextProperty.letCliContext(CliContext aCliCtx) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenCliContext(setter) as ofCliContextAccessor.CliContextMutator.setCliContext(CliContext)and returns the very same value (getter).Operand<?>[]AbstractDirective.parseArgs(String[] aArgs, String[] aKeywords, CliContext aCliCtx) Parses the given command line arguments using the provided keyword set and CLI context.Operand<?>[]AbstractOperand.parseArgs(String[] aArgs, String[] aKeywords, CliContext aCliCtx) Parses the given command line arguments using the provided keyword set and CLI context.Operand<?>[]AbstractOption.parseArgs(String[] aArgs, String[] aKeywords, CliContext aCliCtx) Parses the given command line arguments using the provided keyword set and CLI context.Operand<?>[]AbstractProperty.parseArgs(String[] aArgs, String[] aKeywords, CliContext aCliCtx) Parses the given command line arguments using the provided keyword set and CLI context.Operand<?>[]AllCondition.parseArgs(String[] aArgs, String[] aKeywords, CliContext aCliCtx) Parses the given command line arguments using the provided keyword set and CLI context.Operand<?>[]AndCondition.parseArgs(String[] aArgs, String[] aKeywords, CliContext aCliCtx) Parses the given command line arguments using the provided keyword set and CLI context.Operand<?>[]AnyCondition.parseArgs(String[] aArgs, String[] aKeywords, CliContext aCliCtx) Parses the given command line arguments using the provided keyword set and CLI context.Operand<?>[]ArrayOperand.parseArgs(String[] aArgs, String[] aOperands, CliContext aCliCtx) Parses the given command line arguments using the provided keyword set and CLI context.Flag.parseArgs(String[] aArgs, String[] aKeywords, CliContext aCliCtx) Parses the given command line arguments using the provided keyword set and CLI context.Operand<?>[]NoneOperand.parseArgs(String[] aArgs, String[] aKeywords, CliContext aCliCtx) Parses the given command line arguments using the provided keyword set and CLI context.Operation.parseArgs(String[] aArgs, String[] aKeywords, CliContext aCliCtx) Parses the given command line arguments using the provided keyword set and CLI context.Operand<?>[]OrCondition.parseArgs(String[] aArgs, String[] aKeywords, CliContext aCliCtx) Parses the given command line arguments using the provided keyword set and CLI context.Operand<?>[]Term.parseArgs(String[] aArgs, String[] aKeywords, CliContext aCliCtx) Parses the given command line arguments using the provided keyword set and CLI context.default Operand<?>[]Term.parseArgs(String[] aArgs, CliContext aCliCtx) Parses the given command line arguments using the provided CLI context deriving its keyword.Operand<?>[]XorCondition.parseArgs(String[] aArgs, String[] aKeywords, CliContext aCliCtx) Parses the given command line arguments using the provided keyword set and CLI context.voidCliContextAccessor.CliContextMutator.setCliContext(CliContext aCliCtx) Sets theCliContextfor theCliContextproperty.protected UnknownArgsExceptionAbstractOption.toException(String[] aArgs, CliContext aCliCtx) Convenience method to create anUnknownArgsException.String[]ArrayOperand.toKeywords(CliContext aCliCtx) Produces the keywords (short and/or long options, operations, commands, whatever) with the according prefix (if any) to be considered when overall parsing the command line arguments.default String[]Directive.toKeywords(CliContext aCliCtx) Produces the keywords (short and/or long options, operations, commands, whatever) with the according prefix (if any) to be considered when overall parsing the command line arguments.default String[]Operand.toKeywords(CliContext aCliCtx) Produces the keywords (short and/or long options, operations, commands, whatever) with the according prefix (if any) to be considered when overall parsing the command line arguments.String[]Operation.toKeywords(CliContext aCliCtx) Produces the keywords (short and/or long options, operations, commands, whatever) with the according prefix (if any) to be considered when overall parsing the command line arguments.default String[]Option.toKeywords(CliContext aCliCtx) Produces the keywords (short and/or long options, operations, commands, whatever) with the according prefix (if any) to be considered when overall parsing the command line arguments.default StringOption.toLongOption(CliContext aCliCtx) Creates theCliContextinstance specific prefixed long optionStringfrom thisOptionby prefixing theOption's long option (as ofOption.getLongOption()) with the long option prefix (as ofLongOptionPrefixAccessor.getLongOptionPrefix()).AbstractProperty.toPropertyArgument(String[] aArgs, String aOption, CliContext aCliCtx) AbstractProperty.toPropertyArgument(String[] aArgs, CliContext aCliCtx) default StringOption.toShortOption(CliContext aCliCtx) Creates theCliContextinstance specific prefixed short optionStringfrom thisOptionby prefixing theOption's short option (as ofOption.getShortOption()) with the short option prefix (as ofShortOptionPrefixAccessor.getShortOptionPrefix()).ArrayOperand.toSpec(CliContext aCliCtx) Creates a specification including its arguments.default StringDirective.toSpec(CliContext aCliCtx) Creates a specification including its arguments.Flag.toSpec(CliContext aCliCtx) Creates a specification including its arguments.NoneOperand.toSpec(CliContext aCliCtx) Creates a specification including its arguments.default StringOperand.toSpec(CliContext aCliCtx) Creates a specification including its arguments.Operation.toSpec(CliContext aCliCtx) Creates a specification including its arguments.default StringOption.toSpec(CliContext aCliCtx) Creates a specification including its arguments.default StringProperty.toSpec(CliContext aCliCtx) Creates a specification including its arguments.AllCondition.toSynopsis(CliContext aCliCtx) Creates the synopsis for the syntax hierarchy.AndCondition.toSynopsis(CliContext aCliCtx) Creates the synopsis for the syntax hierarchy.OrCondition.toSynopsis(CliContext aCliCtx) Creates the synopsis for the syntax hierarchy.Synopsisable.toSynopsis(CliContext aCliCtx) Creates the synopsis for the syntax hierarchy.default StringTerm.toSynopsis(CliContext aCliCtx) Creates the synopsis for the syntax hierarchy.XorCondition.toSynopsis(CliContext aCliCtx) Creates the synopsis for the syntax hierarchy.AbstractCondition.toSyntax(CliContext aCliCtx) Creates a syntax including its arguments.AllCondition.toSyntax(CliContext aCliCtx) Creates a syntax including its arguments.AndCondition.toSyntax(CliContext aCliCtx) Creates a syntax including its arguments.AnyCondition.toSyntax(CliContext aCliCtx) Creates a syntax including its arguments.ArrayDirective.toSyntax(CliContext aCliCtx) Creates a syntax including its arguments.ArrayOperand.toSyntax(CliContext aCliCtx) Creates a syntax including its arguments.ArrayOption.toSyntax(CliContext aCliCtx) Creates a syntax including its arguments.default StringDirective.toSyntax(CliContext aCliCtx) Creates a syntax including its arguments.Flag.toSyntax(CliContext aCliCtx) Creates a syntax including its arguments.NoneOperand.toSyntax(CliContext aCliCtx) Creates a syntax including its arguments.default StringOperand.toSyntax(CliContext aCliCtx) Creates a syntax including its arguments.Operation.toSyntax(CliContext aCliCtx) Creates a syntax including its arguments.default StringOption.toSyntax(CliContext aCliCtx) Creates a syntax including its arguments.default StringProperty.toSyntax(CliContext aCliCtx) Creates a syntax including its arguments.Term.toSyntax(CliContext aCliCtx) Creates a syntax including its arguments.ArrayOperand.toUsage(CliContext aCliCtx) Creates a plain usage specification without any escape codes, helpful e.g. in human readable messages.default StringDirective.toUsage(CliContext aCliCtx) Creates a plain usage specification without any escape codes, helpful e.g. in human readable messages.NoneOperand.toUsage(CliContext aCliCtx) Creates a plain usage specification without any escape codes, helpful e.g. in human readable messages.default StringOperand.toUsage(CliContext aCliCtx) Creates a plain usage specification without any escape codes, helpful e.g. in human readable messages.Operation.toUsage(CliContext aCliCtx) Creates a plain usage specification without any escape codes, helpful e.g. in human readable messages.default StringOption.toUsage(CliContext aCliCtx) Creates a plain usage specification without any escape codes, helpful e.g. in human readable messages.CliContextAccessor.CliContextBuilder.withCliContext(CliContext aCliCtx) Sets theCliContextfor theCliContextproperty.Constructors in org.refcodes.cli with parameters of type CliContextModifierConstructorDescriptionCliArgsParser(CliContext aCliCtx) Constructs theArgsParserinstance without any restrictions to the parsed arguments.CliArgsParser(Term aArgsSyntax, CliContext aCliCtx) Constructs theArgsParserinstance with the given rootConditionand the defaultSyntaxNotation.LOGICAL.