Thrown in case the provided command line arguments do not respect the
required semantics or cannot be converted to the required type by a
Directive (having an operation alongside an expected operand), e.g.
Thrown in case the provided command line arguments do not respect the
required semantics or cannot be converted to the required type by an
Option (having a short- and/or a long-option), e.g. the arguments
were rejected as them did not work for the according syntax.
Thrown in case command line arguments were not processed (did not match the
expected arguments), e.g. the arguments were rejected as them did not work
for the according syntax.
Thrown in case command line arguments were not processed (did not match the
expected arguments) by an Option (having a short- and/or a
long-option), e.g. the arguments were rejected as them did not work for the
according syntax.
Thrown in case command line arguments were not processed (did not match the
expected arguments) by an Option (having a short- and/or a
long-option), e.g. the arguments were rejected as them did not work for the
according syntax.