Uses of Class
org.refcodes.cli.CliException.ConsoleArgsException
-
-
Uses of CliException.ConsoleArgsException in org.refcodes.cli
Subclasses of CliException.ConsoleArgsException in org.refcodes.cli Modifier and Type Class Description classAmbiguousArgsExceptionThrown in case the command line arguments do not match the required syntax.classArgsSyntaxExceptionThrown in case of a command line arguments mismatch regarding provided and expected args.classParseArgsExceptionThrown in case the provided command line arguments do not respect the required semantics or cannot be converted to the required type.classSuperfluousArgsExceptionThrown in case there were arguments found not being used (superfluous arguments).classUnknownArgsExceptionThrown in case command line arguments were not processed (did not match the expected arguments), e.g. the arguments were rejected as them did not work for the according syntax.
-