Uses of Enum Class
org.refcodes.cli.CliSchemaOntology
-
Uses of CliSchemaOntology in org.refcodes.cli
Subclasses with type arguments of type CliSchemaOntology in org.refcodes.cliModifier and TypeClassDescriptionenumTheCliSchemaOntologydescribes the terms used in the CLI forSchemageneration.Methods in org.refcodes.cli that return CliSchemaOntologyModifier and TypeMethodDescriptionstatic CliSchemaOntologyReturns the enum constant of this class with the specified name.static CliSchemaOntology[]CliSchemaOntology.values()Returns an array containing the constants of this enum class, in the order they are declared.