Uses of Interface
org.refcodes.cli.Condition
-
Uses of Condition in org.refcodes.cli
Classes in org.refcodes.cli that implement ConditionModifier and TypeClassDescriptionclassTheAbstractConditionis an abstract implementation of theConditioninterface providing the boiler plate when implementing theConditioninterface as done by theAbstractCondition's sub-classes.classTheAllConditionenforces that the encapsulatedTermconsumes all arguments passed via invoking itsTerm.parseArgs(String[], CliContext), else aSuperfluousArgsExceptionis thrown.classAnAndConditioncontains (represents) a list ofCondition(Term) instances (nested by theAndCondition) of which all are to be parsed successfully as of invoking theTerm.parseArgs(String[], String[], CliContext)methods.classAny of the nestedConditionconditions may match for theAnyConditionto match, e.g. all of the nested conditions are optional.classTheCasesConditionis anXorConditionmaking sure that all possible cases inside theXorConditionmust(!)classAnOrConditionrepresents a list ofCondition(Term) instances of which at least one must be parsed successfully when theTerms'Term.parseArgs(String[], String[], CliContext)methods are invoked.classAnXorConditionrepresents a list ofCondition(Term) instances of which only one is allowed to be parsed successfully when theTerm.parseArgs(String[], String[], CliContext)methods are invoked.Methods in org.refcodes.cli that return Condition