Uses of Interface
org.refcodes.cli.Directive
-
Uses of Directive in org.refcodes.cli
Classes in org.refcodes.cli that implement DirectiveModifier and TypeClassDescriptionclassTheAbstractDirectiveis an abstract implementation of anDirectiveproviding the boiler plate when implementing theDirectiveinterface.classCreates an array representation facade for the encapsulatedDirective.classclassclassclassEnumDirective<T extends Enum<T>>TheEnumDirectiverepresents aDirectiveof enumeration types.classclassclassclassclassMethods in org.refcodes.cli with parameters of type DirectiveModifier and TypeMethodDescriptionstatic <T> ArrayDirective<T> Creates an array representation facade for the encapsulatedDirective.static <T> ArrayDirective<T> Creates an array representation facade for the encapsulatedDirective.static <T> ArrayDirective<T> Creates an array representation facade for the encapsulatedDirective.Constructors in org.refcodes.cli with parameters of type DirectiveModifierConstructorDescriptionArrayDirective(Directive<T> aDirective) Constructs theArrayDirectiveby encapsulating the givenDirectiveand providing its definition as array definition to the CLI.ArrayDirective(Directive<T> aDirective, int aLength) Constructs theArrayDirectiveby encapsulating the givenDirectiveand providing its definition as array definition to the CLI.ArrayDirective(Directive<T> aDirective, int aMinLength, int aMaxLength) Constructs theArrayDirectiveby encapsulating the givenDirectiveand providing its definition as array definition to the CLI.