Uses of Class
org.refcodes.cli.Example
-
Uses of Example in org.refcodes.cli
Methods in org.refcodes.cli that return ExampleModifier and TypeMethodDescriptionstatic Examplestatic Example[]Sugar for creating anExamplearray from a varargs argument.Example[]ArgsParser.getExamples()Example[]ExamplesAccessor.getExamples()Example[]ParseArgs.getExamples()default Example[]ExamplesAccessor.ExamplesProperty.letExamples(Example[] aExamples) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenCondition(setter) as ofExamplesAccessor.ExamplesMutator.setExamples(Example[])and returns the very same value (getter).Methods in org.refcodes.cli with parameters of type ExampleModifier and TypeMethodDescriptionvoidArgsParser.addExample(Example aExampleUsage) Adds a usage example by providing a description of the example and the command line arguments required by the example.voidParseArgs.addExample(Example aExample) Adds a usage example by providing a description of the example and the command line arguments required by the example.static Example[]Sugar for creating anExamplearray from a varargs argument.default Example[]ExamplesAccessor.ExamplesProperty.letExamples(Example[] aExamples) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenCondition(setter) as ofExamplesAccessor.ExamplesMutator.setExamples(Example[])and returns the very same value (getter).voidArgsParser.setExamples(Example[] aExamples) voidExamplesAccessor.ExamplesMutator.setExamples(Example[] aExamples) ArgsParser.withAddExample(Example aExamples) Builder method adding an application'sExampleelement.ArgsProcessorBuilder.withAddExample(Example aExamples) Builder method adding an application'sExampleelement.default ParseArgsParseArgs.withAddExample(Example aExample) Builder method adding an application'sExampleelement.ArgsParser.withExamples(Example[] aExamples) ExamplesAccessor.ExamplesBuilder.withExamples(Example[] aExamples) default ParseArgsParseArgs.withExamples(Example[] aExamples) Method parameters in org.refcodes.cli with type arguments of type ExampleModifier and TypeMethodDescriptiondefault voidExamplesAccessor.ExamplesMutator.setExamples(Collection<Example> aExamples) ArgsParser.withExamples(Collection<Example> aExamples) Builder method providing the application'sExampleelements.default BExamplesAccessor.ExamplesBuilder.withExamples(Collection<Example> aExamples) Builder method providing the application'sExampleelements.default ParseArgsParseArgs.withExamples(Collection<Example> aExamples) Builder method providing the application'sExampleelements.