Uses of Interface
org.refcodes.cli.ExamplesAccessor.ExamplesBuilder
-
Uses of ExamplesAccessor.ExamplesBuilder in org.refcodes.cli
Classes in org.refcodes.cli with type parameters of type ExamplesAccessor.ExamplesBuilderModifier and TypeInterfaceDescriptionstatic interfaceProvides a builder method for anExampleinstances property returning the builder for applying multiple build operations.Subinterfaces of ExamplesAccessor.ExamplesBuilder in org.refcodes.cliModifier and TypeInterfaceDescriptioninterfaceTheArgsParserprovides means for parsing command line arguments and constructing a command line utility's help output.interfaceArgsProcessorBuilder<B extends ArgsProcessorBuilder<B>>TheArgsProcessorBuilderprovides common minimum builder functionality required by to build an argument processing instance.Classes in org.refcodes.cli that implement ExamplesAccessor.ExamplesBuilderModifier and TypeClassDescriptionclassA straightforward implementation of theArgsParserinterface.