-
Methods in org.refcodes.cli that return ExitCode
| Modifier and Type |
Method |
Description |
ExitCode |
CliException.ConsoleCliException.getStatusCode() |
Gets the status code.
|
static ExitCode |
ExitCode.valueOf(String name) |
Returns the enum constant of this type with the specified name.
|
static ExitCode[] |
ExitCode.values() |
Returns an array containing the constants of this enum type, in
the order they are declared.
|
Constructors in org.refcodes.cli with parameters of type ExitCode
| Constructor |
Description |
ConsoleCliException(ExitCode aExitCode,
String message) |
Instantiates a new console cli exception.
|
ConsoleCliException(ExitCode aExitCode,
String aMessage,
String aErrorCode) |
Instantiates a new console cli exception.
|
ConsoleCliException(ExitCode aExitCode,
String message,
Throwable cause) |
Instantiates a new console cli exception.
|
ConsoleCliException(ExitCode aExitCode,
String aMessage,
Throwable aCause,
String aErrorCode) |
Instantiates a new console cli exception.
|
ConsoleCliException(ExitCode aExitCode,
Throwable cause) |
Instantiates a new console cli exception.
|
ConsoleCliException(ExitCode aExitCode,
Throwable aCause,
String aErrorCode) |
Instantiates a new console cli exception.
|