Uses of Interface
org.refcodes.cli.LicenseAccessor.LicenseBuilder
-
Uses of LicenseAccessor.LicenseBuilder in org.refcodes.cli
Classes in org.refcodes.cli with type parameters of type LicenseAccessor.LicenseBuilderModifier and TypeInterfaceDescriptionstatic interfaceLicenseAccessor.LicenseBuilder<B extends LicenseAccessor.LicenseBuilder<B>>Provides a builder method for a license property returning the builder for applying multiple build operations.Subinterfaces of LicenseAccessor.LicenseBuilder in org.refcodes.cliModifier and TypeInterfaceDescriptioninterfaceArgsProcessorBuilder<B extends ArgsProcessorBuilder<B>>TheArgsProcessorBuilderprovides common minimum builder functionality required by to build an argument processing instance.interfaceTheParseArgsprovides means for parsing command line arguments and constructing a command line utility's help output.Classes in org.refcodes.cli that implement LicenseAccessor.LicenseBuilderModifier and TypeClassDescriptionclassA straightforward implementation of theParseArgsinterface.