Uses of Interface
org.refcodes.cli.LongOptionPrefixAccessor
-
Uses of LongOptionPrefixAccessor in org.refcodes.cli
Subinterfaces of LongOptionPrefixAccessor in org.refcodes.cliModifier and TypeInterfaceDescriptioninterfaceTheArgsParserprovides means for parsing command line arguments and constructing a command line utility's help output.static interfaceProvides a long option prefix property.interfaceTheSyntaxMetricsprovides properties specific to a specific command line syntax notation.Classes in org.refcodes.cli that implement LongOptionPrefixAccessorModifier and TypeClassDescriptionclassA straightforward implementation of theArgsParserinterface.classTheSyntaxMetricsImplclass implements theSyntaxMetricsinterface for building customSyntaxMetricsinstances.enumTheSyntaxNotationis used by a theConstituent.toSyntax(CliContext)method to determine which notation to be used for the generated syntax.