Uses of Interface
org.refcodes.cli.LongOptionPrefixAccessor.LongOptionPrefixBuilder
-
Uses of LongOptionPrefixAccessor.LongOptionPrefixBuilder in org.refcodes.cli
Classes in org.refcodes.cli with type parameters of type LongOptionPrefixAccessor.LongOptionPrefixBuilderModifier and TypeInterfaceDescriptionstatic interfaceLongOptionPrefixAccessor.LongOptionPrefixBuilder<B extends LongOptionPrefixAccessor.LongOptionPrefixBuilder<B>>Provides a builder method for a long option prefix property returning the builder for applying multiple build operations.Subinterfaces of LongOptionPrefixAccessor.LongOptionPrefixBuilder in org.refcodes.cliModifier and TypeInterfaceDescriptioninterfaceTheArgsParserprovides means for parsing command line arguments and constructing a command line utility's help output.Classes in org.refcodes.cli that implement LongOptionPrefixAccessor.LongOptionPrefixBuilderModifier and TypeClassDescriptionclassA straightforward implementation of theArgsParserinterface.static final classBuilder to buildSyntaxMetricsinstances.