The Condition interface represents a node (and therewith the syntax
for the arguments) in the command line arguments syntax tree by simply
extending the Term interface and adding the functionality of
providing access to the added Operands (leafs).
The Flag class implements the Option interface for
representing either a true or a false state: When a
flag is provided to your command line arguments, then it is considered to be
true, when it is omitted, then it is considered to be
false as of Flag.isEnabled().
The Operation is an argument representing an action of functioning or
the fact of being active or in effect and is either provided (as command line
argument) or not provided as of Operation.isEnabled().
Thrown in case the provided command line arguments do not respect the
required semantics or cannot be converted to the required type by a
Directive (having an operation alongside an expected operand), e.g.
Thrown in case the provided command line arguments do not respect the
required semantics or cannot be converted to the required type by an
Option (having a short- and/or a long-option), e.g. the arguments
were rejected as them did not work for the according syntax.
Thrown in case command line arguments were not processed (did not match the
expected arguments), e.g. the arguments were rejected as them did not work
for the according syntax.
Thrown in case command line arguments were not processed (did not match the
expected arguments) by an Option (having a short- and/or a
long-option), e.g. the arguments were rejected as them did not work for the
according syntax.
Thrown in case command line arguments were not processed (did not match the
expected arguments) by an Option (having a short- and/or a
long-option), e.g. the arguments were rejected as them did not work for the
according syntax.