Uses of Interface
org.refcodes.cli.Operand
-
Uses of Operand in org.refcodes.cli
Subinterfaces of Operand in org.refcodes.cliModifier and TypeInterfaceDescriptioninterfaceDirective<T>AnDirectiverepresents a command line operation with the according operation's operand (value).interfaceOption<T>AnOptionrepresents a command line option with the according option's value.interfaceProperty<T>AnPropertyrepresents an option property with the according porperty's key and value separated by a=(and no whitespace inbetween).Classes in org.refcodes.cli that implement OperandModifier and TypeClassDescriptionclassTheAbstractDirectiveis an abstract implementation of anDirectiveproviding the boiler plate when implementing theDirectiveinterface.classTheAbstractOperandis an abstract implementation of anOperandproviding the boiler plate when implementing theOperandinterface.classTheAbstractOptionis an abstract implementation of anOptionproviding the boiler plate when implementing theOptioninterface.classTheAbstractPropertyis an abstract implementation of aPropertyproviding the boiler plate when implementing thePropertyinterface.classCreates an array representation facade for the encapsulatedDirective.classArrayOperand<T>Creates an array representation facade for the encapsulatedOperand.classArrayOption<T>Creates an array representation facade for the encapsulatedOption.classclassclassclassclassclassclassA predefined cleanFlag: A predefinedFlaggives itsCleanFlag.SHORT_OPTION, itsCleanFlag.LONG_OPTIONas well as itsCleanFlag.ALIASan according semantics regarded by other subsystems.classTheConfigOptionrepresents anOptionholding a value specifying a configuration resource (file).classTheConfigPropertyrepresents anPropertyholding a value specifying a configuration resource (file).classA predefined daemonFlag: A predefinedFlaggives itsDaemonFlag.SHORT_OPTION, itsDaemonFlag.LONG_OPTIONas well as itsDaemonFlag.ALIASan according semantics regarded by other subsystems.classA predefined debugFlag: A predefinedFlaggives itsDebugFlag.SHORT_OPTION, itsDebugFlag.LONG_OPTIONas well as itsDebugFlag.ALIASan according semantics regarded by other subsystems.classclassclassclassEnumDirective<T extends Enum<T>>TheEnumDirectiverepresents aDirectiveof enumeration types.classEnumOption<T extends Enum<T>>TheEnumOptionrepresents anOptionof enumeration types.classEnumProperty<T extends Enum<T>>TheEnumPropertyrepresents anPropertyof enumeration types.classclassclassclassTheFlagclass implements theOptioninterface for representing either atrueor afalsestate: When a flag is provided to your command line arguments, then it is considered to betrue, when it is omitted, then it is considered to befalseas ofFlag.isEnabled().classclassclassclassA predefined forceFlag: A predefinedFlaggives itsForceFlag.SHORT_OPTION, itsForceFlag.LONG_OPTIONas well as itsForceFlag.ALIASan according semantics regarded by other subsystems.classA predefined helpFlag: A predefinedFlaggives itsHelpFlag.SHORT_OPTION, itsHelpFlag.LONG_OPTIONas well as itsHelpFlag.ALIASan according semantics regarded by other subsystems.classA predefined initFlag: A predefinedFlaggives itsInitFlag.SHORT_OPTION, itsInitFlag.LONG_OPTIONas well as itsInitFlag.ALIASan according semantics regarded by other subsystems.classclassclassclassclassclassclassTheNoneOperandrepresents an empty set of arguments, e.g. no command line argument is being passed.classTheOperationis an argument representing an action of functioning or the fact of being active or in effect and is either provided (as command line argument) or not provided as ofOperation.isEnabled().classA predefined "be quiet"Flag: A predefinedFlaggives itsQuietFlag.SHORT_OPTION, itsQuietFlag.LONG_OPTIONas well as itsQuietFlag.ALIASan according semantics regarded by other subsystems.classclassclassclassclassA predefined system informationFlag: A predefinedFlaggives itsSysInfoFlag.SHORT_OPTION, itsSysInfoFlag.LONG_OPTIONas well as itsSysInfoFlag.ALIASan according semantics regarded by other subsystems..classA predefined verboseFlag: A predefinedFlaggives itsVerboseFlag.SHORT_OPTION, itsVerboseFlag.LONG_OPTIONas well as itsVerboseFlag.ALIASan according semantics regarded by other subsystems.Subinterfaces with type arguments of type Operand in org.refcodes.cliModifier and TypeInterfaceDescriptioninterfaceOperand<T>AnOperandrepresents a value parsed from command line arguments.Methods in org.refcodes.cli with type parameters of type OperandModifier and TypeMethodDescription<T extends Operand<?>>
TTraverses the hierarchy ofConditiontree and returns the (first) operand matching the given alias and type.default <T extends Operand<?>>
TTraverses the hierarchy ofConditiontree and returns the (first) operand matching the given type.<T extends Operand<?>>
TTraverses the hierarchy ofConditiontree and returns the (first) operand matching the given alias and type.Methods in org.refcodes.cli that return OperandModifier and TypeMethodDescriptiondefault Operand<?>[]Term.argsParser(String[] aArgs) Parses the given command line arguments using thisTermas the root of the syntax tree.Operand<?>[]Evaluates the provided command line arguments and determines the according values by evaluating the rootCondition.default Operand<?>[]Evaluates the provided command line arguments as ofArgsParser.evalArgs(String[]), additionally filtering (excluding) the arguments matching the providedPattern.default Operand<?>[]ArgsParser.evalArgs(String[] aArgs, ArgsFilter aArgsFilter) Evaluates the provided command line arguments as ofArgsParser.evalArgs(String[]), additionally filtering (excluding) the arguments matching the providedArgsFilter.default Operand<?>[]Same asArgsParser.evalArgs(String[])with the difference that the elements representing the arguments are passed as a list instead of an array.default Operand<?>[]Evaluates the provided command line arguments as ofArgsParser.evalArgs(String[]), additionally filtering (excluding) the arguments matching the providedPattern.default Operand<?>[]ArgsParser.evalArgs(List<String> aArgs, ArgsFilter aArgsFilter) Evaluates the provided command line arguments as ofArgsParser.evalArgs(String[]), additionally filtering (excluding) the arguments matching the providedArgsFilter.Operand<?>[]Evaluates the provided command line arguments and determines the according values by evaluating the rootCondition.ArrayOperand.getOperand()Hook for accessing the encapsulatedOperand.Operand<?>[]Example.getOperands()Retrieves the command line arguments required by the example.Operand<?>[]AbstractDirective.parseArgs(String[] aArgs, String[] aKeywords, CliContext aCliCtx) Parses the given command line arguments using the provided keyword set and CLI context.Operand<?>[]AbstractOperand.parseArgs(String[] aArgs, String[] aKeywords, CliContext aCliCtx) Parses the given command line arguments using the provided keyword set and CLI context.Operand<?>[]AbstractOption.parseArgs(String[] aArgs, String[] aKeywords, CliContext aCliCtx) Parses the given command line arguments using the provided keyword set and CLI context.Operand<?>[]AbstractProperty.parseArgs(String[] aArgs, String[] aKeywords, CliContext aCliCtx) Parses the given command line arguments using the provided keyword set and CLI context.Operand<?>[]AllCondition.parseArgs(String[] aArgs, String[] aKeywords, CliContext aCliCtx) Parses the given command line arguments using the provided keyword set and CLI context.Operand<?>[]AndCondition.parseArgs(String[] aArgs, String[] aKeywords, CliContext aCliCtx) Parses the given command line arguments using the provided keyword set and CLI context.Operand<?>[]AnyCondition.parseArgs(String[] aArgs, String[] aKeywords, CliContext aCliCtx) Parses the given command line arguments using the provided keyword set and CLI context.Operand<?>[]ArrayOperand.parseArgs(String[] aArgs, String[] aOperands, CliContext aCliCtx) Parses the given command line arguments using the provided keyword set and CLI context.Flag.parseArgs(String[] aArgs, String[] aKeywords, CliContext aCliCtx) Parses the given command line arguments using the provided keyword set and CLI context.Operand<?>[]NoneOperand.parseArgs(String[] aArgs, String[] aKeywords, CliContext aCliCtx) Parses the given command line arguments using the provided keyword set and CLI context.Operation.parseArgs(String[] aArgs, String[] aKeywords, CliContext aCliCtx) Parses the given command line arguments using the provided keyword set and CLI context.Operand<?>[]OrCondition.parseArgs(String[] aArgs, String[] aKeywords, CliContext aCliCtx) Parses the given command line arguments using the provided keyword set and CLI context.Operand<?>[]Term.parseArgs(String[] aArgs, String[] aKeywords, CliContext aCliCtx) Parses the given command line arguments using the provided keyword set and CLI context.default Operand<?>[]Term.parseArgs(String[] aArgs, CliContext aCliCtx) Parses the given command line arguments using the provided CLI context deriving its keyword.Operand<?>[]XorCondition.parseArgs(String[] aArgs, String[] aKeywords, CliContext aCliCtx) Parses the given command line arguments using the provided keyword set and CLI context.default Operand<?> Traverses the hierarchy ofConditiontree and returns the (first) operand matching the given alias.Operand<?>[]AbstractCondition.toOperands()Operand<?>[]Condition.toOperands()default Operand<?>[]Condition.toOperands(String[] aArgs) Methods in org.refcodes.cli with parameters of type OperandModifier and TypeMethodDescriptiondefault voidArgsParser.addExample(String aDescription, Operand<?>... aOperands) Adds a usage example by providing a description of the example and the command line arguments required by the example.static <T> ArrayOperand<T> Creates an array representation facade for the encapsulatedOperand.static <T> ArrayOperand<T> Creates an array representation facade for the encapsulatedOperand.static <T> ArrayOperand<T> Creates an array representation facade for the encapsulatedOperand.intintstatic Exampledefault ArgsParserArgsParser.withAddExample(String aDescription, Operand<?>... aOperands) Builder method adding an application'sExampleelement.ArgsProcessorBuilder.withAddExample(String aDescription, Operand<?>... aOperands) Builder method adding an application'sExampleelement.CliArgsParser.withAddExample(String aDescription, Operand<?>... aOperands) Builder method adding an application'sExampleelement.Constructors in org.refcodes.cli with parameters of type OperandModifierConstructorDescriptionArrayOperand(Operand<T> aOperand) Constructs theArrayOperandby encapsulating the givenOperandand providing its definition as array definition to the CLI.ArrayOperand(Operand<T> aOperand, int aLength) Constructs theArrayOperandby encapsulating the givenOperandand providing its definition as array definition to the CLI.ArrayOperand(Operand<T> aOperand, int aMinLength, int aMaxLength) Constructs theArrayOperandby encapsulating the givenOperandand providing its definition as array definition to the CLI.Constructs an example usage.Constructor parameters in org.refcodes.cli with type arguments of type OperandModifierConstructorDescriptionAbstractDirective(String aOperation, Class<T> aType, String aAlias, String aDescription, Consumer<? extends Operand<T>> aConsumer) Constructs anAbstractDirectivewith the given arguments.protectedAbstractDirective(String aOperation, Class<T> aType, String aDescription, Consumer<? extends Operand<T>> aConsumer) Constructs anAbstractDirectivewith the given arguments.AbstractDirective(org.refcodes.struct.Relation<String, T> aProperty, Class<T> aType, Consumer<? extends Operand<T>> aConsumer) Constructs anAbstractDirectivewith the given arguments.AbstractOperand(Class<T> aType, String aAlias, String aDescription, Consumer<? extends Operand<T>> aConsumer) Constructs anOperandwith the given arguments.AbstractOperand(org.refcodes.struct.Relation<String, T> aProperty, Class<T> aType, Consumer<? extends Operand<T>> aConsumer) Constructs anOperandwith the given arguments.AbstractOption(Character aShortOption, String aLongOption, Class<T> aType, String aAlias, String aDescription, Consumer<? extends Operand<T>> aConsumer) Constructs anAbstractOptionwith the given arguments.protectedAbstractOption(Character aShortOption, String aLongOption, Class<T> aType, String aDescription, Consumer<? extends Operand<T>> aConsumer) Constructs anAbstractOptionwith the given arguments.AbstractOption(String aLongOption, Class<T> aType, String aAlias, String aDescription, Consumer<? extends Operand<T>> aConsumer) Constructs anAbstractOptionwith the given arguments.AbstractOption(String aLongOption, Class<T> aType, String aDescription, Consumer<? extends Operand<T>> aConsumer) Constructs anAbstractOptionwith the given arguments.AbstractOption(org.refcodes.struct.Relation<String, T> aProperty, Class<T> aType, Consumer<? extends Operand<T>> aConsumer) Constructs anAbstractOptionwith the given arguments.AbstractProperty(Character aShortProperty, String aLongProperty, Class<T> aType, String aAlias, String aDescription, Consumer<? extends Operand<T>> aConsumer) Instantiates the classAbstractProperty.protectedAbstractProperty(Character aShortProperty, String aLongProperty, Class<T> aType, String aDescription, Consumer<? extends Operand<T>> aConsumer) Instantiates the classAbstractProperty.AbstractProperty(String aLongProperty, Class<T> aType, String aAlias, String aDescription, Consumer<? extends Operand<T>> aConsumer) Instantiates the classAbstractProperty.AbstractProperty(String aLongProperty, Class<T> aType, String aDescription, Consumer<? extends Operand<T>> aConsumer) Instantiates the classAbstractProperty.AbstractProperty(org.refcodes.struct.Relation<String, T> aProperty, Class<T> aType, Consumer<? extends Operand<T>> aConsumer) Instantiates the classAbstractProperty.