Uses of Interface
org.refcodes.cli.ParseArgs
-
Uses of ParseArgs in org.refcodes.cli
Classes in org.refcodes.cli that implement ParseArgsModifier and TypeClassDescriptionclassA straightforward implementation of theParseArgsinterface.Methods in org.refcodes.cli that return ParseArgsModifier and TypeMethodDescriptionArgsParserAccessor.getArgsParser()Retrieves the args-parser from theParseArgsproperty.default ParseArgsArgsParserAccessor.ArgsParserProperty.letArgsParser(ParseArgs aParseArgs) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenParseArgs(setter) as ofArgsParserAccessor.ArgsParserMutator.setArgsParser(ParseArgs)and returns the very same value (getter).default ParseArgsParseArgs.withAddExample(String aDescription, Operand<?>... aOperands) Builder method adding an application'sExampleelement.default ParseArgsParseArgs.withAddExample(Example aExample) Builder method adding an application'sExampleelement.default ParseArgsParseArgs.withArgumentEscapeCode(String aParamEscCode) Sets the argument Escape-Code for the argument Escape-Code property.default ParseArgsParseArgs.withBannerBorderEscapeCode(String aBannerBorderEscCode) Sets the banner border Escape-Code for the banner border Escape-Code property.default ParseArgsParseArgs.withBannerEscapeCode(String aBannerEscCode) Sets the banner Escape-Code for the banner Escape-Code property.default ParseArgsParseArgs.withBannerFont(org.refcodes.textual.Font aBannerFont) Sets the bannerFontfor the bannerFontproperty.default ParseArgsParseArgs.withBannerFontPalette(char[] aColorPalette) Sets the banner font palette for the banner font palette property.default ParseArgsParseArgs.withCommandEscapeCode(String aCommandEscCode) Sets the command Escape-Code for the command Escape-Code property.default ParseArgsParseArgs.withConsoleWidth(int aConsoleWidth) default ParseArgsParseArgs.withCopyright(String aCopyright) Sets the copyright for the copyright property.default ParseArgsParseArgs.withDescription(String aDescription) default ParseArgsParseArgs.withDescriptionEscapeCode(String aDescriptionEscCode) Sets the description Escape-Code for the description Escape-Code property.default ParseArgsParseArgs.withErrorOut(PrintStream aErrorOut) Set the error outPrintStreamand make other adjustments with the result (with regards to the Builder-Pattern).default ParseArgsParseArgs.withEscapeCodesEnabled(boolean isEscCodeEnabled) default ParseArgsParseArgs.withEvalArgs(String[] aArgs) Evaluates the provided command line arguments.default ParseArgsParseArgs.withEvalArgs(List<String> aArgs) Evaluates the provided command line arguments .default ParseArgsParseArgs.withExamples(Collection<Example> aExamples) Builder method providing the application'sExampleelements.default ParseArgsParseArgs.withExamples(Example[] aExamples) default ParseArgsParseArgs.withLicense(String aLicense) Sets the license for the license property.default ParseArgsParseArgs.withLineBreak(String aLineBreak) default ParseArgsParseArgs.withLineSeparatorEscapeCode(String aLineSeparatorEscCode) Sets the line separator Escape-Code for the line separator Escape-Code property.default ParseArgsParseArgs.withLongOptionPrefix(String aLongOptionPrefix) Sets the long option prefix for the long option prefix property.default ParseArgsParseArgs.withMaxConsoleWidth(int aMaxConsoleWidth) default ParseArgsdefault ParseArgsParseArgs.withOptionEscapeCode(String aOptEscCode) Sets the option Escape-Code for the option Escape-Code property.default ParseArgsParseArgs.withResetEscapeCode(String aResetEscCode) default ParseArgsParseArgs.withSeparatorLnChar(char aSeparatorLnChar) Builder method adding an separator line char.default ParseArgsParseArgs.withShortOptionPrefix(Character aShortOptionPrefix) Sets the short option prefix for the short option prefix property.default ParseArgsParseArgs.withStandardOut(PrintStream aStandardOut) Set the standard outPrintStreamand make other adjustments with the result (with regards to the Builder-Pattern).default ParseArgsParseArgs.withSyntaxMetrics(SyntaxMetrics aSyntaxMetrics) Sets theSyntaxMetricsfor theSyntaxMetricsproperty.default ParseArgsParseArgs.withTextBoxGrid(org.refcodes.textual.TextBoxGrid aTextBoxGrid) default ParseArgsParseArgs.withTextBoxGrid(org.refcodes.textual.TextBoxStyle aTextBoxStyle) default ParseArgsMethods in org.refcodes.cli with parameters of type ParseArgsModifier and TypeMethodDescriptiondefault ParseArgsArgsParserAccessor.ArgsParserProperty.letArgsParser(ParseArgs aParseArgs) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenParseArgs(setter) as ofArgsParserAccessor.ArgsParserMutator.setArgsParser(ParseArgs)and returns the very same value (getter).voidArgsParserAccessor.ArgsParserMutator.setArgsParser(ParseArgs aProperties) Sets the args-parser for theParseArgsproperty.ArgsParserAccessor.ArgsParserBuilder.withArgsParser(ParseArgs aProperties) Sets the args-parser for theParseArgsproperty.