Uses of Class
org.refcodes.cli.ParseArgsException

  • Uses of ParseArgsException in org.refcodes.cli

    Modifier and Type
    Class
    Description
    class 
    Thrown in case the provided command line arguments do not respect the required semantics or cannot be converted to the required type by a Directive (having an operation alongside an expected operand), e.g. the arguments were rejected as them did not work for the according syntax.
    class 
    Thrown in case the provided command line arguments do not respect the required semantics or cannot be converted to the required type by an Option (having a short- and/or a long-option), e.g. the arguments were rejected as them did not work for the according syntax.
    Methods in org.refcodes.cli that throw ParseArgsException
    Modifier and Type
    Method
    Description
    protected abstract T
    AbstractOperand.toType(String aArg)
    Double dispatch hook to be implemented by subclasses of the AbstractOperand for converting a command line argument to the required Operand's type.
    protected Boolean
    BooleanDirective.toType(String aArg)
    Double dispatch hook to be implemented by subclasses of the AbstractOperand for converting a command line argument to the required Operand's type.
    protected Boolean
    BooleanOption.toType(String aArg)
    Double dispatch hook to be implemented by subclasses of the AbstractOperand for converting a command line argument to the required Operand's type.
    protected Boolean
    BooleanProperty.toType(String aArg)
    Double dispatch hook to be implemented by subclasses of the AbstractOperand for converting a command line argument to the required Operand's type.
    protected Character
    CharDirective.toType(String aArg)
    Double dispatch hook to be implemented by subclasses of the AbstractOperand for converting a command line argument to the required Operand's type.
    protected Character
    CharOption.toType(String aArg)
    Double dispatch hook to be implemented by subclasses of the AbstractOperand for converting a command line argument to the required Operand's type.
    protected Character
    CharProperty.toType(String aArg)
    Double dispatch hook to be implemented by subclasses of the AbstractOperand for converting a command line argument to the required Operand's type.
    protected Double
    DoubleDirective.toType(String aArg)
    Double dispatch hook to be implemented by subclasses of the AbstractOperand for converting a command line argument to the required Operand's type.
    protected Double
    DoubleOption.toType(String aArg)
    Double dispatch hook to be implemented by subclasses of the AbstractOperand for converting a command line argument to the required Operand's type.
    protected Double
    DoubleProperty.toType(String aArg)
    Double dispatch hook to be implemented by subclasses of the AbstractOperand for converting a command line argument to the required Operand's type.
    protected T
    EnumDirective.toType(String aArg)
    Double dispatch hook to be implemented by subclasses of the AbstractOperand for converting a command line argument to the required Operand's type.
    protected T
    EnumOption.toType(String aArg)
    Double dispatch hook to be implemented by subclasses of the AbstractOperand for converting a command line argument to the required Operand's type.
    protected T
    EnumProperty.toType(String aArg)
    Double dispatch hook to be implemented by subclasses of the AbstractOperand for converting a command line argument to the required Operand's type.
    protected File
    FileDirective.toType(String aArg)
    Double dispatch hook to be implemented by subclasses of the AbstractOperand for converting a command line argument to the required Operand's type.
    protected File
    FileOption.toType(String aArg)
    Double dispatch hook to be implemented by subclasses of the AbstractOperand for converting a command line argument to the required Operand's type.
    protected File
    FileProperty.toType(String aArg)
    Double dispatch hook to be implemented by subclasses of the AbstractOperand for converting a command line argument to the required Operand's type.
    protected Boolean
    Flag.toType(String aArg)
    Double dispatch hook to be implemented by subclasses of the AbstractOperand for converting a command line argument to the required Operand's type.
    protected Float
    FloatDirective.toType(String aArg)
    Double dispatch hook to be implemented by subclasses of the AbstractOperand for converting a command line argument to the required Operand's type.
    protected Float
    FloatOption.toType(String aArg)
    Double dispatch hook to be implemented by subclasses of the AbstractOperand for converting a command line argument to the required Operand's type.
    protected Float
    FloatProperty.toType(String aArg)
    Double dispatch hook to be implemented by subclasses of the AbstractOperand for converting a command line argument to the required Operand's type.
    protected Integer
    IntDirective.toType(String aArg)
    Double dispatch hook to be implemented by subclasses of the AbstractOperand for converting a command line argument to the required Operand's type.
    protected Integer
    IntOption.toType(String aArg)
    Double dispatch hook to be implemented by subclasses of the AbstractOperand for converting a command line argument to the required Operand's type.
    protected Integer
    IntProperty.toType(String aArg)
    Double dispatch hook to be implemented by subclasses of the AbstractOperand for converting a command line argument to the required Operand's type.
    protected Long
    LongDirective.toType(String aArg)
    Double dispatch hook to be implemented by subclasses of the AbstractOperand for converting a command line argument to the required Operand's type.
    protected Long
    LongOption.toType(String aArg)
    Double dispatch hook to be implemented by subclasses of the AbstractOperand for converting a command line argument to the required Operand's type.
    protected Long
    LongProperty.toType(String aArg)
    Double dispatch hook to be implemented by subclasses of the AbstractOperand for converting a command line argument to the required Operand's type.
    protected Boolean
    Operation.toType(String aArg)
    Double dispatch hook to be implemented by subclasses of the AbstractOperand for converting a command line argument to the required Operand's type.
    protected String
    StringDirective.toType(String aArg)
    Double dispatch hook to be implemented by subclasses of the AbstractOperand for converting a command line argument to the required Operand's type.
    protected String
    StringOption.toType(String aArg)
    Double dispatch hook to be implemented by subclasses of the AbstractOperand for converting a command line argument to the required Operand's type.
    protected String
    StringProperty.toType(String aArg)
    Double dispatch hook to be implemented by subclasses of the AbstractOperand for converting a command line argument to the required Operand's type.