Uses of Interface
org.refcodes.cli.ParsedArgsAccessor
-
Uses of ParsedArgsAccessor in org.refcodes.cli
Subinterfaces of ParsedArgsAccessor in org.refcodes.cliModifier and TypeInterfaceDescriptioninterfaceDirective<T>AnDirectiverepresents a command line operation with the according operation's operand (value).interfaceOperand<T>AnOperandrepresents a value parsed from command line arguments.interfaceOption<T>AnOptionrepresents a command line option with the according option's value.static interfaceProvides a parsed args property.interfaceProperty<T>AnPropertyrepresents an option property with the according porperty's key and value separated by a=(and no whitespace inbetween).Classes in org.refcodes.cli that implement ParsedArgsAccessorModifier and TypeClassDescriptionclassTheAbstractDirectiveis an abstract implementation of anDirectiveproviding the boiler plate when implementing theDirectiveinterface.classTheAbstractOperandis an abstract implementation of anOperandproviding the boiler plate when implementing theOperandinterface.classTheAbstractOptionis an abstract implementation of anOptionproviding the boiler plate when implementing theOptioninterface.classTheAbstractPropertyis an abstract implementation of aPropertyproviding the boiler plate when implementing thePropertyinterface.classCreates an array representation facade for the encapsulatedDirective.classArrayOperand<T>Creates an array representation facade for the encapsulatedOperand.classArrayOption<T>Creates an array representation facade for the encapsulatedOption.classclassclassclassclassclassclassA predefined cleanFlag: A predefinedFlaggives itsCleanFlag.SHORT_OPTION, itsCleanFlag.LONG_OPTIONas well as itsCleanFlag.ALIASan according semantics regarded by other subsystems.classTheConfigOptionrepresents anOptionholding a value specifying a configuration resource (file).classTheConfigPropertyrepresents anPropertyholding a value specifying a configuration resource (file).classA predefined daemonFlag: A predefinedFlaggives itsDaemonFlag.SHORT_OPTION, itsDaemonFlag.LONG_OPTIONas well as itsDaemonFlag.ALIASan according semantics regarded by other subsystems.classA predefined debugFlag: A predefinedFlaggives itsDebugFlag.SHORT_OPTION, itsDebugFlag.LONG_OPTIONas well as itsDebugFlag.ALIASan according semantics regarded by other subsystems.classclassclassclassEnumDirective<T extends Enum<T>>TheEnumDirectiverepresents aDirectiveof enumeration types.classEnumOption<T extends Enum<T>>TheEnumOptionrepresents anOptionof enumeration types.classEnumProperty<T extends Enum<T>>TheEnumPropertyrepresents anPropertyof enumeration types.classclassclassclassTheFlagclass implements theOptioninterface for representing either atrueor afalsestate: When a flag is provided to your command line arguments, then it is considered to betrue, when it is omitted, then it is considered to befalseas ofFlag.isEnabled().classclassclassclassA predefined forceFlag: A predefinedFlaggives itsForceFlag.SHORT_OPTION, itsForceFlag.LONG_OPTIONas well as itsForceFlag.ALIASan according semantics regarded by other subsystems.classA predefined helpFlag: A predefinedFlaggives itsHelpFlag.SHORT_OPTION, itsHelpFlag.LONG_OPTIONas well as itsHelpFlag.ALIASan according semantics regarded by other subsystems.classA predefined initFlag: A predefinedFlaggives itsInitFlag.SHORT_OPTION, itsInitFlag.LONG_OPTIONas well as itsInitFlag.ALIASan according semantics regarded by other subsystems.classclassclassclassclassclassclassTheNoneOperandrepresents an empty set of arguments, e.g. no command line argument is being passed.classTheOperationis an argument representing an action of functioning or the fact of being active or in effect and is either provided (as command line argument) or not provided as ofOperation.isEnabled().classA predefined "be quiet"Flag: A predefinedFlaggives itsQuietFlag.SHORT_OPTION, itsQuietFlag.LONG_OPTIONas well as itsQuietFlag.ALIASan according semantics regarded by other subsystems.classclassclassclassclassA predefined system informationFlag: A predefinedFlaggives itsSysInfoFlag.SHORT_OPTION, itsSysInfoFlag.LONG_OPTIONas well as itsSysInfoFlag.ALIASan according semantics regarded by other subsystems..classA predefined verboseFlag: A predefinedFlaggives itsVerboseFlag.SHORT_OPTION, itsVerboseFlag.LONG_OPTIONas well as itsVerboseFlag.ALIASan according semantics regarded by other subsystems.