Uses of Class
org.refcodes.cli.SuperfluousArgsException
-
Uses of SuperfluousArgsException in org.refcodes.cli
Methods in org.refcodes.cli that throw SuperfluousArgsException Modifier and Type Method Description List<? extends Operand<?>>ArgsParser. evalArgs(String[] aArgs)Evaluates the provided command line arguments and determines the according values by evaluating the rootCondition.default List<? extends Operand<?>>ArgsParser. evalArgs(List<String> aArgs)Same asArgsParser.evalArgs(String[])with the difference that the elements representing the arguments are passed as a list instead of an array.List<? extends Operand<?>>ArgsParserImpl. evalArgs(String[] aArgs)Evaluates the provided command line arguments and determines the according values by evaluating the rootCondition.default ArgsParserArgsParser. withEvalArgs(String[] aArgs)Same asArgsParser.evalArgs(String[])with the difference that this class's instance being invoked is returned as of the builder pattern.default ArgsParserArgsParser. withEvalArgs(List<String> aArgs)Same asArgsParser.evalArgs(List)with the difference that this class's instance being invoked is returned as of the builder pattern.BArgsParserMixin. withEvalArgs(String[] aArgs)Evaluates the provided command line arguments.default BArgsParserMixin. withEvalArgs(List<String> aArgs)Evaluates the provided command line arguments .