Uses of Interface
org.refcodes.cli.SyntaxMetricsAccessor.SyntaxMetricsBuilder
-
Uses of SyntaxMetricsAccessor.SyntaxMetricsBuilder in org.refcodes.cli
Classes in org.refcodes.cli with type parameters of type SyntaxMetricsAccessor.SyntaxMetricsBuilderModifier and TypeInterfaceDescriptionstatic interfaceProvides a builder method for aSyntaxMetricsproperty returning the builder for applying multiple build operations.Subinterfaces of SyntaxMetricsAccessor.SyntaxMetricsBuilder in org.refcodes.cliModifier and TypeInterfaceDescriptioninterfaceTheArgsParserprovides means for parsing command line arguments and constructing a command line utility's help output.interfaceArgsProcessorBuilder<B extends ArgsProcessorBuilder<B>>TheArgsProcessorBuilderprovides common minimum builder functionality required by to build an argument processing instance.Classes in org.refcodes.cli that implement SyntaxMetricsAccessor.SyntaxMetricsBuilderModifier and TypeClassDescriptionclassA straightforward implementation of theArgsParserinterface.static final classBuilder to buildSyntaxMetricsAccessor.SyntaxMetricsBuilderinstances.