Uses of Class
org.refcodes.cli.SyntaxMetricsBuilder.Builder
-
Uses of SyntaxMetricsBuilder.Builder in org.refcodes.cli
Classes in org.refcodes.cli that implement interfaces with type arguments of type SyntaxMetricsBuilder.BuilderModifier and TypeClassDescriptionstatic final classBuilder to buildSyntaxMetricsinstances.static final classBuilder to buildSyntaxMetricsinstances.static final classBuilder to buildSyntaxMetricsinstances.static final classBuilder to buildSyntaxMetricsinstances.Methods in org.refcodes.cli that return SyntaxMetricsBuilder.BuilderModifier and TypeMethodDescriptionstatic SyntaxMetricsBuilder.BuilderSyntaxMetrics.builder()Creates aSyntaxMetricsBuilder.Builderused to fluently constructSyntaxMetricsinstances.static SyntaxMetricsBuilder.BuilderSyntaxMetricsBuilder.builder()Creates aSyntaxMetricsBuilder.Builderused to fluently constructSyntaxMetricsinstances.SyntaxMetricsBuilder.Builder.withAllSymbol(String aAllSymbol) Sets the symbol for representing an ALL notation.SyntaxMetricsBuilder.Builder.withAndSymbol(String aAndSymbol) Sets the symbol for representing an AND notation.SyntaxMetricsBuilder.Builder.withAnySymbol(String aAnySymbol) Sets the symbol for representing an ANY notation.SyntaxMetricsBuilder.Builder.withArgumentPrefix(String aArgNotationPrefix) Sets the argument prefix for the argument prefix property.SyntaxMetricsBuilder.Builder.withArgumentSuffix(String aArgNotationSuffix) Sets the argument suffix for the argument suffix property.SyntaxMetricsBuilder.Builder.withAssignmentOperator(String aAssignmentOperator) Sets the assignment operator to be used in the syntax for separating a name from a value.SyntaxMetricsBuilder.Builder.withBeginArraySymbol(String aBeginArraySymbol) Sets the symbol representing the beginning of an array, e.g. an opening square brace.SyntaxMetricsBuilder.Builder.withBeginListSymbol(String aBeginListSymbol) Sets the symbol representing the beginning of a list, e.g. an opening brace.SyntaxMetricsBuilder.Builder.withBeginOptionalSymbol(String aBeginOptionalSymbol) Sets the symbol representing the beginning optional elements, e.g. an opening square brace.SyntaxMetricsBuilder.Builder.withBeginRangeSymbol(String aBeginRangeSymbol) Sets the symbol representing the beginning of a range, e.g. an opening square brace.SyntaxMetricsBuilder.Builder.withEMptySymbol(String aEmptySymbol) Sets the symbol for representing an EMPTY notation.SyntaxMetricsBuilder.Builder.withEndArraySymbol(String aEndArraySymbol) Sets the symbol representing the end of an array, e.g. a closing square brace.SyntaxMetricsBuilder.Builder.withEndListSymbol(String aEndListSymbol) Sets the symbol representing the end of a list, e.g. a closing brace.SyntaxMetricsBuilder.Builder.withEndOptionalSymbol(String aEndOptionalSymbol) Sets the symbol representing the end of optional elements, e.g. a closing square brace.SyntaxMetricsBuilder.Builder.withEndRangeSymbol(String aEndRangeSymbol) Sets the symbol representing the end of a range, e.g. a closing square brace.SyntaxMetricsBuilder.Builder.withIntervalSymbol(String aIntervalSymbol) Sets the symbol representing an interval, e.g. "..." or "-".SyntaxMetricsBuilder.Builder.withLongOptionPrefix(String aLongOptionPrefix) Sets the long option prefix for the long option prefix property.SyntaxMetricsBuilder.Builder.withOrSymbol(String aOrSymbol) Sets the symbol for representing an OR notation.SyntaxMetricsBuilder.Builder.withShortOptionPrefix(Character aShortOptionPrefix) Sets the short option prefix for the short option prefix property.SyntaxMetricsBuilder.Builder.withUndefinedSymbol(String aUndefinedSymbol) Sets the symbol representing for something unknowingly (name, alias, value).SyntaxMetricsBuilder.Builder.withXorSymbol(String aXorSymbol) Sets the symbol for representing an XOR notation.