Uses of Enum Class
org.refcodes.cli.SyntaxNotation
-
Uses of SyntaxNotation in org.refcodes.cli
Subclasses with type arguments of type SyntaxNotation in org.refcodes.cliModifier and TypeClassDescriptionenumTheSyntaxNotationis used by a theTerm.toSyntax(CliContext)method to determine which notation to be used for the generated syntax.Fields in org.refcodes.cli declared as SyntaxNotationMethods in org.refcodes.cli that return SyntaxNotationModifier and TypeMethodDescriptiondefault SyntaxNotationSyntaxMetricsAccessor.SyntaxMetricsProperty.letSyntaxMetrics(SyntaxNotation aSyntaxNotation) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenSyntaxNotation(setter) as ofSyntaxMetricsAccessor.SyntaxMetricsMutator.setSyntaxMetrics(SyntaxNotation)and returns the very same value (getter).static SyntaxNotationSyntaxNotation.toSyntaxNotation(String aValue) Retrieves aSyntaxNotationdepending on the given string, ignoring the case as well as being graceful regarding "-" and "_",.static SyntaxNotationReturns the enum constant of this class with the specified name.static SyntaxNotation[]SyntaxNotation.values()Returns an array containing the constants of this enum class, in the order they are declared.Methods in org.refcodes.cli with parameters of type SyntaxNotationModifier and TypeMethodDescriptiondefault SyntaxNotationSyntaxMetricsAccessor.SyntaxMetricsProperty.letSyntaxMetrics(SyntaxNotation aSyntaxNotation) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenSyntaxNotation(setter) as ofSyntaxMetricsAccessor.SyntaxMetricsMutator.setSyntaxMetrics(SyntaxNotation)and returns the very same value (getter).default voidSyntaxMetricsAccessor.SyntaxMetricsMutator.setSyntaxMetrics(SyntaxNotation aSyntaxNotation) Sets theSyntaxNotationfor theSyntaxNotationproperty.default StringOperand.toSpec(SyntaxNotation aSyntaxNotation) Creates a specification including its arguments.default StringOperand.toSpec(SyntaxNotation aSyntaxNotation, String aOptEscCode, String aParamEscCode, String aResetEscCode) Creates a specification including its arguments.default StringSynopsisable.toSynopsis(SyntaxNotation aSyntaxNotation) Creates the synopsis for the syntax hierarchy.default StringSynopsisable.toSynopsis(SyntaxNotation aSyntaxNotation, String aArgumentEscapeCode, String aKeywordEscapeCode, String aResetEscapeCode) Creates the synopsis for the syntax hierarchy.default StringTerm.toSyntax(SyntaxNotation aSyntaxNotation) Creates a syntax including its arguments.default StringTerm.toSyntax(SyntaxNotation aSyntaxNotation, String aArgumentEscapeCode, String aKeywordEscapeCode, String aResetEscapeCode) Creates a syntax including its arguments.CliArgsParser.withSyntaxMetrics(SyntaxNotation aSyntaxNotation) Sets theSyntaxNotationfor theSyntaxNotationproperty.default BSyntaxMetricsAccessor.SyntaxMetricsBuilder.withSyntaxMetrics(SyntaxNotation aSyntaxNotation) Sets theSyntaxNotationfor theSyntaxNotationproperty.