Uses of Interface
org.refcodes.cli.SyntaxUsage
-
-
Uses of SyntaxUsage in org.refcodes.cli
Subinterfaces of SyntaxUsage in org.refcodes.cli Modifier and Type Interface Description interfaceArgsSyntaxTheArgsSyntaxinterface represents a node (and therewith the syntax for the arguments) in the command line arguments syntax tree; simply extending theSyntaxableinterface and adding the functionality of providing access to the addedOperands (leafs).interfaceConditionInterface indicating that theArgsSyntaxsemantically represents a condition.interfaceOperand<T>AnOperandrepresents a value parsed from command line arguments.interfaceOption<T>AnOptionrepresents a command line option with the according option's value.interfaceSyntaxableASyntaxabledefines the methods at least required when building a command line arguments syntax tree for traversing the syntax tree; either for parsing command line arguments or for constructing the command line arguments syntax.Classes in org.refcodes.cli that implement SyntaxUsage Modifier and Type Class Description classAbstractConditionTheAbstractConditionis an abstract implementation of theArgsSyntaxinterface providing the boiler plate when implementing theArgsSyntaxinterface as done by theAbstractCondition's sub-classes.classAbstractOperand<T>TheAbstractOperandis an abstract implementation of anOperandproviding the boiler plate when implementing theOperandinterface.classAbstractOption<T>TheAbstractOptionis an abstract implementation of anOptionproviding the boiler plate when implementing theOptioninterface.classAllConditionTheAllConditionenforces that the encapsulatedSyntaxableconsumes all arguments passed via invoking itsSyntaxable.parseArgs(String[]), else aSuperfluousArgsExceptionis thrown.classAndConditionAnAndConditioncontains (represents) a list ofArgsSyntax(Syntaxable) instances (nested by theAndCondition) of which all are to be parsed successfully as of invoking theSyntaxable.parseArgs(String[], String[])methods.classAnyConditionAny of the nestedArgsSyntaxconditions may match for theAnyConditionto match, e.g. all of the nested conditions are optional.classArrayOperand<T>Creates an array representation facade for the encapsulatedOperand.classArrayOption<T>Creates an array representation facade for the encapsulatedOption.classCasesConditionTheCasesConditionis anXorConditionmaking sure that all possible cases inside theXorConditionmust(!)classCharOptionclassConfigOptionTheConfigOptionrepresents anOptionholding a value specifying a configuration file or identifying a configuration in general.classDaemonFlagA predefined daemonFlag: A predefinedFlaggives itsDaemonFlag.SHORT_OPTION, itsDaemonFlag.LONG_OPTIONas well as itsDaemonFlag.ALIASan according semantics regarded by other subsystems.classDebugFlagA predefined debugFlag: A predefinedFlaggives itsDebugFlag.SHORT_OPTION, itsDebugFlag.LONG_OPTIONas well as itsDebugFlag.ALIASan according semantics regarded by other subsystems.classDoubleOptionclassEnumOption<T extends Enum<T>>The Class EnumOption.classFileOptionclassFlagTheFlagclass implements theOptioninterface for representing either atrueor afalsestate: When a flag is provided to your command line arguments, then it is considered to betrue, when it is omitted, then it is considered to befalseas ofFlag.isEnabled().classFloatOptionclassForceFlagA predefined forceFlag: A predefinedFlaggives itsForceFlag.SHORT_OPTION, itsForceFlag.LONG_OPTIONas well as itsForceFlag.ALIASan according semantics regarded by other subsystems.classHelpFlagA predefined helpFlag: A predefinedFlaggives itsHelpFlag.SHORT_OPTION, itsHelpFlag.LONG_OPTIONas well as itsHelpFlag.ALIASan according semantics regarded by other subsystems.classInitFlagA predefined initFlag: A predefinedFlaggives itsInitFlag.SHORT_OPTION, itsInitFlag.LONG_OPTIONas well as itsInitFlag.ALIASan according semantics regarded by other subsystems.classIntOptionclassLongOptionclassNoneOperandTheNoneOperandrepresents an empty set of arguments, e.g. no command line argument is being passed.classOperationTheOperationis an argument representing a function or a method ("command") and is either provided or not provided as ofOperation.isEnabled().classOptionConditionclassOrConditionAnOrConditionrepresents a list ofArgsSyntax(Syntaxable) instances of which at least one must be parsed successfully when theSyntaxables'Syntaxable.parseArgs(String[], String[])methods are invoked.classQuietFlagA predefined "be quiet"Flag: A predefinedFlaggives itsQuietFlag.SHORT_OPTION, itsQuietFlag.LONG_OPTIONas well as itsQuietFlag.ALIASan according semantics regarded by other subsystems.classStringOperandclassStringOptionclassSysInfoFlagA predefined system informationFlag: A predefinedFlaggives itsSysInfoFlag.SHORT_OPTION, itsSysInfoFlag.LONG_OPTIONas well as itsSysInfoFlag.ALIASan according semantics regarded by other subsystems..classVerboseFlagA predefined verboseFlag: A predefinedFlaggives itsVerboseFlag.SHORT_OPTION, itsVerboseFlag.LONG_OPTIONas well as itsVerboseFlag.ALIASan according semantics regarded by other subsystems.classXorConditionAnXorConditionrepresents a list ofArgsSyntax(Syntaxable) instances of which only one is allowed to be parsed successfully when theSyntaxable.parseArgs(String[], String[])methods are invoked.
-