Uses of Interface
org.refcodes.cli.Syntaxable
-
Uses of Syntaxable in org.refcodes.cli
Subinterfaces of Syntaxable in org.refcodes.cliModifier and TypeInterfaceDescriptioninterfaceTheArgsSyntaxinterface represents a node (and therewith the syntax for the arguments) in the command line arguments syntax tree; simply extending theSyntaxableinterface and adding the functionality of providing access to the addedOperands (leafs).interfaceInterface indicating that theArgsSyntaxsemantically represents a condition which usally encapsulates otherSyntaxablechildren.interfaceOperand<T>AnOperandrepresents a value parsed from command line arguments.interfaceOption<T>AnOptionrepresents a command line option with the according option's value.Classes in org.refcodes.cli that implement SyntaxableModifier and TypeClassDescriptionclassTheAbstractConditionis an abstract implementation of theArgsSyntaxinterface providing the boiler plate when implementing theArgsSyntaxinterface as done by theAbstractCondition's sub-classes.classTheAbstractOperandis an abstract implementation of anOperandproviding the boiler plate when implementing theOperandinterface.classTheAbstractOptionis an abstract implementation of anOptionproviding the boiler plate when implementing theOptioninterface.classTheAllConditionenforces that the encapsulatedSyntaxableconsumes all arguments passed via invoking itsparseArgs(String[]), else aSuperfluousArgsExceptionis thrown.classAnAndConditioncontains (represents) a list ofArgsSyntax(Syntaxable) instances (nested by theAndCondition) of which all are to be parsed successfully as of invoking theparseArgs(String[], String[])methods.classAny of the nestedArgsSyntaxconditions may match for theAnyConditionto match, e.g. all of the nested conditions are optional.classArrayOperand<T>Creates an array representation facade for the encapsulatedOperand.classArrayOption<T>Creates an array representation facade for the encapsulatedOption.classTheCasesConditionis anXorConditionmaking sure that all possible cases inside theXorConditionmust(!)classclassA predefined cleanFlag: A predefinedFlaggives itsCleanFlag.SHORT_OPTION, itsCleanFlag.LONG_OPTIONas well as itsCleanFlag.ALIASan according semantics regarded by other subsystems.classTheConfigOptionrepresents anOptionholding a value specifying a configuration resource (file).classA predefined daemonFlag: A predefinedFlaggives itsDaemonFlag.SHORT_OPTION, itsDaemonFlag.LONG_OPTIONas well as itsDaemonFlag.ALIASan according semantics regarded by other subsystems.classA predefined debugFlag: A predefinedFlaggives itsDebugFlag.SHORT_OPTION, itsDebugFlag.LONG_OPTIONas well as itsDebugFlag.ALIASan according semantics regarded by other subsystems.classclassEnumOption<T extends Enum<T>>The Class EnumOption.classclassTheFlagclass implements theOptioninterface for representing either atrueor afalsestate: When a flag is provided to your command line arguments, then it is considered to betrue, when it is omitted, then it is considered to befalseas ofFlag.isEnabled().classclassA predefined forceFlag: A predefinedFlaggives itsForceFlag.SHORT_OPTION, itsForceFlag.LONG_OPTIONas well as itsForceFlag.ALIASan according semantics regarded by other subsystems.classA predefined helpFlag: A predefinedFlaggives itsHelpFlag.SHORT_OPTION, itsHelpFlag.LONG_OPTIONas well as itsHelpFlag.ALIASan according semantics regarded by other subsystems.classA predefined initFlag: A predefinedFlaggives itsInitFlag.SHORT_OPTION, itsInitFlag.LONG_OPTIONas well as itsInitFlag.ALIASan according semantics regarded by other subsystems.classclassclassTheNoneOperandrepresents an empty set of arguments, e.g. no command line argument is being passed.classTheOperationis an argument representing a function or a method ("command") and is either provided or not provided as ofOperation.isEnabled().classclassAnOrConditionrepresents a list ofArgsSyntax(Syntaxable) instances of which at least one must be parsed successfully when theSyntaxables'parseArgs(String[], String[])methods are invoked.classA predefined "be quiet"Flag: A predefinedFlaggives itsQuietFlag.SHORT_OPTION, itsQuietFlag.LONG_OPTIONas well as itsQuietFlag.ALIASan according semantics regarded by other subsystems.classclassclassA predefined system informationFlag: A predefinedFlaggives itsSysInfoFlag.SHORT_OPTION, itsSysInfoFlag.LONG_OPTIONas well as itsSysInfoFlag.ALIASan according semantics regarded by other subsystems..classA predefined verboseFlag: A predefinedFlaggives itsVerboseFlag.SHORT_OPTION, itsVerboseFlag.LONG_OPTIONas well as itsVerboseFlag.ALIASan according semantics regarded by other subsystems.classAnXorConditionrepresents a list ofArgsSyntax(Syntaxable) instances of which only one is allowed to be parsed successfully when theparseArgs(String[], String[])methods are invoked.Methods in org.refcodes.cli that return SyntaxableModifier and TypeMethodDescriptionprotected SyntaxableAbstractCondition.getFirst()Gets the first child.Methods in org.refcodes.cli that return types with arguments of type SyntaxableModifier and TypeMethodDescriptionprotected List<Syntaxable>AbstractCondition.getChildren()Gets the children.Methods in org.refcodes.cli with parameters of type SyntaxableModifier and TypeMethodDescriptionprotected voidAbstractCondition.addChild(Syntaxable aArgumentizer) Adds the child.static ArgsSyntaxCliSugar.all(Syntaxable aArg) static ArgsSyntaxCliSugar.and(Syntaxable... aArgs) static ArgsSyntaxCliSugar.any(Syntaxable... aArgs) static ArgsSyntaxCliSugar.cases(Syntaxable... aArgs) static ArgsSyntaxCliSugar.optional(Syntaxable... aArgs) Semantically identical synonym for theCliSugar.optional(Syntaxable...)declaration.static ArgsSyntaxCliSugar.or(Syntaxable... aArgs) static ArgsSyntaxCliSugar.xor(Syntaxable... aArgs) Constructors in org.refcodes.cli with parameters of type SyntaxableModifierConstructorDescriptionAbstractCondition(String aDescription, Syntaxable... aElements) Instantiates a new abstract condition.AllCondition(Syntaxable aArg) AndCondition(Syntaxable... aArgs) AnyCondition(Syntaxable... aArgs) CasesCondition(Syntaxable... aArgs) OrCondition(Syntaxable... aArgs) XorCondition(Syntaxable... aArgs)