Uses of Interface
org.refcodes.cli.Term
-
Uses of Term in org.refcodes.cli
Subinterfaces of Term in org.refcodes.cliModifier and TypeInterfaceDescriptioninterfaceinterfaceDirective<T>AnDirectiverepresents a command line operation with the according operation's operand (value).interfaceOperand<T>AnOperandrepresents a value parsed from command line arguments.interfaceOption<T>AnOptionrepresents a command line option with the according option's value.interfaceProperty<T>AnPropertyrepresents an option property with the according porperty's key and value separated by a=(and no whitespace inbetween).Classes in org.refcodes.cli that implement TermModifier and TypeClassDescriptionclassTheAbstractConditionis an abstract implementation of theConditioninterface providing the boiler plate when implementing theConditioninterface as done by theAbstractCondition's sub-classes.classTheAbstractDirectiveis an abstract implementation of anDirectiveproviding the boiler plate when implementing theDirectiveinterface.classTheAbstractOperandis an abstract implementation of anOperandproviding the boiler plate when implementing theOperandinterface.classTheAbstractOptionis an abstract implementation of anOptionproviding the boiler plate when implementing theOptioninterface.classTheAbstractPropertyis an abstract implementation of aPropertyproviding the boiler plate when implementing thePropertyinterface.classTheAllConditionenforces that the encapsulatedTermconsumes all arguments passed via invoking itsTerm.parseArgs(String[], CliContext), else aSuperfluousArgsExceptionis thrown.classAnAndConditioncontains (represents) a list ofCondition(Term) instances (nested by theAndCondition) of which all are to be parsed successfully as of invoking theTerm.parseArgs(String[], String[], CliContext)methods.classAny of the nestedConditionconditions may match for theAnyConditionto match, e.g. all of the nested conditions are optional.classCreates an array representation facade for the encapsulatedDirective.classArrayOperand<T>Creates an array representation facade for the encapsulatedOperand.classArrayOption<T>Creates an array representation facade for the encapsulatedOption.classclassclassclassTheCasesConditionis anXorConditionmaking sure that all possible cases inside theXorConditionmust(!)classclassclassclassA predefined cleanFlag: A predefinedFlaggives itsCleanFlag.SHORT_OPTION, itsCleanFlag.LONG_OPTIONas well as itsCleanFlag.ALIASan according semantics regarded by other subsystems.classTheConfigOptionrepresents anOptionholding a value specifying a configuration resource (file).classTheConfigPropertyrepresents anPropertyholding a value specifying a configuration resource (file).classA predefined daemonFlag: A predefinedFlaggives itsDaemonFlag.SHORT_OPTION, itsDaemonFlag.LONG_OPTIONas well as itsDaemonFlag.ALIASan according semantics regarded by other subsystems.classA predefined debugFlag: A predefinedFlaggives itsDebugFlag.SHORT_OPTION, itsDebugFlag.LONG_OPTIONas well as itsDebugFlag.ALIASan according semantics regarded by other subsystems.classclassclassclassEnumDirective<T extends Enum<T>>TheEnumDirectiverepresents aDirectiveof enumeration types.classEnumOption<T extends Enum<T>>TheEnumOptionrepresents anOptionof enumeration types.classEnumProperty<T extends Enum<T>>TheEnumPropertyrepresents anPropertyof enumeration types.classclassclassclassTheFlagclass implements theOptioninterface for representing either atrueor afalsestate: When a flag is provided to your command line arguments, then it is considered to betrue, when it is omitted, then it is considered to befalseas ofFlag.isEnabled().classclassclassclassA predefined forceFlag: A predefinedFlaggives itsForceFlag.SHORT_OPTION, itsForceFlag.LONG_OPTIONas well as itsForceFlag.ALIASan according semantics regarded by other subsystems.classA predefined helpFlag: A predefinedFlaggives itsHelpFlag.SHORT_OPTION, itsHelpFlag.LONG_OPTIONas well as itsHelpFlag.ALIASan according semantics regarded by other subsystems.classA predefined initFlag: A predefinedFlaggives itsInitFlag.SHORT_OPTION, itsInitFlag.LONG_OPTIONas well as itsInitFlag.ALIASan according semantics regarded by other subsystems.classclassclassclassclassclassclassTheNoneOperandrepresents an empty set of arguments, e.g. no command line argument is being passed.classTheOperationis an argument representing an action of functioning or the fact of being active or in effect and is either provided (as command line argument) or not provided as ofOperation.isEnabled().classAnOrConditionrepresents a list ofCondition(Term) instances of which at least one must be parsed successfully when theTerms'Term.parseArgs(String[], String[], CliContext)methods are invoked.classA predefined "be quiet"Flag: A predefinedFlaggives itsQuietFlag.SHORT_OPTION, itsQuietFlag.LONG_OPTIONas well as itsQuietFlag.ALIASan according semantics regarded by other subsystems.classclassclassclassclassA predefined system informationFlag: A predefinedFlaggives itsSysInfoFlag.SHORT_OPTION, itsSysInfoFlag.LONG_OPTIONas well as itsSysInfoFlag.ALIASan according semantics regarded by other subsystems..classA predefined verboseFlag: A predefinedFlaggives itsVerboseFlag.SHORT_OPTION, itsVerboseFlag.LONG_OPTIONas well as itsVerboseFlag.ALIASan according semantics regarded by other subsystems.classAnXorConditionrepresents a list ofCondition(Term) instances of which only one is allowed to be parsed successfully when theTerm.parseArgs(String[], String[], CliContext)methods are invoked.Subinterfaces with type arguments of type Term in org.refcodes.cliModifier and TypeInterfaceDescriptioninterfaceATermrepresents a node within a command line argument syntax tree.Classes in org.refcodes.cli that implement interfaces with type arguments of type TermModifier and TypeClassDescriptionclassThrown in case of a command line arguments mismatch regarding provided and expected args.Fields in org.refcodes.cli declared as TermModifier and TypeFieldDescriptionprotected Term[]AbstractCondition._childrenprotected TermArgsSyntaxException._sourceMethods in org.refcodes.cli that return TermModifier and TypeMethodDescriptionArgsParser.getArgsSyntax()ArgsSyntaxAccessor.getArgsSyntax()CliArgsParser.getArgsSyntax()protected TermAllCondition.getChild()Returns the one and only child of thisTerm.Term[]AbstractCondition.getChildren()ArgsSyntaxException.getSource()Returns theTermresponsible for this exception.default TermArgsSyntaxAccessor.ArgsSyntaxProperty.letArgsSyntax(Term aArgsSyntax) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenCondition(setter) as ofArgsSyntaxAccessor.ArgsSyntaxMutator.setArgsSyntax(Term)and returns the very same value (getter).Methods in org.refcodes.cli with parameters of type TermModifier and TypeMethodDescriptionstatic AllConditionInstantiates a newAllConditionwith theTerm.static AndConditionInstantiates a newAndConditionwith theTerm.static AnyConditionInstantiates a newAnyConditionwith theTerm.static CasesConditionInstantiates a newCasesConditionwith theTerm.default booleandefault booleandefault TermArgsSyntaxAccessor.ArgsSyntaxProperty.letArgsSyntax(Term aArgsSyntax) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenCondition(setter) as ofArgsSyntaxAccessor.ArgsSyntaxMutator.setArgsSyntax(Term)and returns the very same value (getter).static AnyConditionSemantically identical synonym for theCliSugar.optional(Term...). declaration.static OrConditionInstantiates a newOrConditionwith theTerm.voidArgsSyntaxAccessor.ArgsSyntaxMutator.setArgsSyntax(Term aArgsSyntax) voidCliArgsParser.setArgsSyntax(Term aArgsSyntax) String[]CliContext.toKeywords(Term aTerm) Determines all keywords (e.g. short- and long-options) found in the providedTermnode and its children.ArgsSyntaxAccessor.ArgsSyntaxBuilder.withArgsSyntax(Term aArgsSyntax) CliArgsParser.withArgsSyntax(Term aArgsSyntax) static XorConditionInstantiates a newXorConditionwith theTerm.Constructors in org.refcodes.cli with parameters of type TermModifierConstructorDescriptionAbstractCondition(String aDescription, Term... aElements) Instantiates anAbstractCondition' s sub-class with the according arguments.AllCondition(Term aArg) AmbiguousArgsException(String[] aArgs, Term aSource, Throwable aCause) Instantiates the classAmbiguousArgsException.AmbiguousArgsException(String[] aArgs, Term aSource, Throwable aCause, String aErrorCode) Instantiates the classAmbiguousArgsException.AmbiguousArgsException(String aMessage, String[] aArgs, Term aSource) Instantiates the classAmbiguousArgsException.AmbiguousArgsException(String aMessage, String[] aArgs, Term aSource, String aErrorCode) Instantiates the classAmbiguousArgsException.AmbiguousArgsException(String aMessage, String[] aArgs, Term aSource, Throwable aCause) Instantiates the classAmbiguousArgsException.AmbiguousArgsException(String aMessage, String[] aArgs, Term aSource, Throwable aCause, String aErrorCode) ArgsSyntaxException#ArgsSyntaxException(String, String[], Term, Throwable, String)AndCondition(Term... aArgs) AnyCondition(Term... aArgs) ArgsSyntaxException(String[] aArgs, Term aSource, Throwable aCause) Instantiates the classArgsSyntaxException.ArgsSyntaxException(String[] aArgs, Term aSource, Throwable aCause, String aErrorCode) Instantiates the classArgsSyntaxException.ArgsSyntaxException(String aMessage, String[] aArgs, Term aSource) Instantiates the classArgsSyntaxException.ArgsSyntaxException(String aMessage, String[] aArgs, Term aSource, String aErrorCode) Instantiates the classArgsSyntaxException.ArgsSyntaxException(String aMessage, String[] aArgs, Term aSource, Throwable aCause) Instantiates the classArgsSyntaxException.ArgsSyntaxException(String aMessage, String[] aArgs, Term aSource, Throwable aCause, String aErrorCode) Instantiates the classArgsSyntaxException.CasesCondition(Term... aArgs) CliArgsParser(Term aArgsSyntax) Constructs theArgsParserinstance with the given rootConditionand the defaultSyntaxNotation.LOGICAL.CliArgsParser(Term aArgsSyntax, CliContext aCliCtx) Constructs theArgsParserinstance with the given rootConditionand the defaultSyntaxNotation.LOGICAL.OrCondition(Term... aArgs) ParseArgsException(String[] aArgs, Term aSource, Throwable aCause) Instantiates the classParseArgsException.ParseArgsException(String[] aArgs, Term aSource, Throwable aCause, String aErrorCode) Instantiates the classParseArgsException.ParseArgsException(String aMessage, String[] aArgs, Term aSource) Instantiates the classParseArgsException.ParseArgsException(String aMessage, String[] aArgs, Term aSource, String aErrorCode) Instantiates the classParseArgsException.ParseArgsException(String aMessage, String[] aArgs, Term aSource, Throwable aCause) Instantiates the classParseArgsException.ParseArgsException(String aMessage, String[] aArgs, Term aSource, Throwable aCause, String aErrorCode) Instantiates the classParseArgsException.ParseDirectiveArgsException(String[] aArgs, String aOperation, Throwable aCause, Term aSource) Instantiates the classParseDirectiveArgsException.ParseDirectiveArgsException(String[] aArgs, String aOperation, Throwable aCause, Term aSource, String aErrorCode) Instantiates the classParseDirectiveArgsException.ParseDirectiveArgsException(String aMessage, String[] aArgs, String aOperation, Throwable aCause, Term aSource) Instantiates the classParseDirectiveArgsException.ParseDirectiveArgsException(String aMessage, String[] aArgs, String aOperation, Throwable aCause, Term aSource, String aErrorCode) Instantiates the classParseDirectiveArgsException.ParseDirectiveArgsException(String aMessage, String[] aArgs, String aOperation, Term aSource) Instantiates the classParseDirectiveArgsException.ParseDirectiveArgsException(String aMessage, String[] aArgs, String aOperation, Term aSource, String aErrorCode) Instantiates the classParseDirectiveArgsException.ParseOptionArgsException(String[] aArgs, String aShortOption, String aLongOption, Throwable aCause, Term aSource) Instantiates the classParseOptionArgsException.ParseOptionArgsException(String[] aArgs, String aShortOption, String aLongOption, Throwable aCause, Term aSource, String aErrorCode) Instantiates the classParseOptionArgsException.ParseOptionArgsException(String aMessage, String[] aArgs, String aShortOption, String aLongOption, Throwable aCause, Term aSource) Instantiates the classParseOptionArgsException.ParseOptionArgsException(String aMessage, String[] aArgs, String aShortOption, String aLongOption, Throwable aCause, Term aSource, String aErrorCode) Instantiates the classParseOptionArgsException.ParseOptionArgsException(String aMessage, String[] aArgs, String aShortOption, String aLongOption, Term aSource) Instantiates the classParseOptionArgsException.ParseOptionArgsException(String aMessage, String[] aArgs, String aShortOption, String aLongOption, Term aSource, String aErrorCode) Instantiates the classParseOptionArgsException.SuperfluousArgsException(String[] aArgs, Term aSource, Throwable aCause) Instantiates the classSuperfluousArgsException.SuperfluousArgsException(String[] aArgs, Term aSource, Throwable aCause, String aErrorCode) Instantiates the classSuperfluousArgsException.SuperfluousArgsException(String aMessage, String[] aArgs, Term aSource) Instantiates the classSuperfluousArgsException.SuperfluousArgsException(String aMessage, String[] aArgs, Term aSource, String aErrorCode) Instantiates the classSuperfluousArgsException.SuperfluousArgsException(String aMessage, String[] aArgs, Term aSource, Throwable aCause) Instantiates the classSuperfluousArgsException.SuperfluousArgsException(String aMessage, String[] aArgs, Term aSource, Throwable aCause, String aErrorCode) Instantiates the classSuperfluousArgsException.UnknownArgsException(String[] aArgs, Term aSource, Throwable aCause) Instantiates the classUnknownArgsException.UnknownArgsException(String[] aArgs, Term aSource, Throwable aCause, String aErrorCode) Instantiates the classUnknownArgsException.UnknownArgsException(String aMessage, String[] aArgs, Term aSource) Instantiates the classUnknownArgsException.UnknownArgsException(String aMessage, String[] aArgs, Term aSource, String aErrorCode) Instantiates the classUnknownArgsException.UnknownArgsException(String aMessage, String[] aArgs, Term aSource, Throwable aCause) Instantiates the classUnknownArgsException.UnknownArgsException(String aMessage, String[] aArgs, Term aSource, Throwable aCause, String aErrorCode) Instantiates the classUnknownArgsException.UnknownOperationArgsException(String aMessage, String[] aArgs, String aOperation, Throwable aCause, Term aSource) Instantiates the classUnknownOperationArgsException.UnknownOperationArgsException(String aMessage, String[] aArgs, String aOperation, Throwable aCause, Term aSource, String aErrorCode) Instantiates the classUnknownOperationArgsException.UnknownOperationArgsException(String aMessage, String[] aArgs, String aOperation, Term aSource) Instantiates the classUnknownOperationArgsException.UnknownOperationArgsException(String aMessage, String[] aArgs, String aOperation, Term aSource, String aErrorCode) Instantiates the classUnknownOperationArgsException.UnknownOperationArgsException(String aShortOption, String aOperation, String[] aArgs, Throwable aCause, Term aSource) Instantiates the classUnknownOperationArgsException.UnknownOperationArgsException(String aShortOption, String aOperation, String[] aArgs, Throwable aCause, Term aSource, String aErrorCode) Instantiates the classUnknownOperationArgsException.UnknownOptionArgsException(String aMessage, String[] aArgs, String aShortOption, String aLongOption, Throwable aCause, Term aSource) Instantiates the classUnknownOptionArgsException.UnknownOptionArgsException(String aMessage, String[] aArgs, String aShortOption, String aLongOption, Throwable aCause, Term aSource, String aErrorCode) Instantiates the classUnknownOptionArgsException.UnknownOptionArgsException(String aMessage, String[] aArgs, String aShortOption, String aLongOption, Term aSource) Instantiates the classUnknownOptionArgsException.UnknownOptionArgsException(String aMessage, String[] aArgs, String aShortOption, String aLongOption, Term aSource, String aErrorCode) Instantiates the classUnknownOptionArgsException.UnknownOptionArgsException(String aShortOption, String aLongOption, String[] aArgs, Throwable aCause, Term aSource) Instantiates the classUnknownOptionArgsException.UnknownOptionArgsException(String aShortOption, String aLongOption, String[] aArgs, Throwable aCause, Term aSource, String aErrorCode) Instantiates the classUnknownOptionArgsException.protectedXorCondition(String aDescription, Term... aArgs) XorCondition(Term... aArgs)