Any of the nested
Condition conditions may match for the
AnyCondition to match, e.g. all of the nested conditions are
optional.
Provides an accessor for a command line arguments (short "args") array.
Provides a mutator for a args property.
Enumeration declaring command line argument filter.
The
ArgsParser provides means for parsing command line arguments and
constructing a command line utility's help output.
Provides a builder method for a
ArgsParser property returning the
builder for applying multiple build operations.
This mixin provides builder additions (as of the builder pattern for chained
configuring method calls) for parsing command line arguments.
The
ArgsProcessorBuilder provides common minimum builder
functionality required by to build an argument processing instance.
Provides an accessor for a (root)
Term property.
Provides a builder method for a (root)
Term property returning
the builder for applying multiple build operations.
Provides a mutator for a (root)
Term property.
Provides a (root)
Term property.
Thrown in case of a command line arguments mismatch regarding provided and
expected args.
Provides an accessor for a argument Escape-Code property.
Provides a builder method for a argument Escape-Code property returning
the builder for applying multiple build operations.
Provides a mutator for a argument Escape-Code property.
Provides a argument Escape-Code property.
Provides an accessor for an argument prefix property.
Provides a builder method for an argument prefix property returning the
builder for applying multiple build operations.
Provides a mutator for an argument prefix property.
Provides an accessor for an argument suffix property.
Provides a builder method for an argument suffix property returning the
builder for applying multiple build operations.
Provides a mutator for an argument suffix property.
Creates an array representation facade for the encapsulated
Directive.
Creates an array representation facade for the encapsulated
Operand.
Creates an array representation facade for the encapsulated
Option.
Provides an accessor for a banner border Escape-Code property.
Provides a builder method for a banner border Escape-Code property
returning the builder for applying multiple build operations.
Provides a mutator for a banner border Escape-Code property.
Provides a banner border Escape-Code property.
Provides an accessor for a banner Escape-Code property.
Provides a builder method for a banner Escape-Code property returning the
builder for applying multiple build operations.
Provides a mutator for a banner Escape-Code property.
Provides a banner Escape-Code property.
Provides an accessor for a banner Font property.
Provides a builder method for a banner Font property returning
the builder for applying multiple build operations.
Provides a mutator for a banner Font property.
Provides a banner Font property.
Provides an accessor for a banner font palette property.
Provides a builder method for a banner font palette property returning
the builder for applying multiple build operations.
Provides a mutator for a banner font palette property.
Provides a banner font palette property.
A straightforward implementation of the
ArgsParser interface.
Provides a builder method for a
CliContext property returning the
builder for applying multiple build operations.
Base exception for the CLI artifact.
This abstract exception is the base exception for all command line
argument related exceptions.
The purpose of a
CliSchema is automatically generate documentation of
Term structures.
Provides an accessor for a command Escape-Code property.
Provides a builder method for a command Escape-Code property returning
the builder for applying multiple build operations.
Provides a mutator for a command Escape-Code property.
Provides a command Escape-Code property.
The
Condition interface represents a node (and therewith the syntax
for the arguments) in the command line arguments syntax tree by simply
extending the
Term interface and adding the functionality of
providing access to the added
Operands (leafs).
The
ConfigOption represents an
Option holding a value
specifying a configuration resource (file).
Provides an accessor for a copyright property.
Provides a builder method for a copyright property returning the builder
for applying multiple build operations.
Provides a mutator for a copyright property.
Provides a copyright property.
Provides an accessor for a description Escape-Code property.
Provides a builder method for a description Escape-Code property
returning the builder for applying multiple build operations.
Provides a mutator for a description Escape-Code property.
Provides a description Escape-Code property.
An
Directive represents a command line operation with the according
operation's operand (value).
An example usage item describing a usage scenario.
Provides an accessor for an
Example instances property.
Provides a builder method for an
Example instances property
returning the builder for applying multiple build operations.
Provides a mutator for an
Example instances property.
Provides an
Example instances property.
The
Flag class implements the
Option interface for
representing either a
true or a
false state: When a
flag is provided to your command line arguments, then it is considered to be
true, when it is omitted, then it is considered to be
false as of
Flag.isEnabled().
Provides an accessor for a keyword (e.g. short- and long-options) Escape-Code
property.
Provides a builder method for a keyword (e.g. short- and long-options)
Escape-Code property returning the builder for applying multiple build
operations.
Provides a mutator for a keyword (e.g. short- and long-options)
Escape-Code property.
Provides a keyword (e.g. short- and long-options) Escape-Code property.
Provides an accessor for a license property.
Provides a builder method for a license property returning the builder
for applying multiple build operations.
Provides a mutator for a license property.
Provides a license property.
Provides an accessor for a line separator Escape-Code property.
Provides a builder method for a line separator Escape-Code property
returning the builder for applying multiple build operations.
Provides a mutator for a line separator Escape-Code property.
Provides a line separator Escape-Code property.
Provides an accessor for a long option property.
Provides a builder method for a long option property returning the
builder for applying multiple build operations.
Provides a mutator for a long option property.
Provides an accessor for a long option prefix property.
Provides a builder method for a long option prefix property returning the
builder for applying multiple build operations.
Provides a mutator for a long option prefix property.
Provides a long option prefix property.
Provides an accessor for a long option prefix property.
Provides a builder method for a long option prefix property returning the
builder for applying multiple build operations.
Provides a mutator for a long option prefix property.
Provides an accessor for a match-count property.
Provides a builder method for a match-count property returning the
builder for applying multiple build operations.
Provides a mutator for a match-count property.
The
NoneOperand represents an empty set of arguments, e.g. no command
line argument is being passed.
An
Operand represents a value parsed from command line arguments.
The
Operation is an argument representing an action of functioning or
the fact of being active or in effect and is either provided (as command line
argument) or not provided as of
Operation.isEnabled().
Provides an accessor for a operation property.
Provides a builder method for a operation property returning the builder
for applying multiple build operations.
Provides a mutator for a operation property.
An
Option represents a command line option with the according
option's value.
Provides means to determine context specific information on
Option
instances.
Thrown in case the provided command line arguments do not respect the
required semantics or cannot be converted to the required type.
Provides an accessor for a command line arguments (short "args") array.
Provides a mutator for a parsed args property.
An
Property represents an option property with the according
porperty's key and value separated by a
= (and no whitespace
inbetween).
Provides an accessor for a option Escape-Code property.
Provides a builder method for a option Escape-Code property returning the
builder for applying multiple build operations.
Provides a mutator for a option Escape-Code property.
Provides an accessor for a short option property.
Provides a builder method for a short option property returning the
builder for applying multiple build operations.
Provides a mutator for a short option property.
Provides an accessor for a short option prefix property.
Provides a builder method for a short option prefix property returning
the builder for applying multiple build operations.
Provides a mutator for a short option prefix property.
Provides a short option prefix property.
Provides an accessor for a short option prefix property.
Provides a builder method for a short option prefix property returning
the builder for applying multiple build operations.
Provides a mutator for a short option prefix property.
An
Operand (neither a short option nor a long option prepended nor
being a flag) represents an argument of type
String.
The
Synopsisable interface defines those methods required to create a
human readable usage
String similar to a manpage's synopsis from the
implementing instance.
The
SyntaxMetrics provides properties specific to a specific command
line syntax notation.
Provides a builder method for a
SyntaxMetrics property returning
the builder for applying multiple build operations.
A
Term represents a node within a command line argument syntax tree.
Thrown in case command line arguments were not processed (did not match the
expected arguments), e.g. the arguments were rejected as them did not work
for the according syntax.