Condition, Syntaxable, SyntaxUsage, org.refcodes.component.ResetableAndCondition, OptionalCondition, OptionConditionFacade, OrCondition, XorConditionpublic abstract class AbstractCondition extends Object implements Condition
AbstractCondition is an abstract implementation of an
Condition providing the boiler plate when implementing the
Condition interface.| Constructor | Description |
|---|---|
AbstractCondition(Syntaxable... aElements) |
Instantiates a new abstract condition.
|
| Modifier and Type | Method | Description |
|---|---|---|
protected void |
addChild(Syntaxable aArgumentizer) |
Adds the child.
|
<V> V |
get(String aAlias) |
Searches for a value being set for the given for given alias in the
syntax tree parsing the command line arguments; if a node in the syntax
tree has a value for the given alias, then this value is returned.
|
protected List<Syntaxable> |
getChildren() |
Gets the children.
|
void |
reset() |
|
List<Operand<?>> |
toOperands() |
|
String |
toString() |
|
String |
toSyntax(SyntaxNotation aSyntaxNotation,
String aOptionEscCode,
String aResetEscCode) |
This method is to be called from inside the
Syntaxable hierarchy;
use the method SyntaxUsage.toUsage(SyntaxNotation) in case you invoke syntax
retrieval from the root Syntaxable. |
String |
toUsage(SyntaxNotation aSyntaxNotation,
String aOptionEscCode,
String aResetEscCode) |
Returns the human readable (verbose) syntax of implementing class
ATTENTION: As of different parenthesis settings for some notations
regarding the root
Syntaxable and the child Syntaxables,
the method Syntaxable.toSyntax(SyntaxNotation, String, String) is
called from inside a Syntaxable hierarchy. |
clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitparseArgs, parseArgs, toState, toSyntaxtoUsage, toUsage, toUsagepublic AbstractCondition(Syntaxable... aElements)
aElements - the elementspublic String toSyntax(SyntaxNotation aSyntaxNotation, String aOptionEscCode, String aResetEscCode)
Syntaxable hierarchy;
use the method SyntaxUsage.toUsage(SyntaxNotation) in case you invoke syntax
retrieval from the root Syntaxable. Returns the human readable
(verbose) syntax of this Syntaxable instance including, in case
of being a node in the syntax tree (such as a Condition, the
syntax of the child Syntaxable instances. ATTENTION: As of
different parenthesis settings for some notations regarding the root
Syntaxable and the child Syntaxables, the method
Syntaxable.toSyntax(SyntaxNotation, String, String) is called from inside
the Syntaxable hierarchy. In case the syntax is to be retrieved
from the root Syntaxable, then the applicable method to be called
is SyntaxUsage.toUsage(SyntaxNotation), as for some notations it will for
example not create the most outer braces.toSyntax in interface SyntaxableaSyntaxNotation - The syntax notation used for generating the
command line arguments syntax.aOptionEscCode - The escape code to be used when processing an
option, e.g. this can be an ANSI Escape-Code to highlight the
option parameters.aResetEscCode - The escape code to close (reset) any Escape-Code
being set before.public void reset()
reset in interface org.refcodes.component.Resetablepublic List<Operand<?>> toOperands()
Conditions and collects all therein
found Operands and sub-types such as the Flag or the
Option. This is most useful when creating a list of
Options, Flages and Operands when printing out
detailed help.toOperands in interface ConditionOperand elements.protected List<Syntaxable> getChildren()
protected void addChild(Syntaxable aArgumentizer)
aArgumentizer - the argumentizerpublic <V> V get(String aAlias)
get in interface SyntaxableV - The type of the value being expected.aAlias - The alias for which to seek for a value being set.public String toUsage(SyntaxNotation aSyntaxNotation, String aOptionEscCode, String aResetEscCode)
Syntaxable and the child Syntaxables,
the method Syntaxable.toSyntax(SyntaxNotation, String, String) is
called from inside a Syntaxable hierarchy. In case the syntax is
to be retrieved from the root Syntaxable or an encapsulating and
different type, then the applicable method to be called is
SyntaxUsage.toUsage(SyntaxNotation), as for some notations it will for
example not create the most outer braces.toUsage in interface SyntaxUsageaSyntaxNotation - The syntax notation used for generating the
command line arguments syntax.aOptionEscCode - The escape code to be used when processing an
option, e.g. this can be an ANSI Escape-Code to highlight the
option parameters (for example "--help", "-q" and so on).aResetEscCode - The escape code to close (reset) any Escape-Code
being set before.Copyright © 2021. All rights reserved.