T - the generic typeCloneable, Comparable<T>, ArgsAccessor, Operand<T>, Option<T>, Syntaxable, SyntaxUsage, org.refcodes.component.Resetable, org.refcodes.mixin.AliasAccessor, org.refcodes.mixin.Clonable, org.refcodes.mixin.DescriptionAccessor, org.refcodes.mixin.TypeAccessor<T>, org.refcodes.mixin.ValueAccessor<T>CharOption, DoubleOption, EnumOption, FileOption, Flag, FloatOption, IntOption, LongOption, StringOptionpublic abstract class AbstractOption<T> extends AbstractOperand<T> implements Option<T>
AbstractOption is an abstract implementation of an Option
providing the boiler plate when implementing the Option interface.org.refcodes.mixin.AliasAccessor.AliasBuilder<B extends org.refcodes.mixin.AliasAccessor.AliasBuilder<B>>, org.refcodes.mixin.AliasAccessor.AliasMutator, org.refcodes.mixin.AliasAccessor.AliasPropertyArgsAccessor.ArgsMutator, ArgsAccessor.ArgsPropertyorg.refcodes.mixin.DescriptionAccessor.DescriptionBuilder<B extends org.refcodes.mixin.DescriptionAccessor.DescriptionBuilder<B>>, org.refcodes.mixin.DescriptionAccessor.DescriptionMutator, org.refcodes.mixin.DescriptionAccessor.DescriptionPropertyorg.refcodes.mixin.TypeAccessor.TypeBuilder<T extends Object,B extends org.refcodes.mixin.TypeAccessor.TypeBuilder<T,B>>, org.refcodes.mixin.TypeAccessor.TypeMutator<T extends Object>, org.refcodes.mixin.TypeAccessor.TypeProperty<T extends Object>org.refcodes.mixin.ValueAccessor.ValueBuilder<V extends Object,B extends org.refcodes.mixin.ValueAccessor.ValueBuilder<V,B>>, org.refcodes.mixin.ValueAccessor.ValueMutator<V extends Object>, org.refcodes.mixin.ValueAccessor.ValueProperty<V extends Object>_value| Modifier | Constructor | Description |
|---|---|---|
protected |
AbstractOption(String aShortOption,
String aLongOption,
Class<T> aType,
String aDescription) |
Constructs a
Option with the given arguments. |
|
AbstractOption(String aShortOption,
String aLongOption,
Class<T> aType,
String aAlias,
String aDescription) |
Constructs a
Option with the given arguments. |
|
AbstractOption(org.refcodes.struct.Relation<String,T> aProperty,
Class<T> aType) |
Instantiates a new option.
|
| Modifier and Type | Method | Description |
|---|---|---|
Object |
clone() |
|
String |
getLongOption() |
Returns the long-option representing an
Option instance. |
protected String[] |
getOptionPrefixes() |
Determines the prefixes suitable for the environment.
|
String |
getShortOption() |
Returns the short-option representing an
Option instance. |
List<Operand<T>> |
parseArgs(String[] aArgs,
String[] aOptions) |
Parses the provided command line arguments and determines the according
values by evaluating this
Syntaxable instance or, in case of
being a node in the syntax tree (such as a Condition, traversing
the child Syntaxable instances'
Syntaxable.parseArgs(String[], String[]) methods. |
protected void |
setArgs(String[] aArgs) |
Sets the command line argument(s) representing the
Operand and
its value as parsed by the AbstractOperand.parseArgs(String[], String[]) method. |
protected void |
setValue(T aValue) |
Sets the value for the
Operand as parsed by the
AbstractOperand.parseArgs(String[], String[]) method. |
String |
toState() |
The
Syntaxable.toState() method might be used by the
Object.toString() method and prints out the state of the
syntaxable and (if any) its children. |
String |
toSyntax(SyntaxNotation aSyntaxNotation,
String aOptionEscCode,
String aResetEscCode) |
This method is to be called from inside the
Syntaxable hierarchy;
use the method SyntaxUsage.toUsage(SyntaxNotation) in case you invoke syntax
retrieval from the root Syntaxable. |
String |
toUsage(SyntaxNotation aSyntaxNotation,
String aOptionEscCode,
String aResetEscCode) |
Returns the human readable (verbose) syntax of implementing class
ATTENTION: As of different parenthesis settings for some notations
regarding the root
Syntaxable and the child Syntaxables,
the method Syntaxable.toSyntax(SyntaxNotation, String, String) is
called from inside a Syntaxable hierarchy. |
compareTo, getAlias, getArgs, getDescription, getType, getValue, reset, toString, toValuecompareToequals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitget, getAlias, getArgs, getValue, hasValuegetOptionsparseArgs, toSyntaxtoUsage, toUsage, toUsagepublic AbstractOption(String aShortOption, String aLongOption, Class<T> aType, String aAlias, String aDescription)
Option with the given arguments.aShortOption - The short-option being a single character with the
additional single hyphen-minus "-" prefix.aLongOption - The long-option being a multi-character sequence with
at least two characters with the additional double hyphen-minus
"--" prefix.aType - The type of the value returned by the AbstractOperand.getValue()
method.aAlias - The option argument's name to be used when constructing the
syntax.aDescription - A description without any line breaks.protected AbstractOption(String aShortOption, String aLongOption, Class<T> aType, String aDescription)
Option with the given arguments.aShortOption - The short-option being a single character with the
additional single hyphen-minus "-" prefix.aLongOption - The long-option being a multi-character sequence with
at least two characters with the additional double hyphen-minus
"--" prefix.aType - The type of the value returned by the AbstractOperand.getValue()
method.aDescription - A description without any line breaks.public List<Operand<T>> parseArgs(String[] aArgs, String[] aOptions) throws UnknownArgsException, AmbiguousArgsException, ParseArgsException
Syntaxable instance or, in case of
being a node in the syntax tree (such as a Condition, traversing
the child Syntaxable instances'
Syntaxable.parseArgs(String[], String[]) methods. In case of successfully
parsing this Syntaxable and / or the child Syntaxable
instances, the evaluated command line arguments are returned: Depending
on the Syntaxable subclasses representing the evaluated command
line arguments, instances of Flag classes, Option classes
or Operand classes may be found in the result. In case of parsing
failure, an according exception is thrown. ATTENTION: This method does
not test for superfluous command line arguments being passed; e.g.
command line arguments not being evaluated by any of the
Syntaxable instance being traversed. This method is commonly used
by a root Syntaxable's ArgsParser.evalArgs(String[])
method, which delegates to the Syntaxable.parseArgs(String[], String[])
method and after which it determines whether there are superfluous
arguments to be taken care of (by throwing an according exception).
Business logic therefore should invoke the root node's
Syntaxable.parseArgs(String[], String[]) method as ignoring superfluous
command line arguments will cause unexpected behavior from the point of
view of the invoker.parseArgs in interface SyntaxableparseArgs in class AbstractOperand<T>aArgs - The command line arguments to be parsed.aOptions - The list of options (short and as well as long) which are
reserved and cannot be used as value.Operand interfaces or its sub-types.UnknownArgsException - Thrown in case not one command line argument
matched regarding the provided args vs. the expected args.AmbiguousArgsException - Thrown in case at least one command line
argument is ambiguous regarding expected args vs. provided args.ParseArgsException - Thrown in case the provided command line
arguments do not respect the required syntax or cannot be
converted to the required typepublic String getShortOption()
Option instance. A short
option usually is being prefixed with a single hyphen-minus "-" as
defined in CommandArgPrefix.POSIX_SHORT_OPTION.getShortOption in interface Option<T>String.public String getLongOption()
Option instance. A long
option usually is being prefixed with a double hyphen-minus "--" as
defined in CommandArgPrefix.POSIX_LONG_OPTION.getLongOption in interface Option<T>String.public String toSyntax(SyntaxNotation aSyntaxNotation, String aOptionEscCode, String aResetEscCode)
Syntaxable hierarchy;
use the method SyntaxUsage.toUsage(SyntaxNotation) in case you invoke syntax
retrieval from the root Syntaxable. Returns the human readable
(verbose) syntax of this Syntaxable instance including, in case
of being a node in the syntax tree (such as a Condition, the
syntax of the child Syntaxable instances. ATTENTION: As of
different parenthesis settings for some notations regarding the root
Syntaxable and the child Syntaxables, the method
Syntaxable.toSyntax(SyntaxNotation, String, String) is called from inside
the Syntaxable hierarchy. In case the syntax is to be retrieved
from the root Syntaxable, then the applicable method to be called
is SyntaxUsage.toUsage(SyntaxNotation), as for some notations it will for
example not create the most outer braces.toSyntax in interface SyntaxabletoSyntax in class AbstractOperand<T>aSyntaxNotation - The syntax notation used for generating the
command line arguments syntax.aOptionEscCode - The escape code to be used when processing an
option, e.g. this can be an ANSI Escape-Code to highlight the
option parameters.aResetEscCode - The escape code to close (reset) any Escape-Code
being set before.public String toState()
Syntaxable.toState() method might be used by the
Object.toString() method and prints out the state of the
syntaxable and (if any) its children. Even in case parsing command line
arguments failed, the state till failure can be inspected with this
method.toState in interface SyntaxabletoState in class AbstractOperand<T>Syntaxable instance and (if any) its
children.public Object clone() throws CloneNotSupportedException
clone in interface org.refcodes.mixin.Clonableclone in class AbstractOperand<T>CloneNotSupportedExceptionprotected String[] getOptionPrefixes()
protected void setValue(T aValue)
Operand as parsed by the
AbstractOperand.parseArgs(String[], String[]) method.setValue in class AbstractOperand<T>aValue - The value to be set for this Operand.protected void setArgs(String[] aArgs)
Operand and
its value as parsed by the AbstractOperand.parseArgs(String[], String[]) method.setArgs in class AbstractOperand<T>aArgs - The command line arguments representing this Operand
with its value.public String toUsage(SyntaxNotation aSyntaxNotation, String aOptionEscCode, String aResetEscCode)
Syntaxable and the child Syntaxables,
the method Syntaxable.toSyntax(SyntaxNotation, String, String) is
called from inside a Syntaxable hierarchy. In case the syntax is
to be retrieved from the root Syntaxable or an encapsulating and
different type, then the applicable method to be called is
SyntaxUsage.toUsage(SyntaxNotation), as for some notations it will for
example not create the most outer braces.toUsage in interface SyntaxUsageaSyntaxNotation - The syntax notation used for generating the
command line arguments syntax.aOptionEscCode - The escape code to be used when processing an
option, e.g. this can be an ANSI Escape-Code to highlight the
option parameters (for example "--help", "-q" and so on).aResetEscCode - The escape code to close (reset) any Escape-Code
being set before.Copyright © 2021. All rights reserved.