ArgsAccessor.ArgsPropertypublic static interface ArgsAccessor.ArgsMutator
| Modifier and Type | Method | Description |
|---|---|---|
void |
setArgs(String[] aArgs) |
Sets the command line arguments for the args property.
|
void setArgs(String[] aArgs)
aArgs - The command line arguments to be stored by the args
property.Copyright © 2021. All rights reserved.