Cloneable, Comparable<T>, ArgsAccessor, Operand<T[]>, Syntaxable, SyntaxUsage, org.refcodes.component.Resetable, org.refcodes.mixin.AliasAccessor, org.refcodes.mixin.Clonable, org.refcodes.mixin.DescriptionAccessor, org.refcodes.mixin.TypeAccessor<T>, org.refcodes.mixin.ValueAccessor<T>ArrayOptionpublic class ArrayOperand<T> extends Object implements Operand<T[]>
org.refcodes.mixin.AliasAccessor.AliasBuilder<B extends org.refcodes.mixin.AliasAccessor.AliasBuilder<B>>, org.refcodes.mixin.AliasAccessor.AliasMutator, org.refcodes.mixin.AliasAccessor.AliasPropertyArgsAccessor.ArgsMutator, ArgsAccessor.ArgsPropertyorg.refcodes.mixin.DescriptionAccessor.DescriptionBuilder<B extends org.refcodes.mixin.DescriptionAccessor.DescriptionBuilder<B>>, org.refcodes.mixin.DescriptionAccessor.DescriptionMutator, org.refcodes.mixin.DescriptionAccessor.DescriptionPropertyorg.refcodes.mixin.TypeAccessor.TypeBuilder<T extends Object,B extends org.refcodes.mixin.TypeAccessor.TypeBuilder<T,B>>, org.refcodes.mixin.TypeAccessor.TypeMutator<T extends Object>, org.refcodes.mixin.TypeAccessor.TypeProperty<T extends Object>org.refcodes.mixin.ValueAccessor.ValueBuilder<V extends Object,B extends org.refcodes.mixin.ValueAccessor.ValueBuilder<V,B>>, org.refcodes.mixin.ValueAccessor.ValueMutator<V extends Object>, org.refcodes.mixin.ValueAccessor.ValueProperty<V extends Object>| Constructor | Description |
|---|---|
ArrayOperand(Operand<T> aOperand) |
Constructs the
ArrayOperand by encapsulating the given
Operand and providing its definition as array definition to the
CLI. |
ArrayOperand(Operand<T> aOperand,
int aLength) |
Constructs the
ArrayOperand by encapsulating the given
Operand and providing its definition as array definition to the
CLI. |
ArrayOperand(Operand<T> aOperand,
int aMinLength,
int aMaxLength) |
Constructs the
ArrayOperand by encapsulating the given
Operand and providing its definition as array definition to the
CLI. |
| Modifier and Type | Method | Description |
|---|---|---|
Object |
clone() |
|
int |
compareTo(Operand<?> o) |
|
String |
getAlias() |
|
String[] |
getArgs() |
Retrieves the command line arguments from the args property.
|
String |
getDescription() |
|
int |
getMaxLength() |
Retrieves the maximum number of array elements to be present, e.g.
|
int |
getMinLength() |
Retrieves the minimum number of array elements to be present, e.g.
|
protected Operand<T> |
getOperand() |
Hook for accessing the encapsulated
Operand. |
Class<T[]> |
getType() |
|
T[] |
getValue() |
|
List<Operand<?>> |
parseArgs(String[] aArgs,
String[] aOperands) |
Parses the provided command line arguments and determines the according
values by evaluating this
Syntaxable instance or, in case of
being a node in the syntax tree (such as a Condition, traversing
the child Syntaxable instances'
Syntaxable.parseArgs(String[], String[]) methods. |
void |
reset() |
|
String |
toState() |
The
Syntaxable.toState() method might be used by the
Object.toString() method and prints out the state of the
syntaxable and (if any) its children. |
String |
toSyntax(SyntaxNotation aSyntaxNotation,
String aOptionEscCode,
String aResetEscCode) |
This method is to be called from inside the
Syntaxable hierarchy;
use the method SyntaxUsage.toUsage(SyntaxNotation) in case you invoke syntax
retrieval from the root Syntaxable. |
String |
toUsage(SyntaxNotation aSyntaxNotation,
String aOptionEscCode,
String aResetEscCode) |
Returns the human readable (verbose) syntax of implementing class
ATTENTION: As of different parenthesis settings for some notations
regarding the root
Syntaxable and the child Syntaxables,
the method Syntaxable.toSyntax(SyntaxNotation, String, String) is
called from inside a Syntaxable hierarchy. |
equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, waitparseArgs, toSyntaxtoUsage, toUsage, toUsagepublic ArrayOperand(Operand<T> aOperand)
ArrayOperand by encapsulating the given
Operand and providing its definition as array definition to the
CLI.aOperand - The Operand which's array counterpart is to be
defined.public ArrayOperand(Operand<T> aOperand, int aLength)
ArrayOperand by encapsulating the given
Operand and providing its definition as array definition to the
CLI.aOperand - The Operand which's array counterpart is to be
defined.aLength - The number of array elements, or -1 if there is no limit.public ArrayOperand(Operand<T> aOperand, int aMinLength, int aMaxLength)
ArrayOperand by encapsulating the given
Operand and providing its definition as array definition to the
CLI.aOperand - The Operand which's array counterpart is to be
defined.aMinLength - The minimum number of array elements, or -1 if there is
no limit.aMaxLength - The maximum number of array elements, or -1 if there is
no limit.public T[] getValue()
public String[] getArgs()
getArgs in interface ArgsAccessorgetArgs in interface Operand<T>public String getAlias()
Operand) or the option argument (Option),
depending on the sub-type inheriting from this interface. The parameter
name is merely used for constructing the command line arguments syntax
String via Syntaxable.toSyntax(SyntaxNotation, String, String) and
the command line arguments detail description when creating a command
line tool's help output. Attention: The alias can also be used as a key
when putting an Operand's key/value-pair into a dictionary such
as is done by the RuntimeProperties type provided by the
refcodes-properties-ext-runime artifact!public String toSyntax(SyntaxNotation aSyntaxNotation, String aOptionEscCode, String aResetEscCode)
Syntaxable hierarchy;
use the method SyntaxUsage.toUsage(SyntaxNotation) in case you invoke syntax
retrieval from the root Syntaxable. Returns the human readable
(verbose) syntax of this Syntaxable instance including, in case
of being a node in the syntax tree (such as a Condition, the
syntax of the child Syntaxable instances. ATTENTION: As of
different parenthesis settings for some notations regarding the root
Syntaxable and the child Syntaxables, the method
Syntaxable.toSyntax(SyntaxNotation, String, String) is called from inside
the Syntaxable hierarchy. In case the syntax is to be retrieved
from the root Syntaxable, then the applicable method to be called
is SyntaxUsage.toUsage(SyntaxNotation), as for some notations it will for
example not create the most outer braces.toSyntax in interface SyntaxableaSyntaxNotation - The syntax notation used for generating the
command line arguments syntax.aOptionEscCode - The escape code to be used when processing an
option, e.g. this can be an ANSI Escape-Code to highlight the
option parameters.aResetEscCode - The escape code to close (reset) any Escape-Code
being set before.public Class<T[]> getType()
getType in interface org.refcodes.mixin.TypeAccessor<T>public List<Operand<?>> parseArgs(String[] aArgs, String[] aOperands) throws UnknownArgsException, AmbiguousArgsException, ParseArgsException
Syntaxable instance or, in case of
being a node in the syntax tree (such as a Condition, traversing
the child Syntaxable instances'
Syntaxable.parseArgs(String[], String[]) methods. In case of successfully
parsing this Syntaxable and / or the child Syntaxable
instances, the evaluated command line arguments are returned: Depending
on the Syntaxable subclasses representing the evaluated command
line arguments, instances of Flag classes, Option classes
or Operand classes may be found in the result. In case of parsing
failure, an according exception is thrown. ATTENTION: This method does
not test for superfluous command line arguments being passed; e.g.
command line arguments not being evaluated by any of the
Syntaxable instance being traversed. This method is commonly used
by a root Syntaxable's ArgsParser.evalArgs(String[])
method, which delegates to the Syntaxable.parseArgs(String[], String[])
method and after which it determines whether there are superfluous
arguments to be taken care of (by throwing an according exception).
Business logic therefore should invoke the root node's
Syntaxable.parseArgs(String[], String[]) method as ignoring superfluous
command line arguments will cause unexpected behavior from the point of
view of the invoker.parseArgs in interface SyntaxableaArgs - The command line arguments to be parsed.aOperands - The list of options (short and as well as long) which are
reserved and cannot be used as value.Operand interfaces or its sub-types.UnknownArgsException - Thrown in case not one command line argument
matched regarding the provided args vs. the expected args.AmbiguousArgsException - Thrown in case at least one command line
argument is ambiguous regarding expected args vs. provided args.ParseArgsException - Thrown in case the provided command line
arguments do not respect the required syntax or cannot be
converted to the required typepublic String toState()
Syntaxable.toState() method might be used by the
Object.toString() method and prints out the state of the
syntaxable and (if any) its children. Even in case parsing command line
arguments failed, the state till failure can be inspected with this
method.toState in interface SyntaxableSyntaxable instance and (if any) its
children.public void reset()
reset in interface org.refcodes.component.Resetablepublic String getDescription()
getDescription in interface org.refcodes.mixin.DescriptionAccessorpublic int compareTo(Operand<?> o)
compareTo in interface Comparable<T>public int getMinLength()
public int getMaxLength()
public Object clone() throws CloneNotSupportedException
clone in interface org.refcodes.mixin.Clonableclone in class ObjectCloneNotSupportedExceptionprotected Operand<T> getOperand()
Operand.Operand.public String toUsage(SyntaxNotation aSyntaxNotation, String aOptionEscCode, String aResetEscCode)
Syntaxable and the child Syntaxables,
the method Syntaxable.toSyntax(SyntaxNotation, String, String) is
called from inside a Syntaxable hierarchy. In case the syntax is
to be retrieved from the root Syntaxable or an encapsulating and
different type, then the applicable method to be called is
SyntaxUsage.toUsage(SyntaxNotation), as for some notations it will for
example not create the most outer braces.toUsage in interface SyntaxUsageaSyntaxNotation - The syntax notation used for generating the
command line arguments syntax.aOptionEscCode - The escape code to be used when processing an
option, e.g. this can be an ANSI Escape-Code to highlight the
option parameters (for example "--help", "-q" and so on).aResetEscCode - The escape code to close (reset) any Escape-Code
being set before.Copyright © 2021. All rights reserved.