Cloneable, Comparable<T>, ArgsAccessor, Operand<T>, Option<T[]>, Syntaxable, SyntaxUsage, org.refcodes.component.Resetable, org.refcodes.mixin.AliasAccessor, org.refcodes.mixin.Clonable, org.refcodes.mixin.DescriptionAccessor, org.refcodes.mixin.TypeAccessor<T>, org.refcodes.mixin.ValueAccessor<T>public class ArrayOption<T> extends ArrayOperand<T> implements Option<T[]>
org.refcodes.mixin.AliasAccessor.AliasBuilder<B extends org.refcodes.mixin.AliasAccessor.AliasBuilder<B>>, org.refcodes.mixin.AliasAccessor.AliasMutator, org.refcodes.mixin.AliasAccessor.AliasPropertyArgsAccessor.ArgsMutator, ArgsAccessor.ArgsPropertyorg.refcodes.mixin.DescriptionAccessor.DescriptionBuilder<B extends org.refcodes.mixin.DescriptionAccessor.DescriptionBuilder<B>>, org.refcodes.mixin.DescriptionAccessor.DescriptionMutator, org.refcodes.mixin.DescriptionAccessor.DescriptionPropertyorg.refcodes.mixin.TypeAccessor.TypeBuilder<T extends Object,B extends org.refcodes.mixin.TypeAccessor.TypeBuilder<T,B>>, org.refcodes.mixin.TypeAccessor.TypeMutator<T extends Object>, org.refcodes.mixin.TypeAccessor.TypeProperty<T extends Object>org.refcodes.mixin.ValueAccessor.ValueBuilder<V extends Object,B extends org.refcodes.mixin.ValueAccessor.ValueBuilder<V,B>>, org.refcodes.mixin.ValueAccessor.ValueMutator<V extends Object>, org.refcodes.mixin.ValueAccessor.ValueProperty<V extends Object>| Constructor | Description |
|---|---|
ArrayOption(Option<T> aOption) |
Constructs the
ArrayOption by encapsulating the given
Option and providing its definition as array definition to the
CLI. |
ArrayOption(Option<T> aOption,
int aLength) |
Constructs the
ArrayOption by encapsulating the given
Option and providing its definition as array definition to the
CLI. |
ArrayOption(Option<T> aOption,
int aMinLength,
int aMaxLength) |
Constructs the
ArrayOption by encapsulating the given
Option and providing its definition as array definition to the
CLI. |
| Modifier and Type | Method | Description |
|---|---|---|
String |
getLongOption() |
Returns the long-option representing an
Option instance. |
String |
getShortOption() |
Returns the short-option representing an
Option instance. |
String |
toSyntax(SyntaxNotation aSyntaxNotation,
String aOptionEscCode,
String aResetEscCode) |
This method is to be called from inside the
Syntaxable hierarchy;
use the method SyntaxUsage.toUsage(SyntaxNotation) in case you invoke syntax
retrieval from the root Syntaxable. |
String |
toUsage(SyntaxNotation aSyntaxNotation,
String aOptionEscCode,
String aResetEscCode) |
Returns the human readable (verbose) syntax of implementing class
ATTENTION: As of different parenthesis settings for some notations
regarding the root
Syntaxable and the child Syntaxables,
the method Syntaxable.toSyntax(SyntaxNotation, String, String) is
called from inside a Syntaxable hierarchy. |
clone, compareTo, getAlias, getArgs, getDescription, getMaxLength, getMinLength, getOperand, getType, getValue, parseArgs, reset, toStatecompareToequals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, waitget, getAlias, getArgs, getValue, hasValuegetOptionsparseArgs, parseArgs, toState, toSyntaxtoUsage, toUsage, toUsagepublic ArrayOption(Option<T> aOption)
ArrayOption by encapsulating the given
Option and providing its definition as array definition to the
CLI.aOption - The Option which's array counterpart is to be
defined.public ArrayOption(Option<T> aOption, int aLength)
ArrayOption by encapsulating the given
Option and providing its definition as array definition to the
CLI.aOption - The Option which's array counterpart is to be
defined.aLength - The number of array elements, or -1 if there is no limit.public ArrayOption(Option<T> aOption, int aMinLength, int aMaxLength)
ArrayOption by encapsulating the given
Option and providing its definition as array definition to the
CLI.aOption - The Option which's array counterpart is to be
defined.aMinLength - The minimum number of array elements, or -1 if there is
no limit.aMaxLength - The maximum number of array elements, or -1 if there is
no limit.public String toSyntax(SyntaxNotation aSyntaxNotation, String aOptionEscCode, String aResetEscCode)
Syntaxable hierarchy;
use the method SyntaxUsage.toUsage(SyntaxNotation) in case you invoke syntax
retrieval from the root Syntaxable. Returns the human readable
(verbose) syntax of this Syntaxable instance including, in case
of being a node in the syntax tree (such as a Condition, the
syntax of the child Syntaxable instances. ATTENTION: As of
different parenthesis settings for some notations regarding the root
Syntaxable and the child Syntaxables, the method
Syntaxable.toSyntax(SyntaxNotation, String, String) is called from inside
the Syntaxable hierarchy. In case the syntax is to be retrieved
from the root Syntaxable, then the applicable method to be called
is SyntaxUsage.toUsage(SyntaxNotation), as for some notations it will for
example not create the most outer braces.toSyntax in interface SyntaxabletoSyntax in class ArrayOperand<T>aSyntaxNotation - The syntax notation used for generating the
command line arguments syntax.aOptionEscCode - The escape code to be used when processing an
option, e.g. this can be an ANSI Escape-Code to highlight the
option parameters.aResetEscCode - The escape code to close (reset) any Escape-Code
being set before.public String getShortOption()
Option instance. A short
option usually is being prefixed with a single hyphen-minus "-" as
defined in CommandArgPrefix.POSIX_SHORT_OPTION.getShortOption in interface Option<T>String.public String getLongOption()
Option instance. A long
option usually is being prefixed with a double hyphen-minus "--" as
defined in CommandArgPrefix.POSIX_LONG_OPTION.getLongOption in interface Option<T>String.public String toUsage(SyntaxNotation aSyntaxNotation, String aOptionEscCode, String aResetEscCode)
Syntaxable and the child Syntaxables,
the method Syntaxable.toSyntax(SyntaxNotation, String, String) is
called from inside a Syntaxable hierarchy. In case the syntax is
to be retrieved from the root Syntaxable or an encapsulating and
different type, then the applicable method to be called is
SyntaxUsage.toUsage(SyntaxNotation), as for some notations it will for
example not create the most outer braces.toUsage in interface SyntaxUsageaSyntaxNotation - The syntax notation used for generating the
command line arguments syntax.aOptionEscCode - The escape code to be used when processing an
option, e.g. this can be an ANSI Escape-Code to highlight the
option parameters (for example "--help", "-q" and so on).aResetEscCode - The escape code to close (reset) any Escape-Code
being set before.Copyright © 2021. All rights reserved.