org.refcodes.component.Resetable, Syntaxable, SyntaxUsageAbstractCondition, AndCondition, OptionalCondition, OptionConditionFacade, OrCondition, XorConditionpublic interface Condition extends Syntaxable
Condition interface represents a node in the command line
arguments syntax tree; simply extending the Syntaxable interface and
adding the functionality of providing access to the added Operands
(leafs). In future extensions, a Condition might provide access to
the child Syntaxable elements contained in a Condition
instance. As of the current findings, access to the children of the
Condition node is not required and would make the interface
unnecessarily complicated.| Modifier and Type | Method | Description |
|---|---|---|
List<? extends Operand<?>> |
toOperands() |
get, parseArgs, parseArgs, toState, toSyntax, toSyntaxtoUsage, toUsage, toUsageList<? extends Operand<?>> toOperands()
Conditions and collects all therein
found Operands and sub-types such as the Flag or the
Option. This is most useful when creating a list of
Options, Flages and Operands when printing out
detailed help.Operand elements.Copyright © 2021. All rights reserved.