Cloneable, Comparable<Boolean>, ArgsAccessor, Operand<Boolean>, Option<Boolean>, Syntaxable, SyntaxUsage, org.refcodes.component.Resetable, org.refcodes.mixin.AliasAccessor, org.refcodes.mixin.Clonable, org.refcodes.mixin.DescriptionAccessor, org.refcodes.mixin.EnabledAccessor, org.refcodes.mixin.TypeAccessor<Boolean>, org.refcodes.mixin.ValueAccessor<Boolean>DebugFlag, ForceFlag, HelpFlag, QuietFlag, SysInfoFlag, VerboseFlagpublic class Flag extends AbstractOption<Boolean> implements Option<Boolean>, org.refcodes.mixin.EnabledAccessor
Flag class implements the Option interface for
representing either a true or a false state: When a
flag is provided to your command line arguments, then it is considered to be
true, when it is omitted, then it is considered to be
false as of isEnabled().org.refcodes.mixin.AliasAccessor.AliasBuilder<B extends org.refcodes.mixin.AliasAccessor.AliasBuilder<B>>, org.refcodes.mixin.AliasAccessor.AliasMutator, org.refcodes.mixin.AliasAccessor.AliasPropertyArgsAccessor.ArgsMutator, ArgsAccessor.ArgsPropertyorg.refcodes.mixin.DescriptionAccessor.DescriptionBuilder<B extends org.refcodes.mixin.DescriptionAccessor.DescriptionBuilder<B>>, org.refcodes.mixin.DescriptionAccessor.DescriptionMutator, org.refcodes.mixin.DescriptionAccessor.DescriptionPropertyorg.refcodes.mixin.EnabledAccessor.EnabledBuilder<B extends org.refcodes.mixin.EnabledAccessor.EnabledBuilder<B>>, org.refcodes.mixin.EnabledAccessor.EnabledMutator, org.refcodes.mixin.EnabledAccessor.EnabledPropertyorg.refcodes.mixin.TypeAccessor.TypeBuilder<T extends Object,B extends org.refcodes.mixin.TypeAccessor.TypeBuilder<T,B>>, org.refcodes.mixin.TypeAccessor.TypeMutator<T extends Object>, org.refcodes.mixin.TypeAccessor.TypeProperty<T extends Object>org.refcodes.mixin.ValueAccessor.ValueBuilder<V extends Object,B extends org.refcodes.mixin.ValueAccessor.ValueBuilder<V,B>>, org.refcodes.mixin.ValueAccessor.ValueMutator<V extends Object>, org.refcodes.mixin.ValueAccessor.ValueProperty<V extends Object>_value| Constructor | Description |
|---|---|
Flag(String aAlias,
boolean aValue) |
Constructs a
Flag. |
Flag(String aLongOption,
String aAlias,
String aDescription) |
Constructs a
Flag. |
Flag(String aShortOption,
String aLongOption,
String aAlias,
String aDescription) |
Constructs a
Flag. |
| Modifier and Type | Method | Description |
|---|---|---|
boolean |
isEnabled() |
Returns true if the switch has been set (enabled).
|
List<Operand<Boolean>> |
parseArgs(String[] aArgs,
String[] aOptions) |
Parses the provided command line arguments and determines the according
values by evaluating this
Syntaxable instance or, in case of
being a node in the syntax tree (such as a Condition, traversing
the child Syntaxable instances'
Syntaxable.parseArgs(String[], String[]) methods. |
void |
reset() |
|
String |
toUsage(SyntaxNotation aSyntaxNotation,
String aOptionEscCode,
String aResetEscCode) |
Returns the human readable (verbose) syntax of implementing class
ATTENTION: As of different parenthesis settings for some notations
regarding the root
Syntaxable and the child Syntaxables,
the method Syntaxable.toSyntax(SyntaxNotation, String, String) is
called from inside a Syntaxable hierarchy. |
protected Boolean |
toValue(String aArg) |
Double dispatch hook to be implemented by subclasses of the
AbstractOperand for converting a command line argument to the
required Operand's type. |
compareTo, getAlias, getArgs, getDescription, getType, getValue, toStringclone, getLongOption, getOptionPrefixes, getShortOption, setArgs, setValue, toState, toSyntaxcompareToequals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitget, getAlias, getArgs, getValue, hasValuegetLongOption, getOptions, getShortOptionparseArgs, toState, toSyntax, toSyntaxtoUsage, toUsage, toUsagepublic Flag(String aShortOption, String aLongOption, String aAlias, String aDescription)
Flag.aShortOption - The short-option being a single character with the
additional single hyphen-minus "-" prefix.aLongOption - The long-option being a multi-character sequence with
at least two characters with the additional double hyphen-minus
"--" prefix.aAlias - The alias identifying this Flag.aDescription - A description without any line breaks.public Flag(String aLongOption, String aAlias, String aDescription)
Flag.aLongOption - The long-option being a multi-character sequence with
at least two characters with the additional double hyphen-minus
"--" prefix.aAlias - The alias identifying this Flag.aDescription - A description without any line breaks.public boolean isEnabled()
isEnabled in interface org.refcodes.mixin.EnabledAccessorFlag has been provided (set), else
false.public List<Operand<Boolean>> parseArgs(String[] aArgs, String[] aOptions) throws UnknownArgsException, AmbiguousArgsException, ParseArgsException
Syntaxable instance or, in case of
being a node in the syntax tree (such as a Condition, traversing
the child Syntaxable instances'
Syntaxable.parseArgs(String[], String[]) methods. In case of successfully
parsing this Syntaxable and / or the child Syntaxable
instances, the evaluated command line arguments are returned: Depending
on the Syntaxable subclasses representing the evaluated command
line arguments, instances of Flag classes, Option classes
or Operand classes may be found in the result. In case of parsing
failure, an according exception is thrown. ATTENTION: This method does
not test for superfluous command line arguments being passed; e.g.
command line arguments not being evaluated by any of the
Syntaxable instance being traversed. This method is commonly used
by a root Syntaxable's ArgsParser.evalArgs(String[])
method, which delegates to the Syntaxable.parseArgs(String[], String[])
method and after which it determines whether there are superfluous
arguments to be taken care of (by throwing an according exception).
Business logic therefore should invoke the root node's
Syntaxable.parseArgs(String[], String[]) method as ignoring superfluous
command line arguments will cause unexpected behavior from the point of
view of the invoker.parseArgs in interface SyntaxableparseArgs in class AbstractOption<Boolean>aArgs - The command line arguments to be parsed.aOptions - The list of options (short and as well as long) which are
reserved and cannot be used as value.Operand interfaces or its sub-types.UnknownArgsException - Thrown in case not one command line argument
matched regarding the provided args vs. the expected args.AmbiguousArgsException - Thrown in case at least one command line
argument is ambiguous regarding expected args vs. provided args.ParseArgsException - Thrown in case the provided command line
arguments do not respect the required syntax or cannot be
converted to the required typepublic void reset()
reset in interface org.refcodes.component.Resetablereset in class AbstractOperand<Boolean>protected Boolean toValue(String aArg) throws ParseArgsException
AbstractOperand for converting a command line argument to the
required Operand's type. In case conversion failed, then an
according exception is to be thrown.toValue in class AbstractOperand<Boolean>aArg - The command line argument to be converted to an instance of
the given type T.ParseArgsException - Thrown in case the provided command line
arguments do not respect the required syntax or cannot be
converted to the required type.public String toUsage(SyntaxNotation aSyntaxNotation, String aOptionEscCode, String aResetEscCode)
Syntaxable and the child Syntaxables,
the method Syntaxable.toSyntax(SyntaxNotation, String, String) is
called from inside a Syntaxable hierarchy. In case the syntax is
to be retrieved from the root Syntaxable or an encapsulating and
different type, then the applicable method to be called is
SyntaxUsage.toUsage(SyntaxNotation), as for some notations it will for
example not create the most outer braces.toUsage in interface SyntaxUsageaSyntaxNotation - The syntax notation used for generating the
command line arguments syntax.aOptionEscCode - The escape code to be used when processing an
option, e.g. this can be an ANSI Escape-Code to highlight the
option parameters (for example "--help", "-q" and so on).aResetEscCode - The escape code to close (reset) any Escape-Code
being set before.Copyright © 2021. All rights reserved.