Cloneable, Comparable<Integer>, ArgsAccessor, Operand<Integer>, Option<Integer>, Syntaxable, SyntaxUsage, org.refcodes.component.Resetable, org.refcodes.mixin.AliasAccessor, org.refcodes.mixin.Clonable, org.refcodes.mixin.DescriptionAccessor, org.refcodes.mixin.TypeAccessor<Integer>, org.refcodes.mixin.ValueAccessor<Integer>public class IntOption extends AbstractOption<Integer>
org.refcodes.mixin.AliasAccessor.AliasBuilder<B extends org.refcodes.mixin.AliasAccessor.AliasBuilder<B>>, org.refcodes.mixin.AliasAccessor.AliasMutator, org.refcodes.mixin.AliasAccessor.AliasPropertyArgsAccessor.ArgsMutator, ArgsAccessor.ArgsPropertyorg.refcodes.mixin.DescriptionAccessor.DescriptionBuilder<B extends org.refcodes.mixin.DescriptionAccessor.DescriptionBuilder<B>>, org.refcodes.mixin.DescriptionAccessor.DescriptionMutator, org.refcodes.mixin.DescriptionAccessor.DescriptionPropertyorg.refcodes.mixin.TypeAccessor.TypeBuilder<T extends Object,B extends org.refcodes.mixin.TypeAccessor.TypeBuilder<T,B>>, org.refcodes.mixin.TypeAccessor.TypeMutator<T extends Object>, org.refcodes.mixin.TypeAccessor.TypeProperty<T extends Object>org.refcodes.mixin.ValueAccessor.ValueBuilder<V extends Object,B extends org.refcodes.mixin.ValueAccessor.ValueBuilder<V,B>>, org.refcodes.mixin.ValueAccessor.ValueMutator<V extends Object>, org.refcodes.mixin.ValueAccessor.ValueProperty<V extends Object>_value| Constructor | Description |
|---|---|
IntOption(String aLongOption,
String aAlias,
String aDescription) |
Instantiates a new integer option impl.
|
IntOption(String aShortOption,
String aLongOption,
String aAlias,
String aDescription) |
Instantiates a new integer option impl.
|
IntOption(org.refcodes.struct.Relation<String,Integer> aProperty) |
Instantiates a new integer option impl.
|
| Modifier and Type | Method | Description |
|---|---|---|
String |
toUsage(SyntaxNotation aSyntaxNotation,
String aOptionEscCode,
String aResetEscCode) |
Returns the human readable (verbose) syntax of implementing class
ATTENTION: As of different parenthesis settings for some notations
regarding the root
Syntaxable and the child Syntaxables,
the method Syntaxable.toSyntax(SyntaxNotation, String, String) is
called from inside a Syntaxable hierarchy. |
protected Integer |
toValue(String aArg) |
Double dispatch hook to be implemented by subclasses of the
AbstractOperand for converting a command line argument to the
required Operand's type. |
compareTo, getAlias, getArgs, getDescription, getType, getValue, reset, toStringclone, getLongOption, getOptionPrefixes, getShortOption, parseArgs, setArgs, setValue, toState, toSyntaxcompareToequals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitget, getAlias, getArgs, getValue, hasValuegetOptionsparseArgs, toSyntaxtoUsage, toUsage, toUsagepublic IntOption(String aLongOption, String aAlias, String aDescription)
aLongOption - the long optionaAlias - the option arg nameaDescription - the descriptionpublic IntOption(String aShortOption, String aLongOption, String aAlias, String aDescription)
aShortOption - the short optionaLongOption - the long optionaAlias - the option arg nameaDescription - the descriptionprotected Integer toValue(String aArg) throws ParseArgsException
AbstractOperand for converting a command line argument to the
required Operand's type. In case conversion failed, then an
according exception is to be thrown.toValue in class AbstractOperand<Integer>aArg - The command line argument to be converted to an instance of
the given type T.ParseArgsException - Thrown in case the provided command line
arguments do not respect the required syntax or cannot be
converted to the required type.public String toUsage(SyntaxNotation aSyntaxNotation, String aOptionEscCode, String aResetEscCode)
Syntaxable and the child Syntaxables,
the method Syntaxable.toSyntax(SyntaxNotation, String, String) is
called from inside a Syntaxable hierarchy. In case the syntax is
to be retrieved from the root Syntaxable or an encapsulating and
different type, then the applicable method to be called is
SyntaxUsage.toUsage(SyntaxNotation), as for some notations it will for
example not create the most outer braces.toUsage in interface SyntaxUsageaSyntaxNotation - The syntax notation used for generating the
command line arguments syntax.aOptionEscCode - The escape code to be used when processing an
option, e.g. this can be an ANSI Escape-Code to highlight the
option parameters (for example "--help", "-q" and so on).aResetEscCode - The escape code to close (reset) any Escape-Code
being set before.Copyright © 2021. All rights reserved.