T - the generic typeorg.refcodes.mixin.AliasAccessor, ArgsAccessor, org.refcodes.mixin.Clonable, Cloneable, Comparable<T>, org.refcodes.mixin.DescriptionAccessor, Operand<T>, org.refcodes.component.Resetable, Syntaxable, SyntaxUsage, org.refcodes.mixin.TypeAccessor<T>, org.refcodes.mixin.ValueAccessor<T>AbstractOption, ArrayOption, CharOption, DebugFlag, DoubleOption, EnumOption, FileOption, Flag, FloatOption, ForceFlag, HelpFlag, IntOption, LongOption, QuietFlag, StringOption, SysInfoFlag, VerboseFlagpublic interface Option<T> extends Operand<T>
Option represents a command line option with the according
option's value. An Option can be seen as a key/value(s) pair defined
in the command line arguments parsed via the
Syntaxable.parseArgs(String[], String[]) method.
An Option has a state which changes with each invocation of the
Syntaxable.parseArgs(String[], String[]) method.
org.refcodes.mixin.AliasAccessor.AliasBuilder<B extends org.refcodes.mixin.AliasAccessor.AliasBuilder<B>>, org.refcodes.mixin.AliasAccessor.AliasMutator, org.refcodes.mixin.AliasAccessor.AliasPropertyArgsAccessor.ArgsMutator, ArgsAccessor.ArgsPropertyorg.refcodes.mixin.DescriptionAccessor.DescriptionBuilder<B extends org.refcodes.mixin.DescriptionAccessor.DescriptionBuilder<B>>, org.refcodes.mixin.DescriptionAccessor.DescriptionMutator, org.refcodes.mixin.DescriptionAccessor.DescriptionPropertyorg.refcodes.mixin.TypeAccessor.TypeBuilder<T extends Object,B extends org.refcodes.mixin.TypeAccessor.TypeBuilder<T,B>>, org.refcodes.mixin.TypeAccessor.TypeMutator<T extends Object>, org.refcodes.mixin.TypeAccessor.TypeProperty<T extends Object>org.refcodes.mixin.ValueAccessor.ValueBuilder<V extends Object,B extends org.refcodes.mixin.ValueAccessor.ValueBuilder<V,B>>, org.refcodes.mixin.ValueAccessor.ValueMutator<V extends Object>, org.refcodes.mixin.ValueAccessor.ValueProperty<V extends Object>| Modifier and Type | Method | Description |
|---|---|---|
String |
getLongOption() |
Returns the long-option representing an
Option instance. |
default String[] |
getOptions() |
Retrieves an array of the options being configured for the implementing
instance, being the long option (when set) and the short option (when
set).
|
String |
getShortOption() |
Returns the short-option representing an
Option instance. |
compareToget, getAlias, getArgs, getValue, hasValueparseArgs, parseArgs, toState, toSyntax, toSyntaxtoUsage, toUsage, toUsageString getShortOption()
Option instance. A short
option usually is being prefixed with a single hyphen-minus "-" as
defined in CommandArgPrefix.POSIX_SHORT_OPTION.String.String getLongOption()
Option instance. A long
option usually is being prefixed with a double hyphen-minus "--" as
defined in CommandArgPrefix.POSIX_LONG_OPTION.String.default String[] getOptions()
Copyright © 2021. All rights reserved.