B - The builder to return in order to be able to apply multiple
build operations.public static interface RootConditionAccessor.RootConditionBuilder<B extends RootConditionAccessor.RootConditionBuilder<B>>
| Modifier and Type | Method | Description |
|---|---|---|
B |
withRootCondition(Condition aRootCondition) |
Sets the root condition for the root condition property.
|
default B |
withRootOption(Option<?> aRootOption) |
Sets the root option for the root condition property.
|
B withRootCondition(Condition aRootCondition)
aRootCondition - The root condition to be stored by the root
condition property.default B withRootOption(Option<?> aRootOption)
Option into a
OptionConditionFacade and passing it to the
withRootCondition(Condition) method.aRootOption - The root condition to be stored by the root
condition property.Copyright © 2021. All rights reserved.