RootConditionAccessor.RootConditionPropertypublic static interface RootConditionAccessor.RootConditionMutator
| Modifier and Type | Method | Description |
|---|---|---|
void |
setRootCondition(Condition aRootCondition) |
Sets the root condition for the root condition property.
|
default void |
setRootOption(Option<?> aRootOption) |
Sets the root option for the root condition property.
|
void setRootCondition(Condition aRootCondition)
aRootCondition - The root condition to be stored by the root
condition property.default void setRootOption(Option<?> aRootOption)
Option into a
OptionConditionFacade and passing it to the
setRootCondition(Condition) method.aRootOption - The root option to be stored by the root condition
property.Copyright © 2021. All rights reserved.