Cloneable, Comparable<String>, ArgsAccessor, Operand<String>, Syntaxable, SyntaxUsage, org.refcodes.component.Resetable, org.refcodes.mixin.AliasAccessor, org.refcodes.mixin.Clonable, org.refcodes.mixin.DescriptionAccessor, org.refcodes.mixin.TypeAccessor<String>, org.refcodes.mixin.ValueAccessor<String>public class StringOperand extends AbstractOperand<String>
org.refcodes.mixin.AliasAccessor.AliasBuilder<B extends org.refcodes.mixin.AliasAccessor.AliasBuilder<B>>, org.refcodes.mixin.AliasAccessor.AliasMutator, org.refcodes.mixin.AliasAccessor.AliasPropertyArgsAccessor.ArgsMutator, ArgsAccessor.ArgsPropertyorg.refcodes.mixin.DescriptionAccessor.DescriptionBuilder<B extends org.refcodes.mixin.DescriptionAccessor.DescriptionBuilder<B>>, org.refcodes.mixin.DescriptionAccessor.DescriptionMutator, org.refcodes.mixin.DescriptionAccessor.DescriptionPropertyorg.refcodes.mixin.TypeAccessor.TypeBuilder<T extends Object,B extends org.refcodes.mixin.TypeAccessor.TypeBuilder<T,B>>, org.refcodes.mixin.TypeAccessor.TypeMutator<T extends Object>, org.refcodes.mixin.TypeAccessor.TypeProperty<T extends Object>org.refcodes.mixin.ValueAccessor.ValueBuilder<V extends Object,B extends org.refcodes.mixin.ValueAccessor.ValueBuilder<V,B>>, org.refcodes.mixin.ValueAccessor.ValueMutator<V extends Object>, org.refcodes.mixin.ValueAccessor.ValueProperty<V extends Object>_value| Constructor | Description |
|---|---|
StringOperand(String aAlias,
String aDescription) |
Instantiates a new string operand impl.
|
StringOperand(org.refcodes.struct.Relation<String,String> aProperty) |
Instantiates a new string operand impl.
|
| Modifier and Type | Method | Description |
|---|---|---|
String |
toUsage(SyntaxNotation aSyntaxNotation,
String aOptionEscCode,
String aResetEscCode) |
Returns the human readable (verbose) syntax of implementing class
ATTENTION: As of different parenthesis settings for some notations
regarding the root
Syntaxable and the child Syntaxables,
the method Syntaxable.toSyntax(SyntaxNotation, String, String) is
called from inside a Syntaxable hierarchy. |
protected String |
toValue(String aArg) |
To value.
|
clone, compareTo, getAlias, getArgs, getDescription, getType, getValue, parseArgs, reset, setArgs, setValue, toState, toString, toSyntaxequals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitparseArgs, toSyntaxtoUsage, toUsage, toUsagepublic StringOperand(String aAlias, String aDescription)
aAlias - The identifier to be used when printing the syntax via the
AbstractOperand.toSyntax(SyntaxNotation, String, String) method.aDescription - A description without any line breaks.protected String toValue(String aArg)
toValue in class AbstractOperand<String>aArg - the argpublic String toUsage(SyntaxNotation aSyntaxNotation, String aOptionEscCode, String aResetEscCode)
Syntaxable and the child Syntaxables,
the method Syntaxable.toSyntax(SyntaxNotation, String, String) is
called from inside a Syntaxable hierarchy. In case the syntax is
to be retrieved from the root Syntaxable or an encapsulating and
different type, then the applicable method to be called is
SyntaxUsage.toUsage(SyntaxNotation), as for some notations it will for
example not create the most outer braces.toUsage in interface SyntaxUsageaSyntaxNotation - The syntax notation used for generating the
command line arguments syntax.aOptionEscCode - The escape code to be used when processing an
option, e.g. this can be an ANSI Escape-Code to highlight the
option parameters (for example "--help", "-q" and so on).aResetEscCode - The escape code to close (reset) any Escape-Code
being set before.Copyright © 2021. All rights reserved.