Serializable, Comparable<SyntaxNotation>public enum SyntaxNotation extends Enum<SyntaxNotation>
SyntaxNotation is used by a the
Syntaxable.toSyntax(SyntaxNotation, String, String) method to
determine which notation to be used for the generated syntax.| Enum Constant | Description |
|---|---|
GNU_POSIX |
A syntax notation derived from GNU and POSIX utility conventions and
utility argument syntax.
|
REFCODES |
A notation which the author of this code believes to unambiguously
describe a command line utility's argument syntax; as defined by the
means of this
refcodes-cli artifact. |
| Modifier and Type | Method | Description |
|---|---|---|
static SyntaxNotation |
valueOf(String name) |
Returns the enum constant of this type with the specified name.
|
static SyntaxNotation[] |
values() |
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final SyntaxNotation REFCODES
refcodes-cli artifact.public static final SyntaxNotation GNU_POSIX
public static SyntaxNotation[] values()
for (SyntaxNotation c : SyntaxNotation.values()) System.out.println(c);
public static SyntaxNotation valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is nullCopyright © 2021. All rights reserved.