org.refcodes.component.Resetable, SyntaxUsageAbstractCondition, AbstractOperand, AbstractOption, AndCondition, ArrayOperand, ArrayOption, CharOption, DebugFlag, DoubleOption, EnumOption, FileOption, Flag, FloatOption, ForceFlag, HelpFlag, IntOption, LongOption, Operation, OptionalCondition, OptionConditionFacade, OrCondition, QuietFlag, StringOperand, StringOption, SysInfoFlag, VerboseFlag, XorConditionpublic interface Syntaxable extends org.refcodes.component.Resetable, SyntaxUsage
Syntaxable defines the methods at least required when building a
command line arguments syntax tree for traversing the syntax tree; either for
parsing command line arguments or for constructing the command line arguments
syntax. By providing various implementations of the Syntaxable's
subclasses such as Operand, Option or Condition, a
command line arguments syntax tree can be constructed. This syntax tree can
be use to create a human readable (verbose) command line arguments syntax and
to parse an array of command line arguments for determining the
Operands', the Flages' or the Options' values.| Modifier and Type | Method | Description |
|---|---|---|
<V> V |
get(String aAlias) |
Searches for a value being set for the given for given alias in the
syntax tree parsing the command line arguments; if a node in the syntax
tree has a value for the given alias, then this value is returned.
|
default List<? extends Operand<?>> |
parseArgs(String[] aArgs) |
Parses the provided command line arguments and determines the according
values by evaluating this
Syntaxable instance or, in case of
being a node in the syntax tree (such as a Condition, traversing
the child Syntaxable instances'
parseArgs(String[], String[]) methods. |
List<? extends Operand<?>> |
parseArgs(String[] aArgs,
String[] aOptions) |
Parses the provided command line arguments and determines the according
values by evaluating this
Syntaxable instance or, in case of
being a node in the syntax tree (such as a Condition, traversing
the child Syntaxable instances'
parseArgs(String[], String[]) methods. |
String |
toState() |
The
toState() method might be used by the
Object.toString() method and prints out the state of the
syntaxable and (if any) its children. |
default String |
toSyntax(SyntaxNotation aSyntaxNotation) |
This method is to be called from inside the
Syntaxable hierarchy;
use the method SyntaxUsage.toUsage(SyntaxNotation) in case you invoke syntax
retrieval from the root Syntaxable. |
String |
toSyntax(SyntaxNotation aSyntaxNotation,
String aOptionEscCode,
String aResetEscCode) |
This method is to be called from inside the
Syntaxable hierarchy;
use the method SyntaxUsage.toUsage(SyntaxNotation) in case you invoke syntax
retrieval from the root Syntaxable. |
toUsage, toUsage, toUsagedefault String toSyntax(SyntaxNotation aSyntaxNotation)
Syntaxable hierarchy;
use the method SyntaxUsage.toUsage(SyntaxNotation) in case you invoke syntax
retrieval from the root Syntaxable. Returns the human readable
(verbose) syntax of this Syntaxable instance including, in case
of being a node in the syntax tree (such as a Condition, the
syntax of the child Syntaxable instances. ATTENTION: As of
different parenthesis settings for some notations regarding the root
Syntaxable and the child Syntaxables, the method
toSyntax(SyntaxNotation, String, String) is called from inside
the Syntaxable hierarchy. In case the syntax is to be retrieved
from the root Syntaxable, then the applicable method to be called
is SyntaxUsage.toUsage(SyntaxNotation), as for some notations it will for
example not create the most outer braces.aSyntaxNotation - The syntax notation used for generating the
command line arguments syntax.String toSyntax(SyntaxNotation aSyntaxNotation, String aOptionEscCode, String aResetEscCode)
Syntaxable hierarchy;
use the method SyntaxUsage.toUsage(SyntaxNotation) in case you invoke syntax
retrieval from the root Syntaxable. Returns the human readable
(verbose) syntax of this Syntaxable instance including, in case
of being a node in the syntax tree (such as a Condition, the
syntax of the child Syntaxable instances. ATTENTION: As of
different parenthesis settings for some notations regarding the root
Syntaxable and the child Syntaxables, the method
toSyntax(SyntaxNotation, String, String) is called from inside
the Syntaxable hierarchy. In case the syntax is to be retrieved
from the root Syntaxable, then the applicable method to be called
is SyntaxUsage.toUsage(SyntaxNotation), as for some notations it will for
example not create the most outer braces.aSyntaxNotation - The syntax notation used for generating the
command line arguments syntax.aOptionEscCode - The escape code to be used when processing an
option, e.g. this can be an ANSI Escape-Code to highlight the
option parameters.aResetEscCode - The escape code to close (reset) any Escape-Code
being set before.default List<? extends Operand<?>> parseArgs(String[] aArgs) throws UnknownArgsException, AmbiguousArgsException, ParseArgsException
Syntaxable instance or, in case of
being a node in the syntax tree (such as a Condition, traversing
the child Syntaxable instances'
parseArgs(String[], String[]) methods. In case of successfully
parsing this Syntaxable and / or the child Syntaxable
instances, the evaluated command line arguments are returned: Depending
on the Syntaxable subclasses representing the evaluated command
line arguments, instances of Flag classes, Option classes
or Operand classes may be found in the result. In case of parsing
failure, an according exception is thrown. ATTENTION: This method does
not test for superfluous command line arguments being passed; e.g.
command line arguments not being evaluated by any of the
Syntaxable instance being traversed. This method is commonly used
by a root Syntaxable's ArgsParser.evalArgs(String[])
method, which delegates to the parseArgs(String[], String[])
method and after which it determines whether there are superfluous
arguments to be taken care of (by throwing an according exception).
Business logic therefore should invoke the root node's
parseArgs(String[], String[]) method as ignoring superfluous
command line arguments will cause unexpected behavior from the point of
view of the invoker.aArgs - The command line arguments to be parsed.Operand interfaces or its sub-types.UnknownArgsException - Thrown in case not one command line argument
matched regarding the provided args vs. the expected args.AmbiguousArgsException - Thrown in case at least one command line
argument is ambiguous regarding expected args vs. provided args.ParseArgsException - Thrown in case the provided command line
arguments do not respect the required syntax or cannot be
converted to the required typeList<? extends Operand<?>> parseArgs(String[] aArgs, String[] aOptions) throws UnknownArgsException, AmbiguousArgsException, ParseArgsException
Syntaxable instance or, in case of
being a node in the syntax tree (such as a Condition, traversing
the child Syntaxable instances'
parseArgs(String[], String[]) methods. In case of successfully
parsing this Syntaxable and / or the child Syntaxable
instances, the evaluated command line arguments are returned: Depending
on the Syntaxable subclasses representing the evaluated command
line arguments, instances of Flag classes, Option classes
or Operand classes may be found in the result. In case of parsing
failure, an according exception is thrown. ATTENTION: This method does
not test for superfluous command line arguments being passed; e.g.
command line arguments not being evaluated by any of the
Syntaxable instance being traversed. This method is commonly used
by a root Syntaxable's ArgsParser.evalArgs(String[])
method, which delegates to the parseArgs(String[], String[])
method and after which it determines whether there are superfluous
arguments to be taken care of (by throwing an according exception).
Business logic therefore should invoke the root node's
parseArgs(String[], String[]) method as ignoring superfluous
command line arguments will cause unexpected behavior from the point of
view of the invoker.aArgs - The command line arguments to be parsed.aOptions - The list of options (short and as well as long) which are
reserved and cannot be used as value.Operand interfaces or its sub-types.UnknownArgsException - Thrown in case not one command line argument
matched regarding the provided args vs. the expected args.AmbiguousArgsException - Thrown in case at least one command line
argument is ambiguous regarding expected args vs. provided args.ParseArgsException - Thrown in case the provided command line
arguments do not respect the required syntax or cannot be
converted to the required type<V> V get(String aAlias)
V - The type of the value being expected.aAlias - The alias for which to seek for a value being set.String toState()
toState() method might be used by the
Object.toString() method and prints out the state of the
syntaxable and (if any) its children. Even in case parsing command line
arguments failed, the state till failure can be inspected with this
method.Syntaxable instance and (if any) its
children.Copyright © 2021. All rights reserved.