Condition, Syntaxable, SyntaxUsage, org.refcodes.component.Resetablepublic class XorCondition extends AbstractCondition implements Condition
XorCondition represents a list of Condition
(Syntaxable) instances of which only one is allowed to be parsed
successfully when the Syntaxable.parseArgs(String[], String[]) methods
are invoked. The command line arguments syntax { -a ^ -b ^ -c }
specifies that only "-a", only "-b" or only "-c" must be set. In case more
then one is set or none, then the XorCondition will terminate the
parseArgs(String[], String[]) method with an exception.| Constructor | Description |
|---|---|
XorCondition(Syntaxable... aArgs) |
| Modifier and Type | Method | Description |
|---|---|---|
List<? extends Operand<?>> |
parseArgs(String[] aArgs,
String[] aOptions) |
Parses the provided command line arguments and determines the according
values by evaluating this
Syntaxable instance or, in case of
being a node in the syntax tree (such as a Condition, traversing
the child Syntaxable instances'
Syntaxable.parseArgs(String[], String[]) methods. |
String |
toState() |
The
Syntaxable.toState() method might be used by the
Object.toString() method and prints out the state of the
syntaxable and (if any) its children. |
String |
toSyntax(SyntaxNotation aSyntaxNotation,
String aOptionEscCode,
String aResetEscCode) |
This method is to be called from inside the
Syntaxable hierarchy;
use the method SyntaxUsage.toUsage(SyntaxNotation) in case you invoke syntax
retrieval from the root Syntaxable. |
String |
toUsage(SyntaxNotation aSyntaxNotation,
String aOptionEscCode,
String aResetEscCode) |
Returns the human readable (verbose) syntax of implementing class
ATTENTION: As of different parenthesis settings for some notations
regarding the root
Syntaxable and the child Syntaxables,
the method Syntaxable.toSyntax(SyntaxNotation, String, String) is
called from inside a Syntaxable hierarchy. |
addChild, get, getChildren, reset, toOperands, toStringtoOperandsclone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitget, parseArgs, toSyntaxtoUsage, toUsagepublic XorCondition(Syntaxable... aArgs)
aArgs - The Syntaxable (Condition) instances to be
nestedpublic List<? extends Operand<?>> parseArgs(String[] aArgs, String[] aOptions) throws UnknownArgsException, AmbiguousArgsException, ParseArgsException
SyntaxableSyntaxable instance or, in case of
being a node in the syntax tree (such as a Condition, traversing
the child Syntaxable instances'
Syntaxable.parseArgs(String[], String[]) methods. In case of successfully
parsing this Syntaxable and / or the child Syntaxable
instances, the evaluated command line arguments are returned: Depending
on the Syntaxable subclasses representing the evaluated command
line arguments, instances of Flag classes, Option classes
or Operand classes may be found in the result. In case of parsing
failure, an according exception is thrown. ATTENTION: This method does
not test for superfluous command line arguments being passed; e.g.
command line arguments not being evaluated by any of the
Syntaxable instance being traversed. This method is commonly used
by a root Syntaxable's ArgsParser.evalArgs(String[])
method, which delegates to the Syntaxable.parseArgs(String[], String[])
method and after which it determines whether there are superfluous
arguments to be taken care of (by throwing an according exception).
Business logic therefore should invoke the root node's
Syntaxable.parseArgs(String[], String[]) method as ignoring superfluous
command line arguments will cause unexpected behavior from the point of
view of the invoker.parseArgs in interface SyntaxableaArgs - The command line arguments to be parsed.aOptions - The list of options (short and as well as long) which are
reserved and cannot be used as value.Operand interfaces or its sub-types.UnknownArgsException - Thrown in case not one command line argument
matched regarding the provided args vs. the expected args.AmbiguousArgsException - Thrown in case at least one command line
argument is ambiguous regarding expected args vs. provided args.ParseArgsException - Thrown in case the provided command line
arguments do not respect the required syntax or cannot be
converted to the required typepublic String toSyntax(SyntaxNotation aSyntaxNotation, String aOptionEscCode, String aResetEscCode)
Syntaxable hierarchy;
use the method SyntaxUsage.toUsage(SyntaxNotation) in case you invoke syntax
retrieval from the root Syntaxable. Returns the human readable
(verbose) syntax of this Syntaxable instance including, in case
of being a node in the syntax tree (such as a Condition, the
syntax of the child Syntaxable instances. ATTENTION: As of
different parenthesis settings for some notations regarding the root
Syntaxable and the child Syntaxables, the method
Syntaxable.toSyntax(SyntaxNotation, String, String) is called from inside
the Syntaxable hierarchy. In case the syntax is to be retrieved
from the root Syntaxable, then the applicable method to be called
is SyntaxUsage.toUsage(SyntaxNotation), as for some notations it will for
example not create the most outer braces.toSyntax in interface SyntaxabletoSyntax in class AbstractConditionaSyntaxNotation - The syntax notation used for generating the
command line arguments syntax.aOptionEscCode - The escape code to be used when processing an
option, e.g. this can be an ANSI Escape-Code to highlight the
option parameters.aResetEscCode - The escape code to close (reset) any Escape-Code
being set before.public String toUsage(SyntaxNotation aSyntaxNotation, String aOptionEscCode, String aResetEscCode)
Syntaxable and the child Syntaxables,
the method Syntaxable.toSyntax(SyntaxNotation, String, String) is
called from inside a Syntaxable hierarchy. In case the syntax is
to be retrieved from the root Syntaxable or an encapsulating and
different type, then the applicable method to be called is
SyntaxUsage.toUsage(SyntaxNotation), as for some notations it will for
example not create the most outer braces.toUsage in interface SyntaxUsageaSyntaxNotation - The syntax notation used for generating the
command line arguments syntax.aOptionEscCode - The escape code to be used when processing an
option, e.g. this can be an ANSI Escape-Code to highlight the
option parameters (for example "--help", "-q" and so on).aResetEscCode - The escape code to close (reset) any Escape-Code
being set before.public String toState()
Syntaxable.toState() method might be used by the
Object.toString() method and prints out the state of the
syntaxable and (if any) its children. Even in case parsing command line
arguments failed, the state till failure can be inspected with this
method.toState in interface SyntaxableSyntaxable instance and (if any) its
children.Copyright © 2021. All rights reserved.