| Modifier and Type | Class | Description |
|---|---|---|
class |
AndCondition |
An
AndCondition contains (represents) a list of Condition
(Syntaxable) instances (nested by the AndCondition) of which
all are to be parsed successfully as of invoking the
Syntaxable.parseArgs(String[], String[]) methods. |
class |
OptionalCondition |
The
OptionalCondition can nested by an AndCondition and
encapsulates a Condition which may be provided but does not
necessarily needs to be provided in order for the AndCondition to
successfully parse the nested Condition items including the
OptionalCondition. |
class |
OptionConditionFacade |
|
class |
OrCondition |
An
OrCondition represents a list of Condition
(Syntaxable) instances of which at least one must be parsed
successfully when the Syntaxable s'
Syntaxable.parseArgs(String[], String[]) methods are invoked. |
class |
XorCondition |
An
XorCondition represents a list of Condition
(Syntaxable) instances of which only one is allowed to be parsed
successfully when the Syntaxable.parseArgs(String[], String[]) methods
are invoked. |
Copyright © 2021. All rights reserved.