| Modifier and Type | Class | Description |
|---|---|---|
class |
AbstractOption<T> |
The
AbstractOption is an abstract implementation of an Option
providing the boiler plate when implementing the Option interface. |
class |
CharOption |
|
class |
DebugFlag |
A predefined debug switch.
|
class |
DoubleOption |
|
class |
EnumOption<T extends Enum<T>> |
The Class EnumOption.
|
class |
FileOption |
|
class |
Flag |
The
Flag class implements the Option interface for
representing either a true or a false state: When a
flag is provided to your command line arguments, then it is considered to be
true, when it is omitted, then it is considered to be
false as of Flag.isEnabled(). |
class |
FloatOption |
|
class |
ForceFlag |
A predefined force switch.
|
class |
HelpFlag |
A predefined help switch.
|
class |
IntOption |
|
class |
LongOption |
|
class |
Operation |
The
Operation is an argument representing a function or a method and
is either provided or not provided as of Operation.isEnabled(). |
class |
QuietFlag |
A predefined "be quiet" switch.
|
class |
StringOperand |
|
class |
StringOption |
|
class |
SysInfoFlag |
A predefined system information switch.
|
class |
VerboseFlag |
A predefined verbose switch.
|
Copyright © 2021. All rights reserved.