| Modifier and Type | Interface | Description |
|---|---|---|
static interface |
ArgsAccessor.ArgsProperty |
Provides a args property.
|
interface |
Operand<T> |
An
Operand represents a value parsed from command line arguments. |
interface |
Option<T> |
An
Option represents a command line option with the according
option's value. |
| Modifier and Type | Class | Description |
|---|---|---|
class |
AbstractOperand<T> |
The
AbstractOperand is an abstract implementation of an
Operand providing the boiler plate when implementing the
Operand interface. |
class |
AbstractOption<T> |
The
AbstractOption is an abstract implementation of an Option
providing the boiler plate when implementing the Option interface. |
class |
AmbiguousArgsException |
Thrown in case at least one command line argument is ambiguous regarding
expected args vs. provided args.
|
class |
ArgsMismatchException |
Thrown in case a command line arguments mismatch regarding provided and
expected args.
|
class |
ArrayOperand<T> |
Creates an array representation facade for the encapsulated
Operand. |
class |
ArrayOption<T> |
Creates an array representation facade for the encapsulated
Option. |
class |
CharOption |
|
static class |
CliException.ConsoleArgsException |
This abstract exception is the base exception for all command line
argument related exceptions.
|
class |
DebugFlag |
A predefined debug switch.
|
class |
DoubleOption |
|
class |
EnumOption<T extends Enum<T>> |
The Class EnumOption.
|
class |
FileOption |
|
class |
Flag |
The
Flag class implements the Option interface for
representing either a true or a false state: When a
flag is provided to your command line arguments, then it is considered to be
true, when it is omitted, then it is considered to be
false as of Flag.isEnabled(). |
class |
FloatOption |
|
class |
ForceFlag |
A predefined force switch.
|
class |
HelpFlag |
A predefined help switch.
|
class |
IntOption |
|
class |
LongOption |
|
class |
Operation |
The
Operation is an argument representing a function or a method and
is either provided or not provided as of Operation.isEnabled(). |
class |
ParseArgsException |
Thrown in case the provided command line arguments do not respect the
required syntax or cannot be converted to the required type.
|
class |
QuietFlag |
A predefined "be quiet" switch.
|
class |
StringOperand |
|
class |
StringOption |
|
class |
SuperfluousArgsException |
Thrown in case there were arguments found not being used (superfluous
arguments).
|
class |
SysInfoFlag |
A predefined system information switch.
|
class |
UnknownArgsException |
Thrown in case not one command line argument matched regarding the provided
args vs. the expected args.
|
class |
VerboseFlag |
A predefined verbose switch.
|
Copyright © 2021. All rights reserved.