| Modifier and Type | Class | Description |
|---|---|---|
class |
AbstractCondition |
The
AbstractCondition is an abstract implementation of an
Condition providing the boiler plate when implementing the
Condition interface. |
class |
AndCondition |
An
AndCondition contains (represents) a list of Condition
(Syntaxable) instances (nested by the AndCondition) of which
all are to be parsed successfully as of invoking the
Syntaxable.parseArgs(String[], String[]) methods. |
class |
OptionalCondition |
The
OptionalCondition can nested by an AndCondition and
encapsulates a Condition which may be provided but does not
necessarily needs to be provided in order for the AndCondition to
successfully parse the nested Condition items including the
OptionalCondition. |
class |
OptionConditionFacade |
|
class |
OrCondition |
An
OrCondition represents a list of Condition
(Syntaxable) instances of which at least one must be parsed
successfully when the Syntaxable s'
Syntaxable.parseArgs(String[], String[]) methods are invoked. |
class |
XorCondition |
An
XorCondition represents a list of Condition
(Syntaxable) instances of which only one is allowed to be parsed
successfully when the Syntaxable.parseArgs(String[], String[]) methods
are invoked. |
| Modifier and Type | Method | Description |
|---|---|---|
static Condition |
CliSugar.and(Syntaxable... aArgs) |
|
Condition |
ArgsParser.getRootCondition() |
The root condition is the starting point node of a
Syntaxable
hierarchy to be traversed when determining the syntax for command line
arguments or when evaluating the command line arguments. |
Condition |
ArgsParserImpl.getRootCondition() |
The root condition is the starting point node of a
Syntaxable
hierarchy to be traversed when determining the syntax for command line
arguments or when evaluating the command line arguments. |
Condition |
RootConditionAccessor.getRootCondition() |
Retrieves the root condition from the root condition property.
|
default Condition |
RootConditionAccessor.RootConditionProperty.letRootCondition(Condition aRootCondition) |
This method stores and passes through the given argument, which is
very useful for builder APIs: Sets the given
Condition
(setter) as of RootConditionAccessor.RootConditionMutator.setRootCondition(Condition) and returns the
very same value (getter). |
static Condition |
CliSugar.optional(Syntaxable... aArgs) |
|
static Condition |
CliSugar.or(Syntaxable... aArgs) |
|
static Condition |
CliSugar.xor(Syntaxable... aArgs) |
| Modifier and Type | Method | Description |
|---|---|---|
default Condition |
RootConditionAccessor.RootConditionProperty.letRootCondition(Condition aRootCondition) |
This method stores and passes through the given argument, which is
very useful for builder APIs: Sets the given
Condition
(setter) as of RootConditionAccessor.RootConditionMutator.setRootCondition(Condition) and returns the
very same value (getter). |
void |
RootConditionAccessor.RootConditionMutator.setRootCondition(Condition aRootCondition) |
Sets the root condition for the root condition property.
|
B |
RootConditionAccessor.RootConditionBuilder.withRootCondition(Condition aRootCondition) |
Sets the root condition for the root condition property.
|
| Constructor | Description |
|---|---|
ArgsParserImpl(Condition aRootCondition) |
Constructs the
ArgsParser instance with the given root
Condition and the default SyntaxNotation.REFCODES. |
Copyright © 2021. All rights reserved.