| Modifier and Type | Class | Description |
|---|---|---|
class |
AbstractOption<T> |
The
AbstractOption is an abstract implementation of an Option
providing the boiler plate when implementing the Option interface. |
class |
ArrayOption<T> |
Creates an array representation facade for the encapsulated
Option. |
class |
CharOption |
|
class |
DebugFlag |
A predefined debug switch.
|
class |
DoubleOption |
|
class |
EnumOption<T extends Enum<T>> |
The Class EnumOption.
|
class |
FileOption |
|
class |
Flag |
The
Flag class implements the Option interface for
representing either a true or a false state: When a
flag is provided to your command line arguments, then it is considered to be
true, when it is omitted, then it is considered to be
false as of Flag.isEnabled(). |
class |
FloatOption |
|
class |
ForceFlag |
A predefined force switch.
|
class |
HelpFlag |
A predefined help switch.
|
class |
IntOption |
|
class |
LongOption |
|
class |
QuietFlag |
A predefined "be quiet" switch.
|
class |
StringOption |
|
class |
SysInfoFlag |
A predefined system information switch.
|
class |
VerboseFlag |
A predefined verbose switch.
|
| Modifier and Type | Method | Description |
|---|---|---|
static <T> ArrayOption<T> |
CliSugar.asArray(Option<T> aOption) |
Creates an array representation facade for the encapsulated
Option. |
static <T> ArrayOption<T> |
CliSugar.asArray(Option<T> aOption,
int aLength) |
Creates an array representation facade for the encapsulated
Option. |
static <T> ArrayOption<T> |
CliSugar.asArray(Option<T> aOption,
int aMinLength,
int aMaxLength) |
Creates an array representation facade for the encapsulated
Option. |
static org.refcodes.struct.Relation<String,String> |
CliUtility.getOptionArgument(Option<?> aOption,
String[] aArgs,
String[] aOptions) |
|
default void |
RootConditionAccessor.RootConditionMutator.setRootOption(Option<?> aRootOption) |
Sets the root option for the root condition property.
|
default B |
RootConditionAccessor.RootConditionBuilder.withRootOption(Option<?> aRootOption) |
Sets the root option for the root condition property.
|
| Constructor | Description |
|---|---|
ArgsParserImpl(Option<?> aRootOption) |
Constructs the
ArgsParser instance with the given root
Option and the default SyntaxNotation.REFCODES. |
ArrayOption(Option<T> aOption) |
Constructs the
ArrayOption by encapsulating the given
Option and providing its definition as array definition to the
CLI. |
ArrayOption(Option<T> aOption,
int aLength) |
Constructs the
ArrayOption by encapsulating the given
Option and providing its definition as array definition to the
CLI. |
ArrayOption(Option<T> aOption,
int aMinLength,
int aMaxLength) |
Constructs the
ArrayOption by encapsulating the given
Option and providing its definition as array definition to the
CLI. |
Copyright © 2021. All rights reserved.