| Modifier and Type | Interface | Description |
|---|---|---|
interface |
Condition |
The
Condition interface represents a node in the command line
arguments syntax tree; simply extending the Syntaxable interface and
adding the functionality of providing access to the added Operands
(leafs). |
interface |
Operand<T> |
An
Operand represents a value parsed from command line arguments. |
interface |
Option<T> |
An
Option represents a command line option with the according
option's value. |
| Modifier and Type | Class | Description |
|---|---|---|
class |
AbstractCondition |
The
AbstractCondition is an abstract implementation of an
Condition providing the boiler plate when implementing the
Condition interface. |
class |
AbstractOperand<T> |
The
AbstractOperand is an abstract implementation of an
Operand providing the boiler plate when implementing the
Operand interface. |
class |
AbstractOption<T> |
The
AbstractOption is an abstract implementation of an Option
providing the boiler plate when implementing the Option interface. |
class |
AndCondition |
An
AndCondition contains (represents) a list of Condition
(Syntaxable) instances (nested by the AndCondition) of which
all are to be parsed successfully as of invoking the
parseArgs(String[], String[]) methods. |
class |
ArrayOperand<T> |
Creates an array representation facade for the encapsulated
Operand. |
class |
ArrayOption<T> |
Creates an array representation facade for the encapsulated
Option. |
class |
CharOption |
|
class |
DebugFlag |
A predefined debug switch.
|
class |
DoubleOption |
|
class |
EnumOption<T extends Enum<T>> |
The Class EnumOption.
|
class |
FileOption |
|
class |
Flag |
The
Flag class implements the Option interface for
representing either a true or a false state: When a
flag is provided to your command line arguments, then it is considered to be
true, when it is omitted, then it is considered to be
false as of Flag.isEnabled(). |
class |
FloatOption |
|
class |
ForceFlag |
A predefined force switch.
|
class |
HelpFlag |
A predefined help switch.
|
class |
IntOption |
|
class |
LongOption |
|
class |
Operation |
The
Operation is an argument representing a function or a method and
is either provided or not provided as of Operation.isEnabled(). |
class |
OptionalCondition |
The
OptionalCondition can nested by an AndCondition and
encapsulates a Condition which may be provided but does not
necessarily needs to be provided in order for the AndCondition to
successfully parse the nested Condition items including the
OptionalCondition. |
class |
OptionConditionFacade |
|
class |
OrCondition |
An
OrCondition represents a list of Condition
(Syntaxable) instances of which at least one must be parsed
successfully when the Syntaxable s'
parseArgs(String[], String[]) methods are invoked. |
class |
QuietFlag |
A predefined "be quiet" switch.
|
class |
StringOperand |
|
class |
StringOption |
|
class |
SysInfoFlag |
A predefined system information switch.
|
class |
VerboseFlag |
A predefined verbose switch.
|
class |
XorCondition |
An
XorCondition represents a list of Condition
(Syntaxable) instances of which only one is allowed to be parsed
successfully when the parseArgs(String[], String[]) methods
are invoked. |
| Modifier and Type | Method | Description |
|---|---|---|
protected List<Syntaxable> |
AbstractCondition.getChildren() |
Gets the children.
|
| Modifier and Type | Method | Description |
|---|---|---|
protected void |
AbstractCondition.addChild(Syntaxable aArgumentizer) |
Adds the child.
|
static Condition |
CliSugar.and(Syntaxable... aArgs) |
|
static Condition |
CliSugar.optional(Syntaxable... aArgs) |
|
static Condition |
CliSugar.or(Syntaxable... aArgs) |
|
static Condition |
CliSugar.xor(Syntaxable... aArgs) |
| Constructor | Description |
|---|---|
AbstractCondition(Syntaxable... aElements) |
Instantiates a new abstract condition.
|
AndCondition(Syntaxable... aArgs) |
|
OptionalCondition(Syntaxable... aArgs) |
|
OptionConditionFacade(Syntaxable aArg) |
|
OrCondition(Syntaxable... aArgs) |
|
XorCondition(Syntaxable... aArgs) |
Copyright © 2021. All rights reserved.