| Modifier and Type | Method | Description |
|---|---|---|
List<? extends Operand<?>> |
ArgsParser.evalArgs(String[] aArgs) |
Evaluates the provided command line arguments and determines the
according values by evaluating the root
Condition. |
default List<? extends Operand<?>> |
ArgsParser.evalArgs(List<String> aArgs) |
Same as
ArgsParser.evalArgs(String[]) with the difference that the elements
representing the arguments are passed as a list instead of an array. |
List<? extends Operand<?>> |
ArgsParserImpl.evalArgs(String[] aArgs) |
Evaluates the provided command line arguments and determines the
according values by evaluating the root
Condition. |
List<Operand<T>> |
AbstractOperand.parseArgs(String[] aArgs,
String[] aOptions) |
Parses the provided command line arguments and determines the according
values by evaluating this
Syntaxable instance or, in case of
being a node in the syntax tree (such as a Condition, traversing
the child Syntaxable instances'
Syntaxable.parseArgs(String[], String[]) methods. |
List<Operand<T>> |
AbstractOption.parseArgs(String[] aArgs,
String[] aOptions) |
Parses the provided command line arguments and determines the according
values by evaluating this
Syntaxable instance or, in case of
being a node in the syntax tree (such as a Condition, traversing
the child Syntaxable instances'
Syntaxable.parseArgs(String[], String[]) methods. |
List<? extends Operand<?>> |
AndCondition.parseArgs(String[] aArgs,
String[] aOptions) |
|
List<Operand<?>> |
ArrayOperand.parseArgs(String[] aArgs,
String[] aOperands) |
Parses the provided command line arguments and determines the according
values by evaluating this
Syntaxable instance or, in case of
being a node in the syntax tree (such as a Condition, traversing
the child Syntaxable instances'
Syntaxable.parseArgs(String[], String[]) methods. |
List<Operand<Boolean>> |
Flag.parseArgs(String[] aArgs,
String[] aOptions) |
Parses the provided command line arguments and determines the according
values by evaluating this
Syntaxable instance or, in case of
being a node in the syntax tree (such as a Condition, traversing
the child Syntaxable instances'
Syntaxable.parseArgs(String[], String[]) methods. |
List<Operand<Boolean>> |
Operation.parseArgs(String[] aArgs,
String[] aOptions) |
Parses the provided command line arguments and determines the according
values by evaluating this
Syntaxable instance or, in case of
being a node in the syntax tree (such as a Condition, traversing
the child Syntaxable instances'
Syntaxable.parseArgs(String[], String[]) methods. |
List<? extends Operand<?>> |
OptionalCondition.parseArgs(String[] aArgs,
String[] aOptions) |
|
List<? extends Operand<?>> |
OptionConditionFacade.parseArgs(String[] aArgs,
String[] aOptions) |
|
List<? extends Operand<?>> |
OrCondition.parseArgs(String[] aArgs,
String[] aOptions) |
|
default List<? extends Operand<?>> |
Syntaxable.parseArgs(String[] aArgs) |
Parses the provided command line arguments and determines the according
values by evaluating this
Syntaxable instance or, in case of
being a node in the syntax tree (such as a Condition, traversing
the child Syntaxable instances'
Syntaxable.parseArgs(String[], String[]) methods. |
List<? extends Operand<?>> |
Syntaxable.parseArgs(String[] aArgs,
String[] aOptions) |
Parses the provided command line arguments and determines the according
values by evaluating this
Syntaxable instance or, in case of
being a node in the syntax tree (such as a Condition, traversing
the child Syntaxable instances'
Syntaxable.parseArgs(String[], String[]) methods. |
List<? extends Operand<?>> |
XorCondition.parseArgs(String[] aArgs,
String[] aOptions) |
|
default ArgsParser |
ArgsParser.withEvalArgs(String[] aArgs) |
Same as
ArgsParser.evalArgs(String[]) with the difference that this class's
instance being invoked is returned as of the builder pattern. |
default ArgsParser |
ArgsParser.withEvalArgs(List<String> aArgs) |
Same as
ArgsParser.evalArgs(List) with the difference that this class's
instance being invoked is returned as of the builder pattern. |
B |
ArgsParserMixin.withEvalArgs(String[] aArgs) |
Evaluates the provided command line arguments.
|
default B |
ArgsParserMixin.withEvalArgs(List<String> aArgs) |
Evaluates the provided command line arguments .
|
Copyright © 2021. All rights reserved.