All Classes and Interfaces
Class
Description
The
AbstractCondition is an abstract implementation of the
Condition interface providing the boiler plate when implementing the
Condition interface as done by the AbstractCondition's
sub-classes.The
AbstractDirective is an abstract implementation of an
Directive providing the boiler plate when implementing the
Directive interface.The
AbstractOperand is an abstract implementation of an
Operand providing the boiler plate when implementing the
Operand interface.The
AbstractOption is an abstract implementation of an Option
providing the boiler plate when implementing the Option interface.The
AbstractProperty is an abstract implementation of a
Property providing the boiler plate when implementing the
Property interface.The
AllCondition enforces that the encapsulated Term consumes
all arguments passed via invoking its
Term.parseArgs(String[], CliContext), else a
SuperfluousArgsException is thrown.Thrown in case the command line arguments do not match the required syntax.
An
AndCondition contains (represents) a list of Condition
(Term) instances (nested by the AndCondition) of which all
are to be parsed successfully as of invoking the
Term.parseArgs(String[], String[], CliContext) methods.Any of the nested
Condition conditions may match for the
AnyCondition to match, e.g. all of the nested conditions are
optional.Provides an accessor for a command line arguments (short "args") array.
Provides a mutator for a args property.
Provides a args property.
Enumeration declaring command line argument filter.
The
ArgsParser provides means for parsing command line arguments and
constructing a command line utility's help output.Provides an accessor for a
ArgsParser property.Provides a builder method for a
ArgsParser property returning the
builder for applying multiple build operations.Provides a mutator for a
ArgsParser property.Provides a
ArgsParser property.This mixin provides builder additions (as of the builder pattern for chained
configuring method calls) for parsing command line arguments.
The
ArgsProcessorBuilder provides common minimum builder
functionality required by to build an argument processing instance.The
ArgsProvidierBuilder interface provides builder methods for
feeding command line arguments.Provides an accessor for a (root)
Term property.Provides a builder method for a (root)
Term property returning
the builder for applying multiple build operations.Provides a mutator for a (root)
Term property.Provides a (root)
Term property.Thrown in case of a command line arguments mismatch regarding provided and
expected args.
Provides an accessor for a argument Escape-Code property.
Provides a builder method for a argument Escape-Code property returning
the builder for applying multiple build operations.
Provides a mutator for a argument Escape-Code property.
Provides a argument Escape-Code property.
Provides an accessor for an argument prefix property.
Provides a builder method for an argument prefix property returning the
builder for applying multiple build operations.
Provides a mutator for an argument prefix property.
Provides an argument prefix property.
Provides an accessor for an argument suffix property.
Provides a builder method for an argument suffix property returning the
builder for applying multiple build operations.
Provides a mutator for an argument suffix property.
Provides an argument suffix property.
Creates an array representation facade for the encapsulated
Directive.Creates an array representation facade for the encapsulated
Operand.Creates an array representation facade for the encapsulated
Option.Provides an accessor for a banner border Escape-Code property.
Provides a builder method for a banner border Escape-Code property
returning the builder for applying multiple build operations.
Provides a mutator for a banner border Escape-Code property.
Provides a banner border Escape-Code property.
Provides an accessor for a banner Escape-Code property.
Provides a builder method for a banner Escape-Code property returning the
builder for applying multiple build operations.
Provides a mutator for a banner Escape-Code property.
Provides a banner Escape-Code property.
Provides an accessor for a banner
Font property.Provides a builder method for a banner
Font property returning
the builder for applying multiple build operations.Provides a mutator for a banner
Font property.Provides a banner
Font property.Provides an accessor for a banner font palette property.
Provides a builder method for a banner font palette property returning
the builder for applying multiple build operations.
Provides a mutator for a banner font palette property.
Provides a banner font palette property.
The
CasesCondition is an XorCondition making sure that all
possible cases inside the XorCondition must(!)A predefined clean
Flag: A predefined Flag gives its
CleanFlag.SHORT_OPTION, its CleanFlag.LONG_OPTION as well as its CleanFlag.ALIAS
an according semantics regarded by other subsystems.A straightforward implementation of the
ArgsParser interface.The
CliContext describes the context in which an ArgsParser
is running.Builder to build
SyntaxMetricsAccessor.SyntaxMetricsBuilder instances.Provides an accessor for a
CliContext property.Provides a builder method for a
CliContext property returning the
builder for applying multiple build operations.Provides a mutator for a
CliContext property.Provides a
CliContext property.Base exception for the CLI artifact.
This abstract exception is the base exception for all command line
argument related exceptions.
CliSchema.Builder to build CliSchema.Provides an accessor for a command Escape-Code property.
Provides a builder method for a command Escape-Code property returning
the builder for applying multiple build operations.
Provides a mutator for a command Escape-Code property.
Provides a command Escape-Code property.
The
ConfigOption represents an Option holding a value
specifying a configuration resource (file).The
ConfigProperty represents an Property holding a value
specifying a configuration resource (file).Provides an accessor for a copyright property.
Provides a builder method for a copyright property returning the builder
for applying multiple build operations.
Provides a mutator for a copyright property.
Provides a copyright property.
A predefined daemon
Flag: A predefined Flag gives its
DaemonFlag.SHORT_OPTION, its DaemonFlag.LONG_OPTION as well as its DaemonFlag.ALIAS
an according semantics regarded by other subsystems.A predefined debug
Flag: A predefined Flag gives its
DebugFlag.SHORT_OPTION, its DebugFlag.LONG_OPTION as well as its DebugFlag.ALIAS
an according semantics regarded by other subsystems.Provides an accessor for a description Escape-Code property.
Provides a builder method for a description Escape-Code property
returning the builder for applying multiple build operations.
Provides a mutator for a description Escape-Code property.
Provides a description Escape-Code property.
An
Directive represents a command line operation with the according
operation's operand (value).The
EnumDirective represents a Directive of enumeration
types.The
EnumOption represents an Option of enumeration types.The
EnumProperty represents an Property of enumeration types.An example usage item describing a usage scenario.
Provides an accessor for an
Example instances property.Provides a builder method for an
Example instances property
returning the builder for applying multiple build operations.Provides a mutator for an
Example instances property.Provides an
Example instances property.The
Flag class implements the Option interface for
representing either a true or a false state: When a
flag is provided to your command line arguments, then it is considered to be
true, when it is omitted, then it is considered to be
false as of Flag.isEnabled().A predefined force
Flag: A predefined Flag gives its
ForceFlag.SHORT_OPTION, its ForceFlag.LONG_OPTION as well as its ForceFlag.ALIAS
an according semantics regarded by other subsystems.A predefined help
Flag: A predefined Flag gives its
HelpFlag.SHORT_OPTION, its HelpFlag.LONG_OPTION as well as its HelpFlag.ALIAS
an according semantics regarded by other subsystems.A predefined init
Flag: A predefined Flag gives its
InitFlag.SHORT_OPTION, its InitFlag.LONG_OPTION as well as its InitFlag.ALIAS
an according semantics regarded by other subsystems.Provides an accessor for a keyword (e.g. short- and long-options) Escape-Code
property.
Provides a builder method for a keyword (e.g. short- and long-options)
Escape-Code property returning the builder for applying multiple build
operations.
Provides a mutator for a keyword (e.g. short- and long-options)
Escape-Code property.
Provides a keyword (e.g. short- and long-options) Escape-Code property.
Provides an accessor for a license property.
Provides a builder method for a license property returning the builder
for applying multiple build operations.
Provides a mutator for a license property.
Provides a license property.
Provides an accessor for a line separator Escape-Code property.
Provides a builder method for a line separator Escape-Code property
returning the builder for applying multiple build operations.
Provides a mutator for a line separator Escape-Code property.
Provides a line separator Escape-Code property.
Provides an accessor for a long option property.
Provides a builder method for a long option property returning the
builder for applying multiple build operations.
Provides a mutator for a long option property.
Provides a long option property.
Provides an accessor for a long option prefix property.
Provides a builder method for a long option prefix property returning the
builder for applying multiple build operations.
Provides a mutator for a long option prefix property.
Provides a long option prefix property.
Provides an accessor for a long option prefix property.
Provides a builder method for a long option prefix property returning the
builder for applying multiple build operations.
Provides a mutator for a long option prefix property.
Provides a long option prefix property.
Provides an accessor for a match-count property.
Provides a builder method for a match-count property returning the
builder for applying multiple build operations.
Provides a mutator for a match-count property.
Provides a match-count property.
The
NoneOperand represents an empty set of arguments, e.g. no command
line argument is being passed.
An
Operand represents a value parsed from command line arguments.The
Operation is an argument representing an action of functioning or
the fact of being active or in effect and is either provided (as command line
argument) or not provided as of Operation.isEnabled().Provides an accessor for a operation property.
Provides a builder method for a operation property returning the builder
for applying multiple build operations.
Provides a mutator for a operation property.
Provides a operation property.
An
Option represents a command line option with the according
option's value.Provides means to determine context specific information on
Option
instances.An
OrCondition represents a list of Condition (Term)
instances of which at least one must be parsed successfully when the
Term s' Term.parseArgs(String[], String[], CliContext)
methods are invoked.Thrown in case the provided command line arguments do not respect the
required semantics or cannot be converted to the required type.
Provides an accessor for a command line arguments (short "args") array.
Provides a mutator for a parsed args property.
Provides a parsed args property.
Thrown in case the provided command line arguments do not respect the
required semantics or cannot be converted to the required type by a
Directive (having an operation alongside an expected operand), e.g.Thrown in case the provided command line arguments do not respect the
required semantics or cannot be converted to the required type by an
Option (having a short- and/or a long-option), e.g. the arguments
were rejected as them did not work for the according syntax.An
Property represents an option property with the according
porperty's key and value separated by a = (and no whitespace
inbetween).Provides an accessor for a option Escape-Code property.
Provides a builder method for a option Escape-Code property returning the
builder for applying multiple build operations.
Provides a mutator for a option Escape-Code property.
Provides a option Escape-Code property.
A predefined "be quiet"
Flag: A predefined Flag gives its
QuietFlag.SHORT_OPTION, its QuietFlag.LONG_OPTION as well as its QuietFlag.ALIAS
an according semantics regarded by other subsystems.Provides an accessor for a short option property.
Provides a builder method for a short option property returning the
builder for applying multiple build operations.
Provides a mutator for a short option property.
Provides a short option property.
Provides an accessor for a short option prefix property.
Provides a builder method for a short option prefix property returning
the builder for applying multiple build operations.
Provides a mutator for a short option prefix property.
Provides a short option prefix property.
Provides an accessor for a short option prefix property.
Provides a builder method for a short option prefix property returning
the builder for applying multiple build operations.
Provides a mutator for a short option prefix property.
Provides a short option prefix property.
Thrown in case there were arguments found not being used (superfluous
arguments).
The
Synopsisable interface defines those methods required to create a
human readable usage String similar to a manpage's synopsis from the
implementing instance.The
SyntaxMetrics provides properties specific to a specific command
line syntax notation.Provides an accessor for a
SyntaxMetrics property.Provides a builder method for a
SyntaxMetrics property returning
the builder for applying multiple build operations.Provides a mutator for a
SyntaxMetrics property.Provides a
SyntaxMetrics property.The
SyntaxMetricsBuilder class implements the SyntaxMetrics
interface for building custom SyntaxMetrics instances.Builder to build
SyntaxMetrics instances.The
SyntaxNotation is used by a the Term.toSyntax(CliContext)
method to determine which notation to be used for the generated syntax.A predefined system information
Flag: A predefined Flag gives
its SysInfoFlag.SHORT_OPTION, its SysInfoFlag.LONG_OPTION as well as its
SysInfoFlag.ALIAS an according semantics regarded by other subsystems..A
Term represents a node within a command line argument syntax tree.Thrown in case command line arguments were not processed (did not match the
expected arguments), e.g. the arguments were rejected as them did not work
for the according syntax.
Thrown in case command line arguments were not processed (did not match the
expected arguments) by an
Option (having a short- and/or a
long-option), e.g. the arguments were rejected as them did not work for the
according syntax.Thrown in case command line arguments were not processed (did not match the
expected arguments) by an
Option (having a short- and/or a
long-option), e.g. the arguments were rejected as them did not work for the
according syntax.A predefined verbose
Flag: A predefined Flag gives its
VerboseFlag.SHORT_OPTION, its VerboseFlag.LONG_OPTION as well as its VerboseFlag.ALIAS
an according semantics regarded by other subsystems.An
XorCondition represents a list of Condition (Term)
instances of which only one is allowed to be parsed successfully when the
Term.parseArgs(String[], String[], CliContext) methods are
invoked.