All Classes and Interfaces
Class
Description
The
AbstractCondition is an abstract implementation of the
Condition interface providing the boiler plate when implementing the
Condition interface as done by the AbstractCondition's
sub-classes.The
AbstractOperand is an abstract implementation of an
Operand providing the boiler plate when implementing the
Operand interface.The
AbstractOption is an abstract implementation of an Option
providing the boiler plate when implementing the Option interface.The
AllCondition enforces that the encapsulated Constituent
consumes all arguments passed via invoking its
parseArgs(String[], CliContext), else a
SuperfluousArgsException is thrown.Thrown in case the command line arguments do not match the required syntax.
An
AndCondition contains (represents) a list of Condition
(Constituent) instances (nested by the AndCondition) of which
all are to be parsed successfully as of invoking the
parseArgs(String[], String[], CliContext) methods.Any of the nested
Condition conditions may match for the
AnyCondition to match, e.g. all of the nested conditions are
optional.Provides an accessor for a command line arguments (short "args") array.
Provides a mutator for a args property.
Provides a args property.
Enumeration declaring command line argument filter.
The
ArgsParser provides means for parsing command line arguments and
constructing a command line utility's help output.Provides an accessor for a
ArgsParser property.Provides a builder method for a
ArgsParser property returning the
builder for applying multiple build operations.Provides a mutator for a
ArgsParser property.Provides a
ArgsParser property.A straightforward implementation of the
ArgsParser interface.This mixin provides builder additions (as of the builder pattern for chained
configuring method calls) for parsing command line arguments.
Provides an accessor for a root condition property.
Provides a builder method for a root condition property returning the
builder for applying multiple build operations.
Provides a mutator for a root condition property.
Provides a root condition property.
Thrown in case of a command line arguments mismatch regarding provided and
expected args.
Provides an accessor for a argument Escape-Code property.
ArgumentEscapeCodeAccessor.ArgumentEscapeCodeBuilder<B extends ArgumentEscapeCodeAccessor.ArgumentEscapeCodeBuilder<B>>
Provides a builder method for a argument Escape-Code property returning
the builder for applying multiple build operations.
Provides a mutator for a argument Escape-Code property.
Provides a argument Escape-Code property.
Provides an accessor for an argument prefix property.
ArgumentPrefixAccessor.ArgumentPrefixBuilder<B extends ArgumentPrefixAccessor.ArgumentPrefixBuilder<B>>
Provides a builder method for an argument prefix property returning the
builder for applying multiple build operations.
Provides a mutator for an argument prefix property.
Provides an argument prefix property.
Provides an accessor for an argument suffix property.
ArgumentSuffixAccessor.ArgumentSuffixBuilder<B extends ArgumentSuffixAccessor.ArgumentSuffixBuilder<B>>
Provides a builder method for an argument suffix property returning the
builder for applying multiple build operations.
Provides a mutator for an argument suffix property.
Provides an argument suffix property.
Creates an array representation facade for the encapsulated
Operand.Creates an array representation facade for the encapsulated
Option.The
CasesCondition is an XorCondition making sure that all
possible cases inside the XorCondition must(!)A predefined clean
Flag: A predefined Flag gives its
CleanFlag.SHORT_OPTION, its CleanFlag.LONG_OPTION as well as its CleanFlag.ALIAS
an according semantics regarded by other subsystems.The
CliContext describes the context in which an ArgsParser
is running.Builder to build
SyntaxMetricsAccessor.SyntaxMetricsBuilder instances.Provides an accessor for a
CliContext property.Provides a builder method for a
CliContext property returning the
builder for applying multiple build operations.Provides a mutator for a
CliContext property.Provides a
CliContext property.Base exception for the console artifact.
This abstract exception is the base exception for all command line
argument related exceptions.
The Class ConsoleCliException.
The
CliMetrics define the attributes required to parse a
Constituent tree's syntax by an ArgsParser.The purpose of a
CliSchema is automatically generate documentation of
Constituent structures.This utility class provides method useful for the refcodes-cli artifact and
whose implementation has been motivated by the implementation of the
refcodes-cli artifact.
The
Condition interface represents a node (and therewith the syntax
for the arguments) in the command line arguments syntax tree; simply
extending the Constituent interface and adding the functionality of
providing access to the added Operands (leafs).The
ConfigOption represents an Option holding a value
specifying a configuration resource (file).A
Constituent defines the methods at least required when building a
command line arguments syntax tree for traversing the syntax tree; either for
parsing command line arguments or for constructing the command line arguments
syntax.A predefined daemon
Flag: A predefined Flag gives its
DaemonFlag.SHORT_OPTION, its DaemonFlag.LONG_OPTION as well as its DaemonFlag.ALIAS
an according semantics regarded by other subsystems.A predefined debug
Flag: A predefined Flag gives its
DebugFlag.SHORT_OPTION, its DebugFlag.LONG_OPTION as well as its DebugFlag.ALIAS
an according semantics regarded by other subsystems.The
EnumOption represents an Option of enumeration types.An example usage item describing a usage scenario.
The
Flag class implements the Option interface for
representing either a true or a false state: When a
flag is provided to your command line arguments, then it is considered to be
true, when it is omitted, then it is considered to be
false as of Flag.isEnabled().A predefined force
Flag: A predefined Flag gives its
ForceFlag.SHORT_OPTION, its ForceFlag.LONG_OPTION as well as its ForceFlag.ALIAS
an according semantics regarded by other subsystems.A predefined help
Flag: A predefined Flag gives its
HelpFlag.SHORT_OPTION, its HelpFlag.LONG_OPTION as well as its HelpFlag.ALIAS
an according semantics regarded by other subsystems.A predefined init
Flag: A predefined Flag gives its
InitFlag.SHORT_OPTION, its InitFlag.LONG_OPTION as well as its InitFlag.ALIAS
an according semantics regarded by other subsystems.Provides an accessor for a long option prefix property.
LongOptionPrefixAccessor.LongOptionPrefixBuilder<B extends LongOptionPrefixAccessor.LongOptionPrefixBuilder<B>>
Provides a builder method for a long option prefix property returning the
builder for applying multiple build operations.
Provides a mutator for a long option prefix property.
Provides a long option prefix property.
The
NoneOperand represents an empty set of arguments, e.g. no command
line argument is being passed.An
Operand represents a value parsed from command line arguments.The
Operation is an argument representing a function or a method
("command") and is either provided or not provided as of
Operation.isEnabled().An
Option represents a command line option with the according
option's value.Provides means to determine context specific information on
Option
instances.Provides an accessor for a option Escape-Code property.
OptionEscapeCodeAccessor.OptionEscapeCodeBuilder<B extends OptionEscapeCodeAccessor.OptionEscapeCodeBuilder<B>>
Provides a builder method for a option Escape-Code property returning the
builder for applying multiple build operations.
Provides a mutator for a option Escape-Code property.
Provides a option Escape-Code property.
An
OrCondition represents a list of Condition
(Constituent) instances of which at least one must be parsed
successfully when the Constituent s'
parseArgs(String[], String[], CliContext) methods are invoked.Thrown in case the provided command line arguments do not respect the
required semantics or cannot be converted to the required type.
A predefined "be quiet"
Flag: A predefined Flag gives its
QuietFlag.SHORT_OPTION, its QuietFlag.LONG_OPTION as well as its QuietFlag.ALIAS
an according semantics regarded by other subsystems.Provides an accessor for a short option prefix property.
ShortOptionPrefixAccessor.ShortOptionPrefixBuilder<B extends ShortOptionPrefixAccessor.ShortOptionPrefixBuilder<B>>
Provides a builder method for a short option prefix property returning
the builder for applying multiple build operations.
Provides a mutator for a short option prefix property.
Provides a short option prefix property.
Thrown in case there were arguments found not being used (superfluous
arguments).
The
Synopsisable interface defines those methods required to create a
human readable usage String similar to a manpage's synopsis from the
implementing instance.The
SyntaxMetrics provides properties specific to a specific command
line syntax notation.Provides an accessor for a
SyntaxMetrics property.Provides a builder method for a
SyntaxMetrics property returning
the builder for applying multiple build operations.Provides a mutator for a
SyntaxMetrics property.Provides a
SyntaxMetrics property.The
SyntaxMetricsImpl class implements the SyntaxMetrics
interface for building custom SyntaxMetrics instances.Builder to build
SyntaxMetrics instances.The
SyntaxNotation is used by a the
toSyntax(CliContext) method to determine which notation
to be used for the generated syntax.A predefined system information
Flag: A predefined Flag gives
its SysInfoFlag.SHORT_OPTION, its SysInfoFlag.LONG_OPTION as well as its
SysInfoFlag.ALIAS an according semantics regarded by other subsystems..Thrown in case command line arguments were not processed (did not match the
expected arguments), e.g. the arguments were rejected as them did not work
for the according syntax.
A predefined verbose
Flag: A predefined Flag gives its
VerboseFlag.SHORT_OPTION, its VerboseFlag.LONG_OPTION as well as its VerboseFlag.ALIAS
an according semantics regarded by other subsystems.An
XorCondition represents a list of Condition
(Constituent) instances of which only one is allowed to be parsed
successfully when the
parseArgs(String[], String[], CliContext) methods are
invoked.