All Classes
| Class | Description |
|---|---|
| AbstractCondition |
The
AbstractCondition is an abstract implementation of an
Condition providing the boiler plate when implementing the
Condition interface. |
| AbstractOperand<T> |
The
AbstractOperand is an abstract implementation of an
Operand providing the boiler plate when implementing the
Operand interface. |
| AbstractOption<T> |
The
AbstractOption is an abstract implementation of an Option
providing the boiler plate when implementing the Option interface. |
| AmbiguousArgsException |
Thrown in case at least one command line argument is ambiguous regarding
expected args vs. provided args.
|
| AndCondition |
An
AndCondition contains (represents) a list of Condition
(Syntaxable) instances (nested by the AndCondition) of which
all are to be parsed successfully as of invoking the
Syntaxable.parseArgs(String[], String[]) methods. |
| ArgsAccessor |
Provides an accessor for a command line arguments (short "args") array.
|
| ArgsAccessor.ArgsMutator |
Provides a mutator for a args property.
|
| ArgsAccessor.ArgsProperty |
Provides a args property.
|
| ArgsMismatchException |
Thrown in case a command line arguments mismatch regarding provided and
expected args.
|
| ArgsParser |
The
ArgsParser provides means for parsing command line arguments and
constructing a command line utility's help output. |
| ArgsParserAccessor |
Provides an accessor for a
ArgsParser property. |
| ArgsParserAccessor.ArgsParserBuilder<B extends ArgsParserAccessor.ArgsParserBuilder<B>> |
Provides a builder method for a
ArgsParser property returning the
builder for applying multiple build operations. |
| ArgsParserAccessor.ArgsParserMutator |
Provides a mutator for a
ArgsParser property. |
| ArgsParserAccessor.ArgsParserProperty |
Provides a
ArgsParser property. |
| ArgsParserImpl |
A straightforward implementation of the
ArgsParser interface. |
| ArgsParserMixin<B extends ArgsParserMixin<B>> |
This mixin provides builder additions (as of the builder pattern for chained
configuring method calls) for parsing command line arguments.
|
| ArrayOperand<T> |
Creates an array representation facade for the encapsulated
Operand. |
| ArrayOption<T> |
Creates an array representation facade for the encapsulated
Option. |
| CharOption | |
| CliException |
Base exception for the console artifact.
|
| CliException.ConsoleArgsException |
This abstract exception is the base exception for all command line
argument related exceptions.
|
| CliException.ConsoleCliException |
The Class ConsoleCliException.
|
| CliSugar | |
| CliUtility |
This utility class provides method useful for the refcodes-cli artifact and
whose implementation has been motivated by the implementation of the
refcodes-cli artifact.
|
| Condition |
The
Condition interface represents a node in the command line
arguments syntax tree; simply extending the Syntaxable interface and
adding the functionality of providing access to the added Operands
(leafs). |
| DebugFlag |
A predefined debug switch.
|
| DoubleOption | |
| EnumOption<T extends Enum<T>> |
The Class EnumOption.
|
| ExampleUsage |
An example usage item describing a usage scenario.
|
| ExitCode |
Some default exit codes defined for CLI applications.
|
| FileOption | |
| Flag |
The
Flag class implements the Option interface for
representing either a true or a false state: When a
flag is provided to your command line arguments, then it is considered to be
true, when it is omitted, then it is considered to be
false as of Flag.isEnabled(). |
| FloatOption | |
| ForceFlag |
A predefined force switch.
|
| HelpFlag |
A predefined help switch.
|
| IntOption | |
| LongOption | |
| Operand<T> |
An
Operand represents a value parsed from command line arguments. |
| Operation |
The
Operation is an argument representing a function or a method and
is either provided or not provided as of Operation.isEnabled(). |
| Option<T> |
An
Option represents a command line option with the according
option's value. |
| OptionalCondition |
The
OptionalCondition can nested by an AndCondition and
encapsulates a Condition which may be provided but does not
necessarily needs to be provided in order for the AndCondition to
successfully parse the nested Condition items including the
OptionalCondition. |
| OptionConditionFacade | |
| OrCondition |
An
OrCondition represents a list of Condition
(Syntaxable) instances of which at least one must be parsed
successfully when the Syntaxable s'
Syntaxable.parseArgs(String[], String[]) methods are invoked. |
| ParseArgsException |
Thrown in case the provided command line arguments do not respect the
required syntax or cannot be converted to the required type.
|
| QuietFlag |
A predefined "be quiet" switch.
|
| RootConditionAccessor |
Provides an accessor for a root condition property.
|
| RootConditionAccessor.RootConditionBuilder<B extends RootConditionAccessor.RootConditionBuilder<B>> |
Provides a builder method for a root condition property returning the
builder for applying multiple build operations.
|
| RootConditionAccessor.RootConditionMutator |
Provides a mutator for a root condition property.
|
| RootConditionAccessor.RootConditionProperty |
Provides a root condition property.
|
| StringOperand | |
| StringOption | |
| SuperfluousArgsException |
Thrown in case there were arguments found not being used (superfluous
arguments).
|
| Syntaxable |
A
Syntaxable defines the methods at least required when building a
command line arguments syntax tree for traversing the syntax tree; either for
parsing command line arguments or for constructing the command line arguments
syntax. |
| SyntaxNotation |
The
SyntaxNotation is used by a the
Syntaxable.toSyntax(SyntaxNotation, String, String) method to
determine which notation to be used for the generated syntax. |
| SyntaxUsage |
The
SyntaxUsage interface defines those methods required to create a
human readable usage String from the implementing instance. |
| SysInfoFlag |
A predefined system information switch.
|
| UnknownArgsException |
Thrown in case not one command line argument matched regarding the provided
args vs. the expected args.
|
| VerboseFlag |
A predefined verbose switch.
|
| XorCondition |
An
XorCondition represents a list of Condition
(Syntaxable) instances of which only one is allowed to be parsed
successfully when the Syntaxable.parseArgs(String[], String[]) methods
are invoked. |