Class AbstractOperand<T>
- Type Parameters:
T- The generic type of theAbstractOperand's value.
- All Implemented Interfaces:
Cloneable,Comparable<Operand<?>>,MatchCountAccessor,Operand<T>,ParsedArgsAccessor,Synopsisable,Term,org.refcodes.exception.ExceptionAccessor<ArgsSyntaxException>,org.refcodes.graphical.VisibleAccessor,org.refcodes.graphical.VisibleAccessor.VisibleBuilder<Term>,org.refcodes.graphical.VisibleAccessor.VisibleMutator,org.refcodes.graphical.VisibleAccessor.VisibleProperty,org.refcodes.mixin.AliasAccessor,org.refcodes.mixin.Clonable,org.refcodes.mixin.DescriptionAccessor,org.refcodes.mixin.Resetable,org.refcodes.mixin.TypeAccessor<T>,org.refcodes.mixin.ValueAccessor<T>,org.refcodes.schema.Schemable
- Direct Known Subclasses:
AbstractDirective,AbstractOption,NoneOperand,Operation,StringOperand
AbstractOperand is an abstract implementation of an
Operand providing the boiler plate when implementing the
Operand interface.
As the Operand stands for an arbitrary value parsed from the command
line arguments, disambiguation may occur when parsing the command line
arguments. The arguments are parsed from right to left to prevent parsing
errors in case of ambiguous arguments: An Operand matches any
argument not having an option prefix (short option and long option prefix).
-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.mixin.AliasAccessor
org.refcodes.mixin.AliasAccessor.AliasBuilder<B extends org.refcodes.mixin.AliasAccessor.AliasBuilder<B>>, org.refcodes.mixin.AliasAccessor.AliasMutator, org.refcodes.mixin.AliasAccessor.AliasPropertyNested classes/interfaces inherited from interface org.refcodes.mixin.DescriptionAccessor
org.refcodes.mixin.DescriptionAccessor.DescriptionBuilder<B extends org.refcodes.mixin.DescriptionAccessor.DescriptionBuilder<B>>, org.refcodes.mixin.DescriptionAccessor.DescriptionMutator, org.refcodes.mixin.DescriptionAccessor.DescriptionPropertyNested classes/interfaces inherited from interface org.refcodes.exception.ExceptionAccessor
org.refcodes.exception.ExceptionAccessor.ExceptionBuilder<EXC extends Throwable,B extends org.refcodes.exception.ExceptionAccessor.ExceptionBuilder<EXC, B>>, org.refcodes.exception.ExceptionAccessor.ExceptionMutator<EXC extends Throwable>, org.refcodes.exception.ExceptionAccessor.ExceptionProperty<EXC extends Throwable> Nested classes/interfaces inherited from interface org.refcodes.cli.MatchCountAccessor
MatchCountAccessor.MatchCountBuilder<B extends MatchCountAccessor.MatchCountBuilder<B>>, MatchCountAccessor.MatchCountMutator, MatchCountAccessor.MatchCountPropertyNested classes/interfaces inherited from interface org.refcodes.cli.ParsedArgsAccessor
ParsedArgsAccessor.ParsedArgsMutator, ParsedArgsAccessor.ParsedArgsPropertyNested classes/interfaces inherited from interface org.refcodes.mixin.TypeAccessor
org.refcodes.mixin.TypeAccessor.TypeBuilder<T,B extends org.refcodes.mixin.TypeAccessor.TypeBuilder<T, B>>, org.refcodes.mixin.TypeAccessor.TypeMutator<T>, org.refcodes.mixin.TypeAccessor.TypeProperty<T> Nested classes/interfaces inherited from interface org.refcodes.mixin.ValueAccessor
org.refcodes.mixin.ValueAccessor.ValueBuilder<V,B extends org.refcodes.mixin.ValueAccessor.ValueBuilder<V, B>>, org.refcodes.mixin.ValueAccessor.ValueMutator<V>, org.refcodes.mixin.ValueAccessor.ValueProperty<V> Nested classes/interfaces inherited from interface org.refcodes.graphical.VisibleAccessor
org.refcodes.graphical.VisibleAccessor.VisibleBuilder<B extends org.refcodes.graphical.VisibleAccessor.VisibleBuilder<B>>, org.refcodes.graphical.VisibleAccessor.VisibleMutator, org.refcodes.graphical.VisibleAccessor.VisibleProperty -
Field Summary
FieldsModifier and TypeFieldDescriptionprotected Stringprotected ArgsSyntaxExceptionprotected booleanprotected int -
Constructor Summary
ConstructorsConstructorDescriptionAbstractOperand(Class<T> aType, String aAlias, String aDescription) Constructs anOperandwith the given arguments.AbstractOperand(Class<T> aType, String aAlias, String aDescription, Consumer<? extends Operand<T>> aConsumer) Constructs anOperandwith the given arguments.AbstractOperand(org.refcodes.struct.Relation<String, T> aProperty, Class<T> aType) Constructs anOperandwith the given arguments.AbstractOperand(org.refcodes.struct.Relation<String, T> aProperty, Class<T> aType, Consumer<? extends Operand<T>> aConsumer) Constructs anOperandwith the given arguments. -
Method Summary
Modifier and TypeMethodDescriptionprotected voidapprove()In case thisTermparticipated in successful parsing command line arguments, then thisTermgets approved by theCliArgsParser.clone()intgetAlias()Retrieves theArgsSyntaxExceptionexception in case invokingTerm.parseArgs(String[], CliContext)failed.intDetermines the number of args being matched by theTerm.parseArgs(String[], CliContext)(and similar) method(s) of the according syntax.String[]Retrieves the (command line) args which represent thisOperandafter being "parsed" (provided with command line args).getType()getValue()booleanOperand<?>[]parseArgs(String[] aArgs, String[] aKeywords, CliContext aCliCtx) Parses the given command line arguments using the provided keyword set and CLI context.voidreset()protected voidsetParsedArgs(String[] aArgs) Sets the command line argument(s) representing theOperandand its value as parsed by theparseArgs(String[], String[], CliContext)method.protected voidSets the value for theOperandas parsed by theparseArgs(String[], String[], CliContext)method.voidsetVisible(boolean isVisible) protected static String[]toArgsDiff(String[] aArgs, String[] aArgsSubset) Creates the difference between the provided set and the provided subset.protected static String[]toArgsDiff(String[] aArgs, List<? extends Operand<?>> aArgsSubset) Creates the difference between the provided set and the providedLists therein found argument arrays subset (as ofOperand.getParsedArgs()).protected static String[]toArgsDiff(String[] aArgs, Operand<?>[] aArgsSubset) Creates the difference between the provided set and the providedLists therein found argument arrays subset (as ofOperand.getParsedArgs()).protected static String[]toParsedArgs(Operand<?>[]... aOperands) Takes allOperandinstances found in the providedLists and adds all therein found argument arrays (as ofOperand.getParsedArgs()) to the result.toSchema()toString()protected abstract TDouble dispatch hook to be implemented by subclasses of theAbstractOperandfor converting a command line argument to the requiredOperand's type.Methods inherited from class java.lang.Object
equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface org.refcodes.mixin.DescriptionAccessor
getDescriptionMethods inherited from interface org.refcodes.cli.Operand
hasValue, toKeywords, toSpec, toSpec, toSpec, toSpec, toSpec, toSyntax, toUsage, toUsage, toValueMethods inherited from interface org.refcodes.schema.Schemable
toSchemaMethods inherited from interface org.refcodes.cli.Synopsisable
toSynopsis, toSynopsis, toSynopsis, toSynopsisMethods inherited from interface org.refcodes.cli.Term
argsParser, getException, isVisible, parseArgs, setVisible, toSynopsis, toSyntax, toSyntax, toSyntax, toSyntaxMethods inherited from interface org.refcodes.mixin.ValueAccessor
getValueOrMethods inherited from interface org.refcodes.graphical.VisibleAccessor.VisibleBuilder
withHide, withShow, withVisibleMethods inherited from interface org.refcodes.graphical.VisibleAccessor.VisibleMutator
hide, showMethods inherited from interface org.refcodes.graphical.VisibleAccessor.VisibleProperty
letVisible
-
Field Details
-
_matchCount
protected int _matchCount -
_description
-
_exception
-
_isVisible
protected boolean _isVisible
-
-
Constructor Details
-
AbstractOperand
Constructs anOperandwith the given arguments.- Parameters:
aType- The type of the value returned by thegetValue()method.aAlias- TheOperand's name, used for syntax creation.aDescription- The description to be used (without any line breaks).
-
AbstractOperand
public AbstractOperand(Class<T> aType, String aAlias, String aDescription, Consumer<? extends Operand<T>> aConsumer) Constructs anOperandwith the given arguments.- Parameters:
aType- The type of the value returned by thegetValue()method.aAlias- TheOperand's name, used for syntax creation.aDescription- The description to be used (without any line breaks).aConsumer- TheConsumerbeing invoked in case thisOperandparticipated in successfully parsing the command line arguments.
-
AbstractOperand
-
AbstractOperand
public AbstractOperand(org.refcodes.struct.Relation<String, T> aProperty, Class<T> aType, Consumer<? extends Operand<T>> aConsumer) Constructs anOperandwith the given arguments.- Parameters:
aProperty- The key (= alias) and the value for the operand.aType- The type of the value returned by thegetValue()method.aConsumer- TheConsumerbeing invoked in case thisOptionparticipated in successfully parsing the command line arguments.
-
-
Method Details
-
clone
- Specified by:
clonein interfaceorg.refcodes.mixin.Clonable- Overrides:
clonein classObject- Throws:
CloneNotSupportedException
-
compareTo
- Specified by:
compareToin interfaceComparable<T>
-
getAlias
Retrieves the name (alias) of the parameter value which can be the name of the operand (Operand) or the option argument (Option), depending on the sub-type inheriting from this interface. The parameter name is merely used for constructing the command line arguments syntaxStringviaOperand.toSyntax(CliContext)and the command line arguments detail description when creating a command line tool's help output. Attention: The alias can also be used as a key when putting anOperand's key/value-pair into a dictionary such as is done by theApplicationPropertiestype provided by therefcodes-properties-ext-runimeartifact! -
getType
-
getValue
-
parseArgs
public Operand<?>[] parseArgs(String[] aArgs, String[] aKeywords, CliContext aCliCtx) throws ArgsSyntaxException Parses the given command line arguments using the provided keyword set and CLI context.This method represents the core parsing operation. It evaluates this
Termor, if this term is an inner node, delegates parsing to its child terms.The
aKeywordsparameter defines reserved tokens such as option names that must not be interpreted as operand values.This method does not validate whether all arguments have been consumed. Superfluous arguments must be handled by the caller.
- Specified by:
parseArgsin interfaceTerm- Parameters:
aArgs- The command line arguments to parseaKeywords- Reserved option and keyword tokensaCliCtx- TheCliContextcontrolling parsing and rendering- Returns:
- The evaluated operands
- Throws:
ArgsSyntaxException- If the arguments do not match the syntax
-
getMatchCount
public int getMatchCount()Determines the number of args being matched by theTerm.parseArgs(String[], CliContext)(and similar) method(s) of the according syntax. This way we can determine which part of the syntax (tree) had most matches.- Specified by:
getMatchCountin interfaceMatchCountAccessor- Specified by:
getMatchCountin interfaceTerm- Returns:
- The number of args matching the according syntax (tree).
-
reset
public void reset()- Specified by:
resetin interfaceorg.refcodes.mixin.Resetable
-
getParsedArgs
Retrieves the (command line) args which represent thisOperandafter being "parsed" (provided with command line args).- Specified by:
getParsedArgsin interfaceOperand<T>- Specified by:
getParsedArgsin interfaceParsedArgsAccessor- Returns:
- The according args from the command line args.
-
toSchema
-
toString
-
approve
protected void approve()In case thisTermparticipated in successful parsing command line arguments, then thisTermgets approved by theCliArgsParser. An approval my trigger actions such as notifying registered lambda expressions upon approval, -
setParsedArgs
Sets the command line argument(s) representing theOperandand its value as parsed by theparseArgs(String[], String[], CliContext)method.- Parameters:
aArgs- The command line arguments representing thisOperandwith its value.
-
setValue
Sets the value for theOperandas parsed by theparseArgs(String[], String[], CliContext)method.- Parameters:
aValue- The value to be set for thisOperand.
-
toType
Double dispatch hook to be implemented by subclasses of theAbstractOperandfor converting a command line argument to the requiredOperand's type. In case conversion failed, then an according exception is to be thrown.- Parameters:
aArg- The command line argument to be converted to an instance of the given type T.- Returns:
- An instance of type T from the provided command line argument.
- Throws:
ParseArgsException- Thrown in case the provided command line arguments do not respect the required syntax or cannot be converted to the required type.
-
getDescription
- Specified by:
getDescriptionin interfaceorg.refcodes.mixin.DescriptionAccessor
-
getException
Retrieves theArgsSyntaxExceptionexception in case invokingTerm.parseArgs(String[], CliContext)failed. The exception (and the according suppressed ones alongside the causes) does not necessarily have been thrown by theTerm.parseArgs(String[], CliContext)method depending on the semantics of theTermhanding the exception (theAnyConditionprovides any exceptions it caught even though it did not throw them as of its semantics).- Specified by:
getExceptionin interfaceorg.refcodes.exception.ExceptionAccessor<ArgsSyntaxException>- Specified by:
getExceptionin interfaceTerm- Returns:
- The
ArgsSyntaxExceptionexception occurring while parsing the arguments.
-
setVisible
public void setVisible(boolean isVisible) Visibility in this context means displaying or hiding this
Term's existence to the user (defaults totrue).- Specified by:
setVisiblein interfaceTerm- Specified by:
setVisiblein interfaceorg.refcodes.graphical.VisibleAccessor.VisibleMutator
-
isVisible
-
toArgsDiff
Creates the difference between the provided set and the providedLists therein found argument arrays subset (as ofOperand.getParsedArgs()).- Parameters:
aArgs- The set to be used for the diff operation.aArgsSubset- The subset to be used for the diff operation being the lists containing theOperandinstances whose command line arguments are to be diffed.- Returns:
- The difference between the set and the subset.
-
toArgsDiff
Creates the difference between the provided set and the providedLists therein found argument arrays subset (as ofOperand.getParsedArgs()).- Parameters:
aArgs- The set to be used for the diff operation.aArgsSubset- The subset to be used for the diff operation being the lists containing theOperandinstances whose command line arguments are to be diffed.- Returns:
- The difference between the set and the subset.
-
toArgsDiff
Creates the difference between the provided set and the provided subset.- Parameters:
aArgs- The set to be used for the diff operation.aArgsSubset- The subset to be used for the diff operation.- Returns:
- The difference between the set and the subset.
-
toParsedArgs
Takes allOperandinstances found in the providedLists and adds all therein found argument arrays (as ofOperand.getParsedArgs()) to the result.
-