java.lang.Object
org.refcodes.cli.AbstractOperand<T>
- Type Parameters:
T- The generic type of theAbstractOperand's value.
- All Implemented Interfaces:
Cloneable,Comparable<Operand<?>>,MatchCountAccessor,Operand<T>,ParsedArgsAccessor,Synopsisable,Term,org.refcodes.exception.ExceptionAccessor<ArgsSyntaxException>,org.refcodes.mixin.AliasAccessor,org.refcodes.mixin.Clonable,org.refcodes.mixin.DescriptionAccessor,org.refcodes.mixin.Resetable,org.refcodes.mixin.Schemable,org.refcodes.mixin.TypeAccessor<T>,org.refcodes.mixin.ValueAccessor<T>
- Direct Known Subclasses:
AbstractOption,NoneOperand,Operation,StringOperand
The
AbstractOperand is an abstract implementation of an
Operand providing the boiler plate when implementing the
Operand interface.-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.mixin.AliasAccessor
org.refcodes.mixin.AliasAccessor.AliasBuilder<B extends org.refcodes.mixin.AliasAccessor.AliasBuilder<B>>, org.refcodes.mixin.AliasAccessor.AliasMutator, org.refcodes.mixin.AliasAccessor.AliasPropertyNested classes/interfaces inherited from interface org.refcodes.mixin.DescriptionAccessor
org.refcodes.mixin.DescriptionAccessor.DescriptionBuilder<B extends org.refcodes.mixin.DescriptionAccessor.DescriptionBuilder<B>>, org.refcodes.mixin.DescriptionAccessor.DescriptionMutator, org.refcodes.mixin.DescriptionAccessor.DescriptionPropertyNested classes/interfaces inherited from interface org.refcodes.exception.ExceptionAccessor
org.refcodes.exception.ExceptionAccessor.ExceptionBuilder<EXC extends Throwable,B extends org.refcodes.exception.ExceptionAccessor.ExceptionBuilder<EXC, B>>, org.refcodes.exception.ExceptionAccessor.ExceptionMutator<EXC extends Throwable>, org.refcodes.exception.ExceptionAccessor.ExceptionProperty<EXC extends Throwable> Nested classes/interfaces inherited from interface org.refcodes.cli.MatchCountAccessor
MatchCountAccessor.MatchCountBuilder<B extends MatchCountAccessor.MatchCountBuilder<B>>, MatchCountAccessor.MatchCountMutator, MatchCountAccessor.MatchCountPropertyNested classes/interfaces inherited from interface org.refcodes.cli.ParsedArgsAccessor
ParsedArgsAccessor.ParsedArgsMutator, ParsedArgsAccessor.ParsedArgsPropertyNested classes/interfaces inherited from interface org.refcodes.mixin.TypeAccessor
org.refcodes.mixin.TypeAccessor.TypeBuilder<T extends Object,B extends org.refcodes.mixin.TypeAccessor.TypeBuilder<T, B>>, org.refcodes.mixin.TypeAccessor.TypeMutator<T extends Object>, org.refcodes.mixin.TypeAccessor.TypeProperty<T extends Object> Nested classes/interfaces inherited from interface org.refcodes.mixin.ValueAccessor
org.refcodes.mixin.ValueAccessor.ValueBuilder<V extends Object,B extends org.refcodes.mixin.ValueAccessor.ValueBuilder<V, B>>, org.refcodes.mixin.ValueAccessor.ValueMutator<V extends Object>, org.refcodes.mixin.ValueAccessor.ValueProperty<V extends Object> -
Field Summary
Fields -
Constructor Summary
ConstructorsConstructorDescriptionAbstractOperand(Class<T> aType, String aAlias, String aDescription) Constructs anOperandwith the given arguments.AbstractOperand(Class<T> aType, String aAlias, String aDescription, Consumer<? extends Operand<T>> aConsumer) Constructs anOperandwith the given arguments.AbstractOperand(org.refcodes.struct.Relation<String, T> aProperty, Class<T> aType) Constructs anOperandwith the given arguments.AbstractOperand(org.refcodes.struct.Relation<String, T> aProperty, Class<T> aType, Consumer<? extends Operand<T>> aConsumer) Constructs anOperandwith the given arguments. -
Method Summary
Modifier and TypeMethodDescriptionprotected voidapprove()In case thisTermparticipated in successful parsing command line arguments, then thisTermgets approved by theArgsParser.clone()intgetAlias()Retrieves theArgsSyntaxExceptionexception in case invokingTerm.parseArgs(String[], CliContext)failed.intDetermines the number of args being matched by theTerm.parseArgs(String[], CliContext)(and similar) method(s) of the according syntax.String[]Retrieves the (command line) args which represent thisOperandafter being "parsed" (provided with command line args).getType()getValue()Operand<?>[]parseArgs(String[] aArgs, String[] aOptions, CliContext aCliContext) Parses the provided command line arguments and determines the according values by evaluating thisTerminstance or, in case of being a node in the syntax tree (such as aCondition, traversing the childTerminstances'Term.parseArgs(String[], String[], CliContext)methods.voidreset()protected voidsetParsedArgs(String[] aArgs) Sets the command line argument(s) representing theOperandand its value as parsed by theparseArgs(String[], String[], CliContext)method.protected voidSets the value for theOperandas parsed by theparseArgs(String[], String[], CliContext)method.protected static String[]toArgsDiff(String[] aArgs, String[] aArgsSubset) Creates the difference between the provided set and the provided subset.protected static String[]toArgsDiff(String[] aArgs, List<? extends Operand<?>> aArgsSubset) Creates the difference between the provided set and the providedLists therein found argument arrays subset (as ofOperand.getParsedArgs()).protected static String[]toArgsDiff(String[] aArgs, Operand<?>[] aArgsSubset) Creates the difference between the provided set and the providedLists therein found argument arrays subset (as ofOperand.getParsedArgs()).protected static String[]toParsedArgs(Operand<?>[]... aOperands) Takes allOperandinstances found in the providedLists and adds all therein found argument arrays (as ofOperand.getParsedArgs()) to the result.toSchema()toString()toSyntax(CliContext aCliCtx) This method is to be called from inside theTermhierarchy; use the methodSynopsisable.toSynopsis(SyntaxNotation)in case you invoke syntax retrieval from the rootTerm.protected abstract TDouble dispatch hook to be implemented by subclasses of theAbstractOperandfor converting a command line argument to the requiredOperand's type.Methods inherited from class java.lang.Object
equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface org.refcodes.mixin.DescriptionAccessor
getDescriptionMethods inherited from interface org.refcodes.cli.Operand
hasValue, toSpec, toSpec, toUsage, toUsage, toValueMethods inherited from interface org.refcodes.cli.Synopsisable
toSynopsis, toSynopsis, toSynopsis, toSynopsisMethods inherited from interface org.refcodes.cli.Term
getException, parseArgs, toSynopsis, toSyntax, toSyntax, toSyntax, toSyntaxMethods inherited from interface org.refcodes.mixin.ValueAccessor
getValueOr
-
Field Details
-
_matchCount
protected int _matchCount -
_description
-
_exception
-
-
Constructor Details
-
AbstractOperand
Constructs anOperandwith the given arguments.- Parameters:
aType- The type of the value returned by thegetValue()method.aAlias- TheOperand's name, used for syntax creation.aDescription- The description to be used (without any line breaks).
-
AbstractOperand
public AbstractOperand(Class<T> aType, String aAlias, String aDescription, Consumer<? extends Operand<T>> aConsumer) Constructs anOperandwith the given arguments.- Parameters:
aType- The type of the value returned by thegetValue()method.aAlias- TheOperand's name, used for syntax creation.aDescription- The description to be used (without any line breaks).aConsumer- TheConsumerbeing invoked in case thisOperandparticipated in successfully parsing the command line arguments.
-
AbstractOperand
Constructs anOperandwith the given arguments.- Parameters:
aProperty- The key (= alias) and the value for the operand.aType- The type of the value returned by thegetValue()method.
-
AbstractOperand
public AbstractOperand(org.refcodes.struct.Relation<String, T> aProperty, Class<T> aType, Consumer<? extends Operand<T>> aConsumer) Constructs anOperandwith the given arguments.- Parameters:
aProperty- The key (= alias) and the value for the operand.aType- The type of the value returned by thegetValue()method.aConsumer- TheConsumerbeing invoked in case thisOptionparticipated in successfully parsing the command line arguments.
-
-
Method Details
-
clone
- Specified by:
clonein interfaceorg.refcodes.mixin.Clonable- Overrides:
clonein classObject- Throws:
CloneNotSupportedException
-
compareTo
- Specified by:
compareToin interfaceComparable<T>
-
getAlias
Retrieves the name (alias) of the parameter value which can be the name of the operand (Operand) or the option argument (Option), depending on the sub-type inheriting from this interface. The parameter name is merely used for constructing the command line arguments syntaxStringviaTerm.toSyntax(CliContext)and the command line arguments detail description when creating a command line tool's help output. Attention: The alias can also be used as a key when putting anOperand's key/value-pair into a dictionary such as is done by theApplicationPropertiestype provided by therefcodes-properties-ext-runimeartifact! -
getType
- Specified by:
getTypein interfaceorg.refcodes.mixin.TypeAccessor<T>
-
getValue
-
parseArgs
public Operand<?>[] parseArgs(String[] aArgs, String[] aOptions, CliContext aCliContext) throws ArgsSyntaxException Parses the provided command line arguments and determines the according values by evaluating thisTerminstance or, in case of being a node in the syntax tree (such as aCondition, traversing the childTerminstances'Term.parseArgs(String[], String[], CliContext)methods. In case of successfully parsing thisTermand / or the childTerminstances, the evaluated command line arguments are returned: Depending on theTermsubclasses representing the evaluated command line arguments, instances ofFlagclasses,Optionclasses orOperandclasses may be found in the result. In case of parsing failure, an according exception is thrown. ATTENTION: This method does not test for superfluous command line arguments being passed; e.g. command line arguments not being evaluated by any of theTerminstance being traversed. This method is commonly used by a rootTerm'sParseArgs.evalArgs(String[])method, which delegates to theTerm.parseArgs(String[], String[], CliContext)method and after which it determines whether there are superfluous arguments to be taken care of (by throwing an according exception). Business logic therefore should invoke the root node'sTerm.parseArgs(String[], String[], CliContext)method as ignoring superfluous command line arguments will aCause unexpected behavior from the point of view of the invoker.- Specified by:
parseArgsin interfaceTerm- Parameters:
aArgs- The command line arguments to be parsed.aOptions- The list of options (short and as well as long) which are reserved and cannot be used as value.aCliContext- the cli context- Returns:
- The list of evaluated command line arguments being instances of
the
Operandinterfaces or its sub-types. - Throws:
ArgsSyntaxException- thrown in case of a command line arguments mismatch regarding provided and expected args.
-
getMatchCount
public int getMatchCount()Determines the number of args being matched by theTerm.parseArgs(String[], CliContext)(and similar) method(s) of the according syntax. This way we can determine which part of the syntax (tree) had most matches.- Specified by:
getMatchCountin interfaceMatchCountAccessor- Specified by:
getMatchCountin interfaceTerm- Returns:
- The number of args matching the according syntax (tree).
-
reset
public void reset()- Specified by:
resetin interfaceorg.refcodes.mixin.Resetable
-
getParsedArgs
Retrieves the (command line) args which represent thisOperandafter being "parsed" (provided with command line args).- Specified by:
getParsedArgsin interfaceOperand<T>- Specified by:
getParsedArgsin interfaceParsedArgsAccessor- Returns:
- The according args from the command line args.
-
toSchema
-
toString
-
toSyntax
This method is to be called from inside theTermhierarchy; use the methodSynopsisable.toSynopsis(SyntaxNotation)in case you invoke syntax retrieval from the rootTerm. Returns the human readable (verbose) syntax of thisTerminstance including, in case of being a node in the syntax tree (such as aCondition, the syntax of the childTerminstances. ATTENTION: As of different parenthesis settings for some notations regarding the rootTermand the childTerms, the methodTerm.toSyntax(CliContext)is called from inside theTermhierarchy. In case the syntax is to be retrieved from the rootTerm, then the applicable method to be called isSynopsisable.toSynopsis(SyntaxNotation), as for some notations it will for example not create the most outer braces.- Specified by:
toSyntaxin interfaceTerm- Parameters:
aCliCtx- TheCliContextfor which the syntax is being generated.- Returns:
- The human readable (verbose) command line arguments syntax.
-
approve
protected void approve()In case thisTermparticipated in successful parsing command line arguments, then thisTermgets approved by theArgsParser. An approval my trigger actions such as notifying registered lambda expressions upon approval, -
setParsedArgs
Sets the command line argument(s) representing theOperandand its value as parsed by theparseArgs(String[], String[], CliContext)method.- Parameters:
aArgs- The command line arguments representing thisOperandwith its value.
-
setValue
Sets the value for theOperandas parsed by theparseArgs(String[], String[], CliContext)method.- Parameters:
aValue- The value to be set for thisOperand.
-
toType
Double dispatch hook to be implemented by subclasses of theAbstractOperandfor converting a command line argument to the requiredOperand's type. In case conversion failed, then an according exception is to be thrown.- Parameters:
aArg- The command line argument to be converted to an instance of the given type T.- Returns:
- An instance of type T from the provided command line argument.
- Throws:
ParseArgsException- Thrown in case the provided command line arguments do not respect the required syntax or cannot be converted to the required type.
-
getDescription
- Specified by:
getDescriptionin interfaceorg.refcodes.mixin.DescriptionAccessor
-
getException
Retrieves theArgsSyntaxExceptionexception in case invokingTerm.parseArgs(String[], CliContext)failed. The exception (and the according suppressed ones alongside the causes) does not necessarily have been thrown by theTerm.parseArgs(String[], CliContext)method depending on the semantics of theTermhanding the exception (theAnyConditionprovides any exceptions it caught even though it did not throw them as of its semantics).- Specified by:
getExceptionin interfaceorg.refcodes.exception.ExceptionAccessor<ArgsSyntaxException>- Specified by:
getExceptionin interfaceTerm- Returns:
- The
ArgsSyntaxExceptionexception occurring while parsing the arguments.
-
toArgsDiff
Creates the difference between the provided set and the providedLists therein found argument arrays subset (as ofOperand.getParsedArgs()).- Parameters:
aArgs- The set to be used for the diff operation.aArgsSubset- The subset to be used for the diff operation being the lists containing theOperandinstances whose command line arguments are to be diffed.- Returns:
- The difference between the set and the subset.
-
toArgsDiff
Creates the difference between the provided set and the providedLists therein found argument arrays subset (as ofOperand.getParsedArgs()).- Parameters:
aArgs- The set to be used for the diff operation.aArgsSubset- The subset to be used for the diff operation being the lists containing theOperandinstances whose command line arguments are to be diffed.- Returns:
- The difference between the set and the subset.
-
toArgsDiff
Creates the difference between the provided set and the provided subset.- Parameters:
aArgs- The set to be used for the diff operation.aArgsSubset- The subset to be used for the diff operation.- Returns:
- The difference between the set and the subset.
-
toParsedArgs
Takes allOperandinstances found in the providedLists and adds all therein found argument arrays (as ofOperand.getParsedArgs()) to the result.
-