java.lang.Object
org.refcodes.cli.AbstractOperand<T>
- Type Parameters:
T- the generic type
- All Implemented Interfaces:
Cloneable,Comparable<Operand<?>>,ArgsAccessor,Operand<T>,Synopsisable,Syntaxable,org.refcodes.mixin.AliasAccessor,org.refcodes.mixin.Clonable,org.refcodes.mixin.DescriptionAccessor,org.refcodes.mixin.Resetable,org.refcodes.mixin.Schemable<CliSchema>,org.refcodes.mixin.TypeAccessor<T>,org.refcodes.mixin.ValueAccessor<T>
- Direct Known Subclasses:
AbstractOption,NoneOperand,Operation,StringOperand
The
AbstractOperand is an abstract implementation of an
Operand providing the boiler plate when implementing the
Operand interface.-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.mixin.AliasAccessor
org.refcodes.mixin.AliasAccessor.AliasBuilder<B extends org.refcodes.mixin.AliasAccessor.AliasBuilder<B>>, org.refcodes.mixin.AliasAccessor.AliasMutator, org.refcodes.mixin.AliasAccessor.AliasPropertyNested classes/interfaces inherited from interface org.refcodes.cli.ArgsAccessor
ArgsAccessor.ArgsMutator, ArgsAccessor.ArgsPropertyNested classes/interfaces inherited from interface org.refcodes.mixin.DescriptionAccessor
org.refcodes.mixin.DescriptionAccessor.DescriptionBuilder<B extends org.refcodes.mixin.DescriptionAccessor.DescriptionBuilder<B>>, org.refcodes.mixin.DescriptionAccessor.DescriptionMutator, org.refcodes.mixin.DescriptionAccessor.DescriptionPropertyNested classes/interfaces inherited from interface org.refcodes.mixin.TypeAccessor
org.refcodes.mixin.TypeAccessor.TypeBuilder<T extends Object,B extends org.refcodes.mixin.TypeAccessor.TypeBuilder<T, B>>, org.refcodes.mixin.TypeAccessor.TypeMutator<T extends Object>, org.refcodes.mixin.TypeAccessor.TypeProperty<T extends Object> Nested classes/interfaces inherited from interface org.refcodes.mixin.ValueAccessor
org.refcodes.mixin.ValueAccessor.ValueBuilder<V extends Object,B extends org.refcodes.mixin.ValueAccessor.ValueBuilder<V, B>>, org.refcodes.mixin.ValueAccessor.ValueMutator<V extends Object>, org.refcodes.mixin.ValueAccessor.ValueProperty<V extends Object> -
Field Summary
Fields -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionclone()intgetAlias()String[]getArgs()Retrieves the command line arguments from the args property.getType()getValue()Parses the provided command line arguments and determines the according values by evaluating thisSyntaxableinstance or, in case of being a node in the syntax tree (such as aArgsSyntax, traversing the childSyntaxableinstances'Syntaxable.parseArgs(String[], String[])methods.voidreset()protected voidSets the command line argument(s) representing theOperandand its value as parsed by theparseArgs(String[], String[])method.protected voidSets the value for theOperandas parsed by theparseArgs(String[], String[])method.toSchema()toState()TheSyntaxable.toState()method might be used by theObject.toString()method and prints out the state of the syntaxable and (if any) its children.toString()toSynopsis(SyntaxNotation aSyntaxNotation, String aOptEscCode, String aParamEscCode, String aResetEscCode) Returns the human readable (verbose) syntax of implementing class ATTENTION: As of different parenthesis settings for some notations regarding the rootSyntaxableand the childSyntaxables, the methodSyntaxable.toSyntax(SyntaxNotation, String, String, String)is called from inside aSyntaxablehierarchy.toSyntax(SyntaxNotation aSyntaxNotation, String aOptEscCode, String aParamEscCode, String aResetEscCode) This method is to be called from inside theSyntaxablehierarchy; use the methodSynopsisable.toSynopsis(SyntaxNotation)in case you invoke syntax retrieval from the rootSyntaxable.protected abstract TDouble dispatch hook to be implemented by subclasses of theAbstractOperandfor converting a command line argument to the requiredOperand's type.Methods inherited from class java.lang.Object
equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface org.refcodes.cli.Synopsisable
toSynopsis, toSynopsis, toSynopsis, toSynopsisMethods inherited from interface org.refcodes.cli.Syntaxable
parseArgs, toSyntax, toSyntax, toSyntaxMethods inherited from interface org.refcodes.mixin.ValueAccessor
getValueOr
-
Field Details
-
_value
-
-
Constructor Details
-
AbstractOperand
Constructs aOperandwith the given arguments.- Parameters:
aType- The type of the value returned by thegetValue()method.aAlias- TheOperand's name, used for syntax creation.aDescription- A description without any line breaks.
-
AbstractOperand
Instantiates a new operand.- Parameters:
aProperty- The key (= alias) and the value for the operand.aType- the type
-
-
Method Details
-
parseArgs
Parses the provided command line arguments and determines the according values by evaluating thisSyntaxableinstance or, in case of being a node in the syntax tree (such as aArgsSyntax, traversing the childSyntaxableinstances'Syntaxable.parseArgs(String[], String[])methods. In case of successfully parsing thisSyntaxableand / or the childSyntaxableinstances, the evaluated command line arguments are returned: Depending on theSyntaxablesubclasses representing the evaluated command line arguments, instances ofFlagclasses,Optionclasses orOperandclasses may be found in the result. In case of parsing failure, an according exception is thrown. ATTENTION: This method does not test for superfluous command line arguments being passed; e.g. command line arguments not being evaluated by any of theSyntaxableinstance being traversed. This method is commonly used by a rootSyntaxable'sArgsParser.evalArgs(String[])method, which delegates to theSyntaxable.parseArgs(String[], String[])method and after which it determines whether there are superfluous arguments to be taken care of (by throwing an according exception). Business logic therefore should invoke the root node'sSyntaxable.parseArgs(String[], String[])method as ignoring superfluous command line arguments will cause unexpected behavior from the point of view of the invoker.- Specified by:
parseArgsin interfaceSyntaxable- Parameters:
aArgs- The command line arguments to be parsed.aOptions- The list of options (short and as well as long) which are reserved and cannot be used as value.- Returns:
- The list of evaluated command line arguments being instances of
the
Operandinterfaces or its sub-types. - Throws:
ArgsSyntaxException- thrown in case of a command line arguments mismatch regarding provided and expected args.
-
getDescription
- Specified by:
getDescriptionin interfaceorg.refcodes.mixin.DescriptionAccessor
-
toSyntax
public String toSyntax(SyntaxNotation aSyntaxNotation, String aOptEscCode, String aParamEscCode, String aResetEscCode) This method is to be called from inside theSyntaxablehierarchy; use the methodSynopsisable.toSynopsis(SyntaxNotation)in case you invoke syntax retrieval from the rootSyntaxable. Returns the human readable (verbose) syntax of thisSyntaxableinstance including, in case of being a node in the syntax tree (such as aArgsSyntax, the syntax of the childSyntaxableinstances. ATTENTION: As of different parenthesis settings for some notations regarding the rootSyntaxableand the childSyntaxables, the methodSyntaxable.toSyntax(SyntaxNotation, String, String, String)is called from inside theSyntaxablehierarchy. In case the syntax is to be retrieved from the rootSyntaxable, then the applicable method to be called isSynopsisable.toSynopsis(SyntaxNotation), as for some notations it will for example not create the most outer braces.- Specified by:
toSyntaxin interfaceSyntaxable- Parameters:
aSyntaxNotation- The syntax notation used for generating the command line arguments syntax.aOptEscCode- The escape code to be used when processing an option, e.g. this can be an ANSI Escape-Code to highlight the option.aParamEscCode- The escape code to be used when processing a keyword, e.g. this can be an ANSI Escape-Code to highlight the option and/or parameters.aResetEscCode- The escape code to close (reset) any Escape-Code being set before.- Returns:
- The human readable (verbose) command line arguments syntax.
-
getAlias
Retrieves the name (alias) of the parameter value which can be the name of the operand (Operand) or the option argument (Option), depending on the sub-type inheriting from this interface. The parameter name is merely used for constructing the command line arguments syntaxStringviaSyntaxable.toSyntax(SyntaxNotation, String, String, String)and the command line arguments detail description when creating a command line tool's help output. Attention: The alias can also be used as a key when putting anOperand's key/value-pair into a dictionary such as is done by theRuntimePropertiestype provided by therefcodes-properties-ext-runimeartifact! -
getType
- Specified by:
getTypein interfaceorg.refcodes.mixin.TypeAccessor<T>
-
getValue
-
getArgs
Retrieves the command line arguments from the args property.- Specified by:
getArgsin interfaceArgsAccessor- Specified by:
getArgsin interfaceOperand<T>- Returns:
- The command line arguments stored by the args property.
-
reset
public void reset()- Specified by:
resetin interfaceorg.refcodes.mixin.Resetable
-
toState
TheSyntaxable.toState()method might be used by theObject.toString()method and prints out the state of the syntaxable and (if any) its children. Even in case parsing command line arguments failed, the state till failure can be inspected with this method.- Specified by:
toStatein interfaceSyntaxable- Returns:
- The state of this
Syntaxableinstance and (if any) its children.
-
toString
-
compareTo
- Specified by:
compareToin interfaceComparable<T>
-
clone
- Specified by:
clonein interfaceorg.refcodes.mixin.Clonable- Overrides:
clonein classObject- Throws:
CloneNotSupportedException
-
toSchema
- Specified by:
toSchemain interfaceorg.refcodes.mixin.Schemable<T>
-
setValue
Sets the value for theOperandas parsed by theparseArgs(String[], String[])method.- Parameters:
aValue- The value to be set for thisOperand.
-
setArgs
Sets the command line argument(s) representing theOperandand its value as parsed by theparseArgs(String[], String[])method.- Parameters:
aArgs- The command line arguments representing thisOperandwith its value.
-
toType
Double dispatch hook to be implemented by subclasses of theAbstractOperandfor converting a command line argument to the requiredOperand's type. In case conversion failed, then an according exception is to be thrown.- Parameters:
aArg- The command line argument to be converted to an instance of the given type T.- Returns:
- An instance of type T from the provided command line argument.
- Throws:
ParseArgsException- Thrown in case the provided command line arguments do not respect the required syntax or cannot be converted to the required type.
-
toSynopsis
public String toSynopsis(SyntaxNotation aSyntaxNotation, String aOptEscCode, String aParamEscCode, String aResetEscCode) Returns the human readable (verbose) syntax of implementing class ATTENTION: As of different parenthesis settings for some notations regarding the rootSyntaxableand the childSyntaxables, the methodSyntaxable.toSyntax(SyntaxNotation, String, String, String)is called from inside aSyntaxablehierarchy. In case the syntax is to be retrieved from the rootSyntaxableor an encapsulating and different type, then the applicable method to be called isSynopsisable.toSynopsis(SyntaxNotation), as for some notations it will for example not create the most outer braces.- Specified by:
toSynopsisin interfaceSynopsisable- Parameters:
aSyntaxNotation- The syntax notation used for generating the command line arguments syntax.aOptEscCode- The escape code to be used when processing an option, e.g. this can be an ANSI Escape-Code to highlight the option.aParamEscCode- The escape code to be used when processing am argument, e.g. this can be an ANSI Escape-Code to highlight the option.aResetEscCode- The escape code to close (reset) any Escape-Code being set before.- Returns:
- The human readable (verbose) command line arguments syntax.
-