Class AbstractOption<T>

java.lang.Object
org.refcodes.cli.AbstractOperand<T>
org.refcodes.cli.AbstractOption<T>
Type Parameters:
T - The generic type of the AbstractOption's value.
All Implemented Interfaces:
Cloneable, Comparable<Operand<?>>, MatchCountAccessor, Operand<T>, Option<T>, ParsedArgsAccessor, Synopsisable, Term, org.refcodes.exception.ExceptionAccessor<ArgsSyntaxException>, org.refcodes.graphical.VisibleAccessor, org.refcodes.graphical.VisibleAccessor.VisibleBuilder<Term>, org.refcodes.graphical.VisibleAccessor.VisibleMutator, org.refcodes.graphical.VisibleAccessor.VisibleProperty, org.refcodes.mixin.AliasAccessor, org.refcodes.mixin.Clonable, org.refcodes.mixin.DescriptionAccessor, org.refcodes.mixin.Resetable, org.refcodes.mixin.TypeAccessor<T>, org.refcodes.mixin.ValueAccessor<T>, org.refcodes.schema.Schemable
Direct Known Subclasses:
AbstractProperty, BooleanOption, CharOption, DoubleOption, EnumOption, FileOption, Flag, FloatOption, IntOption, LongOption, StringOption

public abstract class AbstractOption<T> extends AbstractOperand<T> implements Option<T>
The AbstractOption is an abstract implementation of an Option providing the boiler plate when implementing the Option interface.
  • Field Details

    • _description

      protected String _description
    • _exception

      protected ArgsSyntaxException _exception
    • _isVisible

      protected boolean _isVisible
  • Constructor Details

    • AbstractOption

      public AbstractOption(Character aShortOption, String aLongOption, Class<T> aType, String aAlias, String aDescription)
      Constructs an AbstractOption with the given arguments.
      Parameters:
      aShortOption - The short-option being a single character with the additional single hyphen-minus "-" prefix.
      aLongOption - The long-option being a multi-character sequence with at least two characters with the additional double hyphen-minus "--" prefix.
      aType - The type of the value returned by the AbstractOperand.getValue() method.
      aAlias - The option argument's name to be used when constructing the syntax.
      aDescription - The description to be used (without any line breaks).
    • AbstractOption

      public AbstractOption(Character aShortOption, String aLongOption, Class<T> aType, String aAlias, String aDescription, Consumer<? extends Operand<T>> aConsumer)
      Constructs an AbstractOption with the given arguments.
      Parameters:
      aShortOption - The short-option being a single character with the additional single hyphen-minus "-" prefix.
      aLongOption - The long-option being a multi-character sequence with at least two characters with the additional double hyphen-minus "--" prefix.
      aType - The type of the value returned by the AbstractOperand.getValue() method.
      aAlias - The option argument's name to be used when constructing the syntax.
      aDescription - The description to be used (without any line breaks).
      aConsumer - The Consumer being invoked in case this Option participated in successfully parsing the command line arguments.
    • AbstractOption

      public AbstractOption(org.refcodes.struct.Relation<String,T> aProperty, Class<T> aType)
      Constructs an AbstractOption with the given arguments.
      Parameters:
      aProperty - The key (= alias) and the value for the operand.
      aType - The type of the value returned by the AbstractOperand.getValue() method.
    • AbstractOption

      public AbstractOption(org.refcodes.struct.Relation<String,T> aProperty, Class<T> aType, Consumer<? extends Operand<T>> aConsumer)
      Constructs an AbstractOption with the given arguments.
      Parameters:
      aProperty - The key (= alias) and the value for the operand.
      aType - The type of the value returned by the AbstractOperand.getValue() method.
      aConsumer - The Consumer being invoked in case this Option participated in successfully parsing the command line arguments.
    • AbstractOption

      public AbstractOption(String aLongOption, Class<T> aType, String aDescription)
      Constructs an AbstractOption with the given arguments.
      Parameters:
      aLongOption - The long-option being a multi-character sequence with at least two characters with the additional double hyphen-minus "--" prefix.
      aType - The type of the value returned by the AbstractOperand.getValue() method.
      aDescription - The description to be used (without any line breaks).
    • AbstractOption

      public AbstractOption(String aLongOption, Class<T> aType, String aDescription, Consumer<? extends Operand<T>> aConsumer)
      Constructs an AbstractOption with the given arguments.
      Parameters:
      aLongOption - The long-option being a multi-character sequence with at least two characters with the additional double hyphen-minus "--" prefix.
      aType - The type of the value returned by the AbstractOperand.getValue() method.
      aDescription - The description to be used (without any line breaks).
      aConsumer - The Consumer being invoked in case this Option participated in successfully parsing the command line arguments.
    • AbstractOption

      public AbstractOption(String aLongOption, Class<T> aType, String aAlias, String aDescription)
      Constructs an AbstractOption with the given arguments.
      Parameters:
      aLongOption - The long-option being a multi-character sequence with at least two characters with the additional double hyphen-minus "--" prefix.
      aType - The type of the value returned by the AbstractOperand.getValue() method.
      aAlias - The option argument's name to be used when constructing the syntax.
      aDescription - The description to be used (without any line breaks).
    • AbstractOption

      public AbstractOption(String aLongOption, Class<T> aType, String aAlias, String aDescription, Consumer<? extends Operand<T>> aConsumer)
      Constructs an AbstractOption with the given arguments.
      Parameters:
      aLongOption - The long-option being a multi-character sequence with at least two characters with the additional double hyphen-minus "--" prefix.
      aType - The type of the value returned by the AbstractOperand.getValue() method.
      aAlias - The option argument's name to be used when constructing the syntax.
      aDescription - The description to be used (without any line breaks).
      aConsumer - The Consumer being invoked in case this Option participated in successfully parsing the command line arguments.
    • AbstractOption

      protected AbstractOption(Character aShortOption, String aLongOption, Class<T> aType, String aDescription)
      Constructs an AbstractOption with the given arguments.
      Parameters:
      aShortOption - The short-option being a single character with the additional single hyphen-minus "-" prefix.
      aLongOption - The long-option being a multi-character sequence with at least two characters with the additional double hyphen-minus "--" prefix.
      aType - The type of the value returned by the AbstractOperand.getValue() method.
      aDescription - The description to be used (without any line breaks).
    • AbstractOption

      protected AbstractOption(Character aShortOption, String aLongOption, Class<T> aType, String aDescription, Consumer<? extends Operand<T>> aConsumer)
      Constructs an AbstractOption with the given arguments.
      Parameters:
      aShortOption - The short-option being a single character with the additional single hyphen-minus "-" prefix.
      aLongOption - The long-option being a multi-character sequence with at least two characters with the additional double hyphen-minus "--" prefix.
      aType - The type of the value returned by the AbstractOperand.getValue() method.
      aDescription - The description to be used (without any line breaks).
      aConsumer - The Consumer being invoked in case this Option participated in successfully parsing the command line arguments.
  • Method Details

    • clone

      public Object clone() throws CloneNotSupportedException
      Specified by:
      clone in interface org.refcodes.mixin.Clonable
      Overrides:
      clone in class AbstractOperand<T>
      Throws:
      CloneNotSupportedException
    • getLongOption

      public String getLongOption()
      Returns the long-option representing an Option instance. A long option usually is being prefixed with a double hyphen-minus "--" as defined in ArgsPrefix.POSIX_LONG_OPTION.
      Specified by:
      getLongOption in interface Option<T>
      Returns:
      The long-option String.
    • getShortOption

      public Character getShortOption()
      Returns the short-option representing an Option instance. A short option usually is being prefixed with a single hyphen-minus "-" as defined in ArgsPrefix.POSIX_SHORT_OPTION.
      Specified by:
      getShortOption in interface Option<T>
      Returns:
      The short-option String.
    • parseArgs

      public Operand<?>[] parseArgs(String[] aArgs, String[] aKeywords, CliContext aCliCtx) throws ArgsSyntaxException
      Parses the given command line arguments using the provided keyword set and CLI context.

      This method represents the core parsing operation. It evaluates this Term or, if this term is an inner node, delegates parsing to its child terms.

      The aKeywords parameter defines reserved tokens such as option names that must not be interpreted as operand values.

      This method does not validate whether all arguments have been consumed. Superfluous arguments must be handled by the caller.

      Specified by:
      parseArgs in interface Term
      Overrides:
      parseArgs in class AbstractOperand<T>
      Parameters:
      aArgs - The command line arguments to parse
      aKeywords - Reserved option and keyword tokens
      aCliCtx - The CliContext controlling parsing and rendering
      Returns:
      The evaluated operands
      Throws:
      ArgsSyntaxException - If the arguments do not match the syntax
    • toSchema

      public CliSchema toSchema()
      Specified by:
      toSchema in interface org.refcodes.schema.Schemable
      Specified by:
      toSchema in interface Term
      Overrides:
      toSchema in class AbstractOperand<T>
    • toString

      public String toString()
      Overrides:
      toString in class AbstractOperand<T>
    • toException

      protected UnknownArgsException toException(String[] aArgs, CliContext aCliCtx)
      Convenience method to create an UnknownArgsException.
      Parameters:
      aArgs - The arguments participating tin the exception.
      aCliCtx - The context to use when creating the exception's details.
      Returns:
      The accordingly created ArgsSyntaxException instance.
    • setParsedArgs

      protected void setParsedArgs(String[] aArgs)
      Sets the command line argument(s) representing the Operand and its value as parsed by the AbstractOperand.parseArgs(String[], String[], CliContext) method.
      Overrides:
      setParsedArgs in class AbstractOperand<T>
      Parameters:
      aArgs - The command line arguments representing this Operand with its value.
    • setValue

      protected void setValue(T aValue)
      Sets the value for the Operand as parsed by the AbstractOperand.parseArgs(String[], String[], CliContext) method.
      Overrides:
      setValue in class AbstractOperand<T>
      Parameters:
      aValue - The value to be set for this Operand.
    • contains

      protected static boolean contains(String[] aArgs, String aArg)
      Determines whether a given String is contained in the given String array.
      Parameters:
      aArgs - The String array to be tested whether it contains the given String.
      aArg - The String to be tested whether it is contained in the provided String array.
      Returns:
      True in case the String is contained in the array, else false.
    • getDescription

      public String getDescription()
      Specified by:
      getDescription in interface org.refcodes.mixin.DescriptionAccessor
    • getException

      public ArgsSyntaxException getException()
      Retrieves the ArgsSyntaxException exception in case invoking Term.parseArgs(String[], CliContext) failed. The exception (and the according suppressed ones alongside the causes) does not necessarily have been thrown by the Term.parseArgs(String[], CliContext) method depending on the semantics of the Term handing the exception (the AnyCondition provides any exceptions it caught even though it did not throw them as of its semantics).
      Specified by:
      getException in interface org.refcodes.exception.ExceptionAccessor<ArgsSyntaxException>
      Specified by:
      getException in interface Term
      Returns:
      The ArgsSyntaxException exception occurring while parsing the arguments.
    • setVisible

      public void setVisible(boolean isVisible)

      Visibility in this context means displaying or hiding this Term's existence to the user (defaults to true).

      Specified by:
      setVisible in interface Term
      Specified by:
      setVisible in interface org.refcodes.graphical.VisibleAccessor.VisibleMutator
    • isVisible

      public boolean isVisible()

      Visibility in this context means displaying or hiding this Term's existence to the user (defaults to true).

      Specified by:
      isVisible in interface Term
      Specified by:
      isVisible in interface org.refcodes.graphical.VisibleAccessor
    • toArgsDiff

      protected static String[] toArgsDiff(String[] aArgs, List<? extends Operand<?>> aArgsSubset)
      Creates the difference between the provided set and the provided Lists therein found argument arrays subset (as of Operand.getParsedArgs()).
      Parameters:
      aArgs - The set to be used for the diff operation.
      aArgsSubset - The subset to be used for the diff operation being the lists containing the Operand instances whose command line arguments are to be diffed.
      Returns:
      The difference between the set and the subset.
    • toArgsDiff

      protected static String[] toArgsDiff(String[] aArgs, Operand<?>[] aArgsSubset)
      Creates the difference between the provided set and the provided Lists therein found argument arrays subset (as of Operand.getParsedArgs()).
      Parameters:
      aArgs - The set to be used for the diff operation.
      aArgsSubset - The subset to be used for the diff operation being the lists containing the Operand instances whose command line arguments are to be diffed.
      Returns:
      The difference between the set and the subset.
    • toArgsDiff

      protected static String[] toArgsDiff(String[] aArgs, String[] aArgsSubset)
      Creates the difference between the provided set and the provided subset.
      Parameters:
      aArgs - The set to be used for the diff operation.
      aArgsSubset - The subset to be used for the diff operation.
      Returns:
      The difference between the set and the subset.
    • toParsedArgs

      protected static String[] toParsedArgs(Operand<?>[]... aOperands)
      Takes all Operand instances found in the provided Lists and adds all therein found argument arrays (as of Operand.getParsedArgs()) to the result.
      Parameters:
      aOperands - The lists containing the Operand instances whose command line arguments are to be added to the result.
      Returns:
      All the command line arguments detected in the provided Operands Lists.