Class AbstractOption<T>
java.lang.Object
org.refcodes.cli.AbstractOperand<T>
org.refcodes.cli.AbstractOption<T>
- Type Parameters:
T- The generic type of theAbstractOption's value.
- All Implemented Interfaces:
Cloneable,Comparable<Operand<?>>,MatchCountAccessor,Operand<T>,Option<T>,ParsedArgsAccessor,Synopsisable,Term,org.refcodes.exception.ExceptionAccessor<ArgsSyntaxException>,org.refcodes.graphical.VisibleAccessor,org.refcodes.graphical.VisibleAccessor.VisibleBuilder<Term>,org.refcodes.graphical.VisibleAccessor.VisibleMutator,org.refcodes.graphical.VisibleAccessor.VisibleProperty,org.refcodes.mixin.AliasAccessor,org.refcodes.mixin.Clonable,org.refcodes.mixin.DescriptionAccessor,org.refcodes.mixin.Resetable,org.refcodes.mixin.TypeAccessor<T>,org.refcodes.mixin.ValueAccessor<T>,org.refcodes.schema.Schemable
- Direct Known Subclasses:
AbstractProperty,BooleanOption,CharOption,DoubleOption,EnumOption,FileOption,Flag,FloatOption,IntOption,LongOption,StringOption
The
AbstractOption is an abstract implementation of an Option
providing the boiler plate when implementing the Option interface.-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.mixin.AliasAccessor
org.refcodes.mixin.AliasAccessor.AliasBuilder<B extends org.refcodes.mixin.AliasAccessor.AliasBuilder<B>>, org.refcodes.mixin.AliasAccessor.AliasMutator, org.refcodes.mixin.AliasAccessor.AliasPropertyNested classes/interfaces inherited from interface org.refcodes.mixin.DescriptionAccessor
org.refcodes.mixin.DescriptionAccessor.DescriptionBuilder<B extends org.refcodes.mixin.DescriptionAccessor.DescriptionBuilder<B>>, org.refcodes.mixin.DescriptionAccessor.DescriptionMutator, org.refcodes.mixin.DescriptionAccessor.DescriptionPropertyNested classes/interfaces inherited from interface org.refcodes.exception.ExceptionAccessor
org.refcodes.exception.ExceptionAccessor.ExceptionBuilder<EXC extends Throwable,B extends org.refcodes.exception.ExceptionAccessor.ExceptionBuilder<EXC, B>>, org.refcodes.exception.ExceptionAccessor.ExceptionMutator<EXC extends Throwable>, org.refcodes.exception.ExceptionAccessor.ExceptionProperty<EXC extends Throwable> Nested classes/interfaces inherited from interface org.refcodes.cli.MatchCountAccessor
MatchCountAccessor.MatchCountBuilder<B extends MatchCountAccessor.MatchCountBuilder<B>>, MatchCountAccessor.MatchCountMutator, MatchCountAccessor.MatchCountPropertyNested classes/interfaces inherited from interface org.refcodes.cli.ParsedArgsAccessor
ParsedArgsAccessor.ParsedArgsMutator, ParsedArgsAccessor.ParsedArgsPropertyNested classes/interfaces inherited from interface org.refcodes.mixin.TypeAccessor
org.refcodes.mixin.TypeAccessor.TypeBuilder<T,B extends org.refcodes.mixin.TypeAccessor.TypeBuilder<T, B>>, org.refcodes.mixin.TypeAccessor.TypeMutator<T>, org.refcodes.mixin.TypeAccessor.TypeProperty<T> Nested classes/interfaces inherited from interface org.refcodes.mixin.ValueAccessor
org.refcodes.mixin.ValueAccessor.ValueBuilder<V,B extends org.refcodes.mixin.ValueAccessor.ValueBuilder<V, B>>, org.refcodes.mixin.ValueAccessor.ValueMutator<V>, org.refcodes.mixin.ValueAccessor.ValueProperty<V> Nested classes/interfaces inherited from interface org.refcodes.graphical.VisibleAccessor
org.refcodes.graphical.VisibleAccessor.VisibleBuilder<B extends org.refcodes.graphical.VisibleAccessor.VisibleBuilder<B>>, org.refcodes.graphical.VisibleAccessor.VisibleMutator, org.refcodes.graphical.VisibleAccessor.VisibleProperty -
Field Summary
FieldsModifier and TypeFieldDescriptionprotected Stringprotected ArgsSyntaxExceptionprotected booleanFields inherited from class org.refcodes.cli.AbstractOperand
_matchCount -
Constructor Summary
ConstructorsModifierConstructorDescriptionprotectedConstructs anAbstractOptionwith the given arguments.AbstractOption(Character aShortOption, String aLongOption, Class<T> aType, String aAlias, String aDescription) Constructs anAbstractOptionwith the given arguments.AbstractOption(Character aShortOption, String aLongOption, Class<T> aType, String aAlias, String aDescription, Consumer<? extends Operand<T>> aConsumer) Constructs anAbstractOptionwith the given arguments.protectedAbstractOption(Character aShortOption, String aLongOption, Class<T> aType, String aDescription, Consumer<? extends Operand<T>> aConsumer) Constructs anAbstractOptionwith the given arguments.AbstractOption(String aLongOption, Class<T> aType, String aDescription) Constructs anAbstractOptionwith the given arguments.Constructs anAbstractOptionwith the given arguments.AbstractOption(String aLongOption, Class<T> aType, String aAlias, String aDescription, Consumer<? extends Operand<T>> aConsumer) Constructs anAbstractOptionwith the given arguments.AbstractOption(String aLongOption, Class<T> aType, String aDescription, Consumer<? extends Operand<T>> aConsumer) Constructs anAbstractOptionwith the given arguments.AbstractOption(org.refcodes.struct.Relation<String, T> aProperty, Class<T> aType) Constructs anAbstractOptionwith the given arguments.AbstractOption(org.refcodes.struct.Relation<String, T> aProperty, Class<T> aType, Consumer<? extends Operand<T>> aConsumer) Constructs anAbstractOptionwith the given arguments. -
Method Summary
Modifier and TypeMethodDescriptionclone()protected static booleanRetrieves theArgsSyntaxExceptionexception in case invokingTerm.parseArgs(String[], CliContext)failed.Returns the long-option representing anOptioninstance.Returns the short-option representing anOptioninstance.booleanOperand<?>[]parseArgs(String[] aArgs, String[] aKeywords, CliContext aCliCtx) Parses the given command line arguments using the provided keyword set and CLI context.protected voidsetParsedArgs(String[] aArgs) Sets the command line argument(s) representing theOperandand its value as parsed by theAbstractOperand.parseArgs(String[], String[], CliContext)method.protected voidSets the value for theOperandas parsed by theAbstractOperand.parseArgs(String[], String[], CliContext)method.voidsetVisible(boolean isVisible) protected static String[]toArgsDiff(String[] aArgs, String[] aArgsSubset) Creates the difference between the provided set and the provided subset.protected static String[]toArgsDiff(String[] aArgs, List<? extends Operand<?>> aArgsSubset) Creates the difference between the provided set and the providedLists therein found argument arrays subset (as ofOperand.getParsedArgs()).protected static String[]toArgsDiff(String[] aArgs, Operand<?>[] aArgsSubset) Creates the difference between the provided set and the providedLists therein found argument arrays subset (as ofOperand.getParsedArgs()).protected UnknownArgsExceptiontoException(String[] aArgs, CliContext aCliCtx) Convenience method to create anUnknownArgsException.protected static String[]toParsedArgs(Operand<?>[]... aOperands) Takes allOperandinstances found in the providedLists and adds all therein found argument arrays (as ofOperand.getParsedArgs()) to the result.toSchema()toString()Methods inherited from class org.refcodes.cli.AbstractOperand
approve, compareTo, getAlias, getMatchCount, getParsedArgs, getType, getValue, reset, toTypeMethods inherited from class java.lang.Object
equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface java.lang.Comparable
compareToMethods inherited from interface org.refcodes.mixin.DescriptionAccessor
getDescriptionMethods inherited from interface org.refcodes.cli.Operand
getAlias, getParsedArgs, getValue, hasValue, toSpec, toSpec, toSpec, toSpec, toUsage, toValueMethods inherited from interface org.refcodes.cli.Option
toKeywords, toLongOption, toShortOption, toSpec, toSyntax, toUsageMethods inherited from interface org.refcodes.mixin.Resetable
resetMethods inherited from interface org.refcodes.schema.Schemable
toSchemaMethods inherited from interface org.refcodes.cli.Synopsisable
toSynopsis, toSynopsis, toSynopsis, toSynopsisMethods inherited from interface org.refcodes.cli.Term
argsParser, getException, getMatchCount, isVisible, parseArgs, setVisible, toSynopsis, toSyntax, toSyntax, toSyntax, toSyntaxMethods inherited from interface org.refcodes.mixin.TypeAccessor
getTypeMethods inherited from interface org.refcodes.mixin.ValueAccessor
getValueOrMethods inherited from interface org.refcodes.graphical.VisibleAccessor.VisibleBuilder
withHide, withShow, withVisibleMethods inherited from interface org.refcodes.graphical.VisibleAccessor.VisibleMutator
hide, showMethods inherited from interface org.refcodes.graphical.VisibleAccessor.VisibleProperty
letVisible
-
Field Details
-
_description
-
_exception
-
_isVisible
protected boolean _isVisible
-
-
Constructor Details
-
AbstractOption
public AbstractOption(Character aShortOption, String aLongOption, Class<T> aType, String aAlias, String aDescription) Constructs anAbstractOptionwith the given arguments.- Parameters:
aShortOption- The short-option being a single character with the additional single hyphen-minus "-" prefix.aLongOption- The long-option being a multi-character sequence with at least two characters with the additional double hyphen-minus "--" prefix.aType- The type of the value returned by theAbstractOperand.getValue()method.aAlias- The option argument's name to be used when constructing the syntax.aDescription- The description to be used (without any line breaks).
-
AbstractOption
public AbstractOption(Character aShortOption, String aLongOption, Class<T> aType, String aAlias, String aDescription, Consumer<? extends Operand<T>> aConsumer) Constructs anAbstractOptionwith the given arguments.- Parameters:
aShortOption- The short-option being a single character with the additional single hyphen-minus "-" prefix.aLongOption- The long-option being a multi-character sequence with at least two characters with the additional double hyphen-minus "--" prefix.aType- The type of the value returned by theAbstractOperand.getValue()method.aAlias- The option argument's name to be used when constructing the syntax.aDescription- The description to be used (without any line breaks).aConsumer- TheConsumerbeing invoked in case thisOptionparticipated in successfully parsing the command line arguments.
-
AbstractOption
Constructs anAbstractOptionwith the given arguments.- Parameters:
aProperty- The key (= alias) and the value for the operand.aType- The type of the value returned by theAbstractOperand.getValue()method.
-
AbstractOption
public AbstractOption(org.refcodes.struct.Relation<String, T> aProperty, Class<T> aType, Consumer<? extends Operand<T>> aConsumer) Constructs anAbstractOptionwith the given arguments.- Parameters:
aProperty- The key (= alias) and the value for the operand.aType- The type of the value returned by theAbstractOperand.getValue()method.aConsumer- TheConsumerbeing invoked in case thisOptionparticipated in successfully parsing the command line arguments.
-
AbstractOption
Constructs anAbstractOptionwith the given arguments.- Parameters:
aLongOption- The long-option being a multi-character sequence with at least two characters with the additional double hyphen-minus "--" prefix.aType- The type of the value returned by theAbstractOperand.getValue()method.aDescription- The description to be used (without any line breaks).
-
AbstractOption
public AbstractOption(String aLongOption, Class<T> aType, String aDescription, Consumer<? extends Operand<T>> aConsumer) Constructs anAbstractOptionwith the given arguments.- Parameters:
aLongOption- The long-option being a multi-character sequence with at least two characters with the additional double hyphen-minus "--" prefix.aType- The type of the value returned by theAbstractOperand.getValue()method.aDescription- The description to be used (without any line breaks).aConsumer- TheConsumerbeing invoked in case thisOptionparticipated in successfully parsing the command line arguments.
-
AbstractOption
Constructs anAbstractOptionwith the given arguments.- Parameters:
aLongOption- The long-option being a multi-character sequence with at least two characters with the additional double hyphen-minus "--" prefix.aType- The type of the value returned by theAbstractOperand.getValue()method.aAlias- The option argument's name to be used when constructing the syntax.aDescription- The description to be used (without any line breaks).
-
AbstractOption
public AbstractOption(String aLongOption, Class<T> aType, String aAlias, String aDescription, Consumer<? extends Operand<T>> aConsumer) Constructs anAbstractOptionwith the given arguments.- Parameters:
aLongOption- The long-option being a multi-character sequence with at least two characters with the additional double hyphen-minus "--" prefix.aType- The type of the value returned by theAbstractOperand.getValue()method.aAlias- The option argument's name to be used when constructing the syntax.aDescription- The description to be used (without any line breaks).aConsumer- TheConsumerbeing invoked in case thisOptionparticipated in successfully parsing the command line arguments.
-
AbstractOption
protected AbstractOption(Character aShortOption, String aLongOption, Class<T> aType, String aDescription) Constructs anAbstractOptionwith the given arguments.- Parameters:
aShortOption- The short-option being a single character with the additional single hyphen-minus "-" prefix.aLongOption- The long-option being a multi-character sequence with at least two characters with the additional double hyphen-minus "--" prefix.aType- The type of the value returned by theAbstractOperand.getValue()method.aDescription- The description to be used (without any line breaks).
-
AbstractOption
protected AbstractOption(Character aShortOption, String aLongOption, Class<T> aType, String aDescription, Consumer<? extends Operand<T>> aConsumer) Constructs anAbstractOptionwith the given arguments.- Parameters:
aShortOption- The short-option being a single character with the additional single hyphen-minus "-" prefix.aLongOption- The long-option being a multi-character sequence with at least two characters with the additional double hyphen-minus "--" prefix.aType- The type of the value returned by theAbstractOperand.getValue()method.aDescription- The description to be used (without any line breaks).aConsumer- TheConsumerbeing invoked in case thisOptionparticipated in successfully parsing the command line arguments.
-
-
Method Details
-
clone
- Specified by:
clonein interfaceorg.refcodes.mixin.Clonable- Overrides:
clonein classAbstractOperand<T>- Throws:
CloneNotSupportedException
-
getLongOption
-
getShortOption
-
parseArgs
public Operand<?>[] parseArgs(String[] aArgs, String[] aKeywords, CliContext aCliCtx) throws ArgsSyntaxException Parses the given command line arguments using the provided keyword set and CLI context.This method represents the core parsing operation. It evaluates this
Termor, if this term is an inner node, delegates parsing to its child terms.The
aKeywordsparameter defines reserved tokens such as option names that must not be interpreted as operand values.This method does not validate whether all arguments have been consumed. Superfluous arguments must be handled by the caller.
- Specified by:
parseArgsin interfaceTerm- Overrides:
parseArgsin classAbstractOperand<T>- Parameters:
aArgs- The command line arguments to parseaKeywords- Reserved option and keyword tokensaCliCtx- TheCliContextcontrolling parsing and rendering- Returns:
- The evaluated operands
- Throws:
ArgsSyntaxException- If the arguments do not match the syntax
-
toSchema
-
toString
- Overrides:
toStringin classAbstractOperand<T>
-
toException
Convenience method to create anUnknownArgsException.- Parameters:
aArgs- The arguments participating tin the exception.aCliCtx- The context to use when creating the exception's details.- Returns:
- The accordingly created
ArgsSyntaxExceptioninstance.
-
setParsedArgs
Sets the command line argument(s) representing theOperandand its value as parsed by theAbstractOperand.parseArgs(String[], String[], CliContext)method.- Overrides:
setParsedArgsin classAbstractOperand<T>- Parameters:
aArgs- The command line arguments representing thisOperandwith its value.
-
setValue
Sets the value for theOperandas parsed by theAbstractOperand.parseArgs(String[], String[], CliContext)method.- Overrides:
setValuein classAbstractOperand<T>- Parameters:
aValue- The value to be set for thisOperand.
-
contains
-
getDescription
- Specified by:
getDescriptionin interfaceorg.refcodes.mixin.DescriptionAccessor
-
getException
Retrieves theArgsSyntaxExceptionexception in case invokingTerm.parseArgs(String[], CliContext)failed. The exception (and the according suppressed ones alongside the causes) does not necessarily have been thrown by theTerm.parseArgs(String[], CliContext)method depending on the semantics of theTermhanding the exception (theAnyConditionprovides any exceptions it caught even though it did not throw them as of its semantics).- Specified by:
getExceptionin interfaceorg.refcodes.exception.ExceptionAccessor<ArgsSyntaxException>- Specified by:
getExceptionin interfaceTerm- Returns:
- The
ArgsSyntaxExceptionexception occurring while parsing the arguments.
-
setVisible
public void setVisible(boolean isVisible) Visibility in this context means displaying or hiding this
Term's existence to the user (defaults totrue).- Specified by:
setVisiblein interfaceTerm- Specified by:
setVisiblein interfaceorg.refcodes.graphical.VisibleAccessor.VisibleMutator
-
isVisible
-
toArgsDiff
Creates the difference between the provided set and the providedLists therein found argument arrays subset (as ofOperand.getParsedArgs()).- Parameters:
aArgs- The set to be used for the diff operation.aArgsSubset- The subset to be used for the diff operation being the lists containing theOperandinstances whose command line arguments are to be diffed.- Returns:
- The difference between the set and the subset.
-
toArgsDiff
Creates the difference between the provided set and the providedLists therein found argument arrays subset (as ofOperand.getParsedArgs()).- Parameters:
aArgs- The set to be used for the diff operation.aArgsSubset- The subset to be used for the diff operation being the lists containing theOperandinstances whose command line arguments are to be diffed.- Returns:
- The difference between the set and the subset.
-
toArgsDiff
Creates the difference between the provided set and the provided subset.- Parameters:
aArgs- The set to be used for the diff operation.aArgsSubset- The subset to be used for the diff operation.- Returns:
- The difference between the set and the subset.
-
toParsedArgs
Takes allOperandinstances found in the providedLists and adds all therein found argument arrays (as ofOperand.getParsedArgs()) to the result.
-