Class AbstractOption<T>

java.lang.Object
org.refcodes.cli.AbstractOperand<T>
org.refcodes.cli.AbstractOption<T>
Type Parameters:
T - The generic type of the AbstractOption's value.
All Implemented Interfaces:
Cloneable, Comparable<Operand<?>>, MatchCountAccessor, Operand<T>, Option<T>, ParsedArgsAccessor, Synopsisable, Term, org.refcodes.exception.ExceptionAccessor<ArgsSyntaxException>, org.refcodes.graphical.VisibleAccessor, org.refcodes.graphical.VisibleAccessor.VisibleBuilder<Term>, org.refcodes.graphical.VisibleAccessor.VisibleMutator, org.refcodes.graphical.VisibleAccessor.VisibleProperty, org.refcodes.mixin.AliasAccessor, org.refcodes.mixin.Clonable, org.refcodes.mixin.DescriptionAccessor, org.refcodes.mixin.Resetable, org.refcodes.mixin.TypeAccessor<T>, org.refcodes.mixin.ValueAccessor<T>, org.refcodes.schema.Schemable
Direct Known Subclasses:
AbstractPropertyOption, BooleanOption, CharOption, DoubleOption, EnumOption, FileOption, Flag, FloatOption, IntOption, LongOption, StringOption

public abstract class AbstractOption<T> extends AbstractOperand<T> implements Option<T>
The AbstractOption is an abstract implementation of an Option providing the boiler plate when implementing the Option interface.