java.lang.Object
org.refcodes.cli.AbstractOperand<T>
org.refcodes.cli.AbstractOption<T>
- Type Parameters:
T- the generic type
- All Implemented Interfaces:
Cloneable,Comparable<Operand<?>>,ArgsAccessor,Constituent,Operand<T>,Option<T>,Synopsisable,org.refcodes.mixin.AliasAccessor,org.refcodes.mixin.Clonable,org.refcodes.mixin.DescriptionAccessor,org.refcodes.mixin.Resetable,org.refcodes.mixin.Schemable<CliSchema>,org.refcodes.mixin.TypeAccessor<T>,org.refcodes.mixin.ValueAccessor<T>
- Direct Known Subclasses:
CharOption,DoubleOption,EnumOption,FileOption,Flag,FloatOption,IntOption,LongOption,StringOption
The
AbstractOption is an abstract implementation of an Option
providing the boiler plate when implementing the Option interface.-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.mixin.AliasAccessor
org.refcodes.mixin.AliasAccessor.AliasBuilder<B extends org.refcodes.mixin.AliasAccessor.AliasBuilder<B>>, org.refcodes.mixin.AliasAccessor.AliasMutator, org.refcodes.mixin.AliasAccessor.AliasPropertyNested classes/interfaces inherited from interface org.refcodes.cli.ArgsAccessor
ArgsAccessor.ArgsMutator, ArgsAccessor.ArgsPropertyNested classes/interfaces inherited from interface org.refcodes.mixin.DescriptionAccessor
org.refcodes.mixin.DescriptionAccessor.DescriptionBuilder<B extends org.refcodes.mixin.DescriptionAccessor.DescriptionBuilder<B>>, org.refcodes.mixin.DescriptionAccessor.DescriptionMutator, org.refcodes.mixin.DescriptionAccessor.DescriptionPropertyNested classes/interfaces inherited from interface org.refcodes.mixin.TypeAccessor
org.refcodes.mixin.TypeAccessor.TypeBuilder<T extends Object,B extends org.refcodes.mixin.TypeAccessor.TypeBuilder<T, B>>, org.refcodes.mixin.TypeAccessor.TypeMutator<T extends Object>, org.refcodes.mixin.TypeAccessor.TypeProperty<T extends Object> Nested classes/interfaces inherited from interface org.refcodes.mixin.ValueAccessor
org.refcodes.mixin.ValueAccessor.ValueBuilder<V extends Object,B extends org.refcodes.mixin.ValueAccessor.ValueBuilder<V, B>>, org.refcodes.mixin.ValueAccessor.ValueMutator<V extends Object>, org.refcodes.mixin.ValueAccessor.ValueProperty<V extends Object> -
Field Summary
FieldsFields inherited from class org.refcodes.cli.AbstractOperand
_value -
Constructor Summary
ConstructorsModifierConstructorDescriptionprotectedConstructs anAbstractOptionwith the given arguments.AbstractOption(Character aShortOption, String aLongOption, Class<T> aType, String aAlias, String aDescription) Constructs anAbstractOptionwith the given arguments.AbstractOption(String aLongOption, Class<T> aType, String aDescription) Constructs anAbstractOptionwith the given arguments.Constructs anAbstractOptionwith the given arguments.AbstractOption(org.refcodes.struct.Relation<String, T> aProperty, Class<T> aType) Constructs anAbstractOptionwith the given arguments. -
Method Summary
Modifier and TypeMethodDescriptionclone()protected static booleanReturns the long-option representing anOptioninstance.Returns the short-option representing anOptioninstance.parseArgs(String[] aArgs, String[] aOptions, CliContext aCliCtx) Parses the provided command line arguments and determines the according values by evaluating thisConstituentinstance or, in case of being a node in the syntax tree (such as aCondition, traversing the childConstituentinstances'Constituent.parseArgs(String[], String[], CliContext)methods.protected voidsetParsedArgs(String[] aArgs) Sets the command line argument(s) representing theOperandand its value as parsed by theAbstractOperand.parseArgs(String[], String[], CliContext)method.protected voidSets the value for theOperandas parsed by theAbstractOperand.parseArgs(String[], String[], CliContext)method.toOptionArgument(String[] aArgs, String aOption, String[] aOptions) toOptionArgument(Option<?> aOption, String[] aArgs, String[] aOptions, CliContext aCliCtx) toSchema()toSyntax(CliContext aCliCtx) This method is to be called from inside theConstituenthierarchy; use the methodSynopsisable.toSynopsis(SyntaxNotation)in case you invoke syntax retrieval from the rootConstituent.Methods inherited from class org.refcodes.cli.AbstractOperand
compareTo, getAlias, getType, getValue, reset, toParsedArgs, toString, toTypeMethods inherited from class java.lang.Object
equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface java.lang.Comparable
compareToMethods inherited from interface org.refcodes.cli.Constituent
parseArgs, toSynopsis, toSyntax, toSyntax, toSyntax, toSyntaxMethods inherited from interface org.refcodes.mixin.DescriptionAccessor
getDescriptionMethods inherited from interface org.refcodes.cli.Operand
getAlias, getValue, hasValue, toParsedArgs, toSpec, toValueMethods inherited from interface org.refcodes.mixin.Resetable
resetMethods inherited from interface org.refcodes.cli.Synopsisable
toSynopsis, toSynopsis, toSynopsis, toSynopsisMethods inherited from interface org.refcodes.mixin.TypeAccessor
getTypeMethods inherited from interface org.refcodes.mixin.ValueAccessor
getValueOr
-
Field Details
-
_description
-
-
Constructor Details
-
AbstractOption
Constructs anAbstractOptionwith the given arguments.- Parameters:
aLongOption- The long-option being a multi-character sequence with at least two characters with the additional double hyphen-minus "--" prefix.aType- The type of the value returned by theAbstractOperand.getValue()method.aDescription- The description to be used (without any line breaks).
-
AbstractOption
Constructs anAbstractOptionwith the given arguments.- Parameters:
aLongOption- The long-option being a multi-character sequence with at least two characters with the additional double hyphen-minus "--" prefix.aType- The type of the value returned by theAbstractOperand.getValue()method.aAlias- The option argument's name to be used when constructing the syntax.aDescription- The description to be used (without any line breaks).
-
AbstractOption
protected AbstractOption(Character aShortOption, String aLongOption, Class<T> aType, String aDescription) Constructs anAbstractOptionwith the given arguments.- Parameters:
aShortOption- The short-option being a single character with the additional single hyphen-minus "-" prefix.aLongOption- The long-option being a multi-character sequence with at least two characters with the additional double hyphen-minus "--" prefix.aType- The type of the value returned by theAbstractOperand.getValue()method.aDescription- The description to be used (without any line breaks).
-
AbstractOption
public AbstractOption(Character aShortOption, String aLongOption, Class<T> aType, String aAlias, String aDescription) Constructs anAbstractOptionwith the given arguments.- Parameters:
aShortOption- The short-option being a single character with the additional single hyphen-minus "-" prefix.aLongOption- The long-option being a multi-character sequence with at least two characters with the additional double hyphen-minus "--" prefix.aType- The type of the value returned by theAbstractOperand.getValue()method.aAlias- The option argument's name to be used when constructing the syntax.aDescription- The description to be used (without any line breaks).
-
AbstractOption
Constructs anAbstractOptionwith the given arguments.- Parameters:
aProperty- The key (= alias) and the value for the operand.aType- the type
-
-
Method Details
-
parseArgs
public List<Operand<T>> parseArgs(String[] aArgs, String[] aOptions, CliContext aCliCtx) throws ArgsSyntaxException Parses the provided command line arguments and determines the according values by evaluating thisConstituentinstance or, in case of being a node in the syntax tree (such as aCondition, traversing the childConstituentinstances'Constituent.parseArgs(String[], String[], CliContext)methods. In case of successfully parsing thisConstituentand / or the childConstituentinstances, the evaluated command line arguments are returned: Depending on theConstituentsubclasses representing the evaluated command line arguments, instances ofFlagclasses,Optionclasses orOperandclasses may be found in the result. In case of parsing failure, an according exception is thrown. ATTENTION: This method does not test for superfluous command line arguments being passed; e.g. command line arguments not being evaluated by any of theConstituentinstance being traversed. This method is commonly used by a rootConstituent'sArgsParser.evalArgs(String[])method, which delegates to theConstituent.parseArgs(String[], String[], CliContext)method and after which it determines whether there are superfluous arguments to be taken care of (by throwing an according exception). Business logic therefore should invoke the root node'sConstituent.parseArgs(String[], String[], CliContext)method as ignoring superfluous command line arguments will cause unexpected behavior from the point of view of the invoker.- Specified by:
parseArgsin interfaceConstituent- Overrides:
parseArgsin classAbstractOperand<T>- Parameters:
aArgs- The command line arguments to be parsed.aOptions- The list of options (short and as well as long) which are reserved and cannot be used as value.aCliCtx- the cli context- Returns:
- The list of evaluated command line arguments being instances of
the
Operandinterfaces or its sub-types. - Throws:
ArgsSyntaxException- thrown in case of a command line arguments mismatch regarding provided and expected args.
-
getShortOption
Returns the short-option representing anOptioninstance. A short option usually is being prefixed with a single hyphen-minus "-" as defined inArgsPrefix.POSIX_SHORT_OPTION.- Specified by:
getShortOptionin interfaceOption<T>- Returns:
- The short-option
String.
-
getLongOption
Returns the long-option representing anOptioninstance. A long option usually is being prefixed with a double hyphen-minus "--" as defined inArgsPrefix.POSIX_LONG_OPTION.- Specified by:
getLongOptionin interfaceOption<T>- Returns:
- The long-option
String.
-
toSyntax
This method is to be called from inside theConstituenthierarchy; use the methodSynopsisable.toSynopsis(SyntaxNotation)in case you invoke syntax retrieval from the rootConstituent. Returns the human readable (verbose) syntax of thisConstituentinstance including, in case of being a node in the syntax tree (such as aCondition, the syntax of the childConstituentinstances. ATTENTION: As of different parenthesis settings for some notations regarding the rootConstituentand the childConstituents, the methodConstituent.toSyntax(CliContext)is called from inside theConstituenthierarchy. In case the syntax is to be retrieved from the rootConstituent, then the applicable method to be called isSynopsisable.toSynopsis(SyntaxNotation), as for some notations it will for example not create the most outer braces.- Specified by:
toSyntaxin interfaceConstituent- Overrides:
toSyntaxin classAbstractOperand<T>- Parameters:
aCliCtx- TheCliContextfor which the syntax is being generated.- Returns:
- The human readable (verbose) command line arguments syntax.
-
clone
- Specified by:
clonein interfaceorg.refcodes.mixin.Clonable- Overrides:
clonein classAbstractOperand<T>- Throws:
CloneNotSupportedException
-
toSchema
- Specified by:
toSchemain interfaceorg.refcodes.mixin.Schemable<T>- Overrides:
toSchemain classAbstractOperand<T>
-
setValue
Sets the value for theOperandas parsed by theAbstractOperand.parseArgs(String[], String[], CliContext)method.- Overrides:
setValuein classAbstractOperand<T>- Parameters:
aValue- The value to be set for thisOperand.
-
setParsedArgs
Sets the command line argument(s) representing theOperandand its value as parsed by theAbstractOperand.parseArgs(String[], String[], CliContext)method.- Overrides:
setParsedArgsin classAbstractOperand<T>- Parameters:
aArgs- The command line arguments representing thisOperandwith its value.
-
contains
-
toOptionArgument
protected static org.refcodes.struct.Relation<String,String> toOptionArgument(Option<?> aOption, String[] aArgs, String[] aOptions, CliContext aCliCtx) Takes theOption's short-option and long-option and tries to determine thatOption's value in the provided command line arguments. Depending on whether the short-option or the long-option was detected with a value, the result contains the according option as the key with the detected value in theRelationinstance. Null is returned when either no option was found or no value for one of the options.- Parameters:
aOption- The option for which to get the valueaArgs- The command line arguments from which to determine theOption's value.aOptions- The list of options (short and well as long) which are reserved and cannot be used as value.aCliCtx- TheCliContextto run this method with.- Returns:
- A key/value-pair containing the detected (short / long) option alongside the detected value.
-
toOptionArgument
protected static org.refcodes.struct.Relation<String,String> toOptionArgument(String[] aArgs, String aOption, String[] aOptions) Takes theOption's short-option and long-option and tries to determine thatOption's value in the provided command line arguments. Depending on whether the short-option or the long-option was detected with a value, the result contains the according option as the key with the detected value in theRelationinstance. Null is returned when either no option was found or no value for one of the options.- Parameters:
aArgs- The command line arguments from which to determine theOption's value.aOption- The option for which to get the valueaOptions- The list of options (short and well as long) which are reserved and cannot be used as value.- Returns:
- A key/value-pair containing the detected (short / long) option alongside the detected value.
-
getDescription
- Specified by:
getDescriptionin interfaceorg.refcodes.mixin.DescriptionAccessor
-