Class AbstractOption<T>

java.lang.Object
org.refcodes.cli.AbstractOperand<T>
org.refcodes.cli.AbstractOption<T>
Type Parameters:
T - the generic type
All Implemented Interfaces:
Cloneable, Comparable<Operand<?>>, ArgsAccessor, Operand<T>, Option<T>, Synopsisable, Syntaxable, org.refcodes.mixin.AliasAccessor, org.refcodes.mixin.Clonable, org.refcodes.mixin.DescriptionAccessor, org.refcodes.mixin.Resetable, org.refcodes.mixin.Schemable<CliSchema>, org.refcodes.mixin.TypeAccessor<T>, org.refcodes.mixin.ValueAccessor<T>
Direct Known Subclasses:
CharOption, DoubleOption, EnumOption, FileOption, Flag, FloatOption, IntOption, LongOption, StringOption

public abstract class AbstractOption<T> extends AbstractOperand<T> implements Option<T>
The AbstractOption is an abstract implementation of an Option providing the boiler plate when implementing the Option interface.
  • Constructor Details

    • AbstractOption

      public AbstractOption(String aShortOption, String aLongOption, Class<T> aType, String aAlias, String aDescription)
      Constructs a Option with the given arguments.
      Parameters:
      aShortOption - The short-option being a single character with the additional single hyphen-minus "-" prefix.
      aLongOption - The long-option being a multi-character sequence with at least two characters with the additional double hyphen-minus "--" prefix.
      aType - The type of the value returned by the AbstractOperand.getValue() method.
      aAlias - The option argument's name to be used when constructing the syntax.
      aDescription - A description without any line breaks.
    • AbstractOption

      protected AbstractOption(String aShortOption, String aLongOption, Class<T> aType, String aDescription)
      Constructs a Option with the given arguments.
      Parameters:
      aShortOption - The short-option being a single character with the additional single hyphen-minus "-" prefix.
      aLongOption - The long-option being a multi-character sequence with at least two characters with the additional double hyphen-minus "--" prefix.
      aType - The type of the value returned by the AbstractOperand.getValue() method.
      aDescription - A description without any line breaks.
    • AbstractOption

      public AbstractOption(org.refcodes.struct.Relation<String,T> aProperty, Class<T> aType)
      Instantiates a new option.
      Parameters:
      aProperty - The key (= alias) and the value for the operand.
      aType - the type
  • Method Details

    • parseArgs

      public List<Operand<T>> parseArgs(String[] aArgs, String[] aOptions) throws ArgsSyntaxException
      Parses the provided command line arguments and determines the according values by evaluating this Syntaxable instance or, in case of being a node in the syntax tree (such as a ArgsSyntax, traversing the child Syntaxable instances' Syntaxable.parseArgs(String[], String[]) methods. In case of successfully parsing this Syntaxable and / or the child Syntaxable instances, the evaluated command line arguments are returned: Depending on the Syntaxable subclasses representing the evaluated command line arguments, instances of Flag classes, Option classes or Operand classes may be found in the result. In case of parsing failure, an according exception is thrown. ATTENTION: This method does not test for superfluous command line arguments being passed; e.g. command line arguments not being evaluated by any of the Syntaxable instance being traversed. This method is commonly used by a root Syntaxable's ArgsParser.evalArgs(String[]) method, which delegates to the Syntaxable.parseArgs(String[], String[]) method and after which it determines whether there are superfluous arguments to be taken care of (by throwing an according exception). Business logic therefore should invoke the root node's Syntaxable.parseArgs(String[], String[]) method as ignoring superfluous command line arguments will cause unexpected behavior from the point of view of the invoker.
      Specified by:
      parseArgs in interface Syntaxable
      Overrides:
      parseArgs in class AbstractOperand<T>
      Parameters:
      aArgs - The command line arguments to be parsed.
      aOptions - The list of options (short and as well as long) which are reserved and cannot be used as value.
      Returns:
      The list of evaluated command line arguments being instances of the Operand interfaces or its sub-types.
      Throws:
      ArgsSyntaxException - thrown in case of a command line arguments mismatch regarding provided and expected args.
    • getShortOption

      public String getShortOption()
      Returns the short-option representing an Option instance. A short option usually is being prefixed with a single hyphen-minus "-" as defined in CommandArgPrefix.POSIX_SHORT_OPTION.
      Specified by:
      getShortOption in interface Option<T>
      Returns:
      The short-option String.
    • getLongOption

      public String getLongOption()
      Returns the long-option representing an Option instance. A long option usually is being prefixed with a double hyphen-minus "--" as defined in CommandArgPrefix.POSIX_LONG_OPTION.
      Specified by:
      getLongOption in interface Option<T>
      Returns:
      The long-option String.
    • toSyntax

      public String toSyntax(SyntaxNotation aSyntaxNotation, String aOptEscCode, String aParamEscCode, String aResetEscCode)
      This method is to be called from inside the Syntaxable hierarchy; use the method Synopsisable.toSynopsis(SyntaxNotation) in case you invoke syntax retrieval from the root Syntaxable. Returns the human readable (verbose) syntax of this Syntaxable instance including, in case of being a node in the syntax tree (such as a ArgsSyntax, the syntax of the child Syntaxable instances. ATTENTION: As of different parenthesis settings for some notations regarding the root Syntaxable and the child Syntaxables, the method Syntaxable.toSyntax(SyntaxNotation, String, String, String) is called from inside the Syntaxable hierarchy. In case the syntax is to be retrieved from the root Syntaxable, then the applicable method to be called is Synopsisable.toSynopsis(SyntaxNotation), as for some notations it will for example not create the most outer braces.
      Specified by:
      toSyntax in interface Syntaxable
      Overrides:
      toSyntax in class AbstractOperand<T>
      Parameters:
      aSyntaxNotation - The syntax notation used for generating the command line arguments syntax.
      aOptEscCode - The escape code to be used when processing an option, e.g. this can be an ANSI Escape-Code to highlight the option.
      aParamEscCode - The escape code to be used when processing a keyword, e.g. this can be an ANSI Escape-Code to highlight the option and/or parameters.
      aResetEscCode - The escape code to close (reset) any Escape-Code being set before.
      Returns:
      The human readable (verbose) command line arguments syntax.
    • toState

      public String toState()
      The Syntaxable.toState() method might be used by the Object.toString() method and prints out the state of the syntaxable and (if any) its children. Even in case parsing command line arguments failed, the state till failure can be inspected with this method.
      Specified by:
      toState in interface Syntaxable
      Overrides:
      toState in class AbstractOperand<T>
      Returns:
      The state of this Syntaxable instance and (if any) its children.
    • clone

      public Object clone() throws CloneNotSupportedException
      Specified by:
      clone in interface org.refcodes.mixin.Clonable
      Overrides:
      clone in class AbstractOperand<T>
      Throws:
      CloneNotSupportedException
    • toSchema

      public CliSchema toSchema()
      Specified by:
      toSchema in interface org.refcodes.mixin.Schemable<T>
      Overrides:
      toSchema in class AbstractOperand<T>
    • getOptionPrefixes

      protected String[] getOptionPrefixes()
      Determines the prefixes suitable for the environment. Prefixes on Windows might differ from those on POSIX conforming systems.
      Returns:
      The prefixes to used for this runtime.
    • setValue

      protected void setValue(T aValue)
      Sets the value for the Operand as parsed by the AbstractOperand.parseArgs(String[], String[]) method.
      Overrides:
      setValue in class AbstractOperand<T>
      Parameters:
      aValue - The value to be set for this Operand.
    • setArgs

      protected void setArgs(String[] aArgs)
      Sets the command line argument(s) representing the Operand and its value as parsed by the AbstractOperand.parseArgs(String[], String[]) method.
      Overrides:
      setArgs in class AbstractOperand<T>
      Parameters:
      aArgs - The command line arguments representing this Operand with its value.
    • toSynopsis

      public String toSynopsis(SyntaxNotation aSyntaxNotation, String aOptEscCode, String aParamEscCode, String aResetEscCode)
      Returns the human readable (verbose) syntax of implementing class ATTENTION: As of different parenthesis settings for some notations regarding the root Syntaxable and the child Syntaxables, the method Syntaxable.toSyntax(SyntaxNotation, String, String, String) is called from inside a Syntaxable hierarchy. In case the syntax is to be retrieved from the root Syntaxable or an encapsulating and different type, then the applicable method to be called is Synopsisable.toSynopsis(SyntaxNotation), as for some notations it will for example not create the most outer braces.
      Specified by:
      toSynopsis in interface Synopsisable
      Parameters:
      aSyntaxNotation - The syntax notation used for generating the command line arguments syntax.
      aOptEscCode - The escape code to be used when processing an option, e.g. this can be an ANSI Escape-Code to highlight the option.
      aParamEscCode - The escape code to be used when processing am argument, e.g. this can be an ANSI Escape-Code to highlight the option.
      aResetEscCode - The escape code to close (reset) any Escape-Code being set before.
      Returns:
      The human readable (verbose) command line arguments syntax.