java.lang.Object
org.refcodes.cli.AbstractOperand<T>
org.refcodes.cli.AbstractOption<T>
- Type Parameters:
T- the generic type
- All Implemented Interfaces:
Cloneable,Comparable<Operand<?>>,ArgsAccessor,Operand<T>,Option<T>,Syntaxable,SyntaxUsage,org.refcodes.component.Resetable,org.refcodes.mixin.AliasAccessor,org.refcodes.mixin.Clonable,org.refcodes.mixin.DescriptionAccessor,org.refcodes.mixin.TypeAccessor<T>,org.refcodes.mixin.ValueAccessor<T>
- Direct Known Subclasses:
CharOption,DoubleOption,EnumOption,FileOption,Flag,FloatOption,IntOption,LongOption,StringOption
public abstract class AbstractOption<T> extends AbstractOperand<T> implements Option<T>
The
AbstractOption is an abstract implementation of an Option
providing the boiler plate when implementing the Option interface.-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.mixin.AliasAccessor
org.refcodes.mixin.AliasAccessor.AliasBuilder<B extends org.refcodes.mixin.AliasAccessor.AliasBuilder<B>>, org.refcodes.mixin.AliasAccessor.AliasMutator, org.refcodes.mixin.AliasAccessor.AliasPropertyNested classes/interfaces inherited from interface org.refcodes.cli.ArgsAccessor
ArgsAccessor.ArgsMutator, ArgsAccessor.ArgsPropertyNested classes/interfaces inherited from interface org.refcodes.mixin.DescriptionAccessor
org.refcodes.mixin.DescriptionAccessor.DescriptionBuilder<B extends org.refcodes.mixin.DescriptionAccessor.DescriptionBuilder<B>>, org.refcodes.mixin.DescriptionAccessor.DescriptionMutator, org.refcodes.mixin.DescriptionAccessor.DescriptionPropertyNested classes/interfaces inherited from interface org.refcodes.mixin.TypeAccessor
org.refcodes.mixin.TypeAccessor.TypeBuilder<T extends Object,B extends org.refcodes.mixin.TypeAccessor.TypeBuilder<T,B>>, org.refcodes.mixin.TypeAccessor.TypeMutator<T extends Object>, org.refcodes.mixin.TypeAccessor.TypeProperty<T extends Object>Nested classes/interfaces inherited from interface org.refcodes.mixin.ValueAccessor
org.refcodes.mixin.ValueAccessor.ValueBuilder<V extends Object,B extends org.refcodes.mixin.ValueAccessor.ValueBuilder<V,B>>, org.refcodes.mixin.ValueAccessor.ValueMutator<V extends Object>, org.refcodes.mixin.ValueAccessor.ValueProperty<V extends Object> -
Field Summary
Fields inherited from class org.refcodes.cli.AbstractOperand
_value -
Constructor Summary
Constructors Modifier Constructor Description protectedAbstractOption(String aShortOption, String aLongOption, Class<T> aType, String aDescription)Constructs aOptionwith the given arguments.AbstractOption(String aShortOption, String aLongOption, Class<T> aType, String aAlias, String aDescription)Constructs aOptionwith the given arguments.AbstractOption(org.refcodes.struct.Relation<String,T> aProperty, Class<T> aType)Instantiates a new option. -
Method Summary
Modifier and Type Method Description Objectclone()StringgetLongOption()Returns the long-option representing anOptioninstance.protected String[]getOptionPrefixes()Determines the prefixes suitable for the environment.StringgetShortOption()Returns the short-option representing anOptioninstance.List<Operand<T>>parseArgs(String[] aArgs, String[] aOptions)Parses the provided command line arguments and determines the according values by evaluating thisSyntaxableinstance or, in case of being a node in the syntax tree (such as aCondition, traversing the childSyntaxableinstances'Syntaxable.parseArgs(String[], String[])methods.protected voidsetArgs(String[] aArgs)Sets the command line argument(s) representing theOperandand its value as parsed by theAbstractOperand.parseArgs(String[], String[])method.protected voidsetValue(T aValue)Sets the value for theOperandas parsed by theAbstractOperand.parseArgs(String[], String[])method.StringtoState()TheSyntaxable.toState()method might be used by theObject.toString()method and prints out the state of the syntaxable and (if any) its children.StringtoSyntax(SyntaxNotation aSyntaxNotation, String aOptionEscCode, String aResetEscCode)This method is to be called from inside theSyntaxablehierarchy; use the methodSyntaxUsage.toUsage(SyntaxNotation)in case you invoke syntax retrieval from the rootSyntaxable.StringtoUsage(SyntaxNotation aSyntaxNotation, String aOptionEscCode, String aResetEscCode)Returns the human readable (verbose) syntax of implementing class ATTENTION: As of different parenthesis settings for some notations regarding the rootSyntaxableand the childSyntaxables, the methodSyntaxable.toSyntax(SyntaxNotation, String, String)is called from inside aSyntaxablehierarchy.Methods inherited from class org.refcodes.cli.AbstractOperand
compareTo, getAlias, getArgs, getDescription, getType, getValue, reset, toString, toValueMethods inherited from class java.lang.Object
equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface java.lang.Comparable
compareToMethods inherited from interface org.refcodes.mixin.DescriptionAccessor
getDescriptionMethods inherited from interface org.refcodes.cli.Operand
get, getAlias, getArgs, getValue, hasValueMethods inherited from interface org.refcodes.cli.Option
getOptionsMethods inherited from interface org.refcodes.component.Resetable
resetMethods inherited from interface org.refcodes.cli.Syntaxable
parseArgs, toSyntaxMethods inherited from interface org.refcodes.cli.SyntaxUsage
toUsage, toUsage, toUsageMethods inherited from interface org.refcodes.mixin.TypeAccessor
getTypeMethods inherited from interface org.refcodes.mixin.ValueAccessor
getValueOr
-
Constructor Details
-
AbstractOption
public AbstractOption(String aShortOption, String aLongOption, Class<T> aType, String aAlias, String aDescription)Constructs aOptionwith the given arguments.- Parameters:
aShortOption- The short-option being a single character with the additional single hyphen-minus "-" prefix.aLongOption- The long-option being a multi-character sequence with at least two characters with the additional double hyphen-minus "--" prefix.aType- The type of the value returned by theAbstractOperand.getValue()method.aAlias- The option argument's name to be used when constructing the syntax.aDescription- A description without any line breaks.
-
AbstractOption
protected AbstractOption(String aShortOption, String aLongOption, Class<T> aType, String aDescription)Constructs aOptionwith the given arguments.- Parameters:
aShortOption- The short-option being a single character with the additional single hyphen-minus "-" prefix.aLongOption- The long-option being a multi-character sequence with at least two characters with the additional double hyphen-minus "--" prefix.aType- The type of the value returned by theAbstractOperand.getValue()method.aDescription- A description without any line breaks.
-
AbstractOption
Instantiates a new option.- Parameters:
aProperty- The key (= alias) and the value for the operand.aType- the type
-
-
Method Details
-
parseArgs
public List<Operand<T>> parseArgs(String[] aArgs, String[] aOptions) throws UnknownArgsException, AmbiguousArgsException, ParseArgsExceptionParses the provided command line arguments and determines the according values by evaluating thisSyntaxableinstance or, in case of being a node in the syntax tree (such as aCondition, traversing the childSyntaxableinstances'Syntaxable.parseArgs(String[], String[])methods. In case of successfully parsing thisSyntaxableand / or the childSyntaxableinstances, the evaluated command line arguments are returned: Depending on theSyntaxablesubclasses representing the evaluated command line arguments, instances ofFlagclasses,Optionclasses orOperandclasses may be found in the result. In case of parsing failure, an according exception is thrown. ATTENTION: This method does not test for superfluous command line arguments being passed; e.g. command line arguments not being evaluated by any of theSyntaxableinstance being traversed. This method is commonly used by a rootSyntaxable'sArgsParser.evalArgs(String[])method, which delegates to theSyntaxable.parseArgs(String[], String[])method and after which it determines whether there are superfluous arguments to be taken care of (by throwing an according exception). Business logic therefore should invoke the root node'sSyntaxable.parseArgs(String[], String[])method as ignoring superfluous command line arguments will cause unexpected behavior from the point of view of the invoker.- Specified by:
parseArgsin interfaceSyntaxable- Overrides:
parseArgsin classAbstractOperand<T>- Parameters:
aArgs- The command line arguments to be parsed.aOptions- The list of options (short and as well as long) which are reserved and cannot be used as value.- Returns:
- The list of evaluated command line arguments being instances of
the
Operandinterfaces or its sub-types. - Throws:
UnknownArgsException- Thrown in case not one command line argument matched regarding the provided args vs. the expected args.AmbiguousArgsException- Thrown in case at least one command line argument is ambiguous regarding expected args vs. provided args.ParseArgsException- Thrown in case the provided command line arguments do not respect the required syntax or cannot be converted to the required type
-
getShortOption
Returns the short-option representing anOptioninstance. A short option usually is being prefixed with a single hyphen-minus "-" as defined inCommandArgPrefix.POSIX_SHORT_OPTION.- Specified by:
getShortOptionin interfaceOption<T>- Returns:
- The short-option
String.
-
getLongOption
Returns the long-option representing anOptioninstance. A long option usually is being prefixed with a double hyphen-minus "--" as defined inCommandArgPrefix.POSIX_LONG_OPTION.- Specified by:
getLongOptionin interfaceOption<T>- Returns:
- The long-option
String.
-
toSyntax
public String toSyntax(SyntaxNotation aSyntaxNotation, String aOptionEscCode, String aResetEscCode)This method is to be called from inside theSyntaxablehierarchy; use the methodSyntaxUsage.toUsage(SyntaxNotation)in case you invoke syntax retrieval from the rootSyntaxable. Returns the human readable (verbose) syntax of thisSyntaxableinstance including, in case of being a node in the syntax tree (such as aCondition, the syntax of the childSyntaxableinstances. ATTENTION: As of different parenthesis settings for some notations regarding the rootSyntaxableand the childSyntaxables, the methodSyntaxable.toSyntax(SyntaxNotation, String, String)is called from inside theSyntaxablehierarchy. In case the syntax is to be retrieved from the rootSyntaxable, then the applicable method to be called isSyntaxUsage.toUsage(SyntaxNotation), as for some notations it will for example not create the most outer braces.- Specified by:
toSyntaxin interfaceSyntaxable- Overrides:
toSyntaxin classAbstractOperand<T>- Parameters:
aSyntaxNotation- The syntax notation used for generating the command line arguments syntax.aOptionEscCode- The escape code to be used when processing an option, e.g. this can be an ANSI Escape-Code to highlight the option parameters.aResetEscCode- The escape code to close (reset) any Escape-Code being set before.- Returns:
- The human readable (verbose) command line arguments syntax.
-
toState
TheSyntaxable.toState()method might be used by theObject.toString()method and prints out the state of the syntaxable and (if any) its children. Even in case parsing command line arguments failed, the state till failure can be inspected with this method.- Specified by:
toStatein interfaceSyntaxable- Overrides:
toStatein classAbstractOperand<T>- Returns:
- The state of this
Syntaxableinstance and (if any) its children.
-
clone
- Specified by:
clonein interfaceorg.refcodes.mixin.Clonable- Overrides:
clonein classAbstractOperand<T>- Throws:
CloneNotSupportedException
-
getOptionPrefixes
Determines the prefixes suitable for the environment. Prefixes on Windows might differ from those on POSIX conforming systems.- Returns:
- The prefixes to used for this runtime.
-
setValue
Sets the value for theOperandas parsed by theAbstractOperand.parseArgs(String[], String[])method.- Overrides:
setValuein classAbstractOperand<T>- Parameters:
aValue- The value to be set for thisOperand.
-
setArgs
Sets the command line argument(s) representing theOperandand its value as parsed by theAbstractOperand.parseArgs(String[], String[])method.- Overrides:
setArgsin classAbstractOperand<T>- Parameters:
aArgs- The command line arguments representing thisOperandwith its value.
-
toUsage
Returns the human readable (verbose) syntax of implementing class ATTENTION: As of different parenthesis settings for some notations regarding the rootSyntaxableand the childSyntaxables, the methodSyntaxable.toSyntax(SyntaxNotation, String, String)is called from inside aSyntaxablehierarchy. In case the syntax is to be retrieved from the rootSyntaxableor an encapsulating and different type, then the applicable method to be called isSyntaxUsage.toUsage(SyntaxNotation), as for some notations it will for example not create the most outer braces.- Specified by:
toUsagein interfaceSyntaxUsage- Parameters:
aSyntaxNotation- The syntax notation used for generating the command line arguments syntax.aOptionEscCode- The escape code to be used when processing an option, e.g. this can be an ANSI Escape-Code to highlight the option parameters (for example "--help", "-q" and so on).aResetEscCode- The escape code to close (reset) any Escape-Code being set before.- Returns:
- The human readable (verbose) command line arguments syntax.
-