Class AbstractProperty<T>

Type Parameters:
T - The generic type of the AbstractProperty's value.
All Implemented Interfaces:
Cloneable, Comparable<Operand<?>>, MatchCountAccessor, Operand<T>, Option<T>, ParsedArgsAccessor, Property<T>, Synopsisable, Term, org.refcodes.exception.ExceptionAccessor<ArgsSyntaxException>, org.refcodes.graphical.VisibleAccessor, org.refcodes.graphical.VisibleAccessor.VisibleBuilder<Term>, org.refcodes.graphical.VisibleAccessor.VisibleMutator, org.refcodes.graphical.VisibleAccessor.VisibleProperty, org.refcodes.mixin.AliasAccessor, org.refcodes.mixin.Clonable, org.refcodes.mixin.DescriptionAccessor, org.refcodes.mixin.Resetable, org.refcodes.mixin.TypeAccessor<T>, org.refcodes.mixin.ValueAccessor<T>, org.refcodes.schema.Schemable
Direct Known Subclasses:
BooleanProperty, CharProperty, DoubleProperty, EnumProperty, FileProperty, FloatProperty, IntProperty, LongProperty, StringProperty

public abstract class AbstractProperty<T> extends AbstractOption<T> implements Property<T>
The AbstractProperty is an abstract implementation of a Property providing the boiler plate when implementing the Property interface. A Property is a key=value pair passed as a single argument (e.g. "--file=someFile").
  • Field Details

    • _description

      protected String _description
    • _exception

      protected ArgsSyntaxException _exception
    • _isVisible

      protected boolean _isVisible
  • Constructor Details

  • Method Details

    • parseArgs

      public Operand<?>[] parseArgs(String[] aArgs, String[] aKeywords, CliContext aCliCtx) throws ArgsSyntaxException
      Parses the given command line arguments using the provided keyword set and CLI context.

      This method represents the core parsing operation. It evaluates this Term or, if this term is an inner node, delegates parsing to its child terms.

      The aKeywords parameter defines reserved tokens such as option names that must not be interpreted as operand values.

      This method does not validate whether all arguments have been consumed. Superfluous arguments must be handled by the caller.

      Specified by:
      parseArgs in interface Term
      Overrides:
      parseArgs in class AbstractOption<T>
      Parameters:
      aArgs - The command line arguments to parse
      aKeywords - Reserved option and keyword tokens
      aCliCtx - The CliContext controlling parsing and rendering
      Returns:
      The evaluated operands
      Throws:
      ArgsSyntaxException - If the arguments do not match the syntax
    • toPropertyArgument

      protected org.refcodes.struct.Relation<String,String> toPropertyArgument(String[] aArgs, CliContext aCliCtx)
      Takes the Option's short-option and long-option and tries to determine that Option's value in the provided command line arguments. Depending on whether the short-option or the long-option was detected with a value, the result contains the according option as the key with the detected value in the Relation instance. Null is returned when either no option was found or no value for one of the options.
      Parameters:
      aArgs - The command line arguments from which to determine the Option's value.
      aCliCtx - The CliContext to run this method with.
      Returns:
      A key/value-pair containing the detected (short / long) option alongside the detected value.
    • toPropertyArgument

      protected static org.refcodes.struct.Relation<String,String> toPropertyArgument(String[] aArgs, String aOption, CliContext aCliCtx)
      Takes the Option's short-option and long-option and tries to determine that Option's value in the provided command line arguments. Depending on whether the short-option or the long-option was detected with a value, the result contains the according option as the key with the detected value in the Relation instance. Null is returned when either no option was found or no value for one of the options.
      Parameters:
      aArgs - The command line arguments from which to determine the Option's value.
      aOption - The option for which to get the value reserved and cannot be used as value.
      Returns:
      A key/value-pair containing the detected (short / long) option alongside the detected value.
    • getDescription

      public String getDescription()
      Specified by:
      getDescription in interface org.refcodes.mixin.DescriptionAccessor
    • getException

      public ArgsSyntaxException getException()
      Retrieves the ArgsSyntaxException exception in case invoking Term.parseArgs(String[], CliContext) failed. The exception (and the according suppressed ones alongside the causes) does not necessarily have been thrown by the Term.parseArgs(String[], CliContext) method depending on the semantics of the Term handing the exception (the AnyCondition provides any exceptions it caught even though it did not throw them as of its semantics).
      Specified by:
      getException in interface org.refcodes.exception.ExceptionAccessor<ArgsSyntaxException>
      Specified by:
      getException in interface Term
      Returns:
      The ArgsSyntaxException exception occurring while parsing the arguments.
    • setVisible

      public void setVisible(boolean isVisible)

      Visibility in this context means displaying or hiding this Term's existence to the user (defaults to true).

      Specified by:
      setVisible in interface Term
      Specified by:
      setVisible in interface org.refcodes.graphical.VisibleAccessor.VisibleMutator
    • isVisible

      public boolean isVisible()

      Visibility in this context means displaying or hiding this Term's existence to the user (defaults to true).

      Specified by:
      isVisible in interface Term
      Specified by:
      isVisible in interface org.refcodes.graphical.VisibleAccessor
    • toArgsDiff

      protected static String[] toArgsDiff(String[] aArgs, List<? extends Operand<?>> aArgsSubset)
      Creates the difference between the provided set and the provided Lists therein found argument arrays subset (as of Operand.getParsedArgs()).
      Parameters:
      aArgs - The set to be used for the diff operation.
      aArgsSubset - The subset to be used for the diff operation being the lists containing the Operand instances whose command line arguments are to be diffed.
      Returns:
      The difference between the set and the subset.
    • toArgsDiff

      protected static String[] toArgsDiff(String[] aArgs, Operand<?>[] aArgsSubset)
      Creates the difference between the provided set and the provided Lists therein found argument arrays subset (as of Operand.getParsedArgs()).
      Parameters:
      aArgs - The set to be used for the diff operation.
      aArgsSubset - The subset to be used for the diff operation being the lists containing the Operand instances whose command line arguments are to be diffed.
      Returns:
      The difference between the set and the subset.
    • toArgsDiff

      protected static String[] toArgsDiff(String[] aArgs, String[] aArgsSubset)
      Creates the difference between the provided set and the provided subset.
      Parameters:
      aArgs - The set to be used for the diff operation.
      aArgsSubset - The subset to be used for the diff operation.
      Returns:
      The difference between the set and the subset.
    • toParsedArgs

      protected static String[] toParsedArgs(Operand<?>[]... aOperands)
      Takes all Operand instances found in the provided Lists and adds all therein found argument arrays (as of Operand.getParsedArgs()) to the result.
      Parameters:
      aOperands - The lists containing the Operand instances whose command line arguments are to be added to the result.
      Returns:
      All the command line arguments detected in the provided Operands Lists.