Class AndCondition

java.lang.Object
org.refcodes.cli.AbstractCondition
org.refcodes.cli.AndCondition
All Implemented Interfaces:
Condition, MatchCountAccessor, Synopsisable, Term, org.refcodes.exception.ExceptionAccessor<ArgsSyntaxException>, org.refcodes.graphical.VisibleAccessor, org.refcodes.graphical.VisibleAccessor.VisibleBuilder<Term>, org.refcodes.graphical.VisibleAccessor.VisibleMutator, org.refcodes.graphical.VisibleAccessor.VisibleProperty, org.refcodes.mixin.ChildrenAccessor<Term[]>, org.refcodes.mixin.DescriptionAccessor, org.refcodes.mixin.Resetable, org.refcodes.schema.Schemable

public class AndCondition extends AbstractCondition
An AndCondition contains (represents) a list of Condition (Term) instances (nested by the AndCondition) of which all are to be parsed successfully as of invoking the Term.parseArgs(String[], String[], CliContext) methods. The command line arguments syntax -a & -b & -c specifies that all "-a", "-b" and "-c" must be set. In case at least one is not set, then the AndCondition will terminate the parseArgs(String[], String[], CliContext) method with an exception. If one argument is optional, then consider nesting it in an AnyCondition.