Class AnyCondition

java.lang.Object
org.refcodes.cli.AbstractCondition
org.refcodes.cli.AnyCondition
All Implemented Interfaces:
Condition, MatchCountAccessor, Synopsisable, Term, org.refcodes.exception.ExceptionAccessor<ArgsSyntaxException>, org.refcodes.graphical.VisibleAccessor, org.refcodes.graphical.VisibleAccessor.VisibleBuilder<Term>, org.refcodes.graphical.VisibleAccessor.VisibleMutator, org.refcodes.graphical.VisibleAccessor.VisibleProperty, org.refcodes.mixin.ChildrenAccessor<Term[]>, org.refcodes.mixin.DescriptionAccessor, org.refcodes.mixin.Resetable, org.refcodes.schema.Schemable

public class AnyCondition extends AbstractCondition
Any of the nested Condition conditions may match for the AnyCondition to match, e.g. all of the nested conditions are optional. The AnyCondition can nested by an AndCondition and encapsulates a Condition which may be provided but does not necessarily needs to be provided in order for the AndCondition to successfully parse the nested Condition items including the AnyCondition.