- All Known Subinterfaces:
ArgsAccessor.ArgsProperty,Operand<T>,Option<T>
- All Known Implementing Classes:
AbstractOperand,AbstractOption,AmbiguousArgsException,ArgsSyntaxException,ArrayOperand,ArrayOption,CharOption,CleanFlag,CliException.ConsoleArgsException,ConfigOption,DaemonFlag,DebugFlag,DoubleOption,EnumOption,FileOption,Flag,FloatOption,ForceFlag,HelpFlag,InitFlag,IntOption,LongOption,NoneOperand,Operation,ParseArgsException,QuietFlag,StringOperand,StringOption,SuperfluousArgsException,SysInfoFlag,UnknownArgsException,VerboseFlag
public interface ArgsAccessor
Provides an accessor for a command line arguments (short "args") array.
-
Nested Class Summary
Nested ClassesModifier and TypeInterfaceDescriptionstatic interfaceProvides a mutator for a args property.static interfaceProvides a args property. -
Method Summary
Modifier and TypeMethodDescriptionString[]Retrieves the command line arguments from the args property.
-
Method Details
-
toParsedArgs
String[] toParsedArgs()Retrieves the command line arguments from the args property.- Returns:
- The command line arguments stored by the args property.
-