-
- All Known Subinterfaces:
ArgsAccessor.ArgsProperty,Operand<T>,Option<T>
- All Known Implementing Classes:
AbstractOperand,AbstractOption,AmbiguousArgsException,ArgsMismatchException,ArrayOperand,ArrayOption,CharOption,CliException.ConsoleArgsException,ConfigOption,DaemonFlag,DebugFlag,DoubleOption,EnumOption,FileOption,Flag,FloatOption,ForceFlag,HelpFlag,InitFlag,IntOption,LongOption,NoneOperand,Operation,ParseArgsException,QuietFlag,StringOperand,StringOption,SuperfluousArgsException,SysInfoFlag,UnknownArgsException,VerboseFlag
public interface ArgsAccessorProvides an accessor for a command line arguments (short "args") array.
-
-
Nested Class Summary
Nested Classes Modifier and Type Interface Description static interfaceArgsAccessor.ArgsMutatorProvides a mutator for a args property.static interfaceArgsAccessor.ArgsPropertyProvides a args property.
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description String[]getArgs()Retrieves the command line arguments from the args property.
-
-
-
Method Detail
-
getArgs
String[] getArgs()
Retrieves the command line arguments from the args property.- Returns:
- The command line arguments stored by the args property.
-
-