- All Known Subinterfaces:
ArgsAccessor.ArgsProperty,Operand<T>,Option<T>
- All Known Implementing Classes:
AbstractOperand,AbstractOption,AmbiguousArgsException,ArgsMismatchException,ArrayOperand,ArrayOption,CharOption,CliException.ConsoleArgsException,DebugFlag,DoubleOption,EnumOption,FileOption,Flag,FloatOption,ForceFlag,HelpFlag,IntOption,LongOption,Operation,ParseArgsException,QuietFlag,StringOperand,StringOption,SuperfluousArgsException,SysInfoFlag,UnknownArgsException,VerboseFlag
public interface ArgsAccessor
Provides an accessor for a command line arguments (short "args") array.
-
Nested Class Summary
Nested Classes Modifier and Type Interface Description static interfaceArgsAccessor.ArgsMutatorProvides a mutator for a args property.static interfaceArgsAccessor.ArgsPropertyProvides a args property. -
Method Summary
-
Method Details
-
getArgs
String[] getArgs()Retrieves the command line arguments from the args property.- Returns:
- The command line arguments stored by the args property.
-