- All Superinterfaces:
ArgsParserMixin<ArgsParser>,org.refcodes.mixin.DescriptionAccessor,org.refcodes.mixin.DescriptionAccessor.DescriptionBuilder<ArgsParser>,org.refcodes.mixin.DescriptionAccessor.DescriptionMutator,org.refcodes.mixin.DescriptionAccessor.DescriptionProperty,org.refcodes.mixin.EscapeCodesStatusAccessor,org.refcodes.mixin.EscapeCodesStatusAccessor.EscapeCodeStatusBuilder<ArgsParser>,org.refcodes.mixin.EscapeCodesStatusAccessor.EscapeCodeStatusMutator,org.refcodes.mixin.EscapeCodesStatusAccessor.EscapeCodeStatusProperty,org.refcodes.mixin.NameAccessor,org.refcodes.mixin.NameAccessor.NameBuilder<ArgsParser>,org.refcodes.mixin.NameAccessor.NameMutator,org.refcodes.mixin.NameAccessor.NameProperty,org.refcodes.component.Resetable,org.refcodes.mixin.ResetEscapeCodeAccessor,org.refcodes.mixin.ResetEscapeCodeAccessor.ResetEscapeCodeBuilder<ArgsParser>,org.refcodes.mixin.ResetEscapeCodeAccessor.ResetEscapeCodeMutator,org.refcodes.mixin.ResetEscapeCodeAccessor.ResetEscapeCodeProperty,RootConditionAccessor,org.refcodes.textual.TextBoxGridAccessor,org.refcodes.textual.TextBoxGridAccessor.TextBoxGridBuilder<ArgsParser>,org.refcodes.textual.TextBoxGridAccessor.TextBoxGridMutator,org.refcodes.textual.TextBoxGridAccessor.TextBoxGridProperty,org.refcodes.mixin.TitleAccessor,org.refcodes.mixin.TitleAccessor.TitleBuilder<ArgsParser>,org.refcodes.mixin.TitleAccessor.TitleMutator,org.refcodes.mixin.TitleAccessor.TitleProperty
- All Known Implementing Classes:
ArgsParserImpl
public interface ArgsParser extends ArgsParserMixin<ArgsParser>, org.refcodes.mixin.TitleAccessor.TitleProperty, org.refcodes.mixin.TitleAccessor.TitleBuilder<ArgsParser>, org.refcodes.mixin.NameAccessor.NameProperty, org.refcodes.mixin.NameAccessor.NameBuilder<ArgsParser>, org.refcodes.mixin.DescriptionAccessor.DescriptionProperty, org.refcodes.mixin.DescriptionAccessor.DescriptionBuilder<ArgsParser>, org.refcodes.component.Resetable, RootConditionAccessor, org.refcodes.mixin.EscapeCodesStatusAccessor.EscapeCodeStatusProperty, org.refcodes.mixin.EscapeCodesStatusAccessor.EscapeCodeStatusBuilder<ArgsParser>, org.refcodes.mixin.ResetEscapeCodeAccessor.ResetEscapeCodeProperty, org.refcodes.mixin.ResetEscapeCodeAccessor.ResetEscapeCodeBuilder<ArgsParser>, org.refcodes.textual.TextBoxGridAccessor.TextBoxGridProperty, org.refcodes.textual.TextBoxGridAccessor.TextBoxGridBuilder<ArgsParser>
The
ArgsParser provides means for parsing command line arguments and
constructing a command line utility's help output.-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.mixin.DescriptionAccessor
org.refcodes.mixin.DescriptionAccessor.DescriptionBuilder<B extends org.refcodes.mixin.DescriptionAccessor.DescriptionBuilder<B>>, org.refcodes.mixin.DescriptionAccessor.DescriptionMutator, org.refcodes.mixin.DescriptionAccessor.DescriptionPropertyNested classes/interfaces inherited from interface org.refcodes.mixin.EscapeCodesStatusAccessor
org.refcodes.mixin.EscapeCodesStatusAccessor.EscapeCodeStatusBuilder<B extends org.refcodes.mixin.EscapeCodesStatusAccessor.EscapeCodeStatusBuilder<B>>, org.refcodes.mixin.EscapeCodesStatusAccessor.EscapeCodeStatusMutator, org.refcodes.mixin.EscapeCodesStatusAccessor.EscapeCodeStatusPropertyNested classes/interfaces inherited from interface org.refcodes.mixin.NameAccessor
org.refcodes.mixin.NameAccessor.NameBuilder<B extends org.refcodes.mixin.NameAccessor.NameBuilder<B>>, org.refcodes.mixin.NameAccessor.NameMutator, org.refcodes.mixin.NameAccessor.NamePropertyNested classes/interfaces inherited from interface org.refcodes.mixin.ResetEscapeCodeAccessor
org.refcodes.mixin.ResetEscapeCodeAccessor.ResetEscapeCodeBuilder<B extends org.refcodes.mixin.ResetEscapeCodeAccessor.ResetEscapeCodeBuilder<B>>, org.refcodes.mixin.ResetEscapeCodeAccessor.ResetEscapeCodeMutator, org.refcodes.mixin.ResetEscapeCodeAccessor.ResetEscapeCodePropertyNested classes/interfaces inherited from interface org.refcodes.cli.RootConditionAccessor
RootConditionAccessor.RootConditionBuilder<B extends RootConditionAccessor.RootConditionBuilder<B>>, RootConditionAccessor.RootConditionMutator, RootConditionAccessor.RootConditionPropertyNested classes/interfaces inherited from interface org.refcodes.textual.TextBoxGridAccessor
org.refcodes.textual.TextBoxGridAccessor.TextBoxGridBuilder<B extends org.refcodes.textual.TextBoxGridAccessor.TextBoxGridBuilder<?>>, org.refcodes.textual.TextBoxGridAccessor.TextBoxGridMutator, org.refcodes.textual.TextBoxGridAccessor.TextBoxGridPropertyNested classes/interfaces inherited from interface org.refcodes.mixin.TitleAccessor
org.refcodes.mixin.TitleAccessor.TitleBuilder<B extends org.refcodes.mixin.TitleAccessor.TitleBuilder<B>>, org.refcodes.mixin.TitleAccessor.TitleMutator, org.refcodes.mixin.TitleAccessor.TitleProperty -
Method Summary
Modifier and Type Method Description voidaddExampleUsage(String aDescription, Operand<?>... aOperands)Adds a usage example by providing a description of the example and the command line arguments required by the example.voiderrorLn(String aLine)Prints the given line to standard error with regards to to the console width as specified by thewithConsoleWidth(int)method.List<? extends Operand<?>>evalArgs(String[] aArgs)Evaluates the provided command line arguments and determines the according values by evaluating the rootCondition.default List<? extends Operand<?>>evalArgs(List<String> aArgs)Same asevalArgs(String[])with the difference that the elements representing the arguments are passed as a list instead of an array.StringgetBannerBorderEscapeCode()Retrieves the banner's border Escape-Code from the banner border Escape-Code property.StringgetBannerEscapeCode()Retrieves the banner's content Escape-Code from the banner Escape-Code property.StringgetCopyrightNote()Retrieves the copyright.StringgetDescription()Retrieves the description.StringgetDescriptionEscapeCode()Retrieves the parameter's description Escape-Code from the parameter's description Escape-Code property.List<ExampleUsage>getExampleUsages()Retrieves theExampleUsageinstances as addeed usingaddExampleUsage(String, Operand...).StringgetLicenseNote()Retrieves the license.StringgetLineSeparatorEscapeCode()Retrieves the line separator Escape-Code from the line separator Escape-Code property.StringgetParameterEscapeCode()Retrieves the parameter Escape-Code from the parameter Escape-Code property.ConditiongetRootCondition()The root condition is the starting point node of aSyntaxablehierarchy to be traversed when determining the syntax for command line arguments or when evaluating the command line arguments.chargetSeparatorLnChar()Gets the character to be used when printing a separator line with theprintSeparatorLn()method.voidprintBanner()Prints the banner; the banner most probably is an ASCII_HEADER_ASCII_BODY art text block which's look depends strongly on the taste of the author implementing this interface.default voidprintBody()Prints the help as ofprintHelp()without the banner.voidprintCopyrightNote()Prints the copyright note as specified by thewithCopyrightNote(String)method; with regards to to the console width as specified by thewithConsoleWidth(int)method.voidprintDescription()Prints the description as set by thewithDescription(String)method with regards to the console width as specified by thewithConsoleWidth(int)method.voidprintExampleUsages()Prints example usages as as added by theaddExampleUsage(String, Operand...)method with regards to the console width as specified by thewithConsoleWidth(int)method.default voidprintHelp()Prints the help to the standard output specified by thewithStandardOut(PrintStream)method.voidprintLicenseNote()Prints the license note as specified by thewithLicenseNote(String)method; with regards to to the console width as specified by thewithConsoleWidth(int)method.voidprintLn()Prints an empty line / a line break.voidprintLn(String aLine)Prints the given line to standard out with regards to to the console width as specified by thewithConsoleWidth(int)method.voidprintOptions()Prints theOptions (short- and the long-options), theFlages and theOperandand their description with regards to the console width as specified by thewithConsoleWidth(int)method.voidprintSeparatorLn()Prints a separator line using the separator character as specified by thewithSeparatorLnChar(char)method; with regards to to the console width as specified by thewithConsoleWidth(int)method.voidprintUsage()Prints the syntax as retrieved by the rootConditionwith regards to theSyntaxNotationset by thewithSyntaxNotation(SyntaxNotation)method; making use of the usage label as passed by thewithUsageLabel(String)method.voidsetBannerBorderEscapeCode(String aBannerBorderEscCode)Sets the banner's border Escape-Code for the banner border Escape-Code property.voidsetBannerEscapeCode(String aBannerEscCode)Sets the banner's content Escape-Code for the banner Escape-Code property.voidsetBannerFont(org.refcodes.textual.Font aBannerFont)Sets the banner font.voidsetBannerFontPalette(char[] aColorPalette)Sets the banner font palette.voidsetConsoleWidth(int aConsoleWidth)Set the console with.voidsetCopyrightNote(String aCopyrightNote)Set the copyright note used by theprintHelp()method when writing out the copyright claim and make other adjustments with the result (with regards to the Builder-Pattern).voidsetDescriptionEscapeCode(String aDescriptionEscCode)Sets the description Escape-Code for the description Escape-Code property.voidsetErrorOut(PrintStream aErrorOut)Set the error outPrintStreamand make other adjustments with the result (with regards to the Builder-Pattern).voidsetLicenseNote(String aLicenseNote)Set the license note used by theprintHelp()method when writing out the licensing conditions.voidsetLineBreak(String aLineBreak)Set the console's line break.voidsetLineSeparatorEscapeCode(String aLineSeparatorEscCode)Sets the line separator Escape-Code for the line separator Escape-Code property.voidsetMaxConsoleWidth(int aMaxConsoleWidth)Set the maximum console width to use in case the console width is greater than the maximum you want.voidsetParameterEscapeCode(String aParamEscCode)Sets the parameter Escape-Code for the parameter Escape-Code property.voidsetSeparatorLnChar(char aSeparatorLnChar)Set the character to be used when printing a separator line with theprintSeparatorLn()method.voidsetStandardOut(PrintStream aStandardOut)Set the standard outPrintStreamand make other adjustments with the result (with regards to the Builder-Pattern).voidsetSyntaxNotation(SyntaxNotation aSyntaxNotation)Set theSyntaxNotation.voidsetUsageLabel(String aUsageLabel)Set the usage label used by theprintHelp()method when writing out the syntax.default ArgsParserwithBannerBorderEscapeCode(String aBannerBorderEscCode)Sets the banner's border Escape-Code for the banner border Escape-Code property.default ArgsParserwithBannerEscapeCode(String aBannerEscCode)Sets the banner's content Escape-Code for the banner Escape-Code property.default ArgsParserwithBannerFont(org.refcodes.textual.Font aBannerFont)With banner font.default ArgsParserwithBannerFontPalette(char[] aColorPalette)With banner font palette.default ArgsParserwithConsoleWidth(int aConsoleWidth)Set the console with.default ArgsParserwithCopyrightNote(String aCopyrightNote)Set the copyright note used by theprintHelp()method when writing out the copyright claim and make other adjustments with the result (with regards to the Builder-Pattern).default ArgsParserwithDescription(String aDescription)With description.default ArgsParserwithDescriptionEscapeCode(String aDescriptionEscCode)Sets the description Escape-Code for the description Escape-Code property.default ArgsParserwithErrorOut(PrintStream aErrorOut)Set the error outPrintStreamand make other adjustments with the result (with regards to the Builder-Pattern).default ArgsParserwithEscapeCodesEnabled(boolean isEscCodeEnabled)default ArgsParserwithEvalArgs(String[] aArgs)Same asevalArgs(String[])with the difference that this class's instance being invoked is returned as of the builder pattern.default ArgsParserwithEvalArgs(List<String> aArgs)Same asevalArgs(List)with the difference that this class's instance being invoked is returned as of the builder pattern.default ArgsParserwithExampleUsage(String aDescription, Operand<?>... aOperands)Adds a usage example by providing a description of the example and the command line arguments required by the example.default ArgsParserwithLicenseNote(String aLicenseNote)Set the license note used by theprintHelp()method when writing out the licensing conditions and make other adjustments with the result (with regards to the Builder-Pattern).default ArgsParserwithLineBreak(String aLineBreak)Set the console's line break.default ArgsParserwithLineSeparatorEscapeCode(String aLineSeparatorEscCode)Sets the line separator Escape-Code for the line separator Escape-Code property.default ArgsParserwithMaxConsoleWidth(int aMaxConsoleWidth)Set the maximum console width to use in case the console width is greater than the maximum you want.default ArgsParserwithName(String aName)With name.default ArgsParserwithParameterEscapeCode(String aParamEscCode)Sets the parameter Escape-Code for the parameter Escape-Code property.default ArgsParserwithResetEscapeCode(String aResetEscCode)default ArgsParserwithSeparatorLnChar(char aSeparatorLnChar)Set the character to be used when printing a separator line with theprintSeparatorLn()method.default ArgsParserwithStandardOut(PrintStream aStandardOut)Set the standard outPrintStreamand make other adjustments with the result (with regards to the Builder-Pattern).default ArgsParserwithSyntaxNotation(SyntaxNotation aSyntaxNotation)Set theSyntaxNotationand make other adjustments with the result (with regards to the Builder-Pattern).default ArgsParserwithTextBoxGrid(org.refcodes.textual.TextBoxGrid aTextBoxGrid)default ArgsParserwithTitle(String aTitle)With title.default ArgsParserwithUsageLabel(String aUsageLabel)Set the usage label used by theprintHelp()method when writing out the syntax and make other adjustments with the result (with regards to the Builder-Pattern).Methods inherited from interface org.refcodes.mixin.DescriptionAccessor.DescriptionMutator
setDescriptionMethods inherited from interface org.refcodes.mixin.DescriptionAccessor.DescriptionProperty
letDescriptionMethods inherited from interface org.refcodes.mixin.EscapeCodesStatusAccessor
isEscapeCodesEnabledMethods inherited from interface org.refcodes.mixin.EscapeCodesStatusAccessor.EscapeCodeStatusMutator
setEscapeCodesEnabledMethods inherited from interface org.refcodes.mixin.EscapeCodesStatusAccessor.EscapeCodeStatusProperty
letEscapeCodesEnabledMethods inherited from interface org.refcodes.mixin.NameAccessor
getNameMethods inherited from interface org.refcodes.mixin.NameAccessor.NameMutator
setNameMethods inherited from interface org.refcodes.mixin.NameAccessor.NameProperty
letNameMethods inherited from interface org.refcodes.component.Resetable
resetMethods inherited from interface org.refcodes.mixin.ResetEscapeCodeAccessor
getResetEscapeCodeMethods inherited from interface org.refcodes.mixin.ResetEscapeCodeAccessor.ResetEscapeCodeMutator
setResetEscapeCodeMethods inherited from interface org.refcodes.mixin.ResetEscapeCodeAccessor.ResetEscapeCodeProperty
letResetEscapeCodeMethods inherited from interface org.refcodes.textual.TextBoxGridAccessor
getTextBoxGridMethods inherited from interface org.refcodes.textual.TextBoxGridAccessor.TextBoxGridMutator
setTextBoxGridMethods inherited from interface org.refcodes.textual.TextBoxGridAccessor.TextBoxGridProperty
letTextBoxGridMethods inherited from interface org.refcodes.mixin.TitleAccessor
getTitleMethods inherited from interface org.refcodes.mixin.TitleAccessor.TitleMutator
setTitleMethods inherited from interface org.refcodes.mixin.TitleAccessor.TitleProperty
letTitle
-
Method Details
-
errorLn
Prints the given line to standard error with regards to to the console width as specified by thewithConsoleWidth(int)method.- Parameters:
aLine- The line to be printed.
-
evalArgs
default List<? extends Operand<?>> evalArgs(List<String> aArgs) throws UnknownArgsException, AmbiguousArgsException, SuperfluousArgsException, ParseArgsExceptionSame asevalArgs(String[])with the difference that the elements representing the arguments are passed as a list instead of an array.- Parameters:
aArgs- The command line arguments to be evaluated.- Returns:
- The list of evaluated command line arguments being instances of
the
Operandinterfaces or its sub-types. - Throws:
UnknownArgsException- Thrown in case not one command line argument matched regarding the provided args vs. the expected args.AmbiguousArgsException- Thrown in case at least one command line argument is ambiguous regarding expected args vs. provided args.SuperfluousArgsException- Thrown in case there were arguments found not being used (superfluous arguments).ParseArgsException- Thrown in case the provided command line arguments do not respect the required syntax or cannot be converted to the required type
-
evalArgs
List<? extends Operand<?>> evalArgs(String[] aArgs) throws UnknownArgsException, AmbiguousArgsException, SuperfluousArgsException, ParseArgsExceptionEvaluates the provided command line arguments and determines the according values by evaluating the rootCondition. In case of parsing failure, an according exception is thrown. ATTENTION: This method tests(!) for superfluous command line arguments being passed; e.g. command line arguments not being evaluated by any of theSyntaxableinstance being traversed starting at the rootConditionwill be reported. Business logic therefore should invoke this root node'sevalArgs(String[])method instead of aCondition'sSyntaxable.parseArgs(String[], String[])method; as ignoring superfluous command line arguments will cause unexpected behavior from the point of view of the invoker.- Parameters:
aArgs- The command line arguments to be evaluated.- Returns:
- The list of evaluated command line arguments being instances of
the
Operandinterfaces or its sub-types. - Throws:
UnknownArgsException- Thrown in case not one command line argument matched regarding the provided args vs. the expected args.AmbiguousArgsException- Thrown in case at least one command line argument is ambiguous regarding expected args vs. provided args.SuperfluousArgsException- Thrown in case there were arguments found not being used (superfluous arguments).ParseArgsException- Thrown in case the provided command line arguments do not respect the required syntax or cannot be converted to the required type
-
getCopyrightNote
String getCopyrightNote()Retrieves the copyright.- Returns:
- The copyright note.
-
getDescription
String getDescription()Retrieves the description.- Specified by:
getDescriptionin interfaceorg.refcodes.mixin.DescriptionAccessor- Returns:
- The description.
-
getLicenseNote
String getLicenseNote()Retrieves the license.- Returns:
- The license note.
-
getDescriptionEscapeCode
String getDescriptionEscapeCode()Retrieves the parameter's description Escape-Code from the parameter's description Escape-Code property.- Returns:
- The description Escape-Code stored by the description Escape-Code property.
-
getParameterEscapeCode
String getParameterEscapeCode()Retrieves the parameter Escape-Code from the parameter Escape-Code property.- Returns:
- The parameter Escape-Code stored by the parameter Escape-Code property.
-
getBannerEscapeCode
String getBannerEscapeCode()Retrieves the banner's content Escape-Code from the banner Escape-Code property.- Returns:
- The banner Escape-Code stored by the banner Escape-Code property.
-
getLineSeparatorEscapeCode
String getLineSeparatorEscapeCode()Retrieves the line separator Escape-Code from the line separator Escape-Code property.- Returns:
- The line separator Escape-Code stored by the line separator Escape-Code property.
-
getSeparatorLnChar
char getSeparatorLnChar()Gets the character to be used when printing a separator line with theprintSeparatorLn()method.- Returns:
- aSeparatorChar The character used by the
printSeparatorLn()method when printing out the line of characters..
-
getBannerBorderEscapeCode
String getBannerBorderEscapeCode()Retrieves the banner's border Escape-Code from the banner border Escape-Code property.- Returns:
- The banner border Escape-Code stored by the banner border Escape-Code property.
-
getRootCondition
Condition getRootCondition()The root condition is the starting point node of aSyntaxablehierarchy to be traversed when determining the syntax for command line arguments or when evaluating the command line arguments. Retrieves the root condition from the root condition property.- Specified by:
getRootConditionin interfaceRootConditionAccessor- Returns:
- The root
Conditionin which's syntax this parser is based.
-
getExampleUsages
List<ExampleUsage> getExampleUsages()Retrieves theExampleUsageinstances as addeed usingaddExampleUsage(String, Operand...).- Returns:
- The according
ExampleUsageelements.
-
addExampleUsage
Adds a usage example by providing a description of the example and the command line arguments required by the example.- Parameters:
aDescription- The description of the example.aOperands- The command line arguments used by the example.
-
withExampleUsage
Adds a usage example by providing a description of the example and the command line arguments required by the example.- Parameters:
aDescription- The description of the example.aOperands- The command line arguments used by the example.- Returns:
- This instance as of the builder pattern.
-
printBanner
void printBanner()Prints the banner; the banner most probably is an ASCII_HEADER_ASCII_BODY art text block which's look depends strongly on the taste of the author implementing this interface. -
printBody
default void printBody()Prints the help as ofprintHelp()without the banner. -
printCopyrightNote
void printCopyrightNote()Prints the copyright note as specified by thewithCopyrightNote(String)method; with regards to to the console width as specified by thewithConsoleWidth(int)method. -
printDescription
void printDescription()Prints the description as set by thewithDescription(String)method with regards to the console width as specified by thewithConsoleWidth(int)method. -
printExampleUsages
void printExampleUsages()Prints example usages as as added by theaddExampleUsage(String, Operand...)method with regards to the console width as specified by thewithConsoleWidth(int)method. -
printHelp
default void printHelp()Prints the help to the standard output specified by thewithStandardOut(PrintStream)method. This method can make use of the more atomic methodsprintBanner(),printUsage(),printDescription(),printOptions()orprintSeparatorLn()to print a help text which's look depends strongly on the taste of the author implementing this interface. In case you dislike the implementing author's taste, feel free to overwrite this method and compose your own help text from the building blocks such asprintBanner(),printUsage(),printDescription(),printOptions()orprintSeparatorLn() -
printLicenseNote
void printLicenseNote()Prints the license note as specified by thewithLicenseNote(String)method; with regards to to the console width as specified by thewithConsoleWidth(int)method. -
printLn
void printLn()Prints an empty line / a line break. -
printLn
Prints the given line to standard out with regards to to the console width as specified by thewithConsoleWidth(int)method.- Parameters:
aLine- The line to be printed.
-
printOptions
void printOptions()Prints theOptions (short- and the long-options), theFlages and theOperandand their description with regards to the console width as specified by thewithConsoleWidth(int)method. -
printSeparatorLn
void printSeparatorLn()Prints a separator line using the separator character as specified by thewithSeparatorLnChar(char)method; with regards to to the console width as specified by thewithConsoleWidth(int)method. -
printUsage
void printUsage()Prints the syntax as retrieved by the rootConditionwith regards to theSyntaxNotationset by thewithSyntaxNotation(SyntaxNotation)method; making use of the usage label as passed by thewithUsageLabel(String)method. -
setBannerFont
void setBannerFont(org.refcodes.textual.Font aBannerFont)Sets the banner font.- Parameters:
aBannerFont- the new banner font
-
setBannerFontPalette
void setBannerFontPalette(char[] aColorPalette)Sets the banner font palette.- Parameters:
aColorPalette- the new banner font palette
-
setConsoleWidth
void setConsoleWidth(int aConsoleWidth)Set the console with. A setting of "-1" makes the instance use theSystemUtility.getTerminalWidth()value, i.e. the console width is set automatically to be the width of your terminal.- Parameters:
aConsoleWidth- The width to set or -1 to let the parser automatically determine the console width.
-
setCopyrightNote
Set the copyright note used by theprintHelp()method when writing out the copyright claim and make other adjustments with the result (with regards to the Builder-Pattern).- Parameters:
aCopyrightNote- The license note printed out by theprintHelp()method.
-
setErrorOut
Set the error outPrintStreamand make other adjustments with the result (with regards to the Builder-Pattern).- Parameters:
aErrorOut- The error outPrintStreamto set.
-
setLicenseNote
Set the license note used by theprintHelp()method when writing out the licensing conditions.- Parameters:
aLicenseNote- The license note printed out by theprintHelp()method.
-
setLineBreak
Set the console's line break. A setting of null makes the instance use theSystemUtility.getLineBreak()value.- Parameters:
aLineBreak- the new line break
-
setMaxConsoleWidth
void setMaxConsoleWidth(int aMaxConsoleWidth)Set the maximum console width to use in case the console width is greater than the maximum you want. This is most useful when the console width is determined automatically to be the width of your terminal.- Parameters:
aMaxConsoleWidth- the new max console width
-
setDescriptionEscapeCode
Sets the description Escape-Code for the description Escape-Code property.- Parameters:
aDescriptionEscCode- The description Escape-Code to be stored by the description Escape-Code property.
-
setParameterEscapeCode
Sets the parameter Escape-Code for the parameter Escape-Code property.- Parameters:
aParamEscCode- The parameter Escape-Code to be stored by the parameter Escape-Code property.
-
setBannerEscapeCode
Sets the banner's content Escape-Code for the banner Escape-Code property.- Parameters:
aBannerEscCode- The banner Escape-Code to be stored by the banner Escape-Code property.
-
setLineSeparatorEscapeCode
Sets the line separator Escape-Code for the line separator Escape-Code property.- Parameters:
aLineSeparatorEscCode- The line separator Escape-Code to be stored by the line separator Escape-Code property.
-
setBannerBorderEscapeCode
Sets the banner's border Escape-Code for the banner border Escape-Code property.- Parameters:
aBannerBorderEscCode- The banner border Escape-Code to be stored by the banner border Escape-Code property.
-
setSeparatorLnChar
void setSeparatorLnChar(char aSeparatorLnChar)Set the character to be used when printing a separator line with theprintSeparatorLn()method.- Parameters:
aSeparatorLnChar- The character used by theprintSeparatorLn()method when printing out the line of characters..
-
setStandardOut
Set the standard outPrintStreamand make other adjustments with the result (with regards to the Builder-Pattern).- Parameters:
aStandardOut- The standard outPrintStreamto set.
-
setSyntaxNotation
Set theSyntaxNotation.- Parameters:
aSyntaxNotation- TheSyntaxNotationto set.
-
setUsageLabel
Set the usage label used by theprintHelp()method when writing out the syntax.- Parameters:
aUsageLabel- The usage label printed out by theprintHelp()method.
-
withTextBoxGrid
- Specified by:
withTextBoxGridin interfaceorg.refcodes.textual.TextBoxGridAccessor.TextBoxGridBuilder<ArgsParser>
-
withBannerFont
With banner font.- Parameters:
aBannerFont- the banner font- Returns:
- the args parser
-
withBannerFontPalette
With banner font palette.- Parameters:
aColorPalette- the color palette- Returns:
- the args parser
-
withConsoleWidth
Set the console with. A setting of "-1" makes the instance use theSystemUtility.getTerminalWidth()value.- Parameters:
aConsoleWidth- The width to set.- Returns:
- This
ArgsParserinstance with regard to the builder pattern.
-
withCopyrightNote
Set the copyright note used by theprintHelp()method when writing out the copyright claim and make other adjustments with the result (with regards to the Builder-Pattern).- Parameters:
aCopyrightNote- The license note printed out by theprintHelp()method.- Returns:
- This
ArgsParserinstance with regard to the builder pattern.
-
withDescription
With description.- Specified by:
withDescriptionin interfaceorg.refcodes.mixin.DescriptionAccessor.DescriptionBuilder<ArgsParser>- Parameters:
aDescription- the description- Returns:
- the args parser
-
withErrorOut
Set the error outPrintStreamand make other adjustments with the result (with regards to the Builder-Pattern).- Parameters:
aErrorOut- The error outPrintStreamto set.- Returns:
- This
ArgsParserinstance with regard to the builder pattern.
-
withEscapeCodesEnabled
- Specified by:
withEscapeCodesEnabledin interfaceorg.refcodes.mixin.EscapeCodesStatusAccessor.EscapeCodeStatusBuilder<ArgsParser>
-
withEvalArgs
default ArgsParser withEvalArgs(List<String> aArgs) throws UnknownArgsException, AmbiguousArgsException, SuperfluousArgsException, ParseArgsExceptionSame asevalArgs(List)with the difference that this class's instance being invoked is returned as of the builder pattern.- Specified by:
withEvalArgsin interfaceArgsParserMixin<ArgsParser>- Parameters:
aArgs- The command line arguments to be evaluated.- Returns:
- This invoked instance as of the builder pattern to chain method calls.
- Throws:
UnknownArgsException- Thrown in case not one command line argument matched regarding the provided args vs. the expected args.AmbiguousArgsException- Thrown in case at least one command line argument is ambiguous regarding expected args vs. provided args.SuperfluousArgsException- Thrown in case there were arguments found not being used (superfluous arguments).ParseArgsException- Thrown in case the provided command line arguments do not respect the required syntax or cannot be converted to the required type
-
withLicenseNote
Set the license note used by theprintHelp()method when writing out the licensing conditions and make other adjustments with the result (with regards to the Builder-Pattern).- Parameters:
aLicenseNote- The license note printed out by theprintHelp()method.- Returns:
- This
ArgsParserinstance with regard to the builder pattern.
-
withLineBreak
Set the console's line break. A setting of null makes the instance use theSystemUtility.getLineBreak()value.- Parameters:
aLineBreak- the line break- Returns:
- This
ArgsParserinstance with regard to the builder pattern.
-
withMaxConsoleWidth
Set the maximum console width to use in case the console width is greater than the maximum you want. This is most useful when the console width is determined automatically to be the width of your terminal.- Parameters:
aMaxConsoleWidth- the max console width- Returns:
- This
ArgsParserinstance with regard to the builder pattern.
-
withName
With name.- Specified by:
withNamein interfaceorg.refcodes.mixin.NameAccessor.NameBuilder<ArgsParser>- Parameters:
aName- the name- Returns:
- the args parser
-
withDescriptionEscapeCode
Sets the description Escape-Code for the description Escape-Code property.- Parameters:
aDescriptionEscCode- The parameter's description Escape-Code to be stored by the parameter's description Escape-Code property.- Returns:
- The builder for applying multiple build operations.
-
withParameterEscapeCode
Sets the parameter Escape-Code for the parameter Escape-Code property.- Parameters:
aParamEscCode- The parameter Escape-Code to be stored by the parameter Escape-Code property.- Returns:
- The builder for applying multiple build operations.
-
withBannerEscapeCode
Sets the banner's content Escape-Code for the banner Escape-Code property.- Parameters:
aBannerEscCode- The banner Escape-Code to be stored by the banner Escape-Code property.- Returns:
- The builder for applying multiple build operations.
-
withLineSeparatorEscapeCode
Sets the line separator Escape-Code for the line separator Escape-Code property.- Parameters:
aLineSeparatorEscCode- The line separator Escape-Code to be stored by the line separator Escape-Code property.- Returns:
- The builder for applying multiple build operations.
-
withBannerBorderEscapeCode
Sets the banner's border Escape-Code for the banner border Escape-Code property.- Parameters:
aBannerBorderEscCode- The banner border Escape-Code to be stored by the banner border Escape-Code property.- Returns:
- The builder for applying multiple build operations.
-
withEvalArgs
default ArgsParser withEvalArgs(String[] aArgs) throws UnknownArgsException, AmbiguousArgsException, SuperfluousArgsException, ParseArgsExceptionSame asevalArgs(String[])with the difference that this class's instance being invoked is returned as of the builder pattern.- Specified by:
withEvalArgsin interfaceArgsParserMixin<ArgsParser>- Parameters:
aArgs- The command line arguments to be evaluated.- Returns:
- This invoked instance as of the builder pattern to chain method calls.
- Throws:
UnknownArgsException- Thrown in case not one command line argument matched regarding the provided args vs. the expected args.AmbiguousArgsException- Thrown in case at least one command line argument is ambiguous regarding expected args vs. provided args.SuperfluousArgsException- Thrown in case there were arguments found not being used (superfluous arguments).ParseArgsException- Thrown in case the provided command line arguments do not respect the required syntax or cannot be converted to the required type
-
withResetEscapeCode
- Specified by:
withResetEscapeCodein interfaceorg.refcodes.mixin.ResetEscapeCodeAccessor.ResetEscapeCodeBuilder<ArgsParser>
-
withSeparatorLnChar
Set the character to be used when printing a separator line with theprintSeparatorLn()method.- Parameters:
aSeparatorLnChar- The character used by theprintSeparatorLn()method when printing out the line of characters..- Returns:
- This
ArgsParserinstance with regard to the builder pattern.
-
withStandardOut
Set the standard outPrintStreamand make other adjustments with the result (with regards to the Builder-Pattern).- Parameters:
aStandardOut- The standard outPrintStreamto set.- Returns:
- This
ArgsParserinstance with regard to the builder pattern.
-
withSyntaxNotation
Set theSyntaxNotationand make other adjustments with the result (with regards to the Builder-Pattern).- Parameters:
aSyntaxNotation- TheSyntaxNotationto set.- Returns:
- This
ArgsParserinstance with regard to the builder pattern.
-
withTitle
With title.- Specified by:
withTitlein interfaceorg.refcodes.mixin.TitleAccessor.TitleBuilder<ArgsParser>- Parameters:
aTitle- the title- Returns:
- the args parser
-
withUsageLabel
Set the usage label used by theprintHelp()method when writing out the syntax and make other adjustments with the result (with regards to the Builder-Pattern).- Parameters:
aUsageLabel- The usage label printed out by theprintHelp()method.- Returns:
- This
ArgsParserinstance with regard to the builder pattern.
-