java.lang.Object
org.refcodes.cli.ArgsParserImpl
- All Implemented Interfaces:
ArgsParser,ArgsParserBuilder<ArgsParser>,ArgsProcessorBuilder<ArgsParser>,ArgsSyntaxAccessor,ArgsSyntaxAccessor.ArgsSyntaxBuilder<ArgsParser>,ArgsSyntaxAccessor.ArgsSyntaxMutator,ArgsSyntaxAccessor.ArgsSyntaxProperty,ArgumentEscapeCodeAccessor,ArgumentEscapeCodeAccessor.ArgumentEscapeCodeBuilder<ArgsParser>,ArgumentEscapeCodeAccessor.ArgumentEscapeCodeMutator,ArgumentEscapeCodeAccessor.ArgumentEscapeCodeProperty,BannerBorderEscapeCodeAccessor,BannerBorderEscapeCodeAccessor.BannerBorderEscapeCodeBuilder<ArgsParser>,BannerBorderEscapeCodeAccessor.BannerBorderEscapeCodeMutator,BannerBorderEscapeCodeAccessor.BannerBorderEscapeCodeProperty,BannerEscapeCodeAccessor,BannerEscapeCodeAccessor.BannerEscapeCodeBuilder<ArgsParser>,BannerEscapeCodeAccessor.BannerEscapeCodeMutator,BannerEscapeCodeAccessor.BannerEscapeCodeProperty,BannerFontAccessor,BannerFontAccessor.BannerFontBuilder<ArgsParser>,BannerFontAccessor.BannerFontMutator,BannerFontAccessor.BannerFontProperty,BannerFontPaletteAccessor,BannerFontPaletteAccessor.BannerFontPaletteBuilder<ArgsParser>,BannerFontPaletteAccessor.BannerFontPaletteMutator,BannerFontPaletteAccessor.BannerFontPaletteProperty,CliMetrics,CommandEscapeCodeAccessor,CommandEscapeCodeAccessor.CommandEscapeCodeBuilder<ArgsParser>,CommandEscapeCodeAccessor.CommandEscapeCodeMutator,CommandEscapeCodeAccessor.CommandEscapeCodeProperty,CopyrightAccessor,CopyrightAccessor.CopyrightBuilder<ArgsParser>,CopyrightAccessor.CopyrightMutator,CopyrightAccessor.CopyrightProperty,DescriptionEscapeCodeAccessor,DescriptionEscapeCodeAccessor.DescriptionEscapeCodeBuilder<ArgsParser>,DescriptionEscapeCodeAccessor.DescriptionEscapeCodeMutator,DescriptionEscapeCodeAccessor.DescriptionEscapeCodeProperty,ExamplesAccessor,ExamplesAccessor.ExamplesBuilder<ArgsParser>,ExamplesAccessor.ExamplesMutator,ExamplesAccessor.ExamplesProperty,LicenseAccessor,LicenseAccessor.LicenseBuilder<ArgsParser>,LicenseAccessor.LicenseMutator,LicenseAccessor.LicenseProperty,LineSeparatorEscapeCodeAccessor,LineSeparatorEscapeCodeAccessor.LineSeparatorEscapeCodeBuilder<ArgsParser>,LineSeparatorEscapeCodeAccessor.LineSeparatorEscapeCodeMutator,LineSeparatorEscapeCodeAccessor.LineSeparatorEscapeCodeProperty,LongOptionPrefixAccessor,LongOptionPrefixAccessor.LongOptionPrefixBuilder<ArgsParser>,LongOptionPrefixAccessor.LongOptionPrefixMutator,LongOptionPrefixAccessor.LongOptionPrefixProperty,Optionable,OptionEscapeCodeAccessor,OptionEscapeCodeAccessor.OptionEscapeCodeBuilder<ArgsParser>,OptionEscapeCodeAccessor.OptionEscapeCodeMutator,OptionEscapeCodeAccessor.OptionEscapeCodeProperty,ShortOptionPrefixAccessor,ShortOptionPrefixAccessor.ShortOptionPrefixBuilder<ArgsParser>,ShortOptionPrefixAccessor.ShortOptionPrefixMutator,ShortOptionPrefixAccessor.ShortOptionPrefixProperty,SyntaxMetricsAccessor,SyntaxMetricsAccessor.SyntaxMetricsBuilder<ArgsParser>,SyntaxMetricsAccessor.SyntaxMetricsMutator,SyntaxMetricsAccessor.SyntaxMetricsProperty,org.refcodes.mixin.ConsoleWidthAccessor,org.refcodes.mixin.ConsoleWidthAccessor.ConsoleWidthBuilder<ArgsParser>,org.refcodes.mixin.ConsoleWidthAccessor.ConsoleWidthMutator,org.refcodes.mixin.ConsoleWidthAccessor.ConsoleWidthProperty,org.refcodes.mixin.DescriptionAccessor,org.refcodes.mixin.DescriptionAccessor.DescriptionBuilder<ArgsParser>,org.refcodes.mixin.DescriptionAccessor.DescriptionMutator,org.refcodes.mixin.DescriptionAccessor.DescriptionProperty,org.refcodes.mixin.EscapeCodesStatusAccessor,org.refcodes.mixin.EscapeCodesStatusAccessor.EscapeCodeStatusBuilder<ArgsParser>,org.refcodes.mixin.EscapeCodesStatusAccessor.EscapeCodeStatusMutator,org.refcodes.mixin.EscapeCodesStatusAccessor.EscapeCodeStatusProperty,org.refcodes.mixin.LineBreakAccessor,org.refcodes.mixin.LineBreakAccessor.LineBreakBuilder<ArgsParser>,org.refcodes.mixin.LineBreakAccessor.LineBreakMutator,org.refcodes.mixin.LineBreakAccessor.LineBreakProperty,org.refcodes.mixin.MaxConsoleWidthAccessor,org.refcodes.mixin.MaxConsoleWidthAccessor.MaxConsoleWidthBuilder<ArgsParser>,org.refcodes.mixin.MaxConsoleWidthAccessor.MaxConsoleWidthMutator,org.refcodes.mixin.MaxConsoleWidthAccessor.MaxConsoleWidthProperty,org.refcodes.mixin.NameAccessor,org.refcodes.mixin.NameAccessor.NameBuilder<ArgsParser>,org.refcodes.mixin.NameAccessor.NameMutator,org.refcodes.mixin.NameAccessor.NameProperty,org.refcodes.mixin.Resetable,org.refcodes.mixin.ResetEscapeCodeAccessor,org.refcodes.mixin.ResetEscapeCodeAccessor.ResetEscapeCodeBuilder<ArgsParser>,org.refcodes.mixin.ResetEscapeCodeAccessor.ResetEscapeCodeMutator,org.refcodes.mixin.ResetEscapeCodeAccessor.ResetEscapeCodeProperty,org.refcodes.mixin.Schemable,org.refcodes.mixin.TitleAccessor,org.refcodes.mixin.TitleAccessor.TitleBuilder<ArgsParser>,org.refcodes.mixin.TitleAccessor.TitleMutator,org.refcodes.mixin.TitleAccessor.TitleProperty,org.refcodes.textual.TextBoxGridAccessor,org.refcodes.textual.TextBoxGridAccessor.TextBoxGridBuilder<ArgsParser>,org.refcodes.textual.TextBoxGridAccessor.TextBoxGridMutator,org.refcodes.textual.TextBoxGridAccessor.TextBoxGridProperty
A straightforward implementation of the
ArgsParser interface. The
constructor only provides means to set the required attributes as the
attributes to be adjusted optionally are already sufficiently preconfigured.
For adjusting them, a flavor of the Builder-Pattern is provided with which
you can easily chain the configuration of this instance; as them methods
return the instance of this class being configured. This helps to prevent the
telescoping constructor anti-pattern.
The SyntaxNotation is pre-set with the SyntaxNotation.LOGICAL
notation.
The console width id preconfigured with the console's width as determined by
the SystemUtility.getTerminalWidth().
The standard out PrintStream is preconfigured with the
System.out PrintStream.
The newline characters to be used for line breaks is "\r\n" on Windows
machines and "\"n" on all other machines as of the
SystemUtility.getLineBreak().
- See Also:
-
- "http://en.wikipedia.org/wiki/Builder_pattern"
-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.cli.ArgsSyntaxAccessor
ArgsSyntaxAccessor.ArgsSyntaxBuilder<B extends ArgsSyntaxAccessor.ArgsSyntaxBuilder<B>>, ArgsSyntaxAccessor.ArgsSyntaxMutator, ArgsSyntaxAccessor.ArgsSyntaxPropertyNested classes/interfaces inherited from interface org.refcodes.cli.ArgumentEscapeCodeAccessor
ArgumentEscapeCodeAccessor.ArgumentEscapeCodeBuilder<B extends ArgumentEscapeCodeAccessor.ArgumentEscapeCodeBuilder<B>>, ArgumentEscapeCodeAccessor.ArgumentEscapeCodeMutator, ArgumentEscapeCodeAccessor.ArgumentEscapeCodePropertyNested classes/interfaces inherited from interface org.refcodes.cli.BannerBorderEscapeCodeAccessor
BannerBorderEscapeCodeAccessor.BannerBorderEscapeCodeBuilder<B extends BannerBorderEscapeCodeAccessor.BannerBorderEscapeCodeBuilder<B>>, BannerBorderEscapeCodeAccessor.BannerBorderEscapeCodeMutator, BannerBorderEscapeCodeAccessor.BannerBorderEscapeCodePropertyNested classes/interfaces inherited from interface org.refcodes.cli.BannerEscapeCodeAccessor
BannerEscapeCodeAccessor.BannerEscapeCodeBuilder<B extends BannerEscapeCodeAccessor.BannerEscapeCodeBuilder<B>>, BannerEscapeCodeAccessor.BannerEscapeCodeMutator, BannerEscapeCodeAccessor.BannerEscapeCodePropertyNested classes/interfaces inherited from interface org.refcodes.cli.BannerFontAccessor
BannerFontAccessor.BannerFontBuilder<B extends BannerFontAccessor.BannerFontBuilder<B>>, BannerFontAccessor.BannerFontMutator, BannerFontAccessor.BannerFontPropertyNested classes/interfaces inherited from interface org.refcodes.cli.BannerFontPaletteAccessor
BannerFontPaletteAccessor.BannerFontPaletteBuilder<B extends BannerFontPaletteAccessor.BannerFontPaletteBuilder<B>>, BannerFontPaletteAccessor.BannerFontPaletteMutator, BannerFontPaletteAccessor.BannerFontPalettePropertyNested classes/interfaces inherited from interface org.refcodes.cli.CommandEscapeCodeAccessor
CommandEscapeCodeAccessor.CommandEscapeCodeBuilder<B extends CommandEscapeCodeAccessor.CommandEscapeCodeBuilder<B>>, CommandEscapeCodeAccessor.CommandEscapeCodeMutator, CommandEscapeCodeAccessor.CommandEscapeCodePropertyNested classes/interfaces inherited from interface org.refcodes.mixin.ConsoleWidthAccessor
org.refcodes.mixin.ConsoleWidthAccessor.ConsoleWidthBuilder<B extends org.refcodes.mixin.ConsoleWidthAccessor.ConsoleWidthBuilder<B>>, org.refcodes.mixin.ConsoleWidthAccessor.ConsoleWidthMutator, org.refcodes.mixin.ConsoleWidthAccessor.ConsoleWidthPropertyNested classes/interfaces inherited from interface org.refcodes.cli.CopyrightAccessor
CopyrightAccessor.CopyrightBuilder<B extends CopyrightAccessor.CopyrightBuilder<B>>, CopyrightAccessor.CopyrightMutator, CopyrightAccessor.CopyrightPropertyNested classes/interfaces inherited from interface org.refcodes.mixin.DescriptionAccessor
org.refcodes.mixin.DescriptionAccessor.DescriptionBuilder<B extends org.refcodes.mixin.DescriptionAccessor.DescriptionBuilder<B>>, org.refcodes.mixin.DescriptionAccessor.DescriptionMutator, org.refcodes.mixin.DescriptionAccessor.DescriptionPropertyNested classes/interfaces inherited from interface org.refcodes.cli.DescriptionEscapeCodeAccessor
DescriptionEscapeCodeAccessor.DescriptionEscapeCodeBuilder<B extends DescriptionEscapeCodeAccessor.DescriptionEscapeCodeBuilder<B>>, DescriptionEscapeCodeAccessor.DescriptionEscapeCodeMutator, DescriptionEscapeCodeAccessor.DescriptionEscapeCodePropertyNested classes/interfaces inherited from interface org.refcodes.mixin.EscapeCodesStatusAccessor
org.refcodes.mixin.EscapeCodesStatusAccessor.EscapeCodeStatusBuilder<B extends org.refcodes.mixin.EscapeCodesStatusAccessor.EscapeCodeStatusBuilder<B>>, org.refcodes.mixin.EscapeCodesStatusAccessor.EscapeCodeStatusMutator, org.refcodes.mixin.EscapeCodesStatusAccessor.EscapeCodeStatusPropertyNested classes/interfaces inherited from interface org.refcodes.cli.ExamplesAccessor
ExamplesAccessor.ExamplesBuilder<B extends ExamplesAccessor.ExamplesBuilder<B>>, ExamplesAccessor.ExamplesMutator, ExamplesAccessor.ExamplesPropertyNested classes/interfaces inherited from interface org.refcodes.cli.LicenseAccessor
LicenseAccessor.LicenseBuilder<B extends LicenseAccessor.LicenseBuilder<B>>, LicenseAccessor.LicenseMutator, LicenseAccessor.LicensePropertyNested classes/interfaces inherited from interface org.refcodes.mixin.LineBreakAccessor
org.refcodes.mixin.LineBreakAccessor.LineBreakBuilder<B extends org.refcodes.mixin.LineBreakAccessor.LineBreakBuilder<B>>, org.refcodes.mixin.LineBreakAccessor.LineBreakMutator, org.refcodes.mixin.LineBreakAccessor.LineBreakPropertyNested classes/interfaces inherited from interface org.refcodes.cli.LineSeparatorEscapeCodeAccessor
LineSeparatorEscapeCodeAccessor.LineSeparatorEscapeCodeBuilder<B extends LineSeparatorEscapeCodeAccessor.LineSeparatorEscapeCodeBuilder<B>>, LineSeparatorEscapeCodeAccessor.LineSeparatorEscapeCodeMutator, LineSeparatorEscapeCodeAccessor.LineSeparatorEscapeCodePropertyNested classes/interfaces inherited from interface org.refcodes.cli.LongOptionPrefixAccessor
LongOptionPrefixAccessor.LongOptionPrefixBuilder<B extends LongOptionPrefixAccessor.LongOptionPrefixBuilder<B>>, LongOptionPrefixAccessor.LongOptionPrefixMutator, LongOptionPrefixAccessor.LongOptionPrefixPropertyNested classes/interfaces inherited from interface org.refcodes.mixin.MaxConsoleWidthAccessor
org.refcodes.mixin.MaxConsoleWidthAccessor.MaxConsoleWidthBuilder<B extends org.refcodes.mixin.MaxConsoleWidthAccessor.MaxConsoleWidthBuilder<B>>, org.refcodes.mixin.MaxConsoleWidthAccessor.MaxConsoleWidthMutator, org.refcodes.mixin.MaxConsoleWidthAccessor.MaxConsoleWidthPropertyNested classes/interfaces inherited from interface org.refcodes.mixin.NameAccessor
org.refcodes.mixin.NameAccessor.NameBuilder<B extends org.refcodes.mixin.NameAccessor.NameBuilder<B>>, org.refcodes.mixin.NameAccessor.NameMutator, org.refcodes.mixin.NameAccessor.NamePropertyNested classes/interfaces inherited from interface org.refcodes.cli.OptionEscapeCodeAccessor
OptionEscapeCodeAccessor.OptionEscapeCodeBuilder<B extends OptionEscapeCodeAccessor.OptionEscapeCodeBuilder<B>>, OptionEscapeCodeAccessor.OptionEscapeCodeMutator, OptionEscapeCodeAccessor.OptionEscapeCodePropertyNested classes/interfaces inherited from interface org.refcodes.mixin.ResetEscapeCodeAccessor
org.refcodes.mixin.ResetEscapeCodeAccessor.ResetEscapeCodeBuilder<B extends org.refcodes.mixin.ResetEscapeCodeAccessor.ResetEscapeCodeBuilder<B>>, org.refcodes.mixin.ResetEscapeCodeAccessor.ResetEscapeCodeMutator, org.refcodes.mixin.ResetEscapeCodeAccessor.ResetEscapeCodePropertyNested classes/interfaces inherited from interface org.refcodes.cli.ShortOptionPrefixAccessor
ShortOptionPrefixAccessor.ShortOptionPrefixBuilder<B extends ShortOptionPrefixAccessor.ShortOptionPrefixBuilder<B>>, ShortOptionPrefixAccessor.ShortOptionPrefixMutator, ShortOptionPrefixAccessor.ShortOptionPrefixPropertyNested classes/interfaces inherited from interface org.refcodes.cli.SyntaxMetricsAccessor
SyntaxMetricsAccessor.SyntaxMetricsBuilder<B extends SyntaxMetricsAccessor.SyntaxMetricsBuilder<B>>, SyntaxMetricsAccessor.SyntaxMetricsMutator, SyntaxMetricsAccessor.SyntaxMetricsPropertyNested classes/interfaces inherited from interface org.refcodes.textual.TextBoxGridAccessor
org.refcodes.textual.TextBoxGridAccessor.TextBoxGridBuilder<B extends org.refcodes.textual.TextBoxGridAccessor.TextBoxGridBuilder<?>>, org.refcodes.textual.TextBoxGridAccessor.TextBoxGridMutator, org.refcodes.textual.TextBoxGridAccessor.TextBoxGridPropertyNested classes/interfaces inherited from interface org.refcodes.mixin.TitleAccessor
org.refcodes.mixin.TitleAccessor.TitleBuilder<B extends org.refcodes.mixin.TitleAccessor.TitleBuilder<B>>, org.refcodes.mixin.TitleAccessor.TitleMutator, org.refcodes.mixin.TitleAccessor.TitleProperty -
Field Summary
Fields -
Constructor Summary
ConstructorsConstructorDescriptionConstructs theArgsParserinstance without any restrictions to the parsed arguments.ArgsParserImpl(CliContext aCliCtx) Constructs theArgsParserinstance without any restrictions to the parsed arguments.ArgsParserImpl(Constituent aArgsSyntax) Constructs theArgsParserinstance with the given rootConditionand the defaultSyntaxNotation.LOGICAL.ArgsParserImpl(Constituent aArgsSyntax, CliContext aCliCtx) Constructs theArgsParserinstance with the given rootConditionand the defaultSyntaxNotation.LOGICAL. -
Method Summary
Modifier and TypeMethodDescriptionvoidaddExample(Example aExampleUsage) Adds a usage example by providing a description of the example and the command line arguments required by the example.voidPrints the given line to standard error with regards to the console width as specified by theArgsParser.withConsoleWidth(int)method.Evaluates the provided command line arguments and determines the according values by evaluating the rootCondition.Heuristically loads the arguments without any syntax required, e.g.Retrieves the (root)Constituentfrom the (root)Constituentproperty.Retrieves the argument Escape-Code from the argument Escape-Code property.Retrieves the banner border Escape-Code from the banner border Escape-Code property.Retrieves the banner Escape-Code from the banner Escape-Code property.org.refcodes.textual.FontRetrieves the bannerFontfrom the bannerFontproperty.char[]Retrieves the banner font palette from the banner font palette property.Retrieves the command Escape-Code from the command Escape-Code property.intRetrieves the copyright from the copyright property.protected charReturns the delimiter to be used by colliding command line args when creating non colliding arg's aliases (keys for key/value-pairs).Retrieves the description Escape-Code from the description Escape-Code property.Example[]Retrieves the license from the license property.Retrieves the line separator Escape-Code from the line separator Escape-Code property.Retrieves the long option prefix from the long option prefix property.intgetName()Retrieves the option Escape-Code from the option Escape-Code property.charGets the character to be used when printing a separator line with theArgsParser.printSeparatorLn()method.Retrieves the short option prefix from the short option prefix property.Retrieves theSyntaxMetricsfrom theSyntaxMetricsproperty.org.refcodes.textual.TextBoxGridgetTitle()booleanvoidPrints the banner; the banner most probably is an ASCII_HEADER_ASCII_BODY art text block which's look depends strongly on the taste of the author implementing this interface.voidPrints the copyright note as specified by theArgsParser.withCopyright(String)method; with regards to the console width as specified by theArgsParser.withConsoleWidth(int)method.voidPrints the description as set by theArgsParser.withDescription(String)method with regards to the console width as specified by theArgsParser.withConsoleWidth(int)method.voidPrints example usages as as added by theArgsParser.addExample(String, Operand...)method with regards to the console width as specified by theArgsParser.withConsoleWidth(int)method.voidPrints the header, which might be a simplified banner: Can be used when overriding methods such asArgsParser.printHelp()orArgsParser.printBanner().voidPrints the license note as specified by theArgsParser.withLicense(String)method; with regards to the console width as specified by theArgsParser.withConsoleWidth(int)method.voidprintLn()Prints an empty line / a line break.voidPrints the given line to standard out with regards to the console width as specified by theArgsParser.withConsoleWidth(int)method.voidPrints theOptions (short- and the long-options), theFlages and theOperandand their description with regards to the console width as specified by theArgsParser.withConsoleWidth(int)method.voidPrints a separator line using the separator character as specified by theArgsParser.withSeparatorLnChar(char)method; with regards to the console width as specified by theArgsParser.withConsoleWidth(int)method.voidPrints the syntax as retrieved by the rootConditionelement as ofSynopsisable.toSynopsis(SyntaxNotation)with regards to theSyntaxNotationset by theArgsParser.withSyntaxMetrics(SyntaxMetrics)method.voidreset()voidsetArgsSyntax(Constituent aArgsSyntax) Sets the (root)Constituentfor the (root)Constituentproperty.voidsetArgumentEscapeCode(String aParamEscapeCode) Sets the argument Escape-Code for the argument Escape-Code property.voidsetBannerBorderEscapeCode(String aBannerBorderEscapeCode) Sets the banner border Escape-Code for the banner border Escape-Code property.voidsetBannerEscapeCode(String aBannerEscapeCode) Sets the banner Escape-Code for the banner Escape-Code property.voidsetBannerFont(org.refcodes.textual.Font aBannerFont) Sets the bannerFontfor the bannerFontproperty.voidsetBannerFontPalette(char[] aColorPalette) Sets the banner font palette for the banner font palette property.voidsetBannerFontPalette(org.refcodes.data.AsciiColorPalette aBannerFontPalette) Sets the banner font palette for the banner font palette property.voidsetCommandEscapeCode(String aCommandEscapeCode) Sets the command Escape-Code for the command Escape-Code property.voidsetConsoleWidth(int aConsoleWidth) voidsetCopyright(String aCopyrightNote) Sets the copyright for the copyright property.voidsetDescription(String aDescription) voidsetDescriptionEscapeCode(String aDescriptionEscapeCode) Sets the description Escape-Code for the description Escape-Code property.voidsetErrorOut(PrintStream aErrorOut) Set the error outPrintStreamand make other adjustments with the result (with regards to the Builder-Pattern).voidsetEscapeCodesEnabled(boolean isEscapeCodesEnabled) voidsetExamples(Example[] aExamples) voidsetLicense(String aLicenseNote) Sets the license for the license property.voidsetLineBreak(String aLineBreak) voidsetLineSeparatorEscapeCode(String aLineSeparatorEscapeCode) Sets the line separator Escape-Code for the line separator Escape-Code property.voidsetLongOptionPrefix(String aLongOptionPrefix) Sets the long option prefix for the long option prefix property.voidsetMaxConsoleWidth(int aMaxConsoleWidth) voidvoidsetOptionEscapeCode(String aOptEscapeCode) Sets the option Escape-Code for the option Escape-Code property.voidsetResetEscapeCode(String aResetEscapeCode) voidsetSeparatorLnChar(char aSeparatorLnChar) Set the character to be used when printing a separator line with theArgsParser.printSeparatorLn()method.voidsetShortOptionPrefix(Character aShortOptionPrefix) Sets the short option prefix for the short option prefix property.voidsetStandardOut(PrintStream aStandardOut) Set the standard outPrintStreamand make other adjustments with the result (with regards to the Builder-Pattern).voidsetSyntaxMetrics(SyntaxMetrics aSyntaxMetrics) Sets theSyntaxMetricsfor theSyntaxMetricsproperty.voidsetTextBoxGrid(org.refcodes.textual.TextBoxGrid aTextBoxGrid) voidwithAddExample(String aDescription, Operand<?>... aOperands) Builder method adding an application'sExampleelement.withAddExample(Example aExamples) Builder method adding an application'sExampleelement.withArgsSyntax(Constituent aArgsSyntax) Sets the (root)Constituentfor the (root)Constituentproperty.withBannerFontPalette(org.refcodes.data.AsciiColorPalette aBannerFontPalette) Sets the banner font palette for the banner font palette property.withSyntaxMetrics(SyntaxNotation aSyntaxNotation) Sets theSyntaxNotationfor theSyntaxNotationproperty.Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, waitMethods inherited from interface org.refcodes.cli.ArgsParser
addExample, evalArgs, evalArgs, evalArgs, evalArgs, evalArgs, printBody, printHelp, toOptions, toSchema, withArgumentEscapeCode, withBannerBorderEscapeCode, withBannerEscapeCode, withBannerFont, withBannerFontPalette, withCommandEscapeCode, withConsoleWidth, withCopyright, withDescription, withDescriptionEscapeCode, withErrorOut, withEscapeCodesEnabled, withEvalArgs, withEvalArgs, withExamples, withExamples, withLicense, withLineBreak, withLineSeparatorEscapeCode, withLongOptionPrefix, withMaxConsoleWidth, withName, withOptionEscapeCode, withResetEscapeCode, withSeparatorLnChar, withShortOptionPrefix, withStandardOut, withSyntaxMetrics, withTextBoxGrid, withTextBoxGrid, withTitleMethods inherited from interface org.refcodes.cli.ArgsParserBuilder
withEvalArgs, withEvalArgs, withEvalArgs, withEvalArgsMethods inherited from interface org.refcodes.cli.ArgsSyntaxAccessor.ArgsSyntaxProperty
letArgsSyntaxMethods inherited from interface org.refcodes.cli.ArgumentEscapeCodeAccessor.ArgumentEscapeCodeProperty
letArgumentEscapeCodeMethods inherited from interface org.refcodes.cli.BannerBorderEscapeCodeAccessor.BannerBorderEscapeCodeProperty
letBannerBorderEscapeCodeMethods inherited from interface org.refcodes.cli.BannerEscapeCodeAccessor.BannerEscapeCodeProperty
letBannerEscapeCodeMethods inherited from interface org.refcodes.cli.BannerFontAccessor.BannerFontProperty
letBannerFontMethods inherited from interface org.refcodes.cli.BannerFontPaletteAccessor.BannerFontPaletteProperty
letBannerFontPaletteMethods inherited from interface org.refcodes.cli.CommandEscapeCodeAccessor.CommandEscapeCodeProperty
letCommandEscapeCodeMethods inherited from interface org.refcodes.mixin.ConsoleWidthAccessor.ConsoleWidthProperty
letConsoleWidthMethods inherited from interface org.refcodes.cli.CopyrightAccessor.CopyrightProperty
letCopyrightMethods inherited from interface org.refcodes.mixin.DescriptionAccessor.DescriptionProperty
letDescriptionMethods inherited from interface org.refcodes.cli.DescriptionEscapeCodeAccessor.DescriptionEscapeCodeProperty
letDescriptionEscapeCodeMethods inherited from interface org.refcodes.mixin.EscapeCodesStatusAccessor.EscapeCodeStatusProperty
letEscapeCodesEnabledMethods inherited from interface org.refcodes.cli.ExamplesAccessor.ExamplesMutator
setExamplesMethods inherited from interface org.refcodes.cli.ExamplesAccessor.ExamplesProperty
letExamplesMethods inherited from interface org.refcodes.cli.LicenseAccessor.LicenseProperty
letLicenseMethods inherited from interface org.refcodes.mixin.LineBreakAccessor.LineBreakProperty
letLineBreakMethods inherited from interface org.refcodes.cli.LineSeparatorEscapeCodeAccessor.LineSeparatorEscapeCodeProperty
letLineSeparatorEscapeCodeMethods inherited from interface org.refcodes.cli.LongOptionPrefixAccessor.LongOptionPrefixProperty
letLongOptionPrefixMethods inherited from interface org.refcodes.mixin.MaxConsoleWidthAccessor.MaxConsoleWidthProperty
letMaxConsoleWidthMethods inherited from interface org.refcodes.mixin.NameAccessor.NameProperty
letNameMethods inherited from interface org.refcodes.cli.OptionEscapeCodeAccessor.OptionEscapeCodeProperty
letOptionEscapeCodeMethods inherited from interface org.refcodes.mixin.ResetEscapeCodeAccessor.ResetEscapeCodeProperty
letResetEscapeCodeMethods inherited from interface org.refcodes.cli.ShortOptionPrefixAccessor.ShortOptionPrefixProperty
letShortOptionPrefixMethods inherited from interface org.refcodes.cli.SyntaxMetricsAccessor.SyntaxMetricsMutator
setSyntaxMetricsMethods inherited from interface org.refcodes.cli.SyntaxMetricsAccessor.SyntaxMetricsProperty
letSyntaxMetrics, letSyntaxMetricsMethods inherited from interface org.refcodes.textual.TextBoxGridAccessor.TextBoxGridMutator
setTextBoxGridMethods inherited from interface org.refcodes.textual.TextBoxGridAccessor.TextBoxGridProperty
letTextBoxGrid, letTextBoxGridMethods inherited from interface org.refcodes.mixin.TitleAccessor.TitleProperty
letTitle
-
Field Details
-
_stdStream
-
_errStream
-
-
Constructor Details
-
ArgsParserImpl
public ArgsParserImpl()Constructs theArgsParserinstance without any restrictions to the parsed arguments. The constructor only provides means to set the required attributes as the attributes to be adjusted optionally are already sufficiently preconfigured. For adjusting them, a flavor of the Builder-Pattern is provided with which you can easily chain the configuration of this instance; as them methods return the instance of this class being configured. -
ArgsParserImpl
Constructs theArgsParserinstance without any restrictions to the parsed arguments. The constructor only provides means to set the required attributes as the attributes to be adjusted optionally are already sufficiently preconfigured. For adjusting them, a flavor of the Builder-Pattern is provided with which you can easily chain the configuration of this instance; as them methods return the instance of this class being configured.- Parameters:
aCliCtx- TheCliContextto be used for initializing.
-
ArgsParserImpl
Constructs theArgsParserinstance with the given rootConditionand the defaultSyntaxNotation.LOGICAL. The constructor only provides means to set the required attributes as the attributes to be adjusted optionally are already sufficiently preconfigured. For adjusting them, a flavor of the Builder-Pattern is provided with which you can easily chain the configuration of this instance; as them methods return the instance of this class being configured.- Parameters:
aArgsSyntax- The args syntax rootConstituentnode being the node from which parsing the command line arguments starts.
-
ArgsParserImpl
Constructs theArgsParserinstance with the given rootConditionand the defaultSyntaxNotation.LOGICAL. The constructor only provides means to set the required attributes as the attributes to be adjusted optionally are already sufficiently preconfigured. For adjusting them, a flavor of the Builder-Pattern is provided with which you can easily chain the configuration of this instance; as them methods return the instance of this class being configured.- Parameters:
aArgsSyntax- The args syntax rootConstituentnode being the node from which parsing the command line arguments starts.aCliCtx- TheCliContextto be used for initializing.
-
-
Method Details
-
addExample
Adds a usage example by providing a description of the example and the command line arguments required by the example.- Specified by:
addExamplein interfaceArgsParser- Parameters:
aExampleUsage- The description as well as the command line arguments used by the example.
-
errorLn
Prints the given line to standard error with regards to the console width as specified by theArgsParser.withConsoleWidth(int)method.- Specified by:
errorLnin interfaceArgsParser- Parameters:
aLine- The line to be printed.
-
evalArgs
Evaluates the provided command line arguments and determines the according values by evaluating the rootCondition. In case of parsing failure, an according exception is thrown. ATTENTION: This method tests(!) for superfluous command line arguments being passed; e.g. command line arguments not being evaluated by any of theConstituentinstance being traversed starting at the rootConditionwill be reported. Business logic therefore should invoke this root node'sArgsParser.evalArgs(String[])method instead of aCondition'sConstituent.parseArgs(String[], String[], CliContext)method; as ignoring superfluous command line arguments will aCause unexpected behavior from the point of view of the invoker.- Specified by:
evalArgsin interfaceArgsParser- Parameters:
aArgs- The command line arguments to be evaluated.- Returns:
- The list of evaluated command line arguments being instances of
the
Operandinterfaces or its sub-types. - Throws:
ArgsSyntaxException- thrown in case of a command line arguments mismatch regarding provided and expected args.
-
getArgsSyntax
Retrieves the (root)Constituentfrom the (root)Constituentproperty.- Specified by:
getArgsSyntaxin interfaceArgsParser- Specified by:
getArgsSyntaxin interfaceArgsSyntaxAccessor- Returns:
- The (root)
Constituentstored by the (root)Constituentproperty.
-
getArgumentEscapeCode
Retrieves the argument Escape-Code from the argument Escape-Code property.- Specified by:
getArgumentEscapeCodein interfaceArgsParser- Specified by:
getArgumentEscapeCodein interfaceArgumentEscapeCodeAccessor- Returns:
- The argument Escape-Code stored by the argument Escape-Code property.
-
getBannerBorderEscapeCode
Retrieves the banner border Escape-Code from the banner border Escape-Code property.- Specified by:
getBannerBorderEscapeCodein interfaceArgsParser- Specified by:
getBannerBorderEscapeCodein interfaceBannerBorderEscapeCodeAccessor- Returns:
- The banner border Escape-Code stored by the banner border Escape-Code property.
-
getBannerEscapeCode
Retrieves the banner Escape-Code from the banner Escape-Code property.- Specified by:
getBannerEscapeCodein interfaceArgsParser- Specified by:
getBannerEscapeCodein interfaceBannerEscapeCodeAccessor- Returns:
- The banner Escape-Code stored by the banner Escape-Code property.
-
getBannerFont
public org.refcodes.textual.Font getBannerFont()Retrieves the bannerFontfrom the bannerFontproperty.- Specified by:
getBannerFontin interfaceBannerFontAccessor- Returns:
- The banner
Fontstored by the bannerFontproperty.
-
getBannerFontPalette
public char[] getBannerFontPalette()Retrieves the banner font palette from the banner font palette property.- Specified by:
getBannerFontPalettein interfaceBannerFontPaletteAccessor- Returns:
- The banner font palette stored by the banner font palette property.
-
getCommandEscapeCode
Retrieves the command Escape-Code from the command Escape-Code property.- Specified by:
getCommandEscapeCodein interfaceArgsParser- Specified by:
getCommandEscapeCodein interfaceCommandEscapeCodeAccessor- Returns:
- The command Escape-Code stored by the command Escape-Code property.
-
getConsoleWidth
public int getConsoleWidth()- Specified by:
getConsoleWidthin interfaceorg.refcodes.mixin.ConsoleWidthAccessor
-
getCopyright
Retrieves the copyright from the copyright property.- Specified by:
getCopyrightin interfaceArgsParser- Specified by:
getCopyrightin interfaceCopyrightAccessor- Returns:
- The copyright stored by the copyright property.
-
getDescription
- Specified by:
getDescriptionin interfaceArgsParser- Specified by:
getDescriptionin interfaceorg.refcodes.mixin.DescriptionAccessor
-
getDescriptionEscapeCode
Retrieves the description Escape-Code from the description Escape-Code property.- Specified by:
getDescriptionEscapeCodein interfaceArgsParser- Specified by:
getDescriptionEscapeCodein interfaceDescriptionEscapeCodeAccessor- Returns:
- The description Escape-Code stored by the description Escape-Code property.
-
getExamples
- Specified by:
getExamplesin interfaceArgsParser- Specified by:
getExamplesin interfaceExamplesAccessor- Returns:
- The
Exampleinstances stored by theExampleinstances property.
-
getLicense
Retrieves the license from the license property.- Specified by:
getLicensein interfaceArgsParser- Specified by:
getLicensein interfaceLicenseAccessor- Returns:
- The license stored by the license property.
-
getLineBreak
- Specified by:
getLineBreakin interfaceorg.refcodes.mixin.LineBreakAccessor
-
getLineSeparatorEscapeCode
Retrieves the line separator Escape-Code from the line separator Escape-Code property.- Specified by:
getLineSeparatorEscapeCodein interfaceArgsParser- Specified by:
getLineSeparatorEscapeCodein interfaceLineSeparatorEscapeCodeAccessor- Returns:
- The line separator Escape-Code stored by the line separator Escape-Code property.
-
getLongOptionPrefix
Retrieves the long option prefix from the long option prefix property.- Specified by:
getLongOptionPrefixin interfaceLongOptionPrefixAccessor- Returns:
- The long option prefix stored by the long option prefix property.
-
getMaxConsoleWidth
public int getMaxConsoleWidth()- Specified by:
getMaxConsoleWidthin interfaceorg.refcodes.mixin.MaxConsoleWidthAccessor
-
getName
- Specified by:
getNamein interfaceorg.refcodes.mixin.NameAccessor
-
getOptionEscapeCode
Retrieves the option Escape-Code from the option Escape-Code property.- Specified by:
getOptionEscapeCodein interfaceArgsParser- Specified by:
getOptionEscapeCodein interfaceOptionEscapeCodeAccessor- Returns:
- The option Escape-Code stored by the option Escape-Code property.
-
getResetEscapeCode
- Specified by:
getResetEscapeCodein interfaceorg.refcodes.mixin.ResetEscapeCodeAccessor
-
getSeparatorLnChar
public char getSeparatorLnChar()Gets the character to be used when printing a separator line with theArgsParser.printSeparatorLn()method.- Specified by:
getSeparatorLnCharin interfaceArgsParser- Returns:
- aSeparatorChar The character used by the
ArgsParser.printSeparatorLn()method when printing out the line of characters..
-
getShortOptionPrefix
Retrieves the short option prefix from the short option prefix property.- Specified by:
getShortOptionPrefixin interfaceShortOptionPrefixAccessor- Returns:
- The short option prefix stored by the short option prefix property.
-
getSyntaxMetrics
Retrieves theSyntaxMetricsfrom theSyntaxMetricsproperty.- Specified by:
getSyntaxMetricsin interfaceSyntaxMetricsAccessor- Returns:
- The
SyntaxMetricsstored by the decorator (enabled) tags property.
-
getTextBoxGrid
public org.refcodes.textual.TextBoxGrid getTextBoxGrid()- Specified by:
getTextBoxGridin interfaceorg.refcodes.textual.TextBoxGridAccessor
-
getTitle
- Specified by:
getTitlein interfaceorg.refcodes.mixin.TitleAccessor
-
isEscapeCodesEnabled
public boolean isEscapeCodesEnabled()- Specified by:
isEscapeCodesEnabledin interfaceorg.refcodes.mixin.EscapeCodesStatusAccessor
-
printBanner
public void printBanner()Prints the banner; the banner most probably is an ASCII_HEADER_ASCII_BODY art text block which's look depends strongly on the taste of the author implementing this interface.- Specified by:
printBannerin interfaceArgsParser
-
printCopyright
public void printCopyright()Prints the copyright note as specified by theArgsParser.withCopyright(String)method; with regards to the console width as specified by theArgsParser.withConsoleWidth(int)method.- Specified by:
printCopyrightin interfaceArgsParser
-
printDescription
public void printDescription()Prints the description as set by theArgsParser.withDescription(String)method with regards to the console width as specified by theArgsParser.withConsoleWidth(int)method.- Specified by:
printDescriptionin interfaceArgsParser
-
printExamples
public void printExamples()Prints example usages as as added by theArgsParser.addExample(String, Operand...)method with regards to the console width as specified by theArgsParser.withConsoleWidth(int)method.- Specified by:
printExamplesin interfaceArgsParser
-
printHeader
public void printHeader()Prints the header, which might be a simplified banner: Can be used when overriding methods such asArgsParser.printHelp()orArgsParser.printBanner().- Specified by:
printHeaderin interfaceArgsParser
-
printLicense
public void printLicense()Prints the license note as specified by theArgsParser.withLicense(String)method; with regards to the console width as specified by theArgsParser.withConsoleWidth(int)method.- Specified by:
printLicensein interfaceArgsParser
-
printLn
public void printLn()Prints an empty line / a line break.- Specified by:
printLnin interfaceArgsParser
-
printLn
Prints the given line to standard out with regards to the console width as specified by theArgsParser.withConsoleWidth(int)method.- Specified by:
printLnin interfaceArgsParser- Parameters:
aLine- The line to be printed.
-
printOptions
public void printOptions()Prints theOptions (short- and the long-options), theFlages and theOperandand their description with regards to the console width as specified by theArgsParser.withConsoleWidth(int)method.- Specified by:
printOptionsin interfaceArgsParser
-
printSeparatorLn
public void printSeparatorLn()Prints a separator line using the separator character as specified by theArgsParser.withSeparatorLnChar(char)method; with regards to the console width as specified by theArgsParser.withConsoleWidth(int)method.- Specified by:
printSeparatorLnin interfaceArgsParser
-
printSynopsis
public void printSynopsis()Prints the syntax as retrieved by the rootConditionelement as ofSynopsisable.toSynopsis(SyntaxNotation)with regards to theSyntaxNotationset by theArgsParser.withSyntaxMetrics(SyntaxMetrics)method.- Specified by:
printSynopsisin interfaceArgsParser
-
reset
public void reset()- Specified by:
resetin interfaceorg.refcodes.mixin.Resetable
-
setArgsSyntax
Sets the (root)Constituentfor the (root)Constituentproperty.- Specified by:
setArgsSyntaxin interfaceArgsSyntaxAccessor.ArgsSyntaxMutator- Parameters:
aArgsSyntax- The (root)Constituentto be stored by the (root)Constituentproperty.
-
setArgumentEscapeCode
Sets the argument Escape-Code for the argument Escape-Code property.- Specified by:
setArgumentEscapeCodein interfaceArgumentEscapeCodeAccessor.ArgumentEscapeCodeMutator- Parameters:
aParamEscapeCode- The argument Escape-Code to be stored by the argument Escape-Code property.
-
setBannerBorderEscapeCode
Sets the banner border Escape-Code for the banner border Escape-Code property.- Specified by:
setBannerBorderEscapeCodein interfaceBannerBorderEscapeCodeAccessor.BannerBorderEscapeCodeMutator- Parameters:
aBannerBorderEscapeCode- The banner border Escape-Code to be stored by the banner border Escape-Code property.
-
setBannerEscapeCode
Sets the banner Escape-Code for the banner Escape-Code property.- Specified by:
setBannerEscapeCodein interfaceBannerEscapeCodeAccessor.BannerEscapeCodeMutator- Parameters:
aBannerEscapeCode- The banner Escape-Code to be stored by the banner Escape-Code property.
-
setBannerFont
public void setBannerFont(org.refcodes.textual.Font aBannerFont) Sets the bannerFontfor the bannerFontproperty.- Specified by:
setBannerFontin interfaceBannerFontAccessor.BannerFontMutator- Parameters:
aBannerFont- The bannerFontto be stored by the bannerFontproperty.
-
setBannerFontPalette
public void setBannerFontPalette(org.refcodes.data.AsciiColorPalette aBannerFontPalette) Sets the banner font palette for the banner font palette property.- Specified by:
setBannerFontPalettein interfaceBannerFontPaletteAccessor.BannerFontPaletteMutator- Parameters:
aBannerFontPalette- The banner font palette to be stored by the banner palette property.
-
setBannerFontPalette
public void setBannerFontPalette(char[] aColorPalette) Sets the banner font palette for the banner font palette property.- Specified by:
setBannerFontPalettein interfaceBannerFontPaletteAccessor.BannerFontPaletteMutator- Parameters:
aColorPalette- The banner font palette to be stored by the banner palette property.
-
setCommandEscapeCode
Sets the command Escape-Code for the command Escape-Code property.- Specified by:
setCommandEscapeCodein interfaceCommandEscapeCodeAccessor.CommandEscapeCodeMutator- Parameters:
aCommandEscapeCode- The command Escape-Code to be stored by the command Escape-Code property.
-
setConsoleWidth
public void setConsoleWidth(int aConsoleWidth) - Specified by:
setConsoleWidthin interfaceorg.refcodes.mixin.ConsoleWidthAccessor.ConsoleWidthMutator
-
setCopyright
Sets the copyright for the copyright property.- Specified by:
setCopyrightin interfaceCopyrightAccessor.CopyrightMutator- Parameters:
aCopyrightNote- The copyright to be stored by the console width property.
-
setDescription
- Specified by:
setDescriptionin interfaceorg.refcodes.mixin.DescriptionAccessor.DescriptionMutator
-
setDescriptionEscapeCode
Sets the description Escape-Code for the description Escape-Code property.- Specified by:
setDescriptionEscapeCodein interfaceDescriptionEscapeCodeAccessor.DescriptionEscapeCodeMutator- Parameters:
aDescriptionEscapeCode- The description Escape-Code to be stored by the description Escape-Code property.
-
setErrorOut
Set the error outPrintStreamand make other adjustments with the result (with regards to the Builder-Pattern).- Specified by:
setErrorOutin interfaceArgsParser- Parameters:
aErrorOut- The error outPrintStreamto set.
-
setEscapeCodesEnabled
public void setEscapeCodesEnabled(boolean isEscapeCodesEnabled) - Specified by:
setEscapeCodesEnabledin interfaceorg.refcodes.mixin.EscapeCodesStatusAccessor.EscapeCodeStatusMutator
-
setExamples
- Specified by:
setExamplesin interfaceExamplesAccessor.ExamplesMutator- Parameters:
aExamples- TheExampleinstances to be stored.
-
setLicense
Sets the license for the license property.- Specified by:
setLicensein interfaceLicenseAccessor.LicenseMutator- Parameters:
aLicenseNote- The license to be stored by the console width property.
-
setLineBreak
- Specified by:
setLineBreakin interfaceorg.refcodes.mixin.LineBreakAccessor.LineBreakMutator
-
setLineSeparatorEscapeCode
Sets the line separator Escape-Code for the line separator Escape-Code property.- Specified by:
setLineSeparatorEscapeCodein interfaceArgsParser- Specified by:
setLineSeparatorEscapeCodein interfaceLineSeparatorEscapeCodeAccessor.LineSeparatorEscapeCodeMutator- Parameters:
aLineSeparatorEscapeCode- The line separator Escape-Code to be stored by the line separator Escape-Code property.
-
setLongOptionPrefix
Sets the long option prefix for the long option prefix property.- Specified by:
setLongOptionPrefixin interfaceLongOptionPrefixAccessor.LongOptionPrefixMutator- Parameters:
aLongOptionPrefix- The long option prefix to be stored by the long option prefix property.
-
setMaxConsoleWidth
public void setMaxConsoleWidth(int aMaxConsoleWidth) - Specified by:
setMaxConsoleWidthin interfaceorg.refcodes.mixin.MaxConsoleWidthAccessor.MaxConsoleWidthMutator
-
setName
- Specified by:
setNamein interfaceorg.refcodes.mixin.NameAccessor.NameMutator
-
setOptionEscapeCode
Sets the option Escape-Code for the option Escape-Code property.- Specified by:
setOptionEscapeCodein interfaceOptionEscapeCodeAccessor.OptionEscapeCodeMutator- Parameters:
aOptEscapeCode- The option Escape-Code to be stored by the option Escape-Code property.
-
setResetEscapeCode
- Specified by:
setResetEscapeCodein interfaceorg.refcodes.mixin.ResetEscapeCodeAccessor.ResetEscapeCodeMutator
-
setSeparatorLnChar
public void setSeparatorLnChar(char aSeparatorLnChar) Set the character to be used when printing a separator line with theArgsParser.printSeparatorLn()method.- Specified by:
setSeparatorLnCharin interfaceArgsParser- Parameters:
aSeparatorLnChar- The character used by theArgsParser.printSeparatorLn()method when printing out the line of characters..
-
setShortOptionPrefix
Sets the short option prefix for the short option prefix property.- Specified by:
setShortOptionPrefixin interfaceShortOptionPrefixAccessor.ShortOptionPrefixMutator- Parameters:
aShortOptionPrefix- The short option prefix to be stored by the short option prefix property.
-
setStandardOut
Set the standard outPrintStreamand make other adjustments with the result (with regards to the Builder-Pattern).- Specified by:
setStandardOutin interfaceArgsParser- Parameters:
aStandardOut- The standard outPrintStreamto set.
-
setSyntaxMetrics
Sets theSyntaxMetricsfor theSyntaxMetricsproperty.- Specified by:
setSyntaxMetricsin interfaceArgsParser- Specified by:
setSyntaxMetricsin interfaceSyntaxMetricsAccessor.SyntaxMetricsMutator- Parameters:
aSyntaxMetrics- TheSyntaxMetricsto be stored by theSyntaxMetricsproperty.
-
setTextBoxGrid
public void setTextBoxGrid(org.refcodes.textual.TextBoxGrid aTextBoxGrid) - Specified by:
setTextBoxGridin interfaceorg.refcodes.textual.TextBoxGridAccessor.TextBoxGridMutator
-
setTitle
- Specified by:
setTitlein interfaceorg.refcodes.mixin.TitleAccessor.TitleMutator
-
withAddExample
Builder method adding an application'sExampleelement.- Specified by:
withAddExamplein interfaceArgsParser- Specified by:
withAddExamplein interfaceArgsProcessorBuilder<ArgsParser>- Parameters:
aExamples- The application'sExampleelement to be added.- Returns:
- This builder as of the builder pattern.
-
withAddExample
Builder method adding an application'sExampleelement.- Specified by:
withAddExamplein interfaceArgsParser- Specified by:
withAddExamplein interfaceArgsProcessorBuilder<ArgsParser>- Parameters:
aDescription- The example's description.aOperands- The command line arguments required by the example.- Returns:
- This builder as of the builder pattern.
-
withArgsSyntax
Sets the (root)Constituentfor the (root)Constituentproperty.- Specified by:
withArgsSyntaxin interfaceArgsSyntaxAccessor.ArgsSyntaxBuilder<ArgsParser>- Parameters:
aArgsSyntax- The (root)Constituentto be stored by the (root)Constituentproperty.- Returns:
- The builder for applying multiple build operations.
-
withBannerFontPalette
Sets the banner font palette for the banner font palette property.- Specified by:
withBannerFontPalettein interfaceBannerFontPaletteAccessor.BannerFontPaletteBuilder<ArgsParser>- Parameters:
aBannerFontPalette- The banner font palette to be stored by the banner palette property.- Returns:
- The builder for applying multiple build operations.
-
withSyntaxMetrics
Sets theSyntaxNotationfor theSyntaxNotationproperty.- Specified by:
withSyntaxMetricsin interfaceSyntaxMetricsAccessor.SyntaxMetricsBuilder<ArgsParser>- Parameters:
aSyntaxNotation- TheSyntaxNotationto be stored by theSyntaxNotationproperty.- Returns:
- The builder for applying multiple build operations.
-
getDelimiter
protected char getDelimiter()Returns the delimiter to be used by colliding command line args when creating non colliding arg's aliases (keys for key/value-pairs).- Returns:
- The according delimiter.
-
fromArgs
Heuristically loads the arguments without any syntax required, e.g. without any rootConditionto be set.- Parameters:
aArgs- The arguments to be loaded.aDelimiter- The delimiter to resolve name clashes.- Returns:
- A list of heuristically determined
FlagandStringOperandinstances.
-