- java.lang.Object
-
- org.refcodes.cli.ArgsParserImpl
-
- All Implemented Interfaces:
ArgsParser,ArgsParserMixin<ArgsParser>,RootConditionAccessor,org.refcodes.component.Resetable,org.refcodes.mixin.DescriptionAccessor,org.refcodes.mixin.DescriptionAccessor.DescriptionBuilder<ArgsParser>,org.refcodes.mixin.DescriptionAccessor.DescriptionMutator,org.refcodes.mixin.DescriptionAccessor.DescriptionProperty,org.refcodes.mixin.EscapeCodesStatusAccessor,org.refcodes.mixin.EscapeCodesStatusAccessor.EscapeCodeStatusBuilder<ArgsParser>,org.refcodes.mixin.EscapeCodesStatusAccessor.EscapeCodeStatusMutator,org.refcodes.mixin.EscapeCodesStatusAccessor.EscapeCodeStatusProperty,org.refcodes.mixin.NameAccessor,org.refcodes.mixin.NameAccessor.NameBuilder<ArgsParser>,org.refcodes.mixin.NameAccessor.NameMutator,org.refcodes.mixin.NameAccessor.NameProperty,org.refcodes.mixin.ResetEscapeCodeAccessor,org.refcodes.mixin.ResetEscapeCodeAccessor.ResetEscapeCodeBuilder<ArgsParser>,org.refcodes.mixin.ResetEscapeCodeAccessor.ResetEscapeCodeMutator,org.refcodes.mixin.ResetEscapeCodeAccessor.ResetEscapeCodeProperty,org.refcodes.mixin.TitleAccessor,org.refcodes.mixin.TitleAccessor.TitleBuilder<ArgsParser>,org.refcodes.mixin.TitleAccessor.TitleMutator,org.refcodes.mixin.TitleAccessor.TitleProperty,org.refcodes.textual.TextBoxGridAccessor,org.refcodes.textual.TextBoxGridAccessor.TextBoxGridBuilder<ArgsParser>,org.refcodes.textual.TextBoxGridAccessor.TextBoxGridMutator,org.refcodes.textual.TextBoxGridAccessor.TextBoxGridProperty
public class ArgsParserImpl extends Object implements ArgsParser
A straightforward implementation of theArgsParserinterface. The constructor only provides means to set the required attributes as the attributes to be adjusted optionally are already sufficiently pre-configured. For adjusting them, a flavor of the Builder-Pattern is provided with which you can easily chain the configuration of this instance; as them methods return the instance of this class being configured. This helps to prevent the telescoping constructor anti-pattern.The
SyntaxNotationis pre-set with theSyntaxNotation.REFCODESnotation.The console width id pre-configured with the console's width as determined by the
SystemUtility.getTerminalWidth().The standard out
PrintStreamis pre-configured with theSystem.outPrintStream.The newline characters to be used for line breaks is "\r\n" on Windows machines and "\"n" on all other machines as of the
SystemUtility.getLineBreak().- See Also:
- "http://en.wikipedia.org/wiki/Builder_pattern"
-
-
Nested Class Summary
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.DescriptionAccessor
org.refcodes.mixin.DescriptionAccessor.DescriptionBuilder<B extends org.refcodes.mixin.DescriptionAccessor.DescriptionBuilder<B>>, org.refcodes.mixin.DescriptionAccessor.DescriptionMutator, org.refcodes.mixin.DescriptionAccessor.DescriptionProperty
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.EscapeCodesStatusAccessor
org.refcodes.mixin.EscapeCodesStatusAccessor.EscapeCodeStatusBuilder<B extends org.refcodes.mixin.EscapeCodesStatusAccessor.EscapeCodeStatusBuilder<B>>, org.refcodes.mixin.EscapeCodesStatusAccessor.EscapeCodeStatusMutator, org.refcodes.mixin.EscapeCodesStatusAccessor.EscapeCodeStatusProperty
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.NameAccessor
org.refcodes.mixin.NameAccessor.NameBuilder<B extends org.refcodes.mixin.NameAccessor.NameBuilder<B>>, org.refcodes.mixin.NameAccessor.NameMutator, org.refcodes.mixin.NameAccessor.NameProperty
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.ResetEscapeCodeAccessor
org.refcodes.mixin.ResetEscapeCodeAccessor.ResetEscapeCodeBuilder<B extends org.refcodes.mixin.ResetEscapeCodeAccessor.ResetEscapeCodeBuilder<B>>, org.refcodes.mixin.ResetEscapeCodeAccessor.ResetEscapeCodeMutator, org.refcodes.mixin.ResetEscapeCodeAccessor.ResetEscapeCodeProperty
-
Nested classes/interfaces inherited from interface org.refcodes.cli.RootConditionAccessor
RootConditionAccessor.RootConditionBuilder<B extends RootConditionAccessor.RootConditionBuilder<B>>, RootConditionAccessor.RootConditionMutator, RootConditionAccessor.RootConditionProperty
-
Nested classes/interfaces inherited from interface org.refcodes.textual.TextBoxGridAccessor
org.refcodes.textual.TextBoxGridAccessor.TextBoxGridBuilder<B extends org.refcodes.textual.TextBoxGridAccessor.TextBoxGridBuilder<?>>, org.refcodes.textual.TextBoxGridAccessor.TextBoxGridMutator, org.refcodes.textual.TextBoxGridAccessor.TextBoxGridProperty
-
-
Field Summary
Fields Modifier and Type Field Description protected PrintStream_errStreamprotected PrintStream_stdStream
-
Constructor Summary
Constructors Constructor Description ArgsParserImpl()Constructs theArgsParserinstance without any restrictions to the parsed arguments.ArgsParserImpl(ArgsSyntax aRootArgsSyntax)Constructs theArgsParserinstance with the given rootArgsSyntaxand the defaultSyntaxNotation.REFCODES.ArgsParserImpl(Option<?> aRootOption)Constructs theArgsParserinstance with the given rootOptionand the defaultSyntaxNotation.REFCODES.
-
Method Summary
All Methods Static Methods Instance Methods Concrete Methods Modifier and Type Method Description voidaddExample(Example aExampleUsage)Adds a usage example by providing a description of the example and the command line arguments required by the example.voiderrorLn(String aLine)Prints the given line to standard error with regards to to the console width as specified by theArgsParser.withConsoleWidth(int)method.List<? extends Operand<?>>evalArgs(String[] aArgs)Evaluates the provided command line arguments and determines the according values by evaluating the rootArgsSyntax.protected static List<? extends Operand<?>>fromArgs(String[] aArgs, char aDelimiter)Heuristically loads the arguments without any syntax required, e.g.ArgsSyntaxgetArgsSyntax()The root condition is the starting point node of aSyntaxablehierarchy to be traversed when determining the syntax for command line arguments or when evaluating the command line arguments.StringgetBannerBorderEscapeCode()Retrieves the banner's border Escape-Code from the banner border Escape-Code property.StringgetBannerEscapeCode()Retrieves the banner's content Escape-Code from the banner Escape-Code property.StringgetCommandEscapeCode()Retrieves the command name's (CLI executable) Escape-Code from the command name Escape-Code property.StringgetCopyrightNote()Retrieves the copyright.protected chargetDelimiter()Returns the delimiter to be used by colliding command line args when creating non colliding arg's aliases (keys for key/value-pairs).StringgetDescription()Retrieves the description.StringgetDescriptionEscapeCode()Retrieves the parameter's description Escape-Code from the parameter's description Escape-Code property.List<Example>getExamples()Retrieves theExampleinstances as added usingArgsParser.addExample(String, Operand...).StringgetLicenseNote()Retrieves the license.StringgetLineSeparatorEscapeCode()Retrieves the line separator Escape-Code from the line separator Escape-Code property.StringgetName()StringgetOptionEscapeCode()Retrieves the option Escape-Code from the option Escape-Code property.StringgetParamEscapeCode()Retrieves the parameter Escape-Code from the parameter Escape-Code property.StringgetResetEscapeCode()chargetSeparatorLnChar()Gets the character to be used when printing a separator line with theArgsParser.printSeparatorLn()method.org.refcodes.textual.TextBoxGridgetTextBoxGrid()StringgetTitle()booleanisEscapeCodesEnabled()voidprintBanner()Prints the banner; the banner most probably is an ASCII_HEADER_ASCII_BODY art text block which's look depends strongly on the taste of the author implementing this interface.voidprintCopyrightNote()Prints the copyright note as specified by theArgsParser.withCopyrightNote(String)method; with regards to to the console width as specified by theArgsParser.withConsoleWidth(int)method.voidprintDescription()Prints the description as set by theArgsParser.withDescription(String)method with regards to the console width as specified by theArgsParser.withConsoleWidth(int)method.voidprintExamples()Prints example usages as as added by theArgsParser.addExample(String, Operand...)method with regards to the console width as specified by theArgsParser.withConsoleWidth(int)method.voidprintLicenseNote()Prints the license note as specified by theArgsParser.withLicenseNote(String)method; with regards to to the console width as specified by theArgsParser.withConsoleWidth(int)method.voidprintLn()Prints an empty line / a line break.voidprintLn(String aLine)Prints the given line to standard out with regards to to the console width as specified by theArgsParser.withConsoleWidth(int)method.voidprintOptions()Prints theOptions (short- and the long-options), theFlages and theOperandand their description with regards to the console width as specified by theArgsParser.withConsoleWidth(int)method.voidprintSeparatorLn()Prints a separator line using the separator character as specified by theArgsParser.withSeparatorLnChar(char)method; with regards to to the console width as specified by theArgsParser.withConsoleWidth(int)method.voidprintSynopsis()Prints the syntax as retrieved by the rootArgsSyntaxelement as ofSynopsis.toSynopsis(SyntaxNotation)with regards to theSyntaxNotationset by theArgsParser.withSyntaxNotation(SyntaxNotation)method.voidreset()voidsetBannerBorderEscapeCode(String aBannerBorderEscCode)Sets the banner's border Escape-Code for the banner border Escape-Code property.voidsetBannerEscapeCode(String aBannerEscCode)Sets the banner's content Escape-Code for the banner Escape-Code property.voidsetBannerFont(org.refcodes.textual.Font aBannerFont)Sets the banner font.voidsetBannerFontPalette(char[] aColorPalette)Sets the banner font palette.voidsetCommandEscapeCode(String aCommandEscCode)Sets the command name's (CLI executable) Escape-Code for the command name Escape-Code property.voidsetConsoleWidth(int aConsoleWidth)Set the console with.voidsetCopyrightNote(String aCopyrightNote)Set the copyright note used by theArgsParser.printHelp()method when writing out the copyright claim and make other adjustments with the result (with regards to the Builder-Pattern).voidsetDescription(String aDescription)voidsetDescriptionEscapeCode(String aDescriptionEscCode)Sets the description Escape-Code for the description Escape-Code property.voidsetErrorOut(PrintStream aErrorOut)Set the error outPrintStreamand make other adjustments with the result (with regards to the Builder-Pattern).voidsetEscapeCodesEnabled(boolean isEscCodeEnabled)voidsetLicenseNote(String aLicenseNote)Set the license note used by theArgsParser.printHelp()method when writing out the licensing conditions.voidsetLineBreak(String aLineBreak)Set the console's line break.voidsetLineSeparatorEscapeCode(String aLineSeparatorEscCode)Sets the line separator Escape-Code for the line separator Escape-Code property.voidsetMaxConsoleWidth(int aMaxConsoleWidth)Set the maximum console width to use in case the console width is greater than the maximum you want.voidsetName(String aName)voidsetOptionEscapeCode(String aOptEscCode)Sets the option Escape-Code for the option Escape-Code property.voidsetParamEscapeCode(String aParamEscCode)Sets the parameter Escape-Code for the parameter Escape-Code property.voidsetResetEscapeCode(String aResetEscCode)voidsetSeparatorLnChar(char aSeparatorLnChar)Set the character to be used when printing a separator line with theArgsParser.printSeparatorLn()method.voidsetStandardOut(PrintStream aStandardOut)Set the standard outPrintStreamand make other adjustments with the result (with regards to the Builder-Pattern).voidsetSyntaxNotation(SyntaxNotation aSyntaxNotation)Set theSyntaxNotation.voidsetTextBoxGrid(org.refcodes.textual.TextBoxGrid aTextBoxGrid)voidsetTitle(String aTitle)-
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
Methods inherited from interface org.refcodes.cli.ArgsParser
addExample, evalArgs, printBody, printHelp, withBannerBorderEscapeCode, withBannerEscapeCode, withBannerFont, withBannerFontPalette, withCommandEscapeCode, withConsoleWidth, withCopyrightNote, withDescription, withDescriptionEscapeCode, withErrorOut, withEscapeCodesEnabled, withEvalArgs, withEvalArgs, withExample, withExample, withExamples, withExamples, withLicenseNote, withLineBreak, withLineSeparatorEscapeCode, withMaxConsoleWidth, withName, withOptionEscapeCode, withParamEscapeCode, withResetEscapeCode, withSeparatorLnChar, withStandardOut, withSyntaxNotation, withTextBoxGrid, withTitle
-
Methods inherited from interface org.refcodes.mixin.DescriptionAccessor.DescriptionProperty
letDescription
-
Methods inherited from interface org.refcodes.mixin.EscapeCodesStatusAccessor.EscapeCodeStatusProperty
letEscapeCodesEnabled
-
Methods inherited from interface org.refcodes.mixin.ResetEscapeCodeAccessor.ResetEscapeCodeProperty
letResetEscapeCode
-
-
-
-
Field Detail
-
_stdStream
protected PrintStream _stdStream
-
_errStream
protected PrintStream _errStream
-
-
Constructor Detail
-
ArgsParserImpl
public ArgsParserImpl()
Constructs theArgsParserinstance without any restrictions to the parsed arguments. The constructor only provides means to set the required attributes as the attributes to be adjusted optionally are already sufficiently pre-configured. For adjusting them, a flavor of the Builder-Pattern is provided with which you can easily chain the configuration of this instance; as them methods return the instance of this class being configured.
-
ArgsParserImpl
public ArgsParserImpl(ArgsSyntax aRootArgsSyntax)
Constructs theArgsParserinstance with the given rootArgsSyntaxand the defaultSyntaxNotation.REFCODES. The constructor only provides means to set the required attributes as the attributes to be adjusted optionally are already sufficiently pre-configured. For adjusting them, a flavor of the Builder-Pattern is provided with which you can easily chain the configuration of this instance; as them methods return the instance of this class being configured.- Parameters:
aRootArgsSyntax- The root condition being the node from which parsing the command line arguments starts.
-
ArgsParserImpl
public ArgsParserImpl(Option<?> aRootOption)
Constructs theArgsParserinstance with the given rootOptionand the defaultSyntaxNotation.REFCODES. The constructor only provides means to set the required attributes as the attributes to be adjusted optionally are already sufficiently pre-configured. For adjusting them, a flavor of the Builder-Pattern is provided with which you can easily chain the configuration of this instance; as them methods return the instance of this class being configured.- Parameters:
aRootOption- The root option being the node from which parsing the command line arguments starts.
-
-
Method Detail
-
getLineSeparatorEscapeCode
public String getLineSeparatorEscapeCode()
Retrieves the line separator Escape-Code from the line separator Escape-Code property.- Specified by:
getLineSeparatorEscapeCodein interfaceArgsParser- Returns:
- The line separator Escape-Code stored by the line separator Escape-Code property.
-
setLineSeparatorEscapeCode
public void setLineSeparatorEscapeCode(String aLineSeparatorEscCode)
Sets the line separator Escape-Code for the line separator Escape-Code property.- Specified by:
setLineSeparatorEscapeCodein interfaceArgsParser- Parameters:
aLineSeparatorEscCode- The line separator Escape-Code to be stored by the line separator Escape-Code property.
-
getBannerEscapeCode
public String getBannerEscapeCode()
Retrieves the banner's content Escape-Code from the banner Escape-Code property.- Specified by:
getBannerEscapeCodein interfaceArgsParser- Returns:
- The banner Escape-Code stored by the banner Escape-Code property.
-
getBannerBorderEscapeCode
public String getBannerBorderEscapeCode()
Retrieves the banner's border Escape-Code from the banner border Escape-Code property.- Specified by:
getBannerBorderEscapeCodein interfaceArgsParser- Returns:
- The banner border Escape-Code stored by the banner border Escape-Code property.
-
setBannerEscapeCode
public void setBannerEscapeCode(String aBannerEscCode)
Sets the banner's content Escape-Code for the banner Escape-Code property.- Specified by:
setBannerEscapeCodein interfaceArgsParser- Parameters:
aBannerEscCode- The banner Escape-Code to be stored by the banner Escape-Code property.
-
setBannerBorderEscapeCode
public void setBannerBorderEscapeCode(String aBannerBorderEscCode)
Sets the banner's border Escape-Code for the banner border Escape-Code property.- Specified by:
setBannerBorderEscapeCodein interfaceArgsParser- Parameters:
aBannerBorderEscCode- The banner border Escape-Code to be stored by the banner border Escape-Code property.
-
getParamEscapeCode
public String getParamEscapeCode()
Retrieves the parameter Escape-Code from the parameter Escape-Code property.- Specified by:
getParamEscapeCodein interfaceArgsParser- Returns:
- The parameter Escape-Code stored by the parameter Escape-Code property.
-
setParamEscapeCode
public void setParamEscapeCode(String aParamEscCode)
Sets the parameter Escape-Code for the parameter Escape-Code property.- Specified by:
setParamEscapeCodein interfaceArgsParser- Parameters:
aParamEscCode- The parameter Escape-Code to be stored by the parameter Escape-Code property.
-
getOptionEscapeCode
public String getOptionEscapeCode()
Retrieves the option Escape-Code from the option Escape-Code property.- Specified by:
getOptionEscapeCodein interfaceArgsParser- Returns:
- The option Escape-Code stored by the option Escape-Code property.
-
setOptionEscapeCode
public void setOptionEscapeCode(String aOptEscCode)
Sets the option Escape-Code for the option Escape-Code property.- Specified by:
setOptionEscapeCodein interfaceArgsParser- Parameters:
aOptEscCode- The option Escape-Code to be stored by the option Escape-Code property.
-
errorLn
public void errorLn(String aLine)
Prints the given line to standard error with regards to to the console width as specified by theArgsParser.withConsoleWidth(int)method.- Specified by:
errorLnin interfaceArgsParser- Parameters:
aLine- The line to be printed.
-
evalArgs
public List<? extends Operand<?>> evalArgs(String[] aArgs) throws ArgsSyntaxException
Evaluates the provided command line arguments and determines the according values by evaluating the rootArgsSyntax. In case of parsing failure, an according exception is thrown. ATTENTION: This method tests(!) for superfluous command line arguments being passed; e.g. command line arguments not being evaluated by any of theSyntaxableinstance being traversed starting at the rootArgsSyntaxwill be reported. Business logic therefore should invoke this root node'sArgsParser.evalArgs(String[])method instead of aArgsSyntax'sSyntaxable.parseArgs(String[], String[])method; as ignoring superfluous command line arguments will cause unexpected behavior from the point of view of the invoker.- Specified by:
evalArgsin interfaceArgsParser- Parameters:
aArgs- The command line arguments to be evaluated.- Returns:
- The list of evaluated command line arguments being instances of
the
Operandinterfaces or its sub-types. - Throws:
ArgsSyntaxException- thrown in case of a command line arguments mismatch regarding provided and expected args.
-
getCopyrightNote
public String getCopyrightNote()
Retrieves the copyright.- Specified by:
getCopyrightNotein interfaceArgsParser- Returns:
- The copyright note.
-
getDelimiter
protected char getDelimiter()
Returns the delimiter to be used by colliding command line args when creating non colliding arg's aliases (keys for key/value-pairs).- Returns:
- The according delimiter.
-
getDescription
public String getDescription()
Retrieves the description.- Specified by:
getDescriptionin interfaceArgsParser- Specified by:
getDescriptionin interfaceorg.refcodes.mixin.DescriptionAccessor- Returns:
- The description.
-
getLicenseNote
public String getLicenseNote()
Retrieves the license.- Specified by:
getLicenseNotein interfaceArgsParser- Returns:
- The license note.
-
getName
public String getName()
- Specified by:
getNamein interfaceorg.refcodes.mixin.NameAccessor
-
getArgsSyntax
public ArgsSyntax getArgsSyntax()
The root condition is the starting point node of aSyntaxablehierarchy to be traversed when determining the syntax for command line arguments or when evaluating the command line arguments. Retrieves the root condition from the root condition property.- Specified by:
getArgsSyntaxin interfaceArgsParser- Specified by:
getArgsSyntaxin interfaceRootConditionAccessor- Returns:
- The root
ArgsSyntaxin which's syntax this parser is based.
-
getResetEscapeCode
public String getResetEscapeCode()
- Specified by:
getResetEscapeCodein interfaceorg.refcodes.mixin.ResetEscapeCodeAccessor
-
setResetEscapeCode
public void setResetEscapeCode(String aResetEscCode)
- Specified by:
setResetEscapeCodein interfaceorg.refcodes.mixin.ResetEscapeCodeAccessor.ResetEscapeCodeMutator
-
getTitle
public String getTitle()
- Specified by:
getTitlein interfaceorg.refcodes.mixin.TitleAccessor
-
printBanner
public void printBanner()
Prints the banner; the banner most probably is an ASCII_HEADER_ASCII_BODY art text block which's look depends strongly on the taste of the author implementing this interface.- Specified by:
printBannerin interfaceArgsParser
-
printCopyrightNote
public void printCopyrightNote()
Prints the copyright note as specified by theArgsParser.withCopyrightNote(String)method; with regards to to the console width as specified by theArgsParser.withConsoleWidth(int)method.- Specified by:
printCopyrightNotein interfaceArgsParser
-
printDescription
public void printDescription()
Prints the description as set by theArgsParser.withDescription(String)method with regards to the console width as specified by theArgsParser.withConsoleWidth(int)method.- Specified by:
printDescriptionin interfaceArgsParser
-
printLicenseNote
public void printLicenseNote()
Prints the license note as specified by theArgsParser.withLicenseNote(String)method; with regards to to the console width as specified by theArgsParser.withConsoleWidth(int)method.- Specified by:
printLicenseNotein interfaceArgsParser
-
printLn
public void printLn()
Prints an empty line / a line break.- Specified by:
printLnin interfaceArgsParser
-
printLn
public void printLn(String aLine)
Prints the given line to standard out with regards to to the console width as specified by theArgsParser.withConsoleWidth(int)method.- Specified by:
printLnin interfaceArgsParser- Parameters:
aLine- The line to be printed.
-
printOptions
public void printOptions()
Prints theOptions (short- and the long-options), theFlages and theOperandand their description with regards to the console width as specified by theArgsParser.withConsoleWidth(int)method.- Specified by:
printOptionsin interfaceArgsParser
-
printExamples
public void printExamples()
Prints example usages as as added by theArgsParser.addExample(String, Operand...)method with regards to the console width as specified by theArgsParser.withConsoleWidth(int)method.- Specified by:
printExamplesin interfaceArgsParser
-
printSeparatorLn
public void printSeparatorLn()
Prints a separator line using the separator character as specified by theArgsParser.withSeparatorLnChar(char)method; with regards to to the console width as specified by theArgsParser.withConsoleWidth(int)method.- Specified by:
printSeparatorLnin interfaceArgsParser
-
printSynopsis
public void printSynopsis()
Prints the syntax as retrieved by the rootArgsSyntaxelement as ofSynopsis.toSynopsis(SyntaxNotation)with regards to theSyntaxNotationset by theArgsParser.withSyntaxNotation(SyntaxNotation)method.- Specified by:
printSynopsisin interfaceArgsParser
-
reset
public void reset()
- Specified by:
resetin interfaceorg.refcodes.component.Resetable
-
setBannerFont
public void setBannerFont(org.refcodes.textual.Font aBannerFont)
Sets the banner font.- Specified by:
setBannerFontin interfaceArgsParser- Parameters:
aBannerFont- the new banner font
-
setBannerFontPalette
public void setBannerFontPalette(char[] aColorPalette)
Sets the banner font palette.- Specified by:
setBannerFontPalettein interfaceArgsParser- Parameters:
aColorPalette- the new banner font palette
-
setConsoleWidth
public void setConsoleWidth(int aConsoleWidth)
Set the console with. A setting of "-1" makes the instance use theSystemUtility.getTerminalWidth()value, i.e. the console width is set automatically to be the width of your terminal.- Specified by:
setConsoleWidthin interfaceArgsParser- Parameters:
aConsoleWidth- The width to set or -1 to let the parser automatically determine the console width.
-
setCopyrightNote
public void setCopyrightNote(String aCopyrightNote)
Set the copyright note used by theArgsParser.printHelp()method when writing out the copyright claim and make other adjustments with the result (with regards to the Builder-Pattern).- Specified by:
setCopyrightNotein interfaceArgsParser- Parameters:
aCopyrightNote- The license note printed out by theArgsParser.printHelp()method.
-
setDescription
public void setDescription(String aDescription)
- Specified by:
setDescriptionin interfaceorg.refcodes.mixin.DescriptionAccessor.DescriptionMutator
-
setErrorOut
public void setErrorOut(PrintStream aErrorOut)
Set the error outPrintStreamand make other adjustments with the result (with regards to the Builder-Pattern).- Specified by:
setErrorOutin interfaceArgsParser- Parameters:
aErrorOut- The error outPrintStreamto set.
-
isEscapeCodesEnabled
public boolean isEscapeCodesEnabled()
- Specified by:
isEscapeCodesEnabledin interfaceorg.refcodes.mixin.EscapeCodesStatusAccessor
-
setEscapeCodesEnabled
public void setEscapeCodesEnabled(boolean isEscCodeEnabled)
- Specified by:
setEscapeCodesEnabledin interfaceorg.refcodes.mixin.EscapeCodesStatusAccessor.EscapeCodeStatusMutator
-
getDescriptionEscapeCode
public String getDescriptionEscapeCode()
Retrieves the parameter's description Escape-Code from the parameter's description Escape-Code property.- Specified by:
getDescriptionEscapeCodein interfaceArgsParser- Returns:
- The description Escape-Code stored by the description Escape-Code property.
-
setDescriptionEscapeCode
public void setDescriptionEscapeCode(String aDescriptionEscCode)
Sets the description Escape-Code for the description Escape-Code property.- Specified by:
setDescriptionEscapeCodein interfaceArgsParser- Parameters:
aDescriptionEscCode- The description Escape-Code to be stored by the description Escape-Code property.
-
getCommandEscapeCode
public String getCommandEscapeCode()
Retrieves the command name's (CLI executable) Escape-Code from the command name Escape-Code property.- Specified by:
getCommandEscapeCodein interfaceArgsParser- Returns:
- The command name's Escape-Code stored by the command name Escape-Code property.
-
setCommandEscapeCode
public void setCommandEscapeCode(String aCommandEscCode)
Sets the command name's (CLI executable) Escape-Code for the command name Escape-Code property.- Specified by:
setCommandEscapeCodein interfaceArgsParser- Parameters:
aCommandEscCode- The command name's Escape-Code to stored by the command name Escape-Code property.
-
setLicenseNote
public void setLicenseNote(String aLicenseNote)
Set the license note used by theArgsParser.printHelp()method when writing out the licensing conditions.- Specified by:
setLicenseNotein interfaceArgsParser- Parameters:
aLicenseNote- The license note printed out by theArgsParser.printHelp()method.
-
setLineBreak
public void setLineBreak(String aLineBreak)
Set the console's line break. A setting of null makes the instance use theSystemUtility.getLineBreak()value.- Specified by:
setLineBreakin interfaceArgsParser- Parameters:
aLineBreak- the new line break
-
setMaxConsoleWidth
public void setMaxConsoleWidth(int aMaxConsoleWidth)
Set the maximum console width to use in case the console width is greater than the maximum you want. This is most useful when the console width is determined automatically to be the width of your terminal.- Specified by:
setMaxConsoleWidthin interfaceArgsParser- Parameters:
aMaxConsoleWidth- the new max console width
-
setName
public void setName(String aName)
- Specified by:
setNamein interfaceorg.refcodes.mixin.NameAccessor.NameMutator
-
setSeparatorLnChar
public void setSeparatorLnChar(char aSeparatorLnChar)
Set the character to be used when printing a separator line with theArgsParser.printSeparatorLn()method.- Specified by:
setSeparatorLnCharin interfaceArgsParser- Parameters:
aSeparatorLnChar- The character used by theArgsParser.printSeparatorLn()method when printing out the line of characters..
-
getSeparatorLnChar
public char getSeparatorLnChar()
Gets the character to be used when printing a separator line with theArgsParser.printSeparatorLn()method.- Specified by:
getSeparatorLnCharin interfaceArgsParser- Returns:
- aSeparatorChar The character used by the
ArgsParser.printSeparatorLn()method when printing out the line of characters..
-
setStandardOut
public void setStandardOut(PrintStream aStandardOut)
Set the standard outPrintStreamand make other adjustments with the result (with regards to the Builder-Pattern).- Specified by:
setStandardOutin interfaceArgsParser- Parameters:
aStandardOut- The standard outPrintStreamto set.
-
setSyntaxNotation
public void setSyntaxNotation(SyntaxNotation aSyntaxNotation)
Set theSyntaxNotation.- Specified by:
setSyntaxNotationin interfaceArgsParser- Parameters:
aSyntaxNotation- TheSyntaxNotationto set.
-
setTitle
public void setTitle(String aTitle)
- Specified by:
setTitlein interfaceorg.refcodes.mixin.TitleAccessor.TitleMutator
-
getTextBoxGrid
public org.refcodes.textual.TextBoxGrid getTextBoxGrid()
- Specified by:
getTextBoxGridin interfaceorg.refcodes.textual.TextBoxGridAccessor
-
setTextBoxGrid
public void setTextBoxGrid(org.refcodes.textual.TextBoxGrid aTextBoxGrid)
- Specified by:
setTextBoxGridin interfaceorg.refcodes.textual.TextBoxGridAccessor.TextBoxGridMutator
-
getExamples
public List<Example> getExamples()
Retrieves theExampleinstances as added usingArgsParser.addExample(String, Operand...).- Specified by:
getExamplesin interfaceArgsParser- Returns:
- The according
Exampleelements.
-
addExample
public void addExample(Example aExampleUsage)
Adds a usage example by providing a description of the example and the command line arguments required by the example.- Specified by:
addExamplein interfaceArgsParser- Parameters:
aExampleUsage- The description as well as the command line arguments used by the example.
-
fromArgs
protected static List<? extends Operand<?>> fromArgs(String[] aArgs, char aDelimiter)
Heuristically loads the arguments without any syntax required, e.g. without any rootArgsSyntaxto be set.- Parameters:
aArgs- The arguments to be loaded.aDelimiter- The delimiter to resolve name clashes.- Returns:
- A list of heuristically determined
FlagandStringOperandinstances.
-
-