- All Superinterfaces:
ArgsSyntaxAccessor,ArgsSyntaxAccessor.ArgsSyntaxMutator
- Enclosing interface:
- ArgsSyntaxAccessor
public static interface ArgsSyntaxAccessor.ArgsSyntaxProperty
extends ArgsSyntaxAccessor, ArgsSyntaxAccessor.ArgsSyntaxMutator
Provides a root condition property.
-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.cli.ArgsSyntaxAccessor
ArgsSyntaxAccessor.ArgsSyntaxBuilder<B extends ArgsSyntaxAccessor.ArgsSyntaxBuilder<B>>, ArgsSyntaxAccessor.ArgsSyntaxMutator, ArgsSyntaxAccessor.ArgsSyntaxProperty -
Method Summary
Modifier and TypeMethodDescriptiondefault ConstituentletArgsSyntax(Constituent aArgsSyntax) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenCondition(setter) as ofArgsSyntaxAccessor.ArgsSyntaxMutator.setArgsSyntax(Constituent)and returns the very same value (getter).Methods inherited from interface org.refcodes.cli.ArgsSyntaxAccessor
getArgsSyntaxMethods inherited from interface org.refcodes.cli.ArgsSyntaxAccessor.ArgsSyntaxMutator
setArgsSyntax
-
Method Details
-
letArgsSyntax
This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenCondition(setter) as ofArgsSyntaxAccessor.ArgsSyntaxMutator.setArgsSyntax(Constituent)and returns the very same value (getter).- Parameters:
aArgsSyntax- TheConditionto set (viaArgsSyntaxAccessor.ArgsSyntaxMutator.setArgsSyntax(Constituent)).- Returns:
- Returns the value passed for it to be used in conclusive processing steps.
-