Class ArrayOperand<T>

java.lang.Object
org.refcodes.cli.ArrayOperand<T>
Type Parameters:
T - the generic type
All Implemented Interfaces:
Cloneable, Comparable<Operand<?>>, MatchCountAccessor, Operand<T[]>, ParsedArgsAccessor, Synopsisable, Term, org.refcodes.exception.ExceptionAccessor<ArgsSyntaxException>, org.refcodes.graphical.VisibleAccessor, org.refcodes.graphical.VisibleAccessor.VisibleBuilder<Term>, org.refcodes.graphical.VisibleAccessor.VisibleMutator, org.refcodes.graphical.VisibleAccessor.VisibleProperty, org.refcodes.mixin.AliasAccessor, org.refcodes.mixin.Clonable, org.refcodes.mixin.DescriptionAccessor, org.refcodes.mixin.Resetable, org.refcodes.mixin.TypeAccessor<T[]>, org.refcodes.mixin.ValueAccessor<T[]>, org.refcodes.runtime.Diagnosable, org.refcodes.schema.Schemable<org.refcodes.runtime.DiagnosticOptions>
Direct Known Subclasses:
ArrayDirective, ArrayOption

public class ArrayOperand<T> extends Object implements Operand<T[]>
Creates an array representation facade for the encapsulated Operand. This way any Operand can also be used as an array Operand, e.g. it can be provided multiple times in the command line arguments.
  • Field Details

    • _description

      protected String _description
    • _exception

      protected ArgsSyntaxException _exception
    • _isVisible

      protected boolean _isVisible
  • Constructor Details

    • ArrayOperand

      public ArrayOperand(Operand<T> aOperand)
      Constructs the ArrayOperand by encapsulating the given Operand and providing its definition as array definition to the CLI.
      Parameters:
      aOperand - The Operand which's array counterpart is to be defined.
    • ArrayOperand

      public ArrayOperand(Operand<T> aOperand, int aLength)
      Constructs the ArrayOperand by encapsulating the given Operand and providing its definition as array definition to the CLI.
      Parameters:
      aOperand - The Operand which's array counterpart is to be defined.
      aLength - The number of array elements, or -1 if there is no limit.
    • ArrayOperand

      public ArrayOperand(Operand<T> aOperand, int aMinLength, int aMaxLength)
      Constructs the ArrayOperand by encapsulating the given Operand and providing its definition as array definition to the CLI.
      Parameters:
      aOperand - The Operand which's array counterpart is to be defined.
      aMinLength - The minimum number of array elements, or -1 if there is no limit.
      aMaxLength - The maximum number of array elements, or -1 if there is no limit.
  • Method Details

    • getMatchCount

      public int getMatchCount()
      Determines the number of args being matched by the Term.parseArgs(String[], CliContext) (and similar) method(s) of the according syntax. This way we can determine which part of the syntax (tree) had most matches.
      Specified by:
      getMatchCount in interface MatchCountAccessor
      Specified by:
      getMatchCount in interface Term
      Returns:
      The number of args matching the according syntax (tree).
    • clone

      public Object clone() throws CloneNotSupportedException
      Specified by:
      clone in interface org.refcodes.mixin.Clonable
      Overrides:
      clone in class Object
      Throws:
      CloneNotSupportedException
    • compareTo

      public int compareTo(Operand<?> o)
      Specified by:
      compareTo in interface Comparable<T>
    • getAlias

      public String getAlias()
      Retrieves the name (alias) of the parameter value which can be the name of the operand (Operand) or the option argument (Option), depending on the sub-type inheriting from this interface. The parameter name is merely used for constructing the command line arguments syntax String via Operand.toSyntax(CliContext) and the command line arguments detail description when creating a command line tool's help output. Attention: The alias can also be used as a key when putting an Operand's key/value-pair into a dictionary such as is done by the ApplicationProperties type provided by the refcodes-properties-ext-runime artifact!
      Specified by:
      getAlias in interface org.refcodes.mixin.AliasAccessor
      Specified by:
      getAlias in interface Operand<T>
      Returns:
      The name of the parameter, e.g the name of the operand or the name of the option argument.
    • getDescription

      public String getDescription()
      Specified by:
      getDescription in interface org.refcodes.mixin.DescriptionAccessor
    • getMaxLength

      public int getMaxLength()
      Retrieves the maximum number of array elements to be present, e.g. maximum number of options provided in the command line arguments.
      Returns:
      The maximum number of array elements, or -1 if there is no limit.
    • getMinLength

      public int getMinLength()
      Retrieves the minimum number of array elements to be present, e.g. minimum number of options provided in the command line arguments.
      Returns:
      The minimum number of array elements, or -1 if there is no limit.
    • getType

      public Class<T[]> getType()
      Specified by:
      getType in interface org.refcodes.mixin.TypeAccessor<T>
    • getValue

      public T[] getValue()
      Specified by:
      getValue in interface Operand<T>
      Specified by:
      getValue in interface org.refcodes.mixin.ValueAccessor<T>
    • parseArgs

      public Operand<?>[] parseArgs(String[] aArgs, String[] aOperands, CliContext aCliCtx) throws ArgsSyntaxException
      Parses the given command line arguments using the provided keyword set and CLI context.

      This method represents the core parsing operation. It evaluates this Term or, if this term is an inner node, delegates parsing to its child terms.

      The aKeywords parameter defines reserved tokens such as option names that must not be interpreted as operand values.

      This method does not validate whether all arguments have been consumed. Superfluous arguments must be handled by the caller.

      Specified by:
      parseArgs in interface Term
      Parameters:
      aArgs - The command line arguments to parse
      aOperands - Reserved option and keyword tokens
      aCliCtx - The CliContext controlling parsing and rendering
      Returns:
      The evaluated operands
      Throws:
      ArgsSyntaxException - If the arguments do not match the syntax
    • reset

      public void reset()
      Specified by:
      reset in interface org.refcodes.mixin.Resetable
    • getParsedArgs

      public String[] getParsedArgs()
      Retrieves the (command line) args which represent this Operand after being "parsed" (provided with command line args).
      Specified by:
      getParsedArgs in interface Operand<T>
      Specified by:
      getParsedArgs in interface ParsedArgsAccessor
      Returns:
      The according args from the command line args.
    • withVisible

      public ArrayOperand<T> withVisible(boolean isVisible)

      Visibility in this context means displaying or hiding this Term's existence to the user (defaults to true).

      Specified by:
      withVisible in interface org.refcodes.graphical.VisibleAccessor.VisibleBuilder<T>
    • toSyntax

      public String toSyntax(CliContext aCliCtx)
      Creates a syntax including its arguments.

      A specification differs from a syntax in that the specification provides the full definition not omitting any choices whereas the syntax only provides a syntactically correct variant. For example, having an option with a short option and a long option, the specification will show the short option and the long option whereas the syntax will only show either the short option or, if no short option is set, the long option.

      Specified by:
      toSyntax in interface Operand<T>
      Specified by:
      toSyntax in interface Term
      Parameters:
      aCliCtx - The CLI context controlling notation and formatting
      Returns:
      The human readable command line syntax
    • toUsage

      public String toUsage(CliContext aCliCtx)
      Creates a plain usage specification without any escape codes, helpful e.g. in human readable messages.
      Specified by:
      toUsage in interface Operand<T>
      Parameters:
      aCliCtx - The CliContext to use when creating a beautiful usage text.
      Returns:
      The according usage text.
    • toSpec

      public String toSpec(CliContext aCliCtx)
      Creates a specification including its arguments.

      A specification differs from a syntax in that the specification provides the full definition not omitting any choices whereas the syntax only provides a syntactically correct variant. For example, having an option with a short option and a long option, the specification will show the short option and the long option whereas the syntax will only show either the short option or, if no short option is set, the long option.

      Specified by:
      toSpec in interface Operand<T>
      Parameters:
      aCliCtx - The CliContext to use when creating a beautiful specification text.
      Returns:
      The according specification text.
    • toKeywords

      public String[] toKeywords(CliContext aCliCtx)
      Produces the keywords (short and/or long options, operations, commands, whatever) with the according prefix (if any) to be considered when overall parsing the command line arguments.
      Specified by:
      toKeywords in interface Operand<T>
      Parameters:
      aCliCtx - The CliContext to use when assembling the keywords.
      Returns:
      The keywords with the according prefix.
    • toSchema

      public CliSchema toSchema()
      Specified by:
      toSchema in interface org.refcodes.schema.Schemable<T>
      Specified by:
      toSchema in interface Term
    • getOperand

      protected Operand<T> getOperand()
      Hook for accessing the encapsulated Operand.
      Returns:
      The according Operand.
    • getException

      public ArgsSyntaxException getException()
      Retrieves the ArgsSyntaxException exception in case invoking Term.parseArgs(String[], CliContext) failed. The exception (and the according suppressed ones alongside the causes) does not necessarily have been thrown by the Term.parseArgs(String[], CliContext) method depending on the semantics of the Term handing the exception (the AnyCondition provides any exceptions it caught even though it did not throw them as of its semantics).
      Specified by:
      getException in interface org.refcodes.exception.ExceptionAccessor<ArgsSyntaxException>
      Specified by:
      getException in interface Term
      Returns:
      The ArgsSyntaxException exception occurring while parsing the arguments.
    • setVisible

      public void setVisible(boolean isVisible)

      Visibility in this context means displaying or hiding this Term's existence to the user (defaults to true).

      Specified by:
      setVisible in interface Term
      Specified by:
      setVisible in interface org.refcodes.graphical.VisibleAccessor.VisibleMutator
    • isVisible

      public boolean isVisible()

      Visibility in this context means displaying or hiding this Term's existence to the user (defaults to true).

      Specified by:
      isVisible in interface Term
      Specified by:
      isVisible in interface org.refcodes.graphical.VisibleAccessor
    • toArgsDiff

      protected static String[] toArgsDiff(String[] aArgs, List<? extends Operand<?>> aArgsSubset)
      Creates the difference between the provided set and the provided Lists therein found argument arrays subset (as of Operand.getParsedArgs()).
      Parameters:
      aArgs - The set to be used for the diff operation.
      aArgsSubset - The subset to be used for the diff operation being the lists containing the Operand instances whose command line arguments are to be diffed.
      Returns:
      The difference between the set and the subset.
    • toArgsDiff

      protected static String[] toArgsDiff(String[] aArgs, Operand<?>[] aArgsSubset)
      Creates the difference between the provided set and the provided Lists therein found argument arrays subset (as of Operand.getParsedArgs()).
      Parameters:
      aArgs - The set to be used for the diff operation.
      aArgsSubset - The subset to be used for the diff operation being the lists containing the Operand instances whose command line arguments are to be diffed.
      Returns:
      The difference between the set and the subset.
    • toArgsDiff

      protected static String[] toArgsDiff(String[] aArgs, String[] aArgsSubset)
      Creates the difference between the provided set and the provided subset.
      Parameters:
      aArgs - The set to be used for the diff operation.
      aArgsSubset - The subset to be used for the diff operation.
      Returns:
      The difference between the set and the subset.
    • toParsedArgs

      protected static String[] toParsedArgs(Operand<?>[]... aOperands)
      Takes all Operand instances found in the provided Lists and adds all therein found argument arrays (as of Operand.getParsedArgs()) to the result.
      Parameters:
      aOperands - The lists containing the Operand instances whose command line arguments are to be added to the result.
      Returns:
      All the command line arguments detected in the provided Operands Lists.