java.lang.Object
org.refcodes.cli.ArrayOperand<T>
- Type Parameters:
T- the generic type
- All Implemented Interfaces:
Cloneable,Comparable<Operand<?>>,ArgsAccessor,Constituent,Operand<T[]>,Synopsisable,org.refcodes.mixin.AliasAccessor,org.refcodes.mixin.Clonable,org.refcodes.mixin.DescriptionAccessor,org.refcodes.mixin.Resetable,org.refcodes.mixin.Schemable,org.refcodes.mixin.TypeAccessor<T[]>,org.refcodes.mixin.ValueAccessor<T[]>
- Direct Known Subclasses:
ArrayOption
-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.mixin.AliasAccessor
org.refcodes.mixin.AliasAccessor.AliasBuilder<B extends org.refcodes.mixin.AliasAccessor.AliasBuilder<B>>, org.refcodes.mixin.AliasAccessor.AliasMutator, org.refcodes.mixin.AliasAccessor.AliasPropertyNested classes/interfaces inherited from interface org.refcodes.cli.ArgsAccessor
ArgsAccessor.ArgsMutator, ArgsAccessor.ArgsPropertyNested classes/interfaces inherited from interface org.refcodes.mixin.DescriptionAccessor
org.refcodes.mixin.DescriptionAccessor.DescriptionBuilder<B extends org.refcodes.mixin.DescriptionAccessor.DescriptionBuilder<B>>, org.refcodes.mixin.DescriptionAccessor.DescriptionMutator, org.refcodes.mixin.DescriptionAccessor.DescriptionPropertyNested classes/interfaces inherited from interface org.refcodes.mixin.TypeAccessor
org.refcodes.mixin.TypeAccessor.TypeBuilder<T extends Object,B extends org.refcodes.mixin.TypeAccessor.TypeBuilder<T, B>>, org.refcodes.mixin.TypeAccessor.TypeMutator<T extends Object>, org.refcodes.mixin.TypeAccessor.TypeProperty<T extends Object> Nested classes/interfaces inherited from interface org.refcodes.mixin.ValueAccessor
org.refcodes.mixin.ValueAccessor.ValueBuilder<V extends Object,B extends org.refcodes.mixin.ValueAccessor.ValueBuilder<V, B>>, org.refcodes.mixin.ValueAccessor.ValueMutator<V extends Object>, org.refcodes.mixin.ValueAccessor.ValueProperty<V extends Object> -
Constructor Summary
ConstructorsConstructorDescriptionArrayOperand(Operand<T> aOperand) Constructs theArrayOperandby encapsulating the givenOperandand providing its definition as array definition to the CLI.ArrayOperand(Operand<T> aOperand, int aLength) Constructs theArrayOperandby encapsulating the givenOperandand providing its definition as array definition to the CLI.ArrayOperand(Operand<T> aOperand, int aMinLength, int aMaxLength) Constructs theArrayOperandby encapsulating the givenOperandand providing its definition as array definition to the CLI. -
Method Summary
Modifier and TypeMethodDescriptionclone()intgetAlias()intRetrieves the maximum number of array elements to be present, e.g.intRetrieves the minimum number of array elements to be present, e.g.Hook for accessing the encapsulatedOperand.getType()T[]getValue()parseArgs(String[] aArgs, String[] aOperands, CliContext aCliCtx) Parses the provided command line arguments and determines the according values by evaluating thisConstituentinstance or, in case of being a node in the syntax tree (such as aCondition, traversing the childConstituentinstances'Constituent.parseArgs(String[], String[], CliContext)methods.voidreset()String[]Retrieves the (command line) args which represent thisOperandafter being "parsed" (provided with command line args).toSchema()toSyntax(CliContext aCliCtx) This method is to be called from inside theConstituenthierarchy; use the methodSynopsisable.toSynopsis(SyntaxNotation)in case you invoke syntax retrieval from the rootConstituent.Methods inherited from class java.lang.Object
equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, waitMethods inherited from interface org.refcodes.cli.Constituent
parseArgs, toSynopsis, toSyntax, toSyntax, toSyntax, toSyntaxMethods inherited from interface org.refcodes.cli.Synopsisable
toSynopsis, toSynopsis, toSynopsis, toSynopsisMethods inherited from interface org.refcodes.mixin.ValueAccessor
getValueOr
-
Constructor Details
-
ArrayOperand
Constructs theArrayOperandby encapsulating the givenOperandand providing its definition as array definition to the CLI.- Parameters:
aOperand- TheOperandwhich's array counterpart is to be defined.
-
ArrayOperand
Constructs theArrayOperandby encapsulating the givenOperandand providing its definition as array definition to the CLI.- Parameters:
aOperand- TheOperandwhich's array counterpart is to be defined.aLength- The number of array elements, or -1 if there is no limit.
-
ArrayOperand
Constructs theArrayOperandby encapsulating the givenOperandand providing its definition as array definition to the CLI.- Parameters:
aOperand- TheOperandwhich's array counterpart is to be defined.aMinLength- The minimum number of array elements, or -1 if there is no limit.aMaxLength- The maximum number of array elements, or -1 if there is no limit.
-
-
Method Details
-
getValue
-
toParsedArgs
Retrieves the (command line) args which represent thisOperandafter being "parsed" (provided with command line args).- Specified by:
toParsedArgsin interfaceArgsAccessor- Specified by:
toParsedArgsin interfaceOperand<T>- Returns:
- The according args from the command line args.
-
getAlias
Retrieves the name (alias) of the parameter value which can be the name of the operand (Operand) or the option argument (Option), depending on the sub-type inheriting from this interface. The parameter name is merely used for constructing the command line arguments syntaxStringviaConstituent.toSyntax(CliContext)and the command line arguments detail description when creating a command line tool's help output. Attention: The alias can also be used as a key when putting anOperand's key/value-pair into a dictionary such as is done by theApplicationPropertiestype provided by therefcodes-properties-ext-runimeartifact! -
toSyntax
This method is to be called from inside theConstituenthierarchy; use the methodSynopsisable.toSynopsis(SyntaxNotation)in case you invoke syntax retrieval from the rootConstituent. Returns the human readable (verbose) syntax of thisConstituentinstance including, in case of being a node in the syntax tree (such as aCondition, the syntax of the childConstituentinstances. ATTENTION: As of different parenthesis settings for some notations regarding the rootConstituentand the childConstituents, the methodConstituent.toSyntax(CliContext)is called from inside theConstituenthierarchy. In case the syntax is to be retrieved from the rootConstituent, then the applicable method to be called isSynopsisable.toSynopsis(SyntaxNotation), as for some notations it will for example not create the most outer braces.- Specified by:
toSyntaxin interfaceConstituent- Parameters:
aCliCtx- TheCliContextfor which the syntax is being generated.- Returns:
- The human readable (verbose) command line arguments syntax.
-
getType
- Specified by:
getTypein interfaceorg.refcodes.mixin.TypeAccessor<T>
-
parseArgs
public List<Operand<?>> parseArgs(String[] aArgs, String[] aOperands, CliContext aCliCtx) throws ArgsSyntaxException Parses the provided command line arguments and determines the according values by evaluating thisConstituentinstance or, in case of being a node in the syntax tree (such as aCondition, traversing the childConstituentinstances'Constituent.parseArgs(String[], String[], CliContext)methods. In case of successfully parsing thisConstituentand / or the childConstituentinstances, the evaluated command line arguments are returned: Depending on theConstituentsubclasses representing the evaluated command line arguments, instances ofFlagclasses,Optionclasses orOperandclasses may be found in the result. In case of parsing failure, an according exception is thrown. ATTENTION: This method does not test for superfluous command line arguments being passed; e.g. command line arguments not being evaluated by any of theConstituentinstance being traversed. This method is commonly used by a rootConstituent'sArgsParser.evalArgs(String[])method, which delegates to theConstituent.parseArgs(String[], String[], CliContext)method and after which it determines whether there are superfluous arguments to be taken care of (by throwing an according exception). Business logic therefore should invoke the root node'sConstituent.parseArgs(String[], String[], CliContext)method as ignoring superfluous command line arguments will aCause unexpected behavior from the point of view of the invoker.- Specified by:
parseArgsin interfaceConstituent- Parameters:
aArgs- The command line arguments to be parsed.aOperands- The list of options (short and as well as long) which are reserved and cannot be used as value.aCliCtx- the cli context- Returns:
- The list of evaluated command line arguments being instances of
the
Operandinterfaces or its sub-types. - Throws:
ArgsSyntaxException- thrown in case of a command line arguments mismatch regarding provided and expected args.
-
reset
public void reset()- Specified by:
resetin interfaceorg.refcodes.mixin.Resetable
-
getDescription
- Specified by:
getDescriptionin interfaceorg.refcodes.mixin.DescriptionAccessor
-
compareTo
- Specified by:
compareToin interfaceComparable<T>
-
getMinLength
public int getMinLength()Retrieves the minimum number of array elements to be present, e.g. minimum number of options provided in the command line arguments.- Returns:
- The minimum number of array elements, or -1 if there is no limit.
-
getMaxLength
public int getMaxLength()Retrieves the maximum number of array elements to be present, e.g. maximum number of options provided in the command line arguments.- Returns:
- The maximum number of array elements, or -1 if there is no limit.
-
clone
- Specified by:
clonein interfaceorg.refcodes.mixin.Clonable- Overrides:
clonein classObject- Throws:
CloneNotSupportedException
-
toSchema
- Specified by:
toSchemain interfaceConstituent- Specified by:
toSchemain interfaceorg.refcodes.mixin.Schemable
-
getOperand
Hook for accessing the encapsulatedOperand.- Returns:
- The according
Operand.
-