java.lang.Object
org.refcodes.cli.ArrayOperand<T>
org.refcodes.cli.ArrayOption<T>
- All Implemented Interfaces:
Cloneable,Comparable<Operand<?>>,ArgsAccessor,Constituent,Operand<T[]>,Option<T[]>,Synopsisable,org.refcodes.mixin.AliasAccessor,org.refcodes.mixin.Clonable,org.refcodes.mixin.DescriptionAccessor,org.refcodes.mixin.Resetable,org.refcodes.mixin.Schemable<CliSchema>,org.refcodes.mixin.TypeAccessor<T[]>,org.refcodes.mixin.ValueAccessor<T[]>
-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.mixin.AliasAccessor
org.refcodes.mixin.AliasAccessor.AliasBuilder<B extends org.refcodes.mixin.AliasAccessor.AliasBuilder<B>>, org.refcodes.mixin.AliasAccessor.AliasMutator, org.refcodes.mixin.AliasAccessor.AliasPropertyNested classes/interfaces inherited from interface org.refcodes.cli.ArgsAccessor
ArgsAccessor.ArgsMutator, ArgsAccessor.ArgsPropertyNested classes/interfaces inherited from interface org.refcodes.mixin.DescriptionAccessor
org.refcodes.mixin.DescriptionAccessor.DescriptionBuilder<B extends org.refcodes.mixin.DescriptionAccessor.DescriptionBuilder<B>>, org.refcodes.mixin.DescriptionAccessor.DescriptionMutator, org.refcodes.mixin.DescriptionAccessor.DescriptionPropertyNested classes/interfaces inherited from interface org.refcodes.mixin.TypeAccessor
org.refcodes.mixin.TypeAccessor.TypeBuilder<T extends Object,B extends org.refcodes.mixin.TypeAccessor.TypeBuilder<T, B>>, org.refcodes.mixin.TypeAccessor.TypeMutator<T extends Object>, org.refcodes.mixin.TypeAccessor.TypeProperty<T extends Object> Nested classes/interfaces inherited from interface org.refcodes.mixin.ValueAccessor
org.refcodes.mixin.ValueAccessor.ValueBuilder<V extends Object,B extends org.refcodes.mixin.ValueAccessor.ValueBuilder<V, B>>, org.refcodes.mixin.ValueAccessor.ValueMutator<V extends Object>, org.refcodes.mixin.ValueAccessor.ValueProperty<V extends Object> -
Constructor Summary
ConstructorsConstructorDescriptionArrayOption(Option<T> aOption) Constructs theArrayOptionby encapsulating the givenOptionand providing its definition as array definition to the CLI.ArrayOption(Option<T> aOption, int aLength) Constructs theArrayOptionby encapsulating the givenOptionand providing its definition as array definition to the CLI.ArrayOption(Option<T> aOption, int aMinLength, int aMaxLength) Constructs theArrayOptionby encapsulating the givenOptionand providing its definition as array definition to the CLI. -
Method Summary
Modifier and TypeMethodDescriptionReturns the long-option representing anOptioninstance.Returns the short-option representing anOptioninstance.toSyntax(CliContext aCliCtx) This method is to be called from inside theConstituenthierarchy; use the methodSynopsisable.toSynopsis(SyntaxNotation)in case you invoke syntax retrieval from the rootConstituent.Methods inherited from class org.refcodes.cli.ArrayOperand
clone, compareTo, getAlias, getDescription, getMaxLength, getMinLength, getOperand, getType, getValue, parseArgs, reset, toParsedArgs, toSchemaMethods inherited from class java.lang.Object
equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, waitMethods inherited from interface org.refcodes.mixin.Clonable
cloneMethods inherited from interface java.lang.Comparable
compareToMethods inherited from interface org.refcodes.cli.Constituent
parseArgs, parseArgs, toSynopsis, toSyntax, toSyntax, toSyntax, toSyntaxMethods inherited from interface org.refcodes.mixin.DescriptionAccessor
getDescriptionMethods inherited from interface org.refcodes.cli.Operand
getAlias, getValue, hasValue, toParsedArgs, toSpec, toValueMethods inherited from interface org.refcodes.mixin.Resetable
resetMethods inherited from interface org.refcodes.mixin.Schemable
toSchemaMethods inherited from interface org.refcodes.cli.Synopsisable
toSynopsis, toSynopsis, toSynopsis, toSynopsisMethods inherited from interface org.refcodes.mixin.TypeAccessor
getTypeMethods inherited from interface org.refcodes.mixin.ValueAccessor
getValueOr
-
Constructor Details
-
ArrayOption
Constructs theArrayOptionby encapsulating the givenOptionand providing its definition as array definition to the CLI.- Parameters:
aOption- TheOptionwhich's array counterpart is to be defined.
-
ArrayOption
Constructs theArrayOptionby encapsulating the givenOptionand providing its definition as array definition to the CLI.- Parameters:
aOption- TheOptionwhich's array counterpart is to be defined.aLength- The number of array elements, or -1 if there is no limit.
-
ArrayOption
Constructs theArrayOptionby encapsulating the givenOptionand providing its definition as array definition to the CLI.- Parameters:
aOption- TheOptionwhich's array counterpart is to be defined.aMinLength- The minimum number of array elements, or -1 if there is no limit.aMaxLength- The maximum number of array elements, or -1 if there is no limit.
-
-
Method Details
-
toSyntax
This method is to be called from inside theConstituenthierarchy; use the methodSynopsisable.toSynopsis(SyntaxNotation)in case you invoke syntax retrieval from the rootConstituent. Returns the human readable (verbose) syntax of thisConstituentinstance including, in case of being a node in the syntax tree (such as aCondition, the syntax of the childConstituentinstances. ATTENTION: As of different parenthesis settings for some notations regarding the rootConstituentand the childConstituents, the methodConstituent.toSyntax(CliContext)is called from inside theConstituenthierarchy. In case the syntax is to be retrieved from the rootConstituent, then the applicable method to be called isSynopsisable.toSynopsis(SyntaxNotation), as for some notations it will for example not create the most outer braces.- Specified by:
toSyntaxin interfaceConstituent- Overrides:
toSyntaxin classArrayOperand<T>- Parameters:
aCliCtx- TheCliContextfor which the syntax is being generated.- Returns:
- The human readable (verbose) command line arguments syntax.
-
getShortOption
Returns the short-option representing anOptioninstance. A short option usually is being prefixed with a single hyphen-minus "-" as defined inArgsPrefix.POSIX_SHORT_OPTION.- Specified by:
getShortOptionin interfaceOption<T>- Returns:
- The short-option
String.
-
getLongOption
Returns the long-option representing anOptioninstance. A long option usually is being prefixed with a double hyphen-minus "--" as defined inArgsPrefix.POSIX_LONG_OPTION.- Specified by:
getLongOptionin interfaceOption<T>- Returns:
- The long-option
String.
-