- java.lang.Object
-
- org.refcodes.cli.ArrayOperand<T>
-
- org.refcodes.cli.ArrayOption<T>
-
- All Implemented Interfaces:
Cloneable,Comparable<Operand<?>>,ArgsAccessor,Operand<T[]>,Option<T[]>,Syntaxable,SyntaxUsage,org.refcodes.component.Resetable,org.refcodes.mixin.AliasAccessor,org.refcodes.mixin.Clonable,org.refcodes.mixin.DescriptionAccessor,org.refcodes.mixin.TypeAccessor<T[]>,org.refcodes.mixin.ValueAccessor<T[]>
public class ArrayOption<T> extends ArrayOperand<T> implements Option<T[]>
-
-
Nested Class Summary
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.AliasAccessor
org.refcodes.mixin.AliasAccessor.AliasBuilder<B extends org.refcodes.mixin.AliasAccessor.AliasBuilder<B>>, org.refcodes.mixin.AliasAccessor.AliasMutator, org.refcodes.mixin.AliasAccessor.AliasProperty
-
Nested classes/interfaces inherited from interface org.refcodes.cli.ArgsAccessor
ArgsAccessor.ArgsMutator, ArgsAccessor.ArgsProperty
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.DescriptionAccessor
org.refcodes.mixin.DescriptionAccessor.DescriptionBuilder<B extends org.refcodes.mixin.DescriptionAccessor.DescriptionBuilder<B>>, org.refcodes.mixin.DescriptionAccessor.DescriptionMutator, org.refcodes.mixin.DescriptionAccessor.DescriptionProperty
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.TypeAccessor
org.refcodes.mixin.TypeAccessor.TypeBuilder<T extends Object,B extends org.refcodes.mixin.TypeAccessor.TypeBuilder<T,B>>, org.refcodes.mixin.TypeAccessor.TypeMutator<T extends Object>, org.refcodes.mixin.TypeAccessor.TypeProperty<T extends Object>
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.ValueAccessor
org.refcodes.mixin.ValueAccessor.ValueBuilder<V extends Object,B extends org.refcodes.mixin.ValueAccessor.ValueBuilder<V,B>>, org.refcodes.mixin.ValueAccessor.ValueMutator<V extends Object>, org.refcodes.mixin.ValueAccessor.ValueProperty<V extends Object>
-
-
Constructor Summary
Constructors Constructor Description ArrayOption(Option<T> aOption)Constructs theArrayOptionby encapsulating the givenOptionand providing its definition as array definition to the CLI.ArrayOption(Option<T> aOption, int aLength)Constructs theArrayOptionby encapsulating the givenOptionand providing its definition as array definition to the CLI.ArrayOption(Option<T> aOption, int aMinLength, int aMaxLength)Constructs theArrayOptionby encapsulating the givenOptionand providing its definition as array definition to the CLI.
-
Method Summary
All Methods Instance Methods Concrete Methods Modifier and Type Method Description StringgetLongOption()Returns the long-option representing anOptioninstance.StringgetShortOption()Returns the short-option representing anOptioninstance.StringtoSyntax(SyntaxNotation aSyntaxNotation, String aOptionEscCode, String aResetEscCode)This method is to be called from inside theSyntaxablehierarchy; use the methodSyntaxUsage.toUsage(SyntaxNotation)in case you invoke syntax retrieval from the rootSyntaxable.StringtoUsage(SyntaxNotation aSyntaxNotation, String aOptionEscCode, String aResetEscCode)Returns the human readable (verbose) syntax of implementing class ATTENTION: As of different parenthesis settings for some notations regarding the rootSyntaxableand the childSyntaxables, the methodSyntaxable.toSyntax(SyntaxNotation, String, String)is called from inside aSyntaxablehierarchy.-
Methods inherited from class org.refcodes.cli.ArrayOperand
clone, compareTo, getAlias, getArgs, getDescription, getMaxLength, getMinLength, getOperand, getType, getValue, parseArgs, reset, toState
-
Methods inherited from class java.lang.Object
equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
Methods inherited from interface java.lang.Comparable
compareTo
-
Methods inherited from interface org.refcodes.cli.Operand
getAlias, getArgs, getValue, hasValue, toValue
-
Methods inherited from interface org.refcodes.cli.Option
getOptions
-
Methods inherited from interface org.refcodes.cli.Syntaxable
parseArgs, parseArgs, toState, toSyntax, toSyntax, toSyntax
-
Methods inherited from interface org.refcodes.cli.SyntaxUsage
toUsage, toUsage, toUsage, toUsage
-
-
-
-
Constructor Detail
-
ArrayOption
public ArrayOption(Option<T> aOption)
Constructs theArrayOptionby encapsulating the givenOptionand providing its definition as array definition to the CLI.- Parameters:
aOption- TheOptionwhich's array counterpart is to be defined.
-
ArrayOption
public ArrayOption(Option<T> aOption, int aLength)
Constructs theArrayOptionby encapsulating the givenOptionand providing its definition as array definition to the CLI.- Parameters:
aOption- TheOptionwhich's array counterpart is to be defined.aLength- The number of array elements, or -1 if there is no limit.
-
ArrayOption
public ArrayOption(Option<T> aOption, int aMinLength, int aMaxLength)
Constructs theArrayOptionby encapsulating the givenOptionand providing its definition as array definition to the CLI.- Parameters:
aOption- TheOptionwhich's array counterpart is to be defined.aMinLength- The minimum number of array elements, or -1 if there is no limit.aMaxLength- The maximum number of array elements, or -1 if there is no limit.
-
-
Method Detail
-
toSyntax
public String toSyntax(SyntaxNotation aSyntaxNotation, String aOptionEscCode, String aResetEscCode)
This method is to be called from inside theSyntaxablehierarchy; use the methodSyntaxUsage.toUsage(SyntaxNotation)in case you invoke syntax retrieval from the rootSyntaxable. Returns the human readable (verbose) syntax of thisSyntaxableinstance including, in case of being a node in the syntax tree (such as aArgsSyntax, the syntax of the childSyntaxableinstances. ATTENTION: As of different parenthesis settings for some notations regarding the rootSyntaxableand the childSyntaxables, the methodSyntaxable.toSyntax(SyntaxNotation, String, String)is called from inside theSyntaxablehierarchy. In case the syntax is to be retrieved from the rootSyntaxable, then the applicable method to be called isSyntaxUsage.toUsage(SyntaxNotation), as for some notations it will for example not create the most outer braces.- Specified by:
toSyntaxin interfaceSyntaxable- Overrides:
toSyntaxin classArrayOperand<T>- Parameters:
aSyntaxNotation- The syntax notation used for generating the command line arguments syntax.aOptionEscCode- The escape code to be used when processing an option, e.g. this can be an ANSI Escape-Code to highlight the option parameters.aResetEscCode- The escape code to close (reset) any Escape-Code being set before.- Returns:
- The human readable (verbose) command line arguments syntax.
-
getShortOption
public String getShortOption()
Returns the short-option representing anOptioninstance. A short option usually is being prefixed with a single hyphen-minus "-" as defined inCommandArgPrefix.POSIX_SHORT_OPTION.- Specified by:
getShortOptionin interfaceOption<T>- Returns:
- The short-option
String.
-
getLongOption
public String getLongOption()
Returns the long-option representing anOptioninstance. A long option usually is being prefixed with a double hyphen-minus "--" as defined inCommandArgPrefix.POSIX_LONG_OPTION.- Specified by:
getLongOptionin interfaceOption<T>- Returns:
- The long-option
String.
-
toUsage
public String toUsage(SyntaxNotation aSyntaxNotation, String aOptionEscCode, String aResetEscCode)
Returns the human readable (verbose) syntax of implementing class ATTENTION: As of different parenthesis settings for some notations regarding the rootSyntaxableand the childSyntaxables, the methodSyntaxable.toSyntax(SyntaxNotation, String, String)is called from inside aSyntaxablehierarchy. In case the syntax is to be retrieved from the rootSyntaxableor an encapsulating and different type, then the applicable method to be called isSyntaxUsage.toUsage(SyntaxNotation), as for some notations it will for example not create the most outer braces.- Specified by:
toUsagein interfaceSyntaxUsage- Parameters:
aSyntaxNotation- The syntax notation used for generating the command line arguments syntax.aOptionEscCode- The escape code to be used when processing an option, e.g. this can be an ANSI Escape-Code to highlight the option parameters (for example "--help", "-q" and so on).aResetEscCode- The escape code to close (reset) any Escape-Code being set before.- Returns:
- The human readable (verbose) command line arguments syntax.
-
-