Class ArrayOption<T>

java.lang.Object
org.refcodes.cli.ArrayOperand<T>
org.refcodes.cli.ArrayOption<T>
All Implemented Interfaces:
Cloneable, Comparable<Operand<?>>, ArgsAccessor, Operand<T[]>, Option<T[]>, Syntaxable, SyntaxUsage, org.refcodes.component.Resetable, org.refcodes.mixin.AliasAccessor, org.refcodes.mixin.Clonable, org.refcodes.mixin.DescriptionAccessor, org.refcodes.mixin.TypeAccessor<T[]>, org.refcodes.mixin.ValueAccessor<T[]>

public class ArrayOption<T>
extends ArrayOperand<T>
implements Option<T[]>
Creates an array representation facade for the encapsulated Option. This way any Option can also be used as an array Option, e.g. it can be provided multiple times in the command line arguments.
  • Nested Class Summary

    Nested classes/interfaces inherited from interface org.refcodes.mixin.AliasAccessor

    org.refcodes.mixin.AliasAccessor.AliasBuilder<B extends org.refcodes.mixin.AliasAccessor.AliasBuilder<B>>, org.refcodes.mixin.AliasAccessor.AliasMutator, org.refcodes.mixin.AliasAccessor.AliasProperty

    Nested classes/interfaces inherited from interface org.refcodes.cli.ArgsAccessor

    ArgsAccessor.ArgsMutator, ArgsAccessor.ArgsProperty

    Nested classes/interfaces inherited from interface org.refcodes.mixin.DescriptionAccessor

    org.refcodes.mixin.DescriptionAccessor.DescriptionBuilder<B extends org.refcodes.mixin.DescriptionAccessor.DescriptionBuilder<B>>, org.refcodes.mixin.DescriptionAccessor.DescriptionMutator, org.refcodes.mixin.DescriptionAccessor.DescriptionProperty

    Nested classes/interfaces inherited from interface org.refcodes.mixin.TypeAccessor

    org.refcodes.mixin.TypeAccessor.TypeBuilder<T extends Object,​B extends org.refcodes.mixin.TypeAccessor.TypeBuilder<T,​B>>, org.refcodes.mixin.TypeAccessor.TypeMutator<T extends Object>, org.refcodes.mixin.TypeAccessor.TypeProperty<T extends Object>

    Nested classes/interfaces inherited from interface org.refcodes.mixin.ValueAccessor

    org.refcodes.mixin.ValueAccessor.ValueBuilder<V extends Object,​B extends org.refcodes.mixin.ValueAccessor.ValueBuilder<V,​B>>, org.refcodes.mixin.ValueAccessor.ValueMutator<V extends Object>, org.refcodes.mixin.ValueAccessor.ValueProperty<V extends Object>
  • Constructor Summary

    Constructors
    Constructor Description
    ArrayOption​(Option<T> aOption)
    Constructs the ArrayOption by encapsulating the given Option and providing its definition as array definition to the CLI.
    ArrayOption​(Option<T> aOption, int aLength)
    Constructs the ArrayOption by encapsulating the given Option and providing its definition as array definition to the CLI.
    ArrayOption​(Option<T> aOption, int aMinLength, int aMaxLength)
    Constructs the ArrayOption by encapsulating the given Option and providing its definition as array definition to the CLI.
  • Method Summary

    Modifier and Type Method Description
    String getLongOption()
    Returns the long-option representing an Option instance.
    String getShortOption()
    Returns the short-option representing an Option instance.
    String toSyntax​(SyntaxNotation aSyntaxNotation, String aOptionEscCode, String aResetEscCode)
    This method is to be called from inside the Syntaxable hierarchy; use the method SyntaxUsage.toUsage(SyntaxNotation) in case you invoke syntax retrieval from the root Syntaxable.
    String toUsage​(SyntaxNotation aSyntaxNotation, String aOptionEscCode, String aResetEscCode)
    Returns the human readable (verbose) syntax of implementing class ATTENTION: As of different parenthesis settings for some notations regarding the root Syntaxable and the child Syntaxables, the method Syntaxable.toSyntax(SyntaxNotation, String, String) is called from inside a Syntaxable hierarchy.

    Methods inherited from class java.lang.Object

    equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait

    Methods inherited from interface org.refcodes.mixin.Clonable

    clone

    Methods inherited from interface java.lang.Comparable

    compareTo

    Methods inherited from interface org.refcodes.mixin.DescriptionAccessor

    getDescription

    Methods inherited from interface org.refcodes.cli.Operand

    get, getAlias, getArgs, getValue, hasValue

    Methods inherited from interface org.refcodes.cli.Option

    getOptions

    Methods inherited from interface org.refcodes.component.Resetable

    reset

    Methods inherited from interface org.refcodes.cli.Syntaxable

    parseArgs, parseArgs, toState, toSyntax

    Methods inherited from interface org.refcodes.cli.SyntaxUsage

    toUsage, toUsage, toUsage

    Methods inherited from interface org.refcodes.mixin.TypeAccessor

    getType

    Methods inherited from interface org.refcodes.mixin.ValueAccessor

    getValueOr
  • Constructor Details

    • ArrayOption

      public ArrayOption​(Option<T> aOption)
      Constructs the ArrayOption by encapsulating the given Option and providing its definition as array definition to the CLI.
      Parameters:
      aOption - The Option which's array counterpart is to be defined.
    • ArrayOption

      public ArrayOption​(Option<T> aOption, int aLength)
      Constructs the ArrayOption by encapsulating the given Option and providing its definition as array definition to the CLI.
      Parameters:
      aOption - The Option which's array counterpart is to be defined.
      aLength - The number of array elements, or -1 if there is no limit.
    • ArrayOption

      public ArrayOption​(Option<T> aOption, int aMinLength, int aMaxLength)
      Constructs the ArrayOption by encapsulating the given Option and providing its definition as array definition to the CLI.
      Parameters:
      aOption - The Option which's array counterpart is to be defined.
      aMinLength - The minimum number of array elements, or -1 if there is no limit.
      aMaxLength - The maximum number of array elements, or -1 if there is no limit.
  • Method Details

    • toSyntax

      public String toSyntax​(SyntaxNotation aSyntaxNotation, String aOptionEscCode, String aResetEscCode)
      This method is to be called from inside the Syntaxable hierarchy; use the method SyntaxUsage.toUsage(SyntaxNotation) in case you invoke syntax retrieval from the root Syntaxable. Returns the human readable (verbose) syntax of this Syntaxable instance including, in case of being a node in the syntax tree (such as a Condition, the syntax of the child Syntaxable instances. ATTENTION: As of different parenthesis settings for some notations regarding the root Syntaxable and the child Syntaxables, the method Syntaxable.toSyntax(SyntaxNotation, String, String) is called from inside the Syntaxable hierarchy. In case the syntax is to be retrieved from the root Syntaxable, then the applicable method to be called is SyntaxUsage.toUsage(SyntaxNotation), as for some notations it will for example not create the most outer braces.
      Specified by:
      toSyntax in interface Syntaxable
      Overrides:
      toSyntax in class ArrayOperand<T>
      Parameters:
      aSyntaxNotation - The syntax notation used for generating the command line arguments syntax.
      aOptionEscCode - The escape code to be used when processing an option, e.g. this can be an ANSI Escape-Code to highlight the option parameters.
      aResetEscCode - The escape code to close (reset) any Escape-Code being set before.
      Returns:
      The human readable (verbose) command line arguments syntax.
    • getShortOption

      public String getShortOption()
      Returns the short-option representing an Option instance. A short option usually is being prefixed with a single hyphen-minus "-" as defined in CommandArgPrefix.POSIX_SHORT_OPTION.
      Specified by:
      getShortOption in interface Option<T>
      Returns:
      The short-option String.
    • getLongOption

      public String getLongOption()
      Returns the long-option representing an Option instance. A long option usually is being prefixed with a double hyphen-minus "--" as defined in CommandArgPrefix.POSIX_LONG_OPTION.
      Specified by:
      getLongOption in interface Option<T>
      Returns:
      The long-option String.
    • toUsage

      public String toUsage​(SyntaxNotation aSyntaxNotation, String aOptionEscCode, String aResetEscCode)
      Returns the human readable (verbose) syntax of implementing class ATTENTION: As of different parenthesis settings for some notations regarding the root Syntaxable and the child Syntaxables, the method Syntaxable.toSyntax(SyntaxNotation, String, String) is called from inside a Syntaxable hierarchy. In case the syntax is to be retrieved from the root Syntaxable or an encapsulating and different type, then the applicable method to be called is SyntaxUsage.toUsage(SyntaxNotation), as for some notations it will for example not create the most outer braces.
      Specified by:
      toUsage in interface SyntaxUsage
      Parameters:
      aSyntaxNotation - The syntax notation used for generating the command line arguments syntax.
      aOptionEscCode - The escape code to be used when processing an option, e.g. this can be an ANSI Escape-Code to highlight the option parameters (for example "--help", "-q" and so on).
      aResetEscCode - The escape code to close (reset) any Escape-Code being set before.
      Returns:
      The human readable (verbose) command line arguments syntax.