- All Superinterfaces:
BannerFontAccessor,BannerFontAccessor.BannerFontMutator
- All Known Subinterfaces:
ParseArgs
- All Known Implementing Classes:
ArgsParser
- Enclosing interface:
- BannerFontAccessor
public static interface BannerFontAccessor.BannerFontProperty
extends BannerFontAccessor, BannerFontAccessor.BannerFontMutator
Provides a banner
Font property.-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.cli.BannerFontAccessor
BannerFontAccessor.BannerFontBuilder<B extends BannerFontAccessor.BannerFontBuilder<B>>, BannerFontAccessor.BannerFontMutator, BannerFontAccessor.BannerFontProperty -
Method Summary
Modifier and TypeMethodDescriptiondefault org.refcodes.textual.FontletBannerFont(org.refcodes.textual.Font aBannerFont) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenFont(setter) as ofBannerFontAccessor.BannerFontMutator.setBannerFont(Font)and returns the very same value (getter).Methods inherited from interface org.refcodes.cli.BannerFontAccessor
getBannerFontMethods inherited from interface org.refcodes.cli.BannerFontAccessor.BannerFontMutator
setBannerFont
-
Method Details
-
letBannerFont
default org.refcodes.textual.Font letBannerFont(org.refcodes.textual.Font aBannerFont) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenFont(setter) as ofBannerFontAccessor.BannerFontMutator.setBannerFont(Font)and returns the very same value (getter).- Parameters:
aBannerFont- TheFontto set (viaBannerFontAccessor.BannerFontMutator.setBannerFont(Font)).- Returns:
- Returns the value passed for it to be used in conclusive processing steps.
-