java.lang.Object
java.lang.Throwable
java.lang.Exception
org.refcodes.exception.AbstractException
org.refcodes.cli.CliException
org.refcodes.cli.CliException.CliArgsException
- All Implemented Interfaces:
Serializable,ArgsAccessor,org.refcodes.exception.ErrorCodeAccessor,org.refcodes.exception.Trap
- Direct Known Subclasses:
ArgsSyntaxException
- Enclosing class:
- CliException
public abstract static class CliException.CliArgsException
extends CliException
implements ArgsAccessor
This abstract exception is the base exception for all command line
argument related exceptions.
- See Also:
-
Nested Class Summary
Nested classes/interfaces inherited from class org.refcodes.cli.CliException
CliException.CliArgsExceptionNested classes/interfaces inherited from interface org.refcodes.cli.ArgsAccessor
ArgsAccessor.ArgsMutator, ArgsAccessor.ArgsPropertyNested classes/interfaces inherited from interface org.refcodes.exception.ErrorCodeAccessor
org.refcodes.exception.ErrorCodeAccessor.ErrorCodeBuilder<B extends org.refcodes.exception.ErrorCodeAccessor.ErrorCodeBuilder<B>>, org.refcodes.exception.ErrorCodeAccessor.ErrorCodeMutator, org.refcodes.exception.ErrorCodeAccessor.ErrorCodeProperty -
Field Summary
Fields -
Constructor Summary
ConstructorsConstructorDescriptionCliArgsException(String[] aArgs, Throwable aCause) CliArgsException(String[] aArgs, Throwable aCause, String aErrorCode) CliArgsException(String aMessage, String[] aArgs) CliArgsException(String aMessage, String[] aArgs, String aErrorCode) CliArgsException(String aMessage, String[] aArgs, Throwable aCause) CliArgsException(String aMessage, String[] aArgs, Throwable aCause, String aErrorCode) -
Method Summary
Methods inherited from class org.refcodes.exception.AbstractException
getErrorCode, getMessageMethods inherited from class java.lang.Throwable
addSuppressed, fillInStackTrace, getCause, getLocalizedMessage, getStackTrace, getSuppressed, initCause, printStackTrace, printStackTrace, printStackTrace, setStackTrace, toStringMethods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface org.refcodes.exception.Trap
toLocalizedMessage, toMessage, toMessage, toMessage, toShortLocalizedMessage, toShortMessage
-
Field Details
-
_args
-
-
Constructor Details
-
CliArgsException
- Parameters:
aArgs- The command line arguments involved in this exception.
-
CliArgsException
- Parameters:
aArgs- The command line arguments involved in this exception.
-
CliArgsException
- Parameters:
aArgs- The command line arguments involved in this exception.
-
CliArgsException
- Parameters:
aArgs- The command line arguments involved in this exception.
-
CliArgsException
- Parameters:
aArgs- The command line arguments involved in this exception.
-
CliArgsException
- Parameters:
aArgs- The command line arguments involved in this exception.
-
-
Method Details
-
getArgs
Retrieves the command line arguments from the args property.- Specified by:
getArgsin interfaceArgsAccessor- Returns:
- The command line arguments stored by the args property.
-
getPatternArguments
- Specified by:
getPatternArgumentsin interfaceorg.refcodes.exception.Trap
-