Enum Class CliSchemaOntology
- All Implemented Interfaces:
Serializable, Comparable<CliSchemaOntology>, Constable, DescriptionAccessor, NameAccessor, TypeAccessor, org.refcodes.ontology.EnumTerm, org.refcodes.ontology.Term, org.refcodes.ontology.UnsafeConcept
public enum CliSchemaOntology
extends Enum<CliSchemaOntology>
implements org.refcodes.ontology.UnsafeConcept
The
CliSchemaOntology describes the terms used in the CLI for
Schema generation.-
Nested Class Summary
Nested classes/interfaces inherited from class Enum
Enum.EnumDesc<E>Nested classes/interfaces inherited from interface DescriptionAccessor
DescriptionAccessor.DescriptionBuilder<B>, DescriptionAccessor.DescriptionMutator, DescriptionAccessor.DescriptionPropertyNested classes/interfaces inherited from interface NameAccessor
NameAccessor.NameBuilder<B>, NameAccessor.NameMutator, NameAccessor.NamePropertyNested classes/interfaces inherited from interface TypeAccessor
TypeAccessor.TypeBuilder<T,B>, TypeAccessor.TypeMutator<T>, TypeAccessor.TypeProperty<T> -
Enum Constant Summary
Enum ConstantsEnum ConstantDescriptionDenotes whether the operand has a value.Denotes the long option name.Denotes the number of matched arguments.Denotes the maximum number of array elements.Denotes the minimum number of array elements.Denotes the operation.Denotes the short option name. -
Method Summary
Modifier and TypeMethodDescriptiongetType()static CliSchemaOntologyReturns the enum constant of this class with the specified name.static CliSchemaOntology[]values()Returns an array containing the constants of this enum class, in the order they are declared.Methods inherited from class Enum
clone, compareTo, describeConstable, equals, finalize, getDeclaringClass, hashCode, name, ordinal, toString, valueOfMethods inherited from interface org.refcodes.ontology.EnumTerm
getName, nameMethods inherited from interface org.refcodes.ontology.UnsafeConcept
get, getOr, put
-
Enum Constant Details
-
LONG_OPTION
Denotes the long option name. -
SHORT_OPTION
Denotes the short option name. -
MATCH_COUNT
Denotes the number of matched arguments. -
HAS_VALUE
Denotes whether the operand has a value. -
OPERATION
Denotes the operation. -
MAX_LENGTH
Denotes the maximum number of array elements. -
MIN_LENGTH
Denotes the minimum number of array elements.
-
-
Method Details
-
values
Returns an array containing the constants of this enum class, in the order they are declared.- Returns:
- an array containing the constants of this enum class, in the order they are declared
-
valueOf
Returns the enum constant of this class with the specified name. The string must match exactly an identifier used to declare an enum constant in this class. (Extraneous whitespace characters are not permitted.)- Parameters:
name- the name of the enum constant to be returned.- Returns:
- the enum constant with the specified name
- Throws:
IllegalArgumentException- if this enum class has no constant with the specified nameNullPointerException- if the argument is null
-
getType
- Specified by:
getTypein interfaceTypeAccessor
-
getDescription
- Specified by:
getDescriptionin interfaceDescriptionAccessor
-