java.lang.Object
org.refcodes.cli.CliSugar
Declarative syntactic sugar which may be statically imported in order to
allow declarative definitions for the command line
Flag,
ArgsSyntax, Option and Operand elements.-
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionstatic ArgsSyntaxall(Syntaxable aArg) static ArgsSyntaxand(Syntaxable... aArgs) static ArgsSyntaxany(Syntaxable... aArgs) static <T> ArrayOperand<T>Creates an array representation facade for the encapsulatedOperand.static <T> ArrayOperand<T>Creates an array representation facade for the encapsulatedOperand.static <T> ArrayOperand<T>Creates an array representation facade for the encapsulatedOperand.static <T> ArrayOption<T>Creates an array representation facade for the encapsulatedOption.static <T> ArrayOption<T>Creates an array representation facade for the encapsulatedOption.static <T> ArrayOption<T>Creates an array representation facade for the encapsulatedOption.static ArgsSyntaxcases(Syntaxable... aArgs) static CharOptioncharOption(String aLongOption, String aAlias, String aDescription) Character option.static CharOptioncharOption(String aShortOption, String aLongOption, String aAlias, String aDescription) Character option.static CleanFlagConstructs the predefined cleanFlag.static CleanFlagcleanFlag(boolean hasShortOption) Constructs the predefined cleanFlag.static CleanFlagConstructs the predefined cleanFlag.static ConfigOptionCreates aConfigOptionrepresenting value specifying a configuration resource (file).static ConfigOptionconfigOption(String aDescription) Creates aConfigOptionrepresenting a value specifying a configuration resource (file).static DaemonFlagConstructs the predefined daemonFlag.static DaemonFlagdaemonFlag(boolean hasShortOption) Constructs the predefined daemonFlag.static DaemonFlagdaemonFlag(String aDescription) Constructs the predefined daemonFlag.static DebugFlagConstructs the predefined debugFlag.static DebugFlagdebugFlag(boolean hasShortOption) Constructs the predefined debugFlag.static DebugFlagConstructs the predefined debugFlag.static DoubleOptiondoubleOption(String aLongOption, String aAlias, String aDescription) Double option.static DoubleOptiondoubleOption(String aShortOption, String aLongOption, String aAlias, String aDescription) Double option.static <T extends Enum<T>>
EnumOption<T>enumOption(String aLongOption, Class<T> aType, String aAlias, String aDescription) Instantiates a new enum option.static <T extends Enum<T>>
EnumOption<T>enumOption(String aShortOption, String aLongOption, Class<T> aType, String aAlias, String aDescription) Instantiates a new enum option.static Examplestatic Example[]Sugar for creating anExamplearray from a varargs argument.static FileOptionfileOption(String aLongOption, String aAlias, String aDescription) Creates aFileOptionfor getting aFileinstance from a path.static FileOptionfileOption(String aShortOption, String aLongOption, String aAlias, String aDescription) Creates aFileOptionfor getting aFileinstance from a path.static FlagAs "switch" is a reserved word in Java, we use "flag" :-(.static FlagAs "switch" is a reserved word in Java, we use "flag" :-(.static FloatOptionfloatOption(String aLongOption, String aAlias, String aDescription) Float option.static FloatOptionfloatOption(String aShortOption, String aLongOption, String aAlias, String aDescription) Float option.static ForceFlagConstructs the predefined forceFlag.static ForceFlagforceFlag(boolean hasShortOption) Constructs the predefined forceFlag.static ForceFlagConstructs the predefined forceFlag.static HelpFlaghelpFlag()Constructs the predefined helpFlag.static HelpFlaghelpFlag(boolean hasShortOption) Constructs the predefined helpFlag.static HelpFlagConstructs the predefined helpFlag.static InitFlaginitFlag()Constructs the predefined initFlag.static InitFlaginitFlag(boolean hasShortOption) Constructs the predefined initFlag.static InitFlagConstructs the predefined initFlag.static IntOptionInt option.static IntOptionInt option.static LongOptionlongOption(String aLongOption, String aAlias, String aDescription) Long option.static LongOptionlongOption(String aShortOption, String aLongOption, String aAlias, String aDescription) Long option.static NoneOperandInstantiates a newNoneOperand.static NoneOperandInstantiates a newNoneOperand.static NoneOperandInstantiates a newNoneOperand.static OperationConstructs aOperationwith the given arguments.static OperationConstructs aOperationwith the given arguments.static ArgsSyntaxoptional(Syntaxable... aArgs) Semantically identical synonym for theoptional(Syntaxable...)declaration.static ArgsSyntaxor(Syntaxable... aArgs) static QuietFlagConstructs the predefined quietFlag.static QuietFlagquietFlag(boolean hasShortOption) Constructs the predefined quietFlag.static QuietFlagConstructs the predefined quietFlag.static StringOperandstringOperand(String aIdentifier, String aDescription) String operand.static StringOptionstringOption(String aLongOption, String aAlias, String aDescription) String option.static StringOptionstringOption(String aShortOption, String aLongOption, String aAlias, String aDescription) String option.static SysInfoFlagConstructs the predefined system infoFlag.static SysInfoFlagsysInfoFlag(boolean hasShortOption) Constructs the predefined system infoFlag.static SysInfoFlagsysInfoFlag(String aDescription) Constructs the predefined system infoFlag.static VerboseFlagConstructs the predefined verboseFlag.static VerboseFlagverboseFlag(boolean hasShortOption) Constructs the predefined verboseFlag.static VerboseFlagverboseFlag(String aDescription) Constructs the predefined verboseFlag.static ArgsSyntaxxor(Syntaxable... aArgs)
-
Constructor Details
-
CliSugar
public CliSugar()
-
-
Method Details
-
examples
Sugar for creating anExamplearray from a varargs argument.- Parameters:
aExamples- theExamplevarargs argument.- Returns:
- The according array representation.
-
example
-
operation
Constructs aOperationwith the given arguments.- Parameters:
aOperation- The operation to declare.aDescription- A description without any line breaks.- Returns:
- The accordingly created
Operation.
-
operation
Constructs aOperationwith the given arguments.- Parameters:
aOperation- The operation to declare.aAlias- The operation's name to be used when constructing the syntax.aDescription- A description without any line breaks.- Returns:
- The accordingly created
Operation.
-
and
- Parameters:
aArgs- TheSyntaxable(ArgsSyntax) instances to be nested.- Returns:
- The according AND condition.
- See Also:
-
all
- Parameters:
aArg- TheSyntaxable(ArgsSyntax) instance to be nested.- Returns:
- The according ALL condition.
- See Also:
-
or
- Parameters:
aArgs- TheSyntaxable(ArgsSyntax) instances to be nested.- Returns:
- The according OR condition.
- See Also:
-
xor
- Parameters:
aArgs- TheSyntaxable(ArgsSyntax) instances to be nested.- Returns:
- The according XOR condition.
- See Also:
-
cases
- Parameters:
aArgs- TheSyntaxable(ArgsSyntax) instances to be nested.- Returns:
- The according CasesCondition (https://www.metacodes.pro XOR) condition.
- See Also:
-
any
Instantiates a newAnyConditionwith theSyntaxable(ArgsSyntax) instances to be nested. Any of the nestedArgsSyntaxconditions may match for theAnyConditionto match, e.g. all of the nested conditions are optional.- Parameters:
aArgs- TheSyntaxable(ArgsSyntax) instances to be nested- Returns:
- The according
AbstractCondition. - See Also:
-
optional
Semantically identical synonym for theoptional(Syntaxable...)declaration.- Parameters:
aArgs- TheSyntaxable(ArgsSyntax) instances to be nested- Returns:
- The according
AbstractCondition. - See Also:
-
none
Instantiates a newNoneOperand.- Parameters:
aAlias- The identifier to be used when printing the syntax via theSyntaxable.toSyntax(SyntaxNotation, String, String, String)method.aDescription- A description without any line breaks.- Returns:
- the none operand
- See Also:
-
none
Instantiates a newNoneOperand.- Parameters:
aDescription- A description without any line breaks.- Returns:
- the none operand
- See Also:
-
none
Instantiates a newNoneOperand.- Parameters:
aProperty- The key (= alias) and the value for the operand.- Returns:
- the none operand
- See Also:
-
enumOption
public static <T extends Enum<T>> EnumOption<T> enumOption(String aShortOption, String aLongOption, Class<T> aType, String aAlias, String aDescription) Instantiates a new enum option.- Type Parameters:
T- the generic type- Parameters:
aShortOption- the short optionaLongOption- the long optionaType- the typeaAlias- the option arg nameaDescription- The description to use when printing out the help text.- Returns:
- the option
- See Also:
-
enumOption
public static <T extends Enum<T>> EnumOption<T> enumOption(String aLongOption, Class<T> aType, String aAlias, String aDescription) Instantiates a new enum option.- Type Parameters:
T- the generic type- Parameters:
aLongOption- the long optionaType- the typeaAlias- the option arg nameaDescription- The description to use when printing out the help text.- Returns:
- the option
- See Also:
-
flag
As "switch" is a reserved word in Java, we use "flag" :-(. -
flag
public static Flag flag(String aShortOption, String aLongOption, String aAlias, String aDescription) As "switch" is a reserved word in Java, we use "flag" :-(. -
daemonFlag
Constructs the predefined daemonFlag.- Parameters:
aDescription- The description to use when printing out the help text.- Returns:
- The according
Flag. - See Also:
-
daemonFlag
Constructs the predefined daemonFlag.- Returns:
- The according
Flag. - See Also:
-
daemonFlag
Constructs the predefined daemonFlag.- Parameters:
hasShortOption- True in case to also enable the short option, else only the long option takes effect.- Returns:
- The according
Flag. - See Also:
-
forceFlag
Constructs the predefined forceFlag. -
forceFlag
Constructs the predefined forceFlag. -
forceFlag
Constructs the predefined forceFlag. -
helpFlag
Constructs the predefined helpFlag. -
helpFlag
Constructs the predefined helpFlag. -
helpFlag
Constructs the predefined helpFlag. -
initFlag
Constructs the predefined initFlag. -
initFlag
Constructs the predefined initFlag. -
initFlag
Constructs the predefined initFlag. -
cleanFlag
Constructs the predefined cleanFlag. -
cleanFlag
Constructs the predefined cleanFlag. -
cleanFlag
Constructs the predefined cleanFlag. -
sysInfoFlag
Constructs the predefined system infoFlag.- Parameters:
aDescription- The description to use when printing out the help text.- Returns:
- The according
Flag. - See Also:
-
sysInfoFlag
Constructs the predefined system infoFlag.- Returns:
- The according
Flag. - See Also:
-
sysInfoFlag
Constructs the predefined system infoFlag.- Parameters:
hasShortOption- True in case to also enable the short option, else only the long option takes effect.- Returns:
- The according
Flag. - See Also:
-
quietFlag
Constructs the predefined quietFlag. -
quietFlag
Constructs the predefined quietFlag. -
quietFlag
Constructs the predefined quietFlag. -
verboseFlag
Constructs the predefined verboseFlag.- Parameters:
aDescription- The description to use when printing out the help text.- Returns:
- The according
Flag. - See Also:
-
verboseFlag
Constructs the predefined verboseFlag.- Returns:
- The according
Flag. - See Also:
-
verboseFlag
Constructs the predefined verboseFlag.- Parameters:
hasShortOption- True in case to also enable the short option, else only the long option takes effect.- Returns:
- The according
Flag. - See Also:
-
debugFlag
Constructs the predefined debugFlag. -
debugFlag
Constructs the predefined debugFlag. -
debugFlag
Constructs the predefined debugFlag. -
intOption
Int option.- Parameters:
aLongOption- the long optionaAlias- the option arg nameaDescription- The description to use when printing out the help text.- Returns:
- the option
- See Also:
-
intOption
public static IntOption intOption(String aShortOption, String aLongOption, String aAlias, String aDescription) Int option.- Parameters:
aShortOption- the short optionaLongOption- the long optionaAlias- the option arg nameaDescription- The description to use when printing out the help text.- Returns:
- the option
- See Also:
-
longOption
Long option.- Parameters:
aLongOption- the long optionaAlias- the option arg nameaDescription- The description to use when printing out the help text.- Returns:
- the option
- See Also:
-
longOption
public static LongOption longOption(String aShortOption, String aLongOption, String aAlias, String aDescription) Long option.- Parameters:
aShortOption- the short optionaLongOption- the long optionaAlias- the option arg nameaDescription- The description to use when printing out the help text.- Returns:
- the option
- See Also:
-
floatOption
Float option.- Parameters:
aLongOption- the long optionaAlias- the option arg nameaDescription- The description to use when printing out the help text.- Returns:
- the option
- See Also:
-
floatOption
public static FloatOption floatOption(String aShortOption, String aLongOption, String aAlias, String aDescription) Float option.- Parameters:
aShortOption- the short optionaLongOption- the long optionaAlias- the option arg nameaDescription- The description to use when printing out the help text.- Returns:
- the option
- See Also:
-
doubleOption
Double option.- Parameters:
aLongOption- the long optionaAlias- the option arg nameaDescription- The description to use when printing out the help text.- Returns:
- the option
- See Also:
-
doubleOption
public static DoubleOption doubleOption(String aShortOption, String aLongOption, String aAlias, String aDescription) Double option.- Parameters:
aShortOption- the short optionaLongOption- the long optionaAlias- the option arg nameaDescription- The description to use when printing out the help text.- Returns:
- the option
- See Also:
-
stringOption
String option.- Parameters:
aLongOption- the long optionaAlias- the option arg nameaDescription- The description to use when printing out the help text.- Returns:
- the option
- See Also:
-
stringOption
public static StringOption stringOption(String aShortOption, String aLongOption, String aAlias, String aDescription) String option.- Parameters:
aShortOption- the short optionaLongOption- the long optionaAlias- the option arg nameaDescription- The description to use when printing out the help text.- Returns:
- the option
- See Also:
-
charOption
Character option.- Parameters:
aLongOption- the long optionaAlias- the option arg nameaDescription- The description to use when printing out the help text.- Returns:
- the option
- See Also:
-
charOption
public static CharOption charOption(String aShortOption, String aLongOption, String aAlias, String aDescription) Character option.- Parameters:
aShortOption- the short optionaLongOption- the long optionaAlias- the option arg nameaDescription- The description to use when printing out the help text.- Returns:
- the option
- See Also:
-
configOption
Creates aConfigOptionrepresenting value specifying a configuration resource (file).- Returns:
- the according
ConfigOption. - See Also:
-
configOption
Creates aConfigOptionrepresenting a value specifying a configuration resource (file).- Parameters:
aDescription- The description to use when printing out the help text. to use when printing out the help text.- Returns:
- the according
ConfigOption. - See Also:
-
fileOption
Creates aFileOptionfor getting aFileinstance from a path.- Parameters:
aLongOption- the long optionaAlias- the option arg nameaDescription- The description to use when printing out the help text.- Returns:
- the option
- See Also:
-
fileOption
public static FileOption fileOption(String aShortOption, String aLongOption, String aAlias, String aDescription) Creates aFileOptionfor getting aFileinstance from a path.- Parameters:
aShortOption- the short optionaLongOption- the long optionaAlias- the option arg nameaDescription- The description to use when printing out the help text.- Returns:
- the option
- See Also:
-
stringOperand
String operand.- Parameters:
aIdentifier- the identifieraDescription- The description to use when printing out the help text.- Returns:
- the operand
- See Also:
-
asArray
Creates an array representation facade for the encapsulatedOption. This way anyOptioncan also be used as an arrayOption, e.g. it can be provided multiple times in the command line arguments.- Type Parameters:
T- The type of theOptionfor which to create anArrayOption.- Parameters:
aOption- TheOptionwhich's array counterpart is to be defined.- Returns:
- The according
ArrayOption.
-
asArray
Creates an array representation facade for the encapsulatedOption. This way anyOptioncan also be used as an arrayOption, e.g. it can by provided multiple times in the command line arguments.- Type Parameters:
T- The type of theOptionfor which to create anArrayOption.- Parameters:
aOption- TheOptionwhich's array counterpart is to be defined.aLength- The number of array elements, or -1 if there is no limit.- Returns:
- The according
ArrayOption.
-
asArray
Creates an array representation facade for the encapsulatedOption. This way anyOptioncan also be used as an arrayOption, e.g. it can by provided multiple times in the command line arguments.- Type Parameters:
T- The type of theOptionfor which to create anArrayOption.- Parameters:
aOption- TheOptionwhich's array counterpart is to be defined.aMinLength- The minimum number of array elements, or -1 if there is no limit.aMaxLength- The maximum number of array elements, or -1 if there is no limit.- Returns:
- The according
ArrayOption.
-
asArray
Creates an array representation facade for the encapsulatedOperand. This way anyOperandcan also be used as an arrayOperand, e.g. it can be provided multiple times in the command line arguments.- Type Parameters:
T- The type of theOperandfor which to create anArrayOperand.- Parameters:
aOperand- TheOperandwhich's array counterpart is to be defined.- Returns:
- The according
ArrayOperand.
-
asArray
Creates an array representation facade for the encapsulatedOperand. This way anyOperandcan also be used as an arrayOperand, e.g. it can by provided multiple times in the command line arguments.- Type Parameters:
T- The type of theOperandfor which to create anArrayOperand.- Parameters:
aOperand- TheOperandwhich's array counterpart is to be defined.aLength- The number of array elements, or -1 if there is no limit.- Returns:
- The according
ArrayOperand.
-
asArray
Creates an array representation facade for the encapsulatedOperand. This way anyOperandcan also be used as an arrayOperand, e.g. it can by provided multiple times in the command line arguments.- Type Parameters:
T- The type of theOperandfor which to create anArrayOperand.- Parameters:
aOperand- TheOperandwhich's array counterpart is to be defined.aMinLength- The minimum number of array elements, or -1 if there is no limit.aMaxLength- The maximum number of array elements, or -1 if there is no limit.- Returns:
- The according
ArrayOperand.
-