The Condition interface represents a node (and therewith the syntax
for the arguments) in the command line arguments syntax tree by simply
extending the Term interface and adding the functionality of
providing access to the added Operands (leafs).
Nested Class Summary
Nested classes/interfaces inherited from interface ChildrenAccessor
Determines the potential Condition instances matching the given
args (intersection) which might be useful to get more details on failing
to parse arguments (in case we have superfluous arguments and want to see
which Condition parent's Operand child addressed them).
Determines the potential Operand instances matching the given
args (intersection) which might be useful to get more details on failing
to parse arguments (in case we have superfluous arguments and want to see
which Operand addressed them).
Traverses the hierarchy of Conditions and collects all therein
found Operands and sub-types such as the Flag or the
Option. This is most useful when creating a list of
Options, Flages and Operands when printing out
detailed help.
Determines the potential Operand instances matching the given
args (intersection) which might be useful to get more details on failing
to parse arguments (in case we have superfluous arguments and want to see
which Operand addressed them).
Parameters:
aArgs - The arguments for which to determine the Operand
parameters.
Returns:
The according Operand parameters or null if none was
found.
Determines the potential Condition instances matching the given
args (intersection) which might be useful to get more details on failing
to parse arguments (in case we have superfluous arguments and want to see
which Condition parent's Operand child addressed them).
Parameters:
aArgs - The arguments for which to determine the Condition
parents.
Returns:
The according Condition parents or null if none was
found.