Interface Condition

All Superinterfaces:
org.refcodes.mixin.ChildrenAccessor<Term[]>, org.refcodes.mixin.DescriptionAccessor, org.refcodes.exception.ExceptionAccessor<ArgsSyntaxException>, MatchCountAccessor, org.refcodes.mixin.Resetable, org.refcodes.schema.Schemable, Synopsisable, Term, org.refcodes.graphical.VisibleAccessor, org.refcodes.graphical.VisibleAccessor.VisibleBuilder<Term>, org.refcodes.graphical.VisibleAccessor.VisibleMutator, org.refcodes.graphical.VisibleAccessor.VisibleProperty
All Known Implementing Classes:
AbstractCondition, AllCondition, AndCondition, AnyCondition, CasesCondition, OrCondition, XorCondition

public interface Condition extends Term, org.refcodes.mixin.ChildrenAccessor<Term[]>
The Condition interface represents a node (and therewith the syntax for the arguments) in the command line arguments syntax tree by simply extending the Term interface and adding the functionality of providing access to the added Operands (leafs).