- All Superinterfaces:
Constituent,org.refcodes.mixin.DescriptionAccessor,org.refcodes.mixin.Resetable,org.refcodes.mixin.Schemable,Synopsisable
- All Known Implementing Classes:
AbstractCondition,AllCondition,AndCondition,AnyCondition,CasesCondition,OrCondition,XorCondition
The
Condition interface represents a node (and therewith the syntax
for the arguments) in the command line arguments syntax tree; simply
extending the Constituent interface and adding the functionality of
providing access to the added Operands (leafs). In future extensions,
a Condition might provide access to the child Constituent
elements contained in a Condition instance. As of the current
findings, access to the children of the Condition node is not
required and would make the interface unnecessarily complicated.-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.mixin.DescriptionAccessor
org.refcodes.mixin.DescriptionAccessor.DescriptionBuilder<B extends org.refcodes.mixin.DescriptionAccessor.DescriptionBuilder<B>>, org.refcodes.mixin.DescriptionAccessor.DescriptionMutator, org.refcodes.mixin.DescriptionAccessor.DescriptionProperty -
Method Summary
Modifier and TypeMethodDescriptiondefault <T extends Operand<?>>
TTraverses the hierarchy ofConditiontree and returns the (first) operand matching the given type.default Operand<?>Traverses the hierarchy ofConditiontree and returns the (first) operand matching the given alias.<T extends Operand<?>>
TTraverses the hierarchy ofConditiontree and returns the (first) operand matching the given alias and type.Methods inherited from interface org.refcodes.cli.Constituent
parseArgs, parseArgs, toSchema, toSynopsis, toSyntax, toSyntax, toSyntax, toSyntax, toSyntax, toValueMethods inherited from interface org.refcodes.mixin.DescriptionAccessor
getDescriptionMethods inherited from interface org.refcodes.mixin.Resetable
resetMethods inherited from interface org.refcodes.cli.Synopsisable
toSynopsis, toSynopsis, toSynopsis, toSynopsis
-
Method Details
-
toOperands
Traverses the hierarchy ofConditions and collects all therein foundOperands and sub-types such as theFlagor theOption. This is most useful when creating a list ofOptions,Flages andOperands when printing out detailed help.- Returns:
- The according
Operandelements.
-
toOperand
Traverses the hierarchy ofConditiontree and returns the (first) operand matching the given alias.- Parameters:
aAlias- The alias for which to seek for.- Returns:
- The according
Operandelement or null if none matching was found.
-
toOperand
Traverses the hierarchy ofConditiontree and returns the (first) operand matching the given type.- Type Parameters:
T- the generic type- Parameters:
aType- The type for which to seek for.- Returns:
- The according
Operandelement or null if none matching was found
-
toOperand
Traverses the hierarchy ofConditiontree and returns the (first) operand matching the given alias and type.- Type Parameters:
T- the generic type- Parameters:
aAlias- The alias for which to seek for.aType- The type for which to seek for.- Returns:
- The according
Operandelement or null if none matching was found
-