- All Implemented Interfaces:
Cloneable,Comparable<Operand<?>>,ArgsAccessor,Constituent,Operand<String>,Option<String>,Synopsisable,org.refcodes.mixin.AliasAccessor,org.refcodes.mixin.Clonable,org.refcodes.mixin.DescriptionAccessor,org.refcodes.mixin.Resetable,org.refcodes.mixin.Schemable<CliSchema>,org.refcodes.mixin.TypeAccessor<String>,org.refcodes.mixin.ValueAccessor<String>
The
ConfigOption represents an Option holding a value
specifying a configuration resource (file).-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.mixin.AliasAccessor
org.refcodes.mixin.AliasAccessor.AliasBuilder<B extends org.refcodes.mixin.AliasAccessor.AliasBuilder<B>>, org.refcodes.mixin.AliasAccessor.AliasMutator, org.refcodes.mixin.AliasAccessor.AliasPropertyNested classes/interfaces inherited from interface org.refcodes.cli.ArgsAccessor
ArgsAccessor.ArgsMutator, ArgsAccessor.ArgsPropertyNested classes/interfaces inherited from interface org.refcodes.mixin.DescriptionAccessor
org.refcodes.mixin.DescriptionAccessor.DescriptionBuilder<B extends org.refcodes.mixin.DescriptionAccessor.DescriptionBuilder<B>>, org.refcodes.mixin.DescriptionAccessor.DescriptionMutator, org.refcodes.mixin.DescriptionAccessor.DescriptionPropertyNested classes/interfaces inherited from interface org.refcodes.mixin.TypeAccessor
org.refcodes.mixin.TypeAccessor.TypeBuilder<T extends Object,B extends org.refcodes.mixin.TypeAccessor.TypeBuilder<T, B>>, org.refcodes.mixin.TypeAccessor.TypeMutator<T extends Object>, org.refcodes.mixin.TypeAccessor.TypeProperty<T extends Object> Nested classes/interfaces inherited from interface org.refcodes.mixin.ValueAccessor
org.refcodes.mixin.ValueAccessor.ValueBuilder<V extends Object,B extends org.refcodes.mixin.ValueAccessor.ValueBuilder<V, B>>, org.refcodes.mixin.ValueAccessor.ValueMutator<V extends Object>, org.refcodes.mixin.ValueAccessor.ValueProperty<V extends Object> -
Field Summary
FieldsModifier and TypeFieldDescriptionprotected Stringstatic final Stringstatic final Stringstatic final CharacterFields inherited from class org.refcodes.cli.AbstractOperand
_value -
Constructor Summary
ConstructorsConstructorDescriptionConstructs the predefined config (file)Option.ConfigOption(boolean hasShortOption) Constructs the predefined config (file)Option.ConfigOption(String aDescription) Instantiates a new config (file)Option.ConfigOption(String aDescription, boolean hasShortOption) Constructs the predefined config (file)Option. -
Method Summary
Methods inherited from class org.refcodes.cli.StringOption
toTypeMethods inherited from class org.refcodes.cli.AbstractOption
clone, contains, getLongOption, getShortOption, parseArgs, setParsedArgs, setValue, toOptionArgument, toOptionArgument, toSchema, toSyntaxMethods inherited from class org.refcodes.cli.AbstractOperand
compareTo, getAlias, getType, getValue, reset, toParsedArgs, toStringMethods inherited from class java.lang.Object
equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface java.lang.Comparable
compareToMethods inherited from interface org.refcodes.cli.Constituent
parseArgs, toSynopsis, toSyntax, toSyntax, toSyntax, toSyntaxMethods inherited from interface org.refcodes.mixin.DescriptionAccessor
getDescriptionMethods inherited from interface org.refcodes.cli.Operand
getAlias, getValue, hasValue, toParsedArgs, toSpec, toValueMethods inherited from interface org.refcodes.mixin.Resetable
resetMethods inherited from interface org.refcodes.cli.Synopsisable
toSynopsis, toSynopsis, toSynopsis, toSynopsisMethods inherited from interface org.refcodes.mixin.TypeAccessor
getTypeMethods inherited from interface org.refcodes.mixin.ValueAccessor
getValueOr
-
Field Details
-
ALIAS
- See Also:
-
LONG_OPTION
- See Also:
-
SHORT_OPTION
-
_description
-
-
Constructor Details
-
ConfigOption
Instantiates a new config (file)Option.- Parameters:
aDescription- The description to use.
-
ConfigOption
Constructs the predefined config (file)Option.- Parameters:
aDescription- The description to be used (without any line breaks).hasShortOption- True in case to also enable the short option, else only the long option takes effect.
-
ConfigOption
public ConfigOption()Constructs the predefined config (file)Option. -
ConfigOption
public ConfigOption(boolean hasShortOption) Constructs the predefined config (file)Option.- Parameters:
hasShortOption- True in case to also enable the short option, else only the long option takes effect.
-
-
Method Details
-
getDescription
- Specified by:
getDescriptionin interfaceorg.refcodes.mixin.DescriptionAccessor
-