Class ConfigOption

    • Constructor Detail

      • ConfigOption

        public ConfigOption​(String aDescription)
        Instantiates a new configuration option (e.g. a file name for a configuration file or some other identifier for a configuration).
        Parameters:
        aDescription - The description to use.
      • ConfigOption

        public ConfigOption()
        Instantiates a new configuration option (e.g. a file name for a configuration file or some other identifier for a configuration).
    • Method Detail

      • toUsage

        public String toUsage​(SyntaxNotation aSyntaxNotation,
                              String aOptionEscCode,
                              String aResetEscCode)
        Returns the human readable (verbose) syntax of implementing class ATTENTION: As of different parenthesis settings for some notations regarding the root Syntaxable and the child Syntaxables, the method Syntaxable.toSyntax(SyntaxNotation, String, String) is called from inside a Syntaxable hierarchy. In case the syntax is to be retrieved from the root Syntaxable or an encapsulating and different type, then the applicable method to be called is SyntaxUsage.toUsage(SyntaxNotation), as for some notations it will for example not create the most outer braces.
        Specified by:
        toUsage in interface SyntaxUsage
        Parameters:
        aSyntaxNotation - The syntax notation used for generating the command line arguments syntax.
        aOptionEscCode - The escape code to be used when processing an option, e.g. this can be an ANSI Escape-Code to highlight the option parameters (for example "--help", "-q" and so on).
        aResetEscCode - The escape code to close (reset) any Escape-Code being set before.
        Returns:
        The human readable (verbose) command line arguments syntax.