- All Implemented Interfaces:
Serializable,Comparable<ExitCode>,java.lang.constant.Constable,org.refcodes.mixin.StatusCodeAccessor<Integer>
public enum ExitCode extends Enum<ExitCode> implements org.refcodes.mixin.StatusCodeAccessor<Integer>
Some default exit codes defined for CLI applications.
- Author:
- steiner
-
Nested Class Summary
Nested classes/interfaces inherited from class java.lang.Enum
Enum.EnumDesc<E extends Enum<E>>Nested classes/interfaces inherited from interface org.refcodes.mixin.StatusCodeAccessor
org.refcodes.mixin.StatusCodeAccessor.StatusCodeBuilder<SC extends Object,B extends org.refcodes.mixin.StatusCodeAccessor.StatusCodeBuilder<SC,B>>, org.refcodes.mixin.StatusCodeAccessor.StatusCodeMutator<SC extends Object>, org.refcodes.mixin.StatusCodeAccessor.StatusCodeProperty<SC extends Object> -
Enum Constant Summary
Enum Constants Enum Constant Description ARGS_ERRORFAILIO_ERRORSUCCESS -
Method Summary
Modifier and Type Method Description IntegergetStatusCode()Gets the status code.static ExitCodevalueOf(String name)Returns the enum constant of this type with the specified name.static ExitCode[]values()Returns an array containing the constants of this enum type, in the order they are declared.
-
Enum Constant Details
-
SUCCESS
-
FAIL
-
ARGS_ERROR
-
IO_ERROR
-
-
Method Details
-
values
Returns an array containing the constants of this enum type, in the order they are declared.- Returns:
- an array containing the constants of this enum type, in the order they are declared
-
valueOf
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)- Parameters:
name- the name of the enum constant to be returned.- Returns:
- the enum constant with the specified name
- Throws:
IllegalArgumentException- if this enum type has no constant with the specified nameNullPointerException- if the argument is null
-
getStatusCode
Gets the status code.- Specified by:
getStatusCodein interfaceorg.refcodes.mixin.StatusCodeAccessor<Integer>- Returns:
- the status code
-