Class Flag

All Implemented Interfaces:
Cloneable, Comparable<Operand<?>>, MatchCountAccessor, Operand<Boolean>, Option<Boolean>, ParsedArgsAccessor, Synopsisable, Term, org.refcodes.exception.ExceptionAccessor<ArgsSyntaxException>, org.refcodes.graphical.VisibleAccessor, org.refcodes.graphical.VisibleAccessor.VisibleBuilder<Term>, org.refcodes.graphical.VisibleAccessor.VisibleMutator, org.refcodes.graphical.VisibleAccessor.VisibleProperty, org.refcodes.mixin.AliasAccessor, org.refcodes.mixin.Clonable, org.refcodes.mixin.DescriptionAccessor, org.refcodes.mixin.EnabledAccessor, org.refcodes.mixin.Resetable, org.refcodes.mixin.TypeAccessor<Boolean>, org.refcodes.mixin.ValueAccessor<Boolean>, org.refcodes.schema.Schemable
Direct Known Subclasses:
CleanFlag, DaemonFlag, DebugFlag, ForceFlag, HelpFlag, InitFlag, QuietFlag, SysInfoFlag, VerboseFlag

public class Flag extends AbstractOption<Boolean> implements org.refcodes.mixin.EnabledAccessor
The Flag class implements the Option interface for representing either a true or a false state: When a flag is provided to your command line arguments, then it is considered to be true, when it is omitted, then it is considered to be false as of isEnabled().
  • Field Details

    • _description

      protected String _description
    • _exception

      protected ArgsSyntaxException _exception
    • _isVisible

      protected boolean _isVisible
  • Constructor Details

    • Flag

      public Flag(Character aShortOption, String aLongOption, String aDescription)
      Instantiates a new Flag with the given arguments. In case a long option is provided, the intance's alias will automatically be set with the long option, else the short option is used as alias.
      Parameters:
      aShortOption - The short option to use.
      aLongOption - The long option to use.
      aDescription - The description of the Flag
    • Flag

      public Flag(Character aShortOption, String aLongOption, String aDescription, Consumer<Flag> aConsumer)
      Instantiates a new Flag with the given arguments. In case a long option is provided, the intance's alias will automatically be set with the long option, else the short option is used as alias.
      Parameters:
      aShortOption - The short option to use.
      aLongOption - The long option to use.
      aDescription - The description of the Flag.
      aConsumer - The Consumer being invoked in case this Flag participated in successfully parsing the command line arguments.
    • Flag

      public Flag(Character aShortOption, String aLongOption, String aAlias, String aDescription)
      Instantiates the class Flag.
      See Also:
    • Flag

      public Flag(Character aShortOption, String aLongOption, String aAlias, String aDescription, Consumer<Flag> aConsumer)
      Instantiates the class Flag.
      See Also:
    • Flag

      public Flag(org.refcodes.struct.Relation<String,Boolean> aProperty)
      Instantiates a new Flag with the alias being the proerty's key and the value being the property's value. Depending on the provided property's key, the key is either used for the short option or the long option.
      Parameters:
      aProperty - The key (=alias) and the value for the operand.
    • Flag

      public Flag(org.refcodes.struct.Relation<String,Boolean> aProperty, Consumer<Flag> aConsumer)
      Instantiates a new Flag with the alias being the proerty's key and the value being the property's value. Depending on the provided property's key, the key is either used for the short option or the long option.
      Parameters:
      aProperty - The key (=alias) and the value for the operand.
      aConsumer - The Consumer being invoked in case this Flag participated in successfully parsing the command line arguments.
    • Flag

      public Flag(String aLongOption, String aDescription)
      Instantiates a new Flag with the given arguments. In case a long option is provided, the intance's alias will automatically be set with the long option.
      Parameters:
      aLongOption - The long option to use.
      aDescription - The description of the Flag
    • Flag

      public Flag(String aLongOption, String aDescription, Consumer<Flag> aConsumer)
      Instantiates a new Flag with the given arguments. In case a long option is provided, the intance's alias will automatically be set with the long option.
      Parameters:
      aLongOption - The long option to use.
      aDescription - The description of the Flag.
      aConsumer - The Consumer being invoked in case this Flag participated in successfully parsing the command line arguments.
    • Flag

      public Flag(String aLongOption, String aAlias, String aDescription)
      Instantiates the class Flag.
      See Also:
    • Flag

      public Flag(String aLongOption, String aAlias, String aDescription, Consumer<Flag> aConsumer)
      Instantiates the class Flag.
      See Also:
  • Method Details

    • isEnabled

      public boolean isEnabled()
      Returns true if the switch has been set (enabled).
      Specified by:
      isEnabled in interface org.refcodes.mixin.EnabledAccessor
      Returns:
      True in case the Flag has been provided (set), else false.
    • parseArgs

      public Operand<Boolean>[] parseArgs(String[] aArgs, String[] aKeywords, CliContext aCliCtx) throws ArgsSyntaxException
      Parses the given command line arguments using the provided keyword set and CLI context.

      This method represents the core parsing operation. It evaluates this Term or, if this term is an inner node, delegates parsing to its child terms.

      The aKeywords parameter defines reserved tokens such as option names that must not be interpreted as operand values.

      This method does not validate whether all arguments have been consumed. Superfluous arguments must be handled by the caller.

      Specified by:
      parseArgs in interface Term
      Overrides:
      parseArgs in class AbstractOption<Boolean>
      Parameters:
      aArgs - The command line arguments to parse
      aKeywords - Reserved option and keyword tokens
      aCliCtx - The CliContext controlling parsing and rendering
      Returns:
      The evaluated operands
      Throws:
      ArgsSyntaxException - If the arguments do not match the syntax
    • reset

      public void reset()
      Specified by:
      reset in interface org.refcodes.mixin.Resetable
      Overrides:
      reset in class AbstractOperand<Boolean>
    • withVisible

      public Flag withVisible(boolean isVisible)

      Visibility in this context means displaying or hiding this Term's existence to the user (defaults to true).

      Specified by:
      withVisible in interface org.refcodes.graphical.VisibleAccessor.VisibleBuilder<Term>
    • toSpec

      public String toSpec(CliContext aCliCtx)
      Creates a specification including its arguments.

      A specification differs from a syntax in that the specification provides the full definition not omitting any choices whereas the syntax only provides a syntactically correct variant. For example, having an option with a short option and a long option, the specification will show the short option and the long option whereas the syntax will only show either the short option or, if no short option is set, the long option.

      Specified by:
      toSpec in interface Operand<Boolean>
      Specified by:
      toSpec in interface Option<Boolean>
      Parameters:
      aCliCtx - The CliContext to use when creating a beautiful specification text.
      Returns:
      The according specification text.
    • toSyntax

      public String toSyntax(CliContext aCliCtx)
      Creates a syntax including its arguments.

      A specification differs from a syntax in that the specification provides the full definition not omitting any choices whereas the syntax only provides a syntactically correct variant. For example, having an option with a short option and a long option, the specification will show the short option and the long option whereas the syntax will only show either the short option or, if no short option is set, the long option.

      Specified by:
      toSyntax in interface Operand<Boolean>
      Specified by:
      toSyntax in interface Option<Boolean>
      Specified by:
      toSyntax in interface Term
      Parameters:
      aCliCtx - The CLI context controlling notation and formatting
      Returns:
      The human readable command line syntax
    • toType

      protected Boolean toType(String aArg) throws ParseArgsException
      Double dispatch hook to be implemented by subclasses of the AbstractOperand for converting a command line argument to the required Operand's type. In case conversion failed, then an according exception is to be thrown.
      Specified by:
      toType in class AbstractOperand<Boolean>
      Parameters:
      aArg - The command line argument to be converted to an instance of the given type T.
      Returns:
      An instance of type T from the provided command line argument.
      Throws:
      ParseArgsException - Thrown in case the provided command line arguments do not respect the required syntax or cannot be converted to the required type.
    • getDescription

      public String getDescription()
      Specified by:
      getDescription in interface org.refcodes.mixin.DescriptionAccessor
    • getException

      public ArgsSyntaxException getException()
      Retrieves the ArgsSyntaxException exception in case invoking Term.parseArgs(String[], CliContext) failed. The exception (and the according suppressed ones alongside the causes) does not necessarily have been thrown by the Term.parseArgs(String[], CliContext) method depending on the semantics of the Term handing the exception (the AnyCondition provides any exceptions it caught even though it did not throw them as of its semantics).
      Specified by:
      getException in interface org.refcodes.exception.ExceptionAccessor<ArgsSyntaxException>
      Specified by:
      getException in interface Term
      Returns:
      The ArgsSyntaxException exception occurring while parsing the arguments.
    • setVisible

      public void setVisible(boolean isVisible)

      Visibility in this context means displaying or hiding this Term's existence to the user (defaults to true).

      Specified by:
      setVisible in interface Term
      Specified by:
      setVisible in interface org.refcodes.graphical.VisibleAccessor.VisibleMutator
    • isVisible

      public boolean isVisible()

      Visibility in this context means displaying or hiding this Term's existence to the user (defaults to true).

      Specified by:
      isVisible in interface Term
      Specified by:
      isVisible in interface org.refcodes.graphical.VisibleAccessor
    • toArgsDiff

      protected static String[] toArgsDiff(String[] aArgs, List<? extends Operand<?>> aArgsSubset)
      Creates the difference between the provided set and the provided Lists therein found argument arrays subset (as of Operand.getParsedArgs()).
      Parameters:
      aArgs - The set to be used for the diff operation.
      aArgsSubset - The subset to be used for the diff operation being the lists containing the Operand instances whose command line arguments are to be diffed.
      Returns:
      The difference between the set and the subset.
    • toArgsDiff

      protected static String[] toArgsDiff(String[] aArgs, Operand<?>[] aArgsSubset)
      Creates the difference between the provided set and the provided Lists therein found argument arrays subset (as of Operand.getParsedArgs()).
      Parameters:
      aArgs - The set to be used for the diff operation.
      aArgsSubset - The subset to be used for the diff operation being the lists containing the Operand instances whose command line arguments are to be diffed.
      Returns:
      The difference between the set and the subset.
    • toArgsDiff

      protected static String[] toArgsDiff(String[] aArgs, String[] aArgsSubset)
      Creates the difference between the provided set and the provided subset.
      Parameters:
      aArgs - The set to be used for the diff operation.
      aArgsSubset - The subset to be used for the diff operation.
      Returns:
      The difference between the set and the subset.
    • toParsedArgs

      protected static String[] toParsedArgs(Operand<?>[]... aOperands)
      Takes all Operand instances found in the provided Lists and adds all therein found argument arrays (as of Operand.getParsedArgs()) to the result.
      Parameters:
      aOperands - The lists containing the Operand instances whose command line arguments are to be added to the result.
      Returns:
      All the command line arguments detected in the provided Operands Lists.