Class Flag

java.lang.Object
All Implemented Interfaces:
Cloneable, Comparable<Operand<?>>, MatchCountAccessor, Operand<Boolean>, Option<Boolean>, ParsedArgsAccessor, Synopsisable, Term, org.refcodes.exception.ExceptionAccessor<ArgsSyntaxException>, org.refcodes.graphical.VisibleAccessor, org.refcodes.graphical.VisibleAccessor.VisibleBuilder<Term>, org.refcodes.graphical.VisibleAccessor.VisibleMutator, org.refcodes.graphical.VisibleAccessor.VisibleProperty, org.refcodes.mixin.AliasAccessor, org.refcodes.mixin.Clonable, org.refcodes.mixin.DescriptionAccessor, org.refcodes.mixin.EnabledAccessor, org.refcodes.mixin.Resetable, org.refcodes.mixin.TypeAccessor<Boolean>, org.refcodes.mixin.ValueAccessor<Boolean>, org.refcodes.schema.Schemable
Direct Known Subclasses:
CleanFlag, DaemonFlag, DebugFlag, ForceFlag, HelpFlag, InitFlag, QuietFlag, SysInfoFlag, VerboseFlag

public class Flag extends AbstractOption<Boolean> implements org.refcodes.mixin.EnabledAccessor
The Flag class implements the Option interface for representing either a true or a false state: When a flag is provided to your command line arguments, then it is considered to be true, when it is omitted, then it is considered to be false as of isEnabled().