- All Implemented Interfaces:
Cloneable,Comparable<Operand<?>>,ArgsAccessor,Constituent,Operand<Boolean>,Option<Boolean>,Synopsisable,org.refcodes.mixin.AliasAccessor,org.refcodes.mixin.Clonable,org.refcodes.mixin.DescriptionAccessor,org.refcodes.mixin.EnabledAccessor,org.refcodes.mixin.Resetable,org.refcodes.mixin.Schemable<CliSchema>,org.refcodes.mixin.TypeAccessor<Boolean>,org.refcodes.mixin.ValueAccessor<Boolean>
- Direct Known Subclasses:
CleanFlag,DaemonFlag,DebugFlag,ForceFlag,HelpFlag,InitFlag,QuietFlag,SysInfoFlag,VerboseFlag
public class Flag
extends AbstractOption<Boolean>
implements Option<Boolean>, org.refcodes.mixin.EnabledAccessor
The
Flag class implements the Option interface for
representing either a true or a false state: When a
flag is provided to your command line arguments, then it is considered to be
true, when it is omitted, then it is considered to be
false as of isEnabled().-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.mixin.AliasAccessor
org.refcodes.mixin.AliasAccessor.AliasBuilder<B extends org.refcodes.mixin.AliasAccessor.AliasBuilder<B>>, org.refcodes.mixin.AliasAccessor.AliasMutator, org.refcodes.mixin.AliasAccessor.AliasPropertyNested classes/interfaces inherited from interface org.refcodes.cli.ArgsAccessor
ArgsAccessor.ArgsMutator, ArgsAccessor.ArgsPropertyNested classes/interfaces inherited from interface org.refcodes.mixin.DescriptionAccessor
org.refcodes.mixin.DescriptionAccessor.DescriptionBuilder<B extends org.refcodes.mixin.DescriptionAccessor.DescriptionBuilder<B>>, org.refcodes.mixin.DescriptionAccessor.DescriptionMutator, org.refcodes.mixin.DescriptionAccessor.DescriptionPropertyNested classes/interfaces inherited from interface org.refcodes.mixin.EnabledAccessor
org.refcodes.mixin.EnabledAccessor.EnabledBuilder<B extends org.refcodes.mixin.EnabledAccessor.EnabledBuilder<B>>, org.refcodes.mixin.EnabledAccessor.EnabledMutator, org.refcodes.mixin.EnabledAccessor.EnabledPropertyNested classes/interfaces inherited from interface org.refcodes.mixin.TypeAccessor
org.refcodes.mixin.TypeAccessor.TypeBuilder<T extends Object,B extends org.refcodes.mixin.TypeAccessor.TypeBuilder<T, B>>, org.refcodes.mixin.TypeAccessor.TypeMutator<T extends Object>, org.refcodes.mixin.TypeAccessor.TypeProperty<T extends Object> Nested classes/interfaces inherited from interface org.refcodes.mixin.ValueAccessor
org.refcodes.mixin.ValueAccessor.ValueBuilder<V extends Object,B extends org.refcodes.mixin.ValueAccessor.ValueBuilder<V, B>>, org.refcodes.mixin.ValueAccessor.ValueMutator<V extends Object>, org.refcodes.mixin.ValueAccessor.ValueProperty<V extends Object> -
Field Summary
FieldsFields inherited from class org.refcodes.cli.AbstractOperand
_value -
Constructor Summary
ConstructorsConstructorDescriptionInstantiates a newFlagwith the given arguments.Instantiates a newFlagwith the given arguments.Instantiates a newFlagwith the given arguments.Instantiates a newFlagwith the given arguments.Instantiates a newFlagwith the alias being the proerty's key and the value being the property's value. -
Method Summary
Modifier and TypeMethodDescriptionbooleanReturns true if the switch has been set (enabled).parseArgs(String[] aArgs, String[] aOptions, CliContext aCliCtx) Parses the provided command line arguments and determines the according values by evaluating thisConstituentinstance or, in case of being a node in the syntax tree (such as aCondition, traversing the childConstituentinstances'Constituent.parseArgs(String[], String[], CliContext)methods.voidreset()toSyntax(CliContext aCliCtx) This method is to be called from inside theConstituenthierarchy; use the methodSynopsisable.toSynopsis(SyntaxNotation)in case you invoke syntax retrieval from the rootConstituent.protected BooleanDouble dispatch hook to be implemented by subclasses of theAbstractOperandfor converting a command line argument to the requiredOperand's type.Methods inherited from class org.refcodes.cli.AbstractOption
clone, contains, getLongOption, getShortOption, setParsedArgs, setValue, toOptionArgument, toOptionArgument, toSchemaMethods inherited from class org.refcodes.cli.AbstractOperand
compareTo, getAlias, getType, getValue, toParsedArgs, toStringMethods inherited from class java.lang.Object
equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface org.refcodes.mixin.Clonable
cloneMethods inherited from interface java.lang.Comparable
compareToMethods inherited from interface org.refcodes.cli.Constituent
parseArgs, toSynopsis, toSyntax, toSyntax, toSyntax, toSyntaxMethods inherited from interface org.refcodes.mixin.DescriptionAccessor
getDescriptionMethods inherited from interface org.refcodes.cli.Operand
getAlias, getValue, hasValue, toParsedArgs, toSpec, toValueMethods inherited from interface org.refcodes.cli.Option
getLongOption, getShortOptionMethods inherited from interface org.refcodes.mixin.Schemable
toSchemaMethods inherited from interface org.refcodes.cli.Synopsisable
toSynopsis, toSynopsis, toSynopsis, toSynopsisMethods inherited from interface org.refcodes.mixin.TypeAccessor
getTypeMethods inherited from interface org.refcodes.mixin.ValueAccessor
getValueOr
-
Field Details
-
_description
-
-
Constructor Details
-
Flag
Instantiates a newFlagwith the given arguments.- Parameters:
aShortOption- The short option to use.aLongOption- The long option to use.aAlias- The alias to be used for naming purposes.aDescription- The description of theFlag
-
Flag
Instantiates a newFlagwith the given arguments. In case a long option is provided, the intance's alias will automatically be set with the long option, else the short option is used ass alias.- Parameters:
aShortOption- The short option to use.aLongOption- The long option to use.aDescription- The description of theFlag
-
Flag
Instantiates a newFlagwith the given arguments.- Parameters:
aLongOption- The long option to use.aAlias- The alias to be used for naming purposes.aDescription- The description of theFlag
-
Flag
Instantiates a newFlagwith the given arguments. In case a long option is provided, the intance's alias will automatically be set with the long option.- Parameters:
aLongOption- The long option to use.aDescription- The description of theFlag
-
Flag
Instantiates a newFlagwith the alias being the proerty's key and the value being the property's value. Depending on the provided property's key, the key is either used for the short option or the long option.- Parameters:
aProperty- The key (=alias) and the value for the operand.
-
-
Method Details
-
isEnabled
public boolean isEnabled()Returns true if the switch has been set (enabled).- Specified by:
isEnabledin interfaceorg.refcodes.mixin.EnabledAccessor- Returns:
- True in case the
Flaghas been provided (set), else false.
-
parseArgs
public List<Operand<Boolean>> parseArgs(String[] aArgs, String[] aOptions, CliContext aCliCtx) throws ArgsSyntaxException Parses the provided command line arguments and determines the according values by evaluating thisConstituentinstance or, in case of being a node in the syntax tree (such as aCondition, traversing the childConstituentinstances'Constituent.parseArgs(String[], String[], CliContext)methods. In case of successfully parsing thisConstituentand / or the childConstituentinstances, the evaluated command line arguments are returned: Depending on theConstituentsubclasses representing the evaluated command line arguments, instances ofFlagclasses,Optionclasses orOperandclasses may be found in the result. In case of parsing failure, an according exception is thrown. ATTENTION: This method does not test for superfluous command line arguments being passed; e.g. command line arguments not being evaluated by any of theConstituentinstance being traversed. This method is commonly used by a rootConstituent'sArgsParser.evalArgs(String[])method, which delegates to theConstituent.parseArgs(String[], String[], CliContext)method and after which it determines whether there are superfluous arguments to be taken care of (by throwing an according exception). Business logic therefore should invoke the root node'sConstituent.parseArgs(String[], String[], CliContext)method as ignoring superfluous command line arguments will cause unexpected behavior from the point of view of the invoker.- Specified by:
parseArgsin interfaceConstituent- Overrides:
parseArgsin classAbstractOption<Boolean>- Parameters:
aArgs- The command line arguments to be parsed.aOptions- The list of options (short and as well as long) which are reserved and cannot be used as value.aCliCtx- the cli context- Returns:
- The list of evaluated command line arguments being instances of
the
Operandinterfaces or its sub-types. - Throws:
ArgsSyntaxException- thrown in case of a command line arguments mismatch regarding provided and expected args.
-
toSyntax
This method is to be called from inside theConstituenthierarchy; use the methodSynopsisable.toSynopsis(SyntaxNotation)in case you invoke syntax retrieval from the rootConstituent. Returns the human readable (verbose) syntax of thisConstituentinstance including, in case of being a node in the syntax tree (such as aCondition, the syntax of the childConstituentinstances. ATTENTION: As of different parenthesis settings for some notations regarding the rootConstituentand the childConstituents, the methodConstituent.toSyntax(CliContext)is called from inside theConstituenthierarchy. In case the syntax is to be retrieved from the rootConstituent, then the applicable method to be called isSynopsisable.toSynopsis(SyntaxNotation), as for some notations it will for example not create the most outer braces.- Specified by:
toSyntaxin interfaceConstituent- Overrides:
toSyntaxin classAbstractOption<Boolean>- Parameters:
aCliCtx- TheCliContextfor which the syntax is being generated.- Returns:
- The human readable (verbose) command line arguments syntax.
-
reset
public void reset()- Specified by:
resetin interfaceorg.refcodes.mixin.Resetable- Overrides:
resetin classAbstractOperand<Boolean>
-
toType
Double dispatch hook to be implemented by subclasses of theAbstractOperandfor converting a command line argument to the requiredOperand's type. In case conversion failed, then an according exception is to be thrown.- Specified by:
toTypein classAbstractOperand<Boolean>- Parameters:
aArg- The command line argument to be converted to an instance of the given type T.- Returns:
- An instance of type T from the provided command line argument.
- Throws:
ParseArgsException- Thrown in case the provided command line arguments do not respect the required syntax or cannot be converted to the required type.
-
getDescription
- Specified by:
getDescriptionin interfaceorg.refcodes.mixin.DescriptionAccessor
-