- java.lang.Object
-
- org.refcodes.cli.AbstractOperand<T>
-
- org.refcodes.cli.AbstractOption<Boolean>
-
- org.refcodes.cli.Flag
-
- All Implemented Interfaces:
Cloneable,Comparable<Operand<?>>,ArgsAccessor,Operand<Boolean>,Option<Boolean>,Synopsis,Syntaxable,org.refcodes.component.Resetable,org.refcodes.mixin.AliasAccessor,org.refcodes.mixin.Clonable,org.refcodes.mixin.DescriptionAccessor,org.refcodes.mixin.EnabledAccessor,org.refcodes.mixin.TypeAccessor<Boolean>,org.refcodes.mixin.ValueAccessor<Boolean>
- Direct Known Subclasses:
CleanFlag,DaemonFlag,DebugFlag,ForceFlag,HelpFlag,InitFlag,QuietFlag,SysInfoFlag,VerboseFlag
public class Flag extends AbstractOption<Boolean> implements Option<Boolean>, org.refcodes.mixin.EnabledAccessor
TheFlagclass implements theOptioninterface for representing either atrueor afalsestate: When a flag is provided to your command line arguments, then it is considered to betrue, when it is omitted, then it is considered to befalseas ofisEnabled().
-
-
Nested Class Summary
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.AliasAccessor
org.refcodes.mixin.AliasAccessor.AliasBuilder<B extends org.refcodes.mixin.AliasAccessor.AliasBuilder<B>>, org.refcodes.mixin.AliasAccessor.AliasMutator, org.refcodes.mixin.AliasAccessor.AliasProperty
-
Nested classes/interfaces inherited from interface org.refcodes.cli.ArgsAccessor
ArgsAccessor.ArgsMutator, ArgsAccessor.ArgsProperty
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.DescriptionAccessor
org.refcodes.mixin.DescriptionAccessor.DescriptionBuilder<B extends org.refcodes.mixin.DescriptionAccessor.DescriptionBuilder<B>>, org.refcodes.mixin.DescriptionAccessor.DescriptionMutator, org.refcodes.mixin.DescriptionAccessor.DescriptionProperty
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.EnabledAccessor
org.refcodes.mixin.EnabledAccessor.EnabledBuilder<B extends org.refcodes.mixin.EnabledAccessor.EnabledBuilder<B>>, org.refcodes.mixin.EnabledAccessor.EnabledMutator, org.refcodes.mixin.EnabledAccessor.EnabledProperty
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.TypeAccessor
org.refcodes.mixin.TypeAccessor.TypeBuilder<T extends Object,B extends org.refcodes.mixin.TypeAccessor.TypeBuilder<T,B>>, org.refcodes.mixin.TypeAccessor.TypeMutator<T extends Object>, org.refcodes.mixin.TypeAccessor.TypeProperty<T extends Object>
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.ValueAccessor
org.refcodes.mixin.ValueAccessor.ValueBuilder<V extends Object,B extends org.refcodes.mixin.ValueAccessor.ValueBuilder<V,B>>, org.refcodes.mixin.ValueAccessor.ValueMutator<V extends Object>, org.refcodes.mixin.ValueAccessor.ValueProperty<V extends Object>
-
-
Field Summary
-
Fields inherited from class org.refcodes.cli.AbstractOperand
_value
-
-
Method Summary
All Methods Instance Methods Concrete Methods Modifier and Type Method Description booleanisEnabled()Returns true if the switch has been set (enabled).List<Operand<Boolean>>parseArgs(String[] aArgs, String[] aOptions)Parses the provided command line arguments and determines the according values by evaluating thisSyntaxableinstance or, in case of being a node in the syntax tree (such as aArgsSyntax, traversing the childSyntaxableinstances'Syntaxable.parseArgs(String[], String[])methods.voidreset()StringtoSynopsis(SyntaxNotation aSyntaxNotation, String aOptEscCode, String aParamEscCode, String aResetEscCode)Returns the human readable (verbose) syntax of implementing class ATTENTION: As of different parenthesis settings for some notations regarding the rootSyntaxableand the childSyntaxables, the methodSyntaxable.toSyntax(SyntaxNotation, String, String, String)is called from inside aSyntaxablehierarchy.StringtoSyntax(SyntaxNotation aSyntaxNotation, String aOptEscCode, String aParamEscCode, String aResetEscCode)This method is to be called from inside theSyntaxablehierarchy; use the methodSynopsis.toSynopsis(SyntaxNotation)in case you invoke syntax retrieval from the rootSyntaxable.protected BooleantoType(String aArg)Double dispatch hook to be implemented by subclasses of theAbstractOperandfor converting a command line argument to the requiredOperand's type.-
Methods inherited from class org.refcodes.cli.AbstractOption
clone, getLongOption, getOptionPrefixes, getShortOption, setArgs, setValue, toState
-
Methods inherited from class org.refcodes.cli.AbstractOperand
compareTo, getAlias, getArgs, getDescription, getType, getValue, toString
-
Methods inherited from class java.lang.Object
equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, wait
-
Methods inherited from interface java.lang.Comparable
compareTo
-
Methods inherited from interface org.refcodes.cli.Operand
getAlias, getArgs, getValue, hasValue, toValue
-
Methods inherited from interface org.refcodes.cli.Option
getLongOption, getOptions, getShortOption
-
Methods inherited from interface org.refcodes.cli.Synopsis
toSynopsis, toSynopsis, toSynopsis, toSynopsis
-
-
-
-
Constructor Detail
-
Flag
public Flag(String aShortOption, String aLongOption, String aAlias, String aDescription)
Constructs aFlag.- Parameters:
aShortOption- The short-option being a single character with the additional single hyphen-minus "-" prefix.aLongOption- The long-option being a multi-character sequence with at least two characters with the additional double hyphen-minus "--" prefix.aAlias- The alias identifying thisFlag.aDescription- A description without any line breaks.
-
Flag
public Flag(String aLongOption, String aAlias, String aDescription)
Constructs aFlag.- Parameters:
aLongOption- The long-option being a multi-character sequence with at least two characters with the additional double hyphen-minus "--" prefix.aAlias- The alias identifying thisFlag.aDescription- A description without any line breaks.
-
-
Method Detail
-
isEnabled
public boolean isEnabled()
Returns true if the switch has been set (enabled).- Specified by:
isEnabledin interfaceorg.refcodes.mixin.EnabledAccessor- Returns:
- True in case the
Flaghas been provided (set), else false.
-
parseArgs
public List<Operand<Boolean>> parseArgs(String[] aArgs, String[] aOptions) throws UnknownArgsException, AmbiguousArgsException, ParseArgsException, SuperfluousArgsException
Parses the provided command line arguments and determines the according values by evaluating thisSyntaxableinstance or, in case of being a node in the syntax tree (such as aArgsSyntax, traversing the childSyntaxableinstances'Syntaxable.parseArgs(String[], String[])methods. In case of successfully parsing thisSyntaxableand / or the childSyntaxableinstances, the evaluated command line arguments are returned: Depending on theSyntaxablesubclasses representing the evaluated command line arguments, instances ofFlagclasses,Optionclasses orOperandclasses may be found in the result. In case of parsing failure, an according exception is thrown. ATTENTION: This method does not test for superfluous command line arguments being passed; e.g. command line arguments not being evaluated by any of theSyntaxableinstance being traversed. This method is commonly used by a rootSyntaxable'sArgsParser.evalArgs(String[])method, which delegates to theSyntaxable.parseArgs(String[], String[])method and after which it determines whether there are superfluous arguments to be taken care of (by throwing an according exception). Business logic therefore should invoke the root node'sSyntaxable.parseArgs(String[], String[])method as ignoring superfluous command line arguments will cause unexpected behavior from the point of view of the invoker.- Specified by:
parseArgsin interfaceSyntaxable- Overrides:
parseArgsin classAbstractOption<Boolean>- Parameters:
aArgs- The command line arguments to be parsed.aOptions- The list of options (short and as well as long) which are reserved and cannot be used as value.- Returns:
- The list of evaluated command line arguments being instances of
the
Operandinterfaces or its sub-types. - Throws:
UnknownArgsException- Thrown in case not one command line argument matched regarding the provided args vs. the expected args.AmbiguousArgsException- Thrown in case at least one command line argument is ambiguous regarding expected args vs. provided args.ParseArgsException- Thrown in case the provided command line arguments do not respect the required syntax or cannot be converted to the required typeSuperfluousArgsException- in case there were arguments found not being used (superfluous arguments), thrown only in very specific cases (throw with care!).
-
toSyntax
public String toSyntax(SyntaxNotation aSyntaxNotation, String aOptEscCode, String aParamEscCode, String aResetEscCode)
This method is to be called from inside theSyntaxablehierarchy; use the methodSynopsis.toSynopsis(SyntaxNotation)in case you invoke syntax retrieval from the rootSyntaxable. Returns the human readable (verbose) syntax of thisSyntaxableinstance including, in case of being a node in the syntax tree (such as aArgsSyntax, the syntax of the childSyntaxableinstances. ATTENTION: As of different parenthesis settings for some notations regarding the rootSyntaxableand the childSyntaxables, the methodSyntaxable.toSyntax(SyntaxNotation, String, String, String)is called from inside theSyntaxablehierarchy. In case the syntax is to be retrieved from the rootSyntaxable, then the applicable method to be called isSynopsis.toSynopsis(SyntaxNotation), as for some notations it will for example not create the most outer braces.- Specified by:
toSyntaxin interfaceSyntaxable- Overrides:
toSyntaxin classAbstractOption<Boolean>- Parameters:
aSyntaxNotation- The syntax notation used for generating the command line arguments syntax.aOptEscCode- The escape code to be used when processing an option, e.g. this can be an ANSI Escape-Code to highlight the option.aParamEscCode- The escape code to be used when processing a keyword, e.g. this can be an ANSI Escape-Code to highlight the option and/or parameters.aResetEscCode- The escape code to close (reset) any Escape-Code being set before.- Returns:
- The human readable (verbose) command line arguments syntax.
-
reset
public void reset()
- Specified by:
resetin interfaceorg.refcodes.component.Resetable- Overrides:
resetin classAbstractOperand<Boolean>
-
toType
protected Boolean toType(String aArg) throws ParseArgsException
Double dispatch hook to be implemented by subclasses of theAbstractOperandfor converting a command line argument to the requiredOperand's type. In case conversion failed, then an according exception is to be thrown.- Specified by:
toTypein classAbstractOperand<Boolean>- Parameters:
aArg- The command line argument to be converted to an instance of the given type T.- Returns:
- An instance of type T from the provided command line argument.
- Throws:
ParseArgsException- Thrown in case the provided command line arguments do not respect the required syntax or cannot be converted to the required type.
-
toSynopsis
public String toSynopsis(SyntaxNotation aSyntaxNotation, String aOptEscCode, String aParamEscCode, String aResetEscCode)
Returns the human readable (verbose) syntax of implementing class ATTENTION: As of different parenthesis settings for some notations regarding the rootSyntaxableand the childSyntaxables, the methodSyntaxable.toSyntax(SyntaxNotation, String, String, String)is called from inside aSyntaxablehierarchy. In case the syntax is to be retrieved from the rootSyntaxableor an encapsulating and different type, then the applicable method to be called isSynopsis.toSynopsis(SyntaxNotation), as for some notations it will for example not create the most outer braces.- Specified by:
toSynopsisin interfaceSynopsis- Parameters:
aSyntaxNotation- The syntax notation used for generating the command line arguments syntax.aOptEscCode- The escape code to be used when processing an option, e.g. this can be an ANSI Escape-Code to highlight the option.aParamEscCode- The escape code to be used when processing am argument, e.g. this can be an ANSI Escape-Code to highlight the option.aResetEscCode- The escape code to close (reset) any Escape-Code being set before.- Returns:
- The human readable (verbose) command line arguments syntax.
-
-