Interface LicenseAccessor.LicenseBuilder<B extends LicenseAccessor.LicenseBuilder<B>>

Type Parameters:
B - The builder to return in order to be able to apply multiple build operations.
All Known Subinterfaces:
ArgsProcessorBuilder<B>, ParseArgs
All Known Implementing Classes:
ArgsParser
Enclosing interface:
LicenseAccessor

public static interface LicenseAccessor.LicenseBuilder<B extends LicenseAccessor.LicenseBuilder<B>>
Provides a builder method for a license property returning the builder for applying multiple build operations.