Interface LongOptionPrefixAccessor.LongOptionPrefixBuilder<B extends LongOptionPrefixAccessor.LongOptionPrefixBuilder<B>>

Type Parameters:
B - The builder to return in order to be able to apply multiple build operations.
All Known Subinterfaces:
ArgsProcessorBuilder<B>, ParseArgs
All Known Implementing Classes:
ArgsParser, SyntaxMetricsImpl.Builder
Enclosing interface:
LongOptionPrefixAccessor

public static interface LongOptionPrefixAccessor.LongOptionPrefixBuilder<B extends LongOptionPrefixAccessor.LongOptionPrefixBuilder<B>>
Provides a builder method for a long option prefix property returning the builder for applying multiple build operations.