Class NoneOperand

All Implemented Interfaces:
Cloneable, Comparable<Operand<?>>, MatchCountAccessor, Operand<Boolean>, ParsedArgsAccessor, Synopsisable, Term, org.refcodes.exception.ExceptionAccessor<ArgsSyntaxException>, org.refcodes.graphical.VisibleAccessor, org.refcodes.graphical.VisibleAccessor.VisibleBuilder<Term>, org.refcodes.graphical.VisibleAccessor.VisibleMutator, org.refcodes.graphical.VisibleAccessor.VisibleProperty, org.refcodes.mixin.AliasAccessor, org.refcodes.mixin.Clonable, org.refcodes.mixin.DescriptionAccessor, org.refcodes.mixin.EnabledAccessor, org.refcodes.mixin.Resetable, org.refcodes.mixin.TypeAccessor<Boolean>, org.refcodes.mixin.ValueAccessor<Boolean>, org.refcodes.schema.Schemable

public class NoneOperand extends AbstractOperand<Boolean> implements org.refcodes.mixin.EnabledAccessor
The NoneOperand represents an empty set of arguments, e.g. no command line argument is being passed. Usually only makes sense near the root of a Term tree (e.g. inside the main XorCondition) to test ALL arguments passed to an application and one invocation may have neither optional (as of AnyCondition) nor mandatory arguments allowed.
  • Field Details

  • Constructor Details

  • Method Details

    • isEnabled

      public boolean isEnabled()
      Determines whether none arguments have been passed.
      Specified by:
      isEnabled in interface org.refcodes.mixin.EnabledAccessor
      Returns:
      True in case none arguments have been passed.
    • parseArgs

      public Operand<?>[] parseArgs(String[] aArgs, String[] aKeywords, CliContext aCliCtx) throws ArgsSyntaxException
      Parses the given command line arguments using the provided keyword set and CLI context.

      This method represents the core parsing operation. It evaluates this Term or, if this term is an inner node, delegates parsing to its child terms.

      The aKeywords parameter defines reserved tokens such as option names that must not be interpreted as operand values.

      This method does not validate whether all arguments have been consumed. Superfluous arguments must be handled by the caller.

      Specified by:
      parseArgs in interface Term
      Overrides:
      parseArgs in class AbstractOperand<Boolean>
      Parameters:
      aArgs - The command line arguments to parse
      aKeywords - Reserved option and keyword tokens
      aCliCtx - The CliContext controlling parsing and rendering
      Returns:
      The evaluated operands
      Throws:
      ArgsSyntaxException - If the arguments do not match the syntax
    • withVisible

      public NoneOperand withVisible(boolean isVisible)

      Visibility in this context means displaying or hiding this Term's existence to the user (defaults to true).

      Specified by:
      withVisible in interface org.refcodes.graphical.VisibleAccessor.VisibleBuilder<Term>
    • toSyntax

      public String toSyntax(CliContext aCliCtx)
      Creates a syntax including its arguments.

      A specification differs from a syntax in that the specification provides the full definition not omitting any choices whereas the syntax only provides a syntactically correct variant. For example, having an option with a short option and a long option, the specification will show the short option and the long option whereas the syntax will only show either the short option or, if no short option is set, the long option.

      Specified by:
      toSyntax in interface Operand<Boolean>
      Specified by:
      toSyntax in interface Term
      Parameters:
      aCliCtx - The CLI context controlling notation and formatting
      Returns:
      The human readable command line syntax
    • toUsage

      public String toUsage(CliContext aCliCtx)
      Creates a plain usage specification without any escape codes, helpful e.g. in human readable messages.
      Specified by:
      toUsage in interface Operand<Boolean>
      Parameters:
      aCliCtx - The CliContext to use when creating a beautiful usage text.
      Returns:
      The according usage text.
    • toSpec

      public String toSpec(CliContext aCliCtx)
      Creates a specification including its arguments.

      A specification differs from a syntax in that the specification provides the full definition not omitting any choices whereas the syntax only provides a syntactically correct variant. For example, having an option with a short option and a long option, the specification will show the short option and the long option whereas the syntax will only show either the short option or, if no short option is set, the long option.

      Specified by:
      toSpec in interface Operand<Boolean>
      Parameters:
      aCliCtx - The CliContext to use when creating a beautiful specification text.
      Returns:
      The according specification text.
    • toType

      protected Boolean toType(String aArg)
      To value.
      Specified by:
      toType in class AbstractOperand<Boolean>
      Parameters:
      aArg - the arg
      Returns:
      the string
    • getDescription

      public String getDescription()
      Specified by:
      getDescription in interface org.refcodes.mixin.DescriptionAccessor
    • getException

      public ArgsSyntaxException getException()
      Retrieves the ArgsSyntaxException exception in case invoking Term.parseArgs(String[], CliContext) failed. The exception (and the according suppressed ones alongside the causes) does not necessarily have been thrown by the Term.parseArgs(String[], CliContext) method depending on the semantics of the Term handing the exception (the AnyCondition provides any exceptions it caught even though it did not throw them as of its semantics).
      Specified by:
      getException in interface org.refcodes.exception.ExceptionAccessor<ArgsSyntaxException>
      Specified by:
      getException in interface Term
      Returns:
      The ArgsSyntaxException exception occurring while parsing the arguments.
    • setVisible

      public void setVisible(boolean isVisible)

      Visibility in this context means displaying or hiding this Term's existence to the user (defaults to true).

      Specified by:
      setVisible in interface Term
      Specified by:
      setVisible in interface org.refcodes.graphical.VisibleAccessor.VisibleMutator
    • isVisible

      public boolean isVisible()

      Visibility in this context means displaying or hiding this Term's existence to the user (defaults to true).

      Specified by:
      isVisible in interface Term
      Specified by:
      isVisible in interface org.refcodes.graphical.VisibleAccessor
    • toArgsDiff

      protected static String[] toArgsDiff(String[] aArgs, List<? extends Operand<?>> aArgsSubset)
      Creates the difference between the provided set and the provided Lists therein found argument arrays subset (as of Operand.getParsedArgs()).
      Parameters:
      aArgs - The set to be used for the diff operation.
      aArgsSubset - The subset to be used for the diff operation being the lists containing the Operand instances whose command line arguments are to be diffed.
      Returns:
      The difference between the set and the subset.
    • toArgsDiff

      protected static String[] toArgsDiff(String[] aArgs, Operand<?>[] aArgsSubset)
      Creates the difference between the provided set and the provided Lists therein found argument arrays subset (as of Operand.getParsedArgs()).
      Parameters:
      aArgs - The set to be used for the diff operation.
      aArgsSubset - The subset to be used for the diff operation being the lists containing the Operand instances whose command line arguments are to be diffed.
      Returns:
      The difference between the set and the subset.
    • toArgsDiff

      protected static String[] toArgsDiff(String[] aArgs, String[] aArgsSubset)
      Creates the difference between the provided set and the provided subset.
      Parameters:
      aArgs - The set to be used for the diff operation.
      aArgsSubset - The subset to be used for the diff operation.
      Returns:
      The difference between the set and the subset.
    • toParsedArgs

      protected static String[] toParsedArgs(Operand<?>[]... aOperands)
      Takes all Operand instances found in the provided Lists and adds all therein found argument arrays (as of Operand.getParsedArgs()) to the result.
      Parameters:
      aOperands - The lists containing the Operand instances whose command line arguments are to be added to the result.
      Returns:
      All the command line arguments detected in the provided Operands Lists.