- All Implemented Interfaces:
Cloneable,Comparable<Operand<?>>,MatchCountAccessor,Operand<Boolean>,ParsedArgsAccessor,Synopsisable,Term,org.refcodes.exception.ExceptionAccessor<ArgsSyntaxException>,org.refcodes.graphical.VisibleAccessor,org.refcodes.graphical.VisibleAccessor.VisibleBuilder<Term>,org.refcodes.graphical.VisibleAccessor.VisibleMutator,org.refcodes.graphical.VisibleAccessor.VisibleProperty,org.refcodes.mixin.AliasAccessor,org.refcodes.mixin.Clonable,org.refcodes.mixin.DescriptionAccessor,org.refcodes.mixin.EnabledAccessor,org.refcodes.mixin.Resetable,org.refcodes.mixin.TypeAccessor<Boolean>,org.refcodes.mixin.ValueAccessor<Boolean>,org.refcodes.schema.Schemable
public class NoneOperand
extends AbstractOperand<Boolean>
implements org.refcodes.mixin.EnabledAccessor
The
NoneOperand represents an empty set of arguments, e.g. no command
line argument is being passed. Usually only makes sense near the root of a
Term tree (e.g. inside the main XorCondition) to test ALL
arguments passed to an application and one invocation may have neither
optional (as of AnyCondition) nor mandatory arguments allowed.-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.mixin.AliasAccessor
org.refcodes.mixin.AliasAccessor.AliasBuilder<B extends org.refcodes.mixin.AliasAccessor.AliasBuilder<B>>, org.refcodes.mixin.AliasAccessor.AliasMutator, org.refcodes.mixin.AliasAccessor.AliasPropertyNested classes/interfaces inherited from interface org.refcodes.mixin.DescriptionAccessor
org.refcodes.mixin.DescriptionAccessor.DescriptionBuilder<B extends org.refcodes.mixin.DescriptionAccessor.DescriptionBuilder<B>>, org.refcodes.mixin.DescriptionAccessor.DescriptionMutator, org.refcodes.mixin.DescriptionAccessor.DescriptionPropertyNested classes/interfaces inherited from interface org.refcodes.mixin.EnabledAccessor
org.refcodes.mixin.EnabledAccessor.EnabledBuilder<B extends org.refcodes.mixin.EnabledAccessor.EnabledBuilder<B>>, org.refcodes.mixin.EnabledAccessor.EnabledMutator, org.refcodes.mixin.EnabledAccessor.EnabledPropertyNested classes/interfaces inherited from interface org.refcodes.exception.ExceptionAccessor
org.refcodes.exception.ExceptionAccessor.ExceptionBuilder<EXC extends Throwable,B extends org.refcodes.exception.ExceptionAccessor.ExceptionBuilder<EXC, B>>, org.refcodes.exception.ExceptionAccessor.ExceptionMutator<EXC extends Throwable>, org.refcodes.exception.ExceptionAccessor.ExceptionProperty<EXC extends Throwable> Nested classes/interfaces inherited from interface org.refcodes.cli.MatchCountAccessor
MatchCountAccessor.MatchCountBuilder<B extends MatchCountAccessor.MatchCountBuilder<B>>, MatchCountAccessor.MatchCountMutator, MatchCountAccessor.MatchCountPropertyNested classes/interfaces inherited from interface org.refcodes.cli.ParsedArgsAccessor
ParsedArgsAccessor.ParsedArgsMutator, ParsedArgsAccessor.ParsedArgsPropertyNested classes/interfaces inherited from interface org.refcodes.mixin.TypeAccessor
org.refcodes.mixin.TypeAccessor.TypeBuilder<T,B extends org.refcodes.mixin.TypeAccessor.TypeBuilder<T, B>>, org.refcodes.mixin.TypeAccessor.TypeMutator<T>, org.refcodes.mixin.TypeAccessor.TypeProperty<T> Nested classes/interfaces inherited from interface org.refcodes.mixin.ValueAccessor
org.refcodes.mixin.ValueAccessor.ValueBuilder<V,B extends org.refcodes.mixin.ValueAccessor.ValueBuilder<V, B>>, org.refcodes.mixin.ValueAccessor.ValueMutator<V>, org.refcodes.mixin.ValueAccessor.ValueProperty<V> Nested classes/interfaces inherited from interface org.refcodes.graphical.VisibleAccessor
org.refcodes.graphical.VisibleAccessor.VisibleBuilder<B extends org.refcodes.graphical.VisibleAccessor.VisibleBuilder<B>>, org.refcodes.graphical.VisibleAccessor.VisibleMutator, org.refcodes.graphical.VisibleAccessor.VisibleProperty -
Field Summary
FieldsModifier and TypeFieldDescriptionprotected Stringprotected ArgsSyntaxExceptionprotected booleanstatic final StringFields inherited from class org.refcodes.cli.AbstractOperand
_matchCount -
Constructor Summary
ConstructorsConstructorDescriptionNoneOperand(String aDescription) Instantiates a newNoneOperand.NoneOperand(String aAlias, String aDescription) Instantiates a newNoneOperand.NoneOperand(String aAlias, String aDescription, Consumer<NoneOperand> aConsumer) Instantiates a newNoneOperand.NoneOperand(String aDescription, Consumer<NoneOperand> aConsumer) Instantiates a newNoneOperand.NoneOperand(org.refcodes.struct.Relation<String, Boolean> aProperty) Instantiates a newNoneOperand.NoneOperand(org.refcodes.struct.Relation<String, Boolean> aProperty, Consumer<NoneOperand> aConsumer) Instantiates a newNoneOperand. -
Method Summary
Modifier and TypeMethodDescriptionRetrieves theArgsSyntaxExceptionexception in case invokingTerm.parseArgs(String[], CliContext)failed.booleanDetermines whether none arguments have been passed.booleanVisibility in this context means displaying or hiding thisTerm's existence to the user (defaults totrue).Operand<?>[]parseArgs(String[] aArgs, String[] aOptions, CliContext aCliContext) Parses the provided command line arguments and determines the according values by evaluating thisTerminstance or, in case of being a node in the syntax tree (such as aCondition, traversing the childTerminstances'Term.parseArgs(String[], String[], CliContext)methods.voidsetVisible(boolean isVisible) Visibility in this context means displaying or hiding thisTerm's existence to the user (defaults totrue).protected static String[]toArgsDiff(String[] aArgs, String[] aArgsSubset) Creates the difference between the provided set and the provided subset.protected static String[]toArgsDiff(String[] aArgs, List<? extends Operand<?>> aArgsSubset) Creates the difference between the provided set and the providedLists therein found argument arrays subset (as ofOperand.getParsedArgs()).protected static String[]toArgsDiff(String[] aArgs, Operand<?>[] aArgsSubset) Creates the difference between the provided set and the providedLists therein found argument arrays subset (as ofOperand.getParsedArgs()).protected static String[]toParsedArgs(Operand<?>[]... aOperands) Takes allOperandinstances found in the providedLists and adds all therein found argument arrays (as ofOperand.getParsedArgs()) to the result.toSyntax(CliContext aCliCtx) This method is to be called from inside theTermhierarchy; use the methodSynopsisable.toSynopsis(SyntaxNotation)in case you invoke syntax retrieval from the rootTerm.protected BooleanTo value.withVisible(boolean isVisible) Visibility in this context means displaying or hiding thisTerm's existence to the user (defaults totrue).Methods inherited from class org.refcodes.cli.AbstractOperand
approve, clone, compareTo, getAlias, getMatchCount, getParsedArgs, getType, getValue, reset, setParsedArgs, setValue, toSchema, toStringMethods inherited from class java.lang.Object
equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface org.refcodes.mixin.DescriptionAccessor
getDescriptionMethods inherited from interface org.refcodes.cli.Operand
hasValue, toSpec, toSpec, toUsage, toUsage, toValueMethods inherited from interface org.refcodes.cli.Synopsisable
toSynopsis, toSynopsis, toSynopsis, toSynopsisMethods inherited from interface org.refcodes.cli.Term
getException, isVisible, parseArgs, setVisible, toSynopsis, toSyntax, toSyntax, toSyntax, toSyntaxMethods inherited from interface org.refcodes.mixin.ValueAccessor
getValueOrMethods inherited from interface org.refcodes.graphical.VisibleAccessor.VisibleBuilder
withHide, withShowMethods inherited from interface org.refcodes.graphical.VisibleAccessor.VisibleMutator
hide, showMethods inherited from interface org.refcodes.graphical.VisibleAccessor.VisibleProperty
letVisible
-
Field Details
-
ALIAS
- See Also:
-
_description
-
_exception
-
_isVisible
protected boolean _isVisible
-
-
Constructor Details
-
NoneOperand
Instantiates a newNoneOperand.- Parameters:
aProperty- The key (= alias) and the value for the operand.
-
NoneOperand
Instantiates a newNoneOperand.- Parameters:
aDescription- The description to be used (without any line breaks).
-
NoneOperand
Instantiates a newNoneOperand.- Parameters:
aAlias- The identifier to be used when printing the syntax via thetoSyntax(CliContext)method.aDescription- The description to be used (without any line breaks).
-
NoneOperand
public NoneOperand(org.refcodes.struct.Relation<String, Boolean> aProperty, Consumer<NoneOperand> aConsumer) Instantiates a newNoneOperand.- Parameters:
aProperty- The key (= alias) and the value for the operand.aConsumer- TheConsumerbeing invoked in case thisNoneOperandparticipated in successfully parsing the command line arguments.
-
NoneOperand
Instantiates a newNoneOperand.- Parameters:
aDescription- The description to be used (without any line breaks).aConsumer- TheConsumerbeing invoked in case thisNoneOperandparticipated in successfully parsing the command line arguments.
-
NoneOperand
Instantiates a newNoneOperand.- Parameters:
aAlias- The identifier to be used when printing the syntax via thetoSyntax(CliContext)method.aDescription- The description to be used (without any line breaks).aConsumer- TheConsumerbeing invoked in case thisNoneOperandparticipated in successfully parsing the command line arguments.
-
-
Method Details
-
isEnabled
public boolean isEnabled()Determines whether none arguments have been passed.- Specified by:
isEnabledin interfaceorg.refcodes.mixin.EnabledAccessor- Returns:
- True in case none arguments have been passed.
-
parseArgs
public Operand<?>[] parseArgs(String[] aArgs, String[] aOptions, CliContext aCliContext) throws ArgsSyntaxException Parses the provided command line arguments and determines the according values by evaluating thisTerminstance or, in case of being a node in the syntax tree (such as aCondition, traversing the childTerminstances'Term.parseArgs(String[], String[], CliContext)methods. In case of successfully parsing thisTermand / or the childTerminstances, the evaluated command line arguments are returned: Depending on theTermsubclasses representing the evaluated command line arguments, instances ofFlagclasses,Optionclasses orOperandclasses may be found in the result. In case of parsing failure, an according exception is thrown. ATTENTION: This method does not test for superfluous command line arguments being passed; e.g. command line arguments not being evaluated by any of theTerminstance being traversed. This method is commonly used by a rootTerm'sParseArgs.evalArgs(String[])method, which delegates to theTerm.parseArgs(String[], String[], CliContext)method and after which it determines whether there are superfluous arguments to be taken care of (by throwing an according exception). Business logic therefore should invoke the root node'sTerm.parseArgs(String[], String[], CliContext)method as ignoring superfluous command line arguments will aCause unexpected behavior from the point of view of the invoker.- Specified by:
parseArgsin interfaceTerm- Overrides:
parseArgsin classAbstractOperand<Boolean>- Parameters:
aArgs- The command line arguments to be parsed.aOptions- The list of options (short and as well as long) which are reserved and cannot be used as value.aCliContext- the cli context- Returns:
- The list of evaluated command line arguments being instances of
the
Operandinterfaces or its sub-types. - Throws:
ArgsSyntaxException- thrown in case of a command line arguments mismatch regarding provided and expected args.
-
toSyntax
This method is to be called from inside theTermhierarchy; use the methodSynopsisable.toSynopsis(SyntaxNotation)in case you invoke syntax retrieval from the rootTerm. Returns the human readable (verbose) syntax of thisTerminstance including, in case of being a node in the syntax tree (such as aCondition, the syntax of the childTerminstances. ATTENTION: As of different parenthesis settings for some notations regarding the rootTermand the childTerms, the methodTerm.toSyntax(CliContext)is called from inside theTermhierarchy. In case the syntax is to be retrieved from the rootTerm, then the applicable method to be called isSynopsisable.toSynopsis(SyntaxNotation), as for some notations it will for example not create the most outer braces.- Specified by:
toSyntaxin interfaceTerm- Overrides:
toSyntaxin classAbstractOperand<Boolean>- Parameters:
aCliCtx- TheCliContextfor which the syntax is being generated.- Returns:
- The human readable (verbose) command line arguments syntax.
-
withVisible
-
toType
To value.- Specified by:
toTypein classAbstractOperand<Boolean>- Parameters:
aArg- the arg- Returns:
- the string
-
getDescription
- Specified by:
getDescriptionin interfaceorg.refcodes.mixin.DescriptionAccessor
-
getException
Retrieves theArgsSyntaxExceptionexception in case invokingTerm.parseArgs(String[], CliContext)failed. The exception (and the according suppressed ones alongside the causes) does not necessarily have been thrown by theTerm.parseArgs(String[], CliContext)method depending on the semantics of theTermhanding the exception (theAnyConditionprovides any exceptions it caught even though it did not throw them as of its semantics).- Specified by:
getExceptionin interfaceorg.refcodes.exception.ExceptionAccessor<ArgsSyntaxException>- Specified by:
getExceptionin interfaceTerm- Returns:
- The
ArgsSyntaxExceptionexception occurring while parsing the arguments.
-
setVisible
public void setVisible(boolean isVisible) Visibility in this context means displaying or hiding thisTerm's existence to the user (defaults totrue).- Specified by:
setVisiblein interfaceTerm- Specified by:
setVisiblein interfaceorg.refcodes.graphical.VisibleAccessor.VisibleMutator
-
isVisible
-
toArgsDiff
Creates the difference between the provided set and the providedLists therein found argument arrays subset (as ofOperand.getParsedArgs()).- Parameters:
aArgs- The set to be used for the diff operation.aArgsSubset- The subset to be used for the diff operation being the lists containing theOperandinstances whose command line arguments are to be diffed.- Returns:
- The difference between the set and the subset.
-
toArgsDiff
Creates the difference between the provided set and the providedLists therein found argument arrays subset (as ofOperand.getParsedArgs()).- Parameters:
aArgs- The set to be used for the diff operation.aArgsSubset- The subset to be used for the diff operation being the lists containing theOperandinstances whose command line arguments are to be diffed.- Returns:
- The difference between the set and the subset.
-
toArgsDiff
Creates the difference between the provided set and the provided subset.- Parameters:
aArgs- The set to be used for the diff operation.aArgsSubset- The subset to be used for the diff operation.- Returns:
- The difference between the set and the subset.
-
toParsedArgs
Takes allOperandinstances found in the providedLists and adds all therein found argument arrays (as ofOperand.getParsedArgs()) to the result.
-