- All Implemented Interfaces:
Cloneable,Comparable<Operand<?>>,ArgsAccessor,Operand<Boolean>,Synopsisable,Syntaxable,org.refcodes.mixin.AliasAccessor,org.refcodes.mixin.Clonable,org.refcodes.mixin.DescriptionAccessor,org.refcodes.mixin.EnabledAccessor,org.refcodes.mixin.Resetable,org.refcodes.mixin.Schemable<CliSchema>,org.refcodes.mixin.TypeAccessor<Boolean>,org.refcodes.mixin.ValueAccessor<Boolean>
public class NoneOperand
extends AbstractOperand<Boolean>
implements Operand<Boolean>, org.refcodes.mixin.EnabledAccessor
The
NoneOperand represents an empty set of arguments, e.g. no command
line argument is being passed. Usually only makes sense near the root of a
Syntaxable tree (e.g. inside the main XorCondition) to test
ALL arguments passed to an application and one invocation may have neither
optional (as of AnyCondition) nor mandatory arguments allowed.-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.mixin.AliasAccessor
org.refcodes.mixin.AliasAccessor.AliasBuilder<B extends org.refcodes.mixin.AliasAccessor.AliasBuilder<B>>, org.refcodes.mixin.AliasAccessor.AliasMutator, org.refcodes.mixin.AliasAccessor.AliasPropertyNested classes/interfaces inherited from interface org.refcodes.cli.ArgsAccessor
ArgsAccessor.ArgsMutator, ArgsAccessor.ArgsPropertyNested classes/interfaces inherited from interface org.refcodes.mixin.DescriptionAccessor
org.refcodes.mixin.DescriptionAccessor.DescriptionBuilder<B extends org.refcodes.mixin.DescriptionAccessor.DescriptionBuilder<B>>, org.refcodes.mixin.DescriptionAccessor.DescriptionMutator, org.refcodes.mixin.DescriptionAccessor.DescriptionPropertyNested classes/interfaces inherited from interface org.refcodes.mixin.EnabledAccessor
org.refcodes.mixin.EnabledAccessor.EnabledBuilder<B extends org.refcodes.mixin.EnabledAccessor.EnabledBuilder<B>>, org.refcodes.mixin.EnabledAccessor.EnabledMutator, org.refcodes.mixin.EnabledAccessor.EnabledPropertyNested classes/interfaces inherited from interface org.refcodes.mixin.TypeAccessor
org.refcodes.mixin.TypeAccessor.TypeBuilder<T extends Object,B extends org.refcodes.mixin.TypeAccessor.TypeBuilder<T, B>>, org.refcodes.mixin.TypeAccessor.TypeMutator<T extends Object>, org.refcodes.mixin.TypeAccessor.TypeProperty<T extends Object> Nested classes/interfaces inherited from interface org.refcodes.mixin.ValueAccessor
org.refcodes.mixin.ValueAccessor.ValueBuilder<V extends Object,B extends org.refcodes.mixin.ValueAccessor.ValueBuilder<V, B>>, org.refcodes.mixin.ValueAccessor.ValueMutator<V extends Object>, org.refcodes.mixin.ValueAccessor.ValueProperty<V extends Object> -
Field Summary
Fields inherited from class org.refcodes.cli.AbstractOperand
_value -
Constructor Summary
ConstructorsConstructorDescriptionNoneOperand(String aDescription) Instantiates a newNoneOperand.NoneOperand(String aAlias, String aDescription) Instantiates a newNoneOperand.NoneOperand(org.refcodes.struct.Relation<String, Boolean> aProperty) Instantiates a newNoneOperand. -
Method Summary
Modifier and TypeMethodDescriptionbooleanDetermines whether none arguments have been passed.Parses the provided command line arguments and determines the according values by evaluating thisSyntaxableinstance or, in case of being a node in the syntax tree (such as aArgsSyntax, traversing the childSyntaxableinstances'Syntaxable.parseArgs(String[], String[])methods.toState()TheSyntaxable.toState()method might be used by theObject.toString()method and prints out the state of the syntaxable and (if any) its children.toSynopsis(SyntaxNotation aSyntaxNotation, String aOptEscCode, String aParamEscCode, String aResetEscCode) Returns the human readable (verbose) syntax of implementing class ATTENTION: As of different parenthesis settings for some notations regarding the rootSyntaxableand the childSyntaxables, the methodSyntaxable.toSyntax(SyntaxNotation, String, String, String)is called from inside aSyntaxablehierarchy.toSyntax(SyntaxNotation aSyntaxNotation, String aOptEscCode, String aParamEscCode, String aResetEscCode) This method is to be called from inside theSyntaxablehierarchy; use the methodSynopsisable.toSynopsis(SyntaxNotation)in case you invoke syntax retrieval from the rootSyntaxable.protected BooleanTo value.Methods inherited from class org.refcodes.cli.AbstractOperand
clone, compareTo, getAlias, getArgs, getDescription, getType, getValue, reset, setArgs, setValue, toSchema, toStringMethods inherited from class java.lang.Object
equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface org.refcodes.mixin.Clonable
cloneMethods inherited from interface java.lang.Comparable
compareToMethods inherited from interface org.refcodes.mixin.DescriptionAccessor
getDescriptionMethods inherited from interface org.refcodes.cli.Operand
getAlias, getArgs, getValue, hasValue, toValueMethods inherited from interface org.refcodes.mixin.Resetable
resetMethods inherited from interface org.refcodes.mixin.Schemable
toSchemaMethods inherited from interface org.refcodes.cli.Synopsisable
toSynopsis, toSynopsis, toSynopsis, toSynopsisMethods inherited from interface org.refcodes.cli.Syntaxable
parseArgs, toSyntax, toSyntax, toSyntaxMethods inherited from interface org.refcodes.mixin.TypeAccessor
getTypeMethods inherited from interface org.refcodes.mixin.ValueAccessor
getValueOr
-
Constructor Details
-
NoneOperand
Instantiates a newNoneOperand.- Parameters:
aDescription- A description without any line breaks.
-
NoneOperand
Instantiates a newNoneOperand.- Parameters:
aAlias- The identifier to be used when printing the syntax via thetoSyntax(SyntaxNotation, String, String, String)method.aDescription- A description without any line breaks.
-
NoneOperand
Instantiates a newNoneOperand.- Parameters:
aProperty- The key (= alias) and the value for the operand.
-
-
Method Details
-
parseArgs
public List<Operand<Boolean>> parseArgs(String[] aArgs, String[] aOptions) throws ArgsSyntaxException Parses the provided command line arguments and determines the according values by evaluating thisSyntaxableinstance or, in case of being a node in the syntax tree (such as aArgsSyntax, traversing the childSyntaxableinstances'Syntaxable.parseArgs(String[], String[])methods. In case of successfully parsing thisSyntaxableand / or the childSyntaxableinstances, the evaluated command line arguments are returned: Depending on theSyntaxablesubclasses representing the evaluated command line arguments, instances ofFlagclasses,Optionclasses orOperandclasses may be found in the result. In case of parsing failure, an according exception is thrown. ATTENTION: This method does not test for superfluous command line arguments being passed; e.g. command line arguments not being evaluated by any of theSyntaxableinstance being traversed. This method is commonly used by a rootSyntaxable'sArgsParser.evalArgs(String[])method, which delegates to theSyntaxable.parseArgs(String[], String[])method and after which it determines whether there are superfluous arguments to be taken care of (by throwing an according exception). Business logic therefore should invoke the root node'sSyntaxable.parseArgs(String[], String[])method as ignoring superfluous command line arguments will cause unexpected behavior from the point of view of the invoker.- Specified by:
parseArgsin interfaceSyntaxable- Overrides:
parseArgsin classAbstractOperand<Boolean>- Parameters:
aArgs- The command line arguments to be parsed.aOptions- The list of options (short and as well as long) which are reserved and cannot be used as value.- Returns:
- The list of evaluated command line arguments being instances of
the
Operandinterfaces or its sub-types. - Throws:
ArgsSyntaxException- thrown in case of a command line arguments mismatch regarding provided and expected args.
-
toSyntax
public String toSyntax(SyntaxNotation aSyntaxNotation, String aOptEscCode, String aParamEscCode, String aResetEscCode) This method is to be called from inside theSyntaxablehierarchy; use the methodSynopsisable.toSynopsis(SyntaxNotation)in case you invoke syntax retrieval from the rootSyntaxable. Returns the human readable (verbose) syntax of thisSyntaxableinstance including, in case of being a node in the syntax tree (such as aArgsSyntax, the syntax of the childSyntaxableinstances. ATTENTION: As of different parenthesis settings for some notations regarding the rootSyntaxableand the childSyntaxables, the methodSyntaxable.toSyntax(SyntaxNotation, String, String, String)is called from inside theSyntaxablehierarchy. In case the syntax is to be retrieved from the rootSyntaxable, then the applicable method to be called isSynopsisable.toSynopsis(SyntaxNotation), as for some notations it will for example not create the most outer braces.- Specified by:
toSyntaxin interfaceSyntaxable- Overrides:
toSyntaxin classAbstractOperand<Boolean>- Parameters:
aSyntaxNotation- The syntax notation used for generating the command line arguments syntax.aOptEscCode- The escape code to be used when processing an option, e.g. this can be an ANSI Escape-Code to highlight the option.aParamEscCode- The escape code to be used when processing a keyword, e.g. this can be an ANSI Escape-Code to highlight the option and/or parameters.aResetEscCode- The escape code to close (reset) any Escape-Code being set before.- Returns:
- The human readable (verbose) command line arguments syntax.
-
toState
TheSyntaxable.toState()method might be used by theObject.toString()method and prints out the state of the syntaxable and (if any) its children. Even in case parsing command line arguments failed, the state till failure can be inspected with this method.- Specified by:
toStatein interfaceSyntaxable- Overrides:
toStatein classAbstractOperand<Boolean>- Returns:
- The state of this
Syntaxableinstance and (if any) its children.
-
isEnabled
public boolean isEnabled()Determines whether none arguments have been passed.- Specified by:
isEnabledin interfaceorg.refcodes.mixin.EnabledAccessor- Returns:
- True in case none arguments have been passed.
-
toType
To value.- Specified by:
toTypein classAbstractOperand<Boolean>- Parameters:
aArg- the arg- Returns:
- the string
-
toSynopsis
public String toSynopsis(SyntaxNotation aSyntaxNotation, String aOptEscCode, String aParamEscCode, String aResetEscCode) Returns the human readable (verbose) syntax of implementing class ATTENTION: As of different parenthesis settings for some notations regarding the rootSyntaxableand the childSyntaxables, the methodSyntaxable.toSyntax(SyntaxNotation, String, String, String)is called from inside aSyntaxablehierarchy. In case the syntax is to be retrieved from the rootSyntaxableor an encapsulating and different type, then the applicable method to be called isSynopsisable.toSynopsis(SyntaxNotation), as for some notations it will for example not create the most outer braces.- Specified by:
toSynopsisin interfaceSynopsisable- Parameters:
aSyntaxNotation- The syntax notation used for generating the command line arguments syntax.aOptEscCode- The escape code to be used when processing an option, e.g. this can be an ANSI Escape-Code to highlight the option.aParamEscCode- The escape code to be used when processing am argument, e.g. this can be an ANSI Escape-Code to highlight the option.aResetEscCode- The escape code to close (reset) any Escape-Code being set before.- Returns:
- The human readable (verbose) command line arguments syntax.
-