Interface Operand<T>

Type Parameters:
T - The generic type of the Operand's value.
All Superinterfaces:
org.refcodes.mixin.AliasAccessor, org.refcodes.mixin.Clonable, Cloneable, Comparable<Operand<?>>, org.refcodes.mixin.DescriptionAccessor, org.refcodes.exception.ExceptionAccessor<ArgsSyntaxException>, MatchCountAccessor, ParsedArgsAccessor, org.refcodes.mixin.Resetable, org.refcodes.schema.Schemable, Synopsisable, Term, org.refcodes.mixin.TypeAccessor<T>, org.refcodes.mixin.ValueAccessor<T>, org.refcodes.graphical.VisibleAccessor, org.refcodes.graphical.VisibleAccessor.VisibleBuilder<Term>, org.refcodes.graphical.VisibleAccessor.VisibleMutator, org.refcodes.graphical.VisibleAccessor.VisibleProperty
All Known Subinterfaces:
Option<T>, PropertyOption<T>
All Known Implementing Classes:
AbstractOperand, AbstractOption, AbstractPropertyOption, ArrayOperand, ArrayOption, BooleanOption, BooleanProperty, CharOption, CharProperty, CleanFlag, ConfigOption, ConfigProperty, DaemonFlag, DebugFlag, DoubleOption, DoubleProperty, EnumOption, EnumProperty, FileOption, FileProperty, Flag, FloatOption, FloatProperty, ForceFlag, HelpFlag, InitFlag, IntOption, IntProperty, LongOption, LongProperty, NoneOperand, Operation, QuietFlag, StringOperand, StringOption, StringProperty, SysInfoFlag, VerboseFlag

public interface Operand<T> extends Term, org.refcodes.mixin.ValueAccessor<T>, org.refcodes.mixin.TypeAccessor<T>, ParsedArgsAccessor, Comparable<Operand<?>>, org.refcodes.mixin.AliasAccessor, Cloneable, org.refcodes.mixin.Clonable
An Operand represents a value parsed from command line arguments. In comparison to an Option an Operand just represents a plain value without an identifier in front of it. An Operand has a state which changes with each invocation of the Term.parseArgs(String[], String[], CliContext) method.

It is recommended to put your Operand instance(s) at the end of your top Condition to enforce it to be the last Term(s) when parsing the command line arguments - this makes sure that any Options pick their option arguments so that the Operand(s) will correctly be left over for parsing command line argument(s); the Operand will not pick by mistake an option argument.