Class Operation

java.lang.Object
org.refcodes.cli.AbstractOperand<Boolean>
org.refcodes.cli.Operation
All Implemented Interfaces:
Cloneable, Comparable<Operand<?>>, MatchCountAccessor, Operand<Boolean>, ParsedArgsAccessor, Synopsisable, Term, org.refcodes.exception.ExceptionAccessor<ArgsSyntaxException>, org.refcodes.graphical.VisibleAccessor, org.refcodes.graphical.VisibleAccessor.VisibleBuilder<Term>, org.refcodes.graphical.VisibleAccessor.VisibleMutator, org.refcodes.graphical.VisibleAccessor.VisibleProperty, org.refcodes.mixin.AliasAccessor, org.refcodes.mixin.Clonable, org.refcodes.mixin.DescriptionAccessor, org.refcodes.mixin.EnabledAccessor, org.refcodes.mixin.Resetable, org.refcodes.mixin.TypeAccessor<Boolean>, org.refcodes.mixin.ValueAccessor<Boolean>, org.refcodes.schema.Schemable

public class Operation extends AbstractOperand<Boolean> implements org.refcodes.mixin.EnabledAccessor
The Operation is an argument representing a function or a method ("command") and is either provided or not provided as of isEnabled(). It must neither be prefixed with "-" nor with "--" in contrast to the Option or the Flag type.