Interface Option<T>

Type Parameters:
T - The generic type of the Option's value.
All Superinterfaces:
org.refcodes.mixin.AliasAccessor, org.refcodes.mixin.Clonable, Cloneable, Comparable<Operand<?>>, org.refcodes.mixin.DescriptionAccessor, org.refcodes.exception.ExceptionAccessor<ArgsSyntaxException>, MatchCountAccessor, Operand<T>, ParsedArgsAccessor, org.refcodes.mixin.Resetable, org.refcodes.schema.Schemable, Synopsisable, Term, org.refcodes.mixin.TypeAccessor<T>, org.refcodes.mixin.ValueAccessor<T>, org.refcodes.graphical.VisibleAccessor, org.refcodes.graphical.VisibleAccessor.VisibleBuilder<Term>, org.refcodes.graphical.VisibleAccessor.VisibleMutator, org.refcodes.graphical.VisibleAccessor.VisibleProperty
All Known Subinterfaces:
PropertyOption<T>
All Known Implementing Classes:
AbstractOption, AbstractPropertyOption, ArrayOption, BooleanOption, BooleanProperty, CharOption, CharProperty, CleanFlag, ConfigOption, ConfigProperty, DaemonFlag, DebugFlag, DoubleOption, DoubleProperty, EnumOption, EnumProperty, FileOption, FileProperty, Flag, FloatOption, FloatProperty, ForceFlag, HelpFlag, InitFlag, IntOption, IntProperty, LongOption, LongProperty, QuietFlag, StringOption, StringProperty, SysInfoFlag, VerboseFlag

public interface Option<T> extends Operand<T>
An Option represents a command line option with the according option's value. An Option can be seen as a key/value(s) pair usually represented by two succeeding arguments (e.g. "--file simeFile". An Option has a state which changes with each invocation of the Term.parseArgs(String[], String[], CliContext) method.