java.lang.Object
java.lang.Throwable
java.lang.Exception
org.refcodes.exception.AbstractException
org.refcodes.cli.CliException
org.refcodes.cli.CliException.ConsoleArgsException
org.refcodes.cli.ArgsSyntaxException
org.refcodes.cli.ParseArgsException
- All Implemented Interfaces:
Serializable,ArgsAccessor,MatchCountAccessor,org.refcodes.exception.ErrorCodeAccessor,org.refcodes.exception.Trap,org.refcodes.mixin.SourceAccessor<Term>
Thrown in case the provided command line arguments do not respect the
required semantics or cannot be converted to the required type.
- See Also:
-
Nested Class Summary
Nested classes/interfaces inherited from class org.refcodes.cli.CliException
CliException.ConsoleArgsException, CliException.ConsoleCliExceptionNested classes/interfaces inherited from interface org.refcodes.cli.ArgsAccessor
ArgsAccessor.ArgsMutator, ArgsAccessor.ArgsPropertyNested classes/interfaces inherited from interface org.refcodes.exception.ErrorCodeAccessor
org.refcodes.exception.ErrorCodeAccessor.ErrorCodeBuilder<B extends org.refcodes.exception.ErrorCodeAccessor.ErrorCodeBuilder<B>>, org.refcodes.exception.ErrorCodeAccessor.ErrorCodeMutator, org.refcodes.exception.ErrorCodeAccessor.ErrorCodePropertyNested classes/interfaces inherited from interface org.refcodes.cli.MatchCountAccessor
MatchCountAccessor.MatchCountBuilder<B extends MatchCountAccessor.MatchCountBuilder<B>>, MatchCountAccessor.MatchCountMutator, MatchCountAccessor.MatchCountProperty -
Constructor Summary
ConstructorsConstructorDescriptionParseArgsException(String[] aArgs, String aMessage) Instantiates a newParseArgsExceptionexception.ParseArgsException(String[] aArgs, String aMessage, String aErrorCode) Instantiates a newParseArgsExceptionexception.ParseArgsException(String[] aArgs, String aMessage, String aErrorCode, Term aSource) Instantiates a newParseArgsExceptionexception.ParseArgsException(String[] aArgs, String aMessage, Throwable aCause) Instantiates a newParseArgsExceptionexception.ParseArgsException(String[] aArgs, String aMessage, Throwable aCause, String aErrorCode) Instantiates a newParseArgsExceptionexception.ParseArgsException(String[] aArgs, String aMessage, Throwable aCause, String aErrorCode, Term aSource) Instantiates a newParseArgsExceptionexception.ParseArgsException(String[] aArgs, String aMessage, Throwable aCause, Term aSource) Instantiates a newParseArgsExceptionexception.ParseArgsException(String[] aArgs, String aMessage, Term aSource) Instantiates a newParseArgsExceptionexception.ParseArgsException(String[] aArgs, Throwable aCause) Instantiates a newParseArgsExceptionexception.ParseArgsException(String[] aArgs, Throwable aCause, String aErrorCode) Instantiates a newParseArgsExceptionexception.ParseArgsException(String[] aArgs, Throwable aCause, String aErrorCode, Term aSource) Instantiates a newParseArgsExceptionexception.ParseArgsException(String[] aArgs, Throwable aCause, Term aSource) Instantiates a newParseArgsExceptionexception. -
Method Summary
Methods inherited from class org.refcodes.cli.ArgsSyntaxException
getMatchCount, getSource, toHeuristicMessage, toRootMatchCauseMethods inherited from class org.refcodes.cli.CliException.ConsoleArgsException
getArgsMethods inherited from class org.refcodes.exception.AbstractException
getErrorCodeMethods inherited from class java.lang.Throwable
addSuppressed, fillInStackTrace, getCause, getLocalizedMessage, getMessage, getStackTrace, getSuppressed, initCause, printStackTrace, printStackTrace, printStackTrace, setStackTrace, toStringMethods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface org.refcodes.exception.Trap
toLocalizedMessage, toMessage, toShortLocalizedMessage, toShortMessage
-
Constructor Details
-
ParseArgsException
Instantiates a newParseArgsExceptionexception.- Parameters:
aArgs- The arguments participating in the exception.aMessage- The aMessage describing this exception.aSource- TheTermresponsible for this exception (source).
-
ParseArgsException
Instantiates a newParseArgsExceptionexception.- Parameters:
aArgs- The arguments participating in the exception.aMessage- The aMessage describing this exception.aErrorCode- The error code identifying this exception.aSource- TheTermresponsible for this exception (source).
-
ParseArgsException
Instantiates a newParseArgsExceptionexception. -
ParseArgsException
public ParseArgsException(String[] aArgs, String aMessage, Throwable aCause, String aErrorCode, Term aSource) Instantiates a newParseArgsExceptionexception. -
ParseArgsException
Instantiates a newParseArgsExceptionexception. -
ParseArgsException
Instantiates a newParseArgsExceptionexception. -
ParseArgsException
Instantiates a newParseArgsExceptionexception.- Parameters:
aArgs- The arguments participating in the exception.aMessage- The aMessage describing this exception.
-
ParseArgsException
Instantiates a newParseArgsExceptionexception.- Parameters:
aArgs- The arguments participating in the exception.aMessage- The aMessage describing this exception.aErrorCode- The error code identifying this exception.
-
ParseArgsException
Instantiates a newParseArgsExceptionexception. -
ParseArgsException
Instantiates a newParseArgsExceptionexception. -
ParseArgsException
Instantiates a newParseArgsExceptionexception. -
ParseArgsException
Instantiates a newParseArgsExceptionexception.
-