Class ParseArgsException

All Implemented Interfaces:
Serializable, ArgsAccessor, MatchCountAccessor, org.refcodes.exception.ErrorCodeAccessor, org.refcodes.exception.Trap, org.refcodes.mixin.SourceAccessor<Term>
Direct Known Subclasses:
ParseDirectiveArgsException, ParseOptionArgsException

public class ParseArgsException extends ArgsSyntaxException
Thrown in case the provided command line arguments do not respect the required semantics or cannot be converted to the required type.
See Also: