Class ParseArgsException
java.lang.Object
java.lang.Throwable
java.lang.Exception
org.refcodes.exception.AbstractException
org.refcodes.cli.CliException
org.refcodes.cli.CliException.CliArgsException
org.refcodes.cli.ArgsSyntaxException
org.refcodes.cli.ParseArgsException
- All Implemented Interfaces:
Serializable,ArgsAccessor,MatchCountAccessor,org.refcodes.exception.ErrorCodeAccessor,org.refcodes.exception.Trap,org.refcodes.mixin.SourceAccessor<Term>
- Direct Known Subclasses:
ParseDirectiveArgsException,ParseOptionArgsException
Thrown in case the provided command line arguments do not respect the
required semantics or cannot be converted to the required type.
- See Also:
-
Nested Class Summary
Nested classes/interfaces inherited from class org.refcodes.cli.CliException
CliException.CliArgsExceptionNested classes/interfaces inherited from interface org.refcodes.cli.ArgsAccessor
ArgsAccessor.ArgsMutator, ArgsAccessor.ArgsPropertyNested classes/interfaces inherited from interface org.refcodes.exception.ErrorCodeAccessor
org.refcodes.exception.ErrorCodeAccessor.ErrorCodeBuilder<B extends org.refcodes.exception.ErrorCodeAccessor.ErrorCodeBuilder<B>>, org.refcodes.exception.ErrorCodeAccessor.ErrorCodeMutator, org.refcodes.exception.ErrorCodeAccessor.ErrorCodePropertyNested classes/interfaces inherited from interface org.refcodes.cli.MatchCountAccessor
MatchCountAccessor.MatchCountBuilder<B extends MatchCountAccessor.MatchCountBuilder<B>>, MatchCountAccessor.MatchCountMutator, MatchCountAccessor.MatchCountPropertyNested classes/interfaces inherited from interface org.refcodes.mixin.SourceAccessor
org.refcodes.mixin.SourceAccessor.SourceBuilder<SRC,B extends org.refcodes.mixin.SourceAccessor.SourceBuilder<SRC, B>>, org.refcodes.mixin.SourceAccessor.SourceMutator<SRC>, org.refcodes.mixin.SourceAccessor.SourceProperty<SRC> -
Field Summary
Fields inherited from class org.refcodes.cli.ArgsSyntaxException
_matchCount, _sourceFields inherited from class org.refcodes.cli.CliException.CliArgsException
_args -
Constructor Summary
ConstructorsConstructorDescriptionParseArgsException(String[] aArgs, Throwable aCause) Instantiates the classParseArgsException.ParseArgsException(String[] aArgs, Throwable aCause, String aErrorCode) Instantiates the classParseArgsException.ParseArgsException(String[] aArgs, Term aSource, Throwable aCause) Instantiates the classParseArgsException.ParseArgsException(String[] aArgs, Term aSource, Throwable aCause, String aErrorCode) Instantiates the classParseArgsException.ParseArgsException(String aMessage, String[] aArgs) Instantiates the classParseArgsException.ParseArgsException(String aMessage, String[] aArgs, String aErrorCode) Instantiates the classParseArgsException.ParseArgsException(String aMessage, String[] aArgs, Throwable aCause) Instantiates the classParseArgsException.ParseArgsException(String aMessage, String[] aArgs, Throwable aCause, String aErrorCode) Instantiates the classParseArgsException.ParseArgsException(String aMessage, String[] aArgs, Term aSource) Instantiates the classParseArgsException.ParseArgsException(String aMessage, String[] aArgs, Term aSource, String aErrorCode) Instantiates the classParseArgsException.ParseArgsException(String aMessage, String[] aArgs, Term aSource, Throwable aCause) Instantiates the classParseArgsException.ParseArgsException(String aMessage, String[] aArgs, Term aSource, Throwable aCause, String aErrorCode) Instantiates the classParseArgsException. -
Method Summary
Methods inherited from class org.refcodes.cli.ArgsSyntaxException
getMatchCount, getPatternArguments, getSource, toHeuristicMessage, toRootMatchCauseMethods inherited from class org.refcodes.cli.CliException.CliArgsException
getArgsMethods inherited from class org.refcodes.exception.AbstractException
getErrorCode, getMessageMethods inherited from class java.lang.Throwable
addSuppressed, fillInStackTrace, getCause, getLocalizedMessage, getStackTrace, getSuppressed, initCause, printStackTrace, printStackTrace, printStackTrace, setStackTrace, toStringMethods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface org.refcodes.exception.Trap
toLocalizedMessage, toMessage, toMessage, toMessage, toShortLocalizedMessage, toShortMessage
-
Constructor Details
-
ParseArgsException
Instantiates the classParseArgsException.- See Also:
-
ParseArgsException
Instantiates the classParseArgsException.- See Also:
-
ParseArgsException
Instantiates the classParseArgsException.- See Also:
-
ParseArgsException
-
ParseArgsException
Instantiates the classParseArgsException.- See Also:
-
ParseArgsException
Instantiates the classParseArgsException.- See Also:
-
ParseArgsException
Instantiates the classParseArgsException.- See Also:
-
ParseArgsException
Instantiates the classParseArgsException.- See Also:
-
ParseArgsException
Instantiates the classParseArgsException.- See Also:
-
ParseArgsException
Instantiates the classParseArgsException.- See Also:
-
ParseArgsException
Instantiates the classParseArgsException.- See Also:
-
ParseArgsException
Instantiates the classParseArgsException.- See Also:
-