java.lang.Object
java.lang.Throwable
java.lang.Exception
org.refcodes.exception.AbstractException
org.refcodes.cli.CliException
org.refcodes.cli.CliException.ConsoleArgsException
org.refcodes.cli.ArgsSyntaxException
org.refcodes.cli.ParseArgsException
- All Implemented Interfaces:
Serializable,ArgsAccessor,org.refcodes.exception.ErrorCodeAccessor,org.refcodes.exception.Trap
Thrown in case the provided command line arguments do not respect the
required semantics or cannot be converted to the required type.
- See Also:
-
Nested Class Summary
Nested classes/interfaces inherited from class org.refcodes.cli.CliException
CliException.ConsoleArgsException, CliException.ConsoleCliExceptionNested classes/interfaces inherited from interface org.refcodes.cli.ArgsAccessor
ArgsAccessor.ArgsMutator, ArgsAccessor.ArgsPropertyNested classes/interfaces inherited from interface org.refcodes.exception.ErrorCodeAccessor
org.refcodes.exception.ErrorCodeAccessor.ErrorCodeBuilder<B extends org.refcodes.exception.ErrorCodeAccessor.ErrorCodeBuilder<B>>, org.refcodes.exception.ErrorCodeAccessor.ErrorCodeMutator, org.refcodes.exception.ErrorCodeAccessor.ErrorCodeProperty -
Constructor Summary
ConstructorsConstructorDescriptionParseArgsException(String[] aArgs, String aMessage) Instantiates a new parses the args exception.ParseArgsException(String[] aArgs, String aMessage, String aErrorCode) Instantiates a new parses the args exception.ParseArgsException(String[] aArgs, String aMessage, Throwable aCause) Instantiates a new parses the args exception.ParseArgsException(String[] aArgs, String aMessage, Throwable aCause, String aErrorCode) Instantiates a new parses the args exception.ParseArgsException(String[] aArgs, Throwable aCause) Instantiates a new parses the args exception.ParseArgsException(String[] aArgs, Throwable aCause, String aErrorCode) Instantiates a new parses the args exception. -
Method Summary
Methods inherited from class org.refcodes.cli.CliException.ConsoleArgsException
toParsedArgsMethods inherited from class org.refcodes.exception.AbstractException
getErrorCodeMethods inherited from class java.lang.Throwable
addSuppressed, fillInStackTrace, getCause, getLocalizedMessage, getMessage, getStackTrace, getSuppressed, initCause, printStackTrace, printStackTrace, printStackTrace, setStackTrace, toString
-
Constructor Details
-
ParseArgsException
Instantiates a new parses the args exception.- Parameters:
aArgs- the argsaMessage- The aMessage describing this exception.aErrorCode- The error code identifying this exception.
-
ParseArgsException
Instantiates a new parses the args exception. -
ParseArgsException
Instantiates a new parses the args exception. -
ParseArgsException
Instantiates a new parses the args exception.- Parameters:
aArgs- the argsaMessage- The aMessage describing this exception.
-
ParseArgsException
Instantiates a new parses the args exception. -
ParseArgsException
Instantiates a new parses the args exception.
-