Class ParseDirectiveArgsException
- All Implemented Interfaces:
Serializable, ArgsAccessor, MatchCountAccessor, OperationAccessor, ErrorCodeAccessor, Trap, SourceAccessor<Term>
Thrown in case the provided command line arguments do not respect the
required semantics or cannot be converted to the required type by a
Directive (having an operation alongside an expected operand), e.g.
the arguments were rejected as them did not work for the according syntax.- See Also:
-
Nested Class Summary
Nested classes/interfaces inherited from class CliException
CliException.CliArgsExceptionNested classes/interfaces inherited from interface ArgsAccessor
ArgsAccessor.ArgsMutator, ArgsAccessor.ArgsPropertyNested classes/interfaces inherited from interface ErrorCodeAccessor
ErrorCodeAccessor.ErrorCodeBuilder<B>, ErrorCodeAccessor.ErrorCodeMutator, ErrorCodeAccessor.ErrorCodePropertyNested classes/interfaces inherited from interface MatchCountAccessor
MatchCountAccessor.MatchCountBuilder<B>, MatchCountAccessor.MatchCountMutator, MatchCountAccessor.MatchCountPropertyNested classes/interfaces inherited from interface OperationAccessor
OperationAccessor.OperationBuilder<B>, OperationAccessor.OperationMutator, OperationAccessor.OperationPropertyNested classes/interfaces inherited from interface SourceAccessor
SourceAccessor.SourceBuilder<SRC,B>, SourceAccessor.SourceMutator<SRC>, SourceAccessor.SourceProperty<SRC> -
Field Summary
Fields inherited from class ArgsSyntaxException
_matchCount, _sourceFields inherited from class CliException.CliArgsException
_args -
Constructor Summary
ConstructorsConstructorDescriptionParseDirectiveArgsException(String[] aArgs, String aOperation, Throwable aCause) Instantiates the classParseDirectiveArgsException.ParseDirectiveArgsException(String[] aArgs, String aOperation, Throwable aCause, String aErrorCode) Instantiates the classParseDirectiveArgsException.ParseDirectiveArgsException(String[] aArgs, String aOperation, Throwable aCause, Term aSource) Instantiates the classParseDirectiveArgsException.ParseDirectiveArgsException(String[] aArgs, String aOperation, Throwable aCause, Term aSource, String aErrorCode) Instantiates the classParseDirectiveArgsException.ParseDirectiveArgsException(String aMessage, String[] aArgs, String aOperation) Instantiates the classParseDirectiveArgsException.ParseDirectiveArgsException(String aMessage, String[] aArgs, String aOperation, String aErrorCode) Instantiates the classParseDirectiveArgsException.ParseDirectiveArgsException(String aMessage, String[] aArgs, String aOperation, Throwable aCause) Instantiates the classParseDirectiveArgsException.ParseDirectiveArgsException(String aMessage, String[] aArgs, String aOperation, Throwable aCause, String aErrorCode) Instantiates the classParseDirectiveArgsException.ParseDirectiveArgsException(String aMessage, String[] aArgs, String aOperation, Throwable aCause, Term aSource) Instantiates the classParseDirectiveArgsException.ParseDirectiveArgsException(String aMessage, String[] aArgs, String aOperation, Throwable aCause, Term aSource, String aErrorCode) Instantiates the classParseDirectiveArgsException.ParseDirectiveArgsException(String aMessage, String[] aArgs, String aOperation, Term aSource) Instantiates the classParseDirectiveArgsException.ParseDirectiveArgsException(String aMessage, String[] aArgs, String aOperation, Term aSource, String aErrorCode) Instantiates the classParseDirectiveArgsException. -
Method Summary
Methods inherited from class ArgsSyntaxException
getMatchCount, getSource, toHeuristicMessage, toRootMatchCauseMethods inherited from class CliException.CliArgsException
getArgsMethods inherited from class AbstractException
getErrorCode, getMessageMethods inherited from class Throwable
addSuppressed, fillInStackTrace, getCause, getLocalizedMessage, getStackTrace, getSuppressed, initCause, printStackTrace, printStackTrace, printStackTrace, setStackTrace, toStringMethods inherited from class Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface Trap
toLocalizedMessage, toMessage, toMessage, toMessage, toShortLocalizedMessage, toShortMessage
-
Constructor Details
-
ParseDirectiveArgsException
public ParseDirectiveArgsException(String aMessage, String[] aArgs, String aOperation, Term aSource) Instantiates the classParseDirectiveArgsException.- Parameters:
aOperation- The operation for which the arguments did not apply.- See Also:
-
ParseDirectiveArgsException
-
ParseDirectiveArgsException
-
ParseDirectiveArgsException
-
ParseDirectiveArgsException
public ParseDirectiveArgsException(String[] aArgs, String aOperation, Throwable aCause, Term aSource) Instantiates the classParseDirectiveArgsException.- Parameters:
aOperation- The operation for which the arguments did not apply.- See Also:
-
ParseDirectiveArgsException
-
ParseDirectiveArgsException
Instantiates the classParseDirectiveArgsException.- Parameters:
aOperation- The operation for which the arguments did not apply.- See Also:
-
ParseDirectiveArgsException
public ParseDirectiveArgsException(String aMessage, String[] aArgs, String aOperation, String aErrorCode) Instantiates the classParseDirectiveArgsException.- Parameters:
aOperation- The operation for which the arguments did not apply.- See Also:
-
ParseDirectiveArgsException
public ParseDirectiveArgsException(String aMessage, String[] aArgs, String aOperation, Throwable aCause) Instantiates the classParseDirectiveArgsException.- Parameters:
aOperation- The operation for which the arguments did not apply.- See Also:
-
ParseDirectiveArgsException
-
ParseDirectiveArgsException
Instantiates the classParseDirectiveArgsException.- Parameters:
aOperation- The operation for which the arguments did not apply.- See Also:
-
ParseDirectiveArgsException
public ParseDirectiveArgsException(String[] aArgs, String aOperation, Throwable aCause, String aErrorCode) Instantiates the classParseDirectiveArgsException.- Parameters:
aOperation- The operation for which the arguments did not apply.- See Also:
-
-
Method Details
-
getOperation
Retrieves the operation from the operation property.- Specified by:
getOperationin interfaceOperationAccessor- Returns:
- The operation stored by the operation property.
-
getPatternArguments
- Specified by:
getPatternArgumentsin interfaceTrap- Overrides:
getPatternArgumentsin classArgsSyntaxException
-