Class ParseDirectiveArgsException

All Implemented Interfaces:
Serializable, ArgsAccessor, MatchCountAccessor, OperationAccessor, org.refcodes.exception.ErrorCodeAccessor, org.refcodes.exception.Trap, org.refcodes.mixin.SourceAccessor<Term>

public class ParseDirectiveArgsException extends ParseArgsException implements OperationAccessor
Thrown in case the provided command line arguments do not respect the required semantics or cannot be converted to the required type by a Directive (having an operation alongside an expected operand), e.g. the arguments were rejected as them did not work for the according syntax.
See Also: