Class ParseOptionArgsException

All Implemented Interfaces:
Serializable, ArgsAccessor, LongOptionAccessor, MatchCountAccessor, ShortOptionAccessor, org.refcodes.exception.ErrorCodeAccessor, org.refcodes.exception.Trap, org.refcodes.mixin.SourceAccessor<Term>

public class ParseOptionArgsException extends ParseArgsException implements ShortOptionAccessor, LongOptionAccessor
Thrown in case the provided command line arguments do not respect the required semantics or cannot be converted to the required type by an Option (having a short- and/or a long-option), e.g. the arguments were rejected as them did not work for the according syntax.
See Also: