Interface ParsedArgsAccessor
- All Known Subinterfaces:
Directive<T>,Operand<T>,Option<T>,ParsedArgsAccessor.ParsedArgsProperty,Property<T>
- All Known Implementing Classes:
AbstractDirective,AbstractOperand,AbstractOption,AbstractProperty,ArrayDirective,ArrayOperand,ArrayOption,BooleanDirective,BooleanOption,BooleanProperty,CharDirective,CharOption,CharProperty,CleanFlag,ConfigOption,ConfigProperty,DaemonFlag,DebugFlag,DoubleDirective,DoubleOption,DoubleProperty,EnumDirective,EnumOption,EnumProperty,FileDirective,FileOption,FileProperty,Flag,FloatDirective,FloatOption,FloatProperty,ForceFlag,HelpFlag,InitFlag,IntDirective,IntOption,IntProperty,LongDirective,LongOption,LongProperty,NoneOperand,Operation,QuietFlag,StringDirective,StringOperand,StringOption,StringProperty,SysInfoFlag,VerboseFlag
public interface ParsedArgsAccessor
Provides an accessor for a command line arguments (short "args") array.
-
Nested Class Summary
Nested ClassesModifier and TypeInterfaceDescriptionstatic interfaceProvides a mutator for a parsed args property.static interfaceProvides a parsed args property. -
Method Summary
Modifier and TypeMethodDescriptionString[]Retrieves the command line arguments from the parsed args property.
-
Method Details
-
getParsedArgs
String[] getParsedArgs()Retrieves the command line arguments from the parsed args property.- Returns:
- The command line arguments stored by the parsed args property.
-