- All Known Subinterfaces:
Operand<T>,Option<T>,ParsedArgsAccessor.ParsedArgsProperty,PropertyOption<T>
- All Known Implementing Classes:
AbstractOperand,AbstractOption,AbstractPropertyOption,ArrayOperand,ArrayOption,BooleanOption,BooleanProperty,CharOption,CharProperty,CleanFlag,ConfigOption,ConfigProperty,DaemonFlag,DebugFlag,DoubleOption,DoubleProperty,EnumOption,EnumProperty,FileOption,FileProperty,Flag,FloatOption,FloatProperty,ForceFlag,HelpFlag,InitFlag,IntOption,IntProperty,LongOption,LongProperty,NoneOperand,Operation,QuietFlag,StringOperand,StringOption,StringProperty,SysInfoFlag,VerboseFlag
public interface ParsedArgsAccessor
Provides an accessor for a command line arguments (short "args") array.
-
Nested Class Summary
Nested ClassesModifier and TypeInterfaceDescriptionstatic interfaceProvides a mutator for a parsed args property.static interfaceProvides a parsed args property. -
Method Summary
Modifier and TypeMethodDescriptionString[]Retrieves the command line arguments from the parsed args property.
-
Method Details
-
getParsedArgs
String[] getParsedArgs()Retrieves the command line arguments from the parsed args property.- Returns:
- The command line arguments stored by the parsed args property.
-