Interface PropertyOption<T>

Type Parameters:
T - The generic type of the PropertyOption's value.
All Superinterfaces:
org.refcodes.mixin.AliasAccessor, org.refcodes.mixin.Clonable, Cloneable, Comparable<Operand<?>>, org.refcodes.mixin.DescriptionAccessor, org.refcodes.exception.ExceptionAccessor<ArgsSyntaxException>, MatchCountAccessor, Operand<T>, Option<T>, ParsedArgsAccessor, org.refcodes.mixin.Resetable, org.refcodes.schema.Schemable, Synopsisable, Term, org.refcodes.mixin.TypeAccessor<T>, org.refcodes.mixin.ValueAccessor<T>, org.refcodes.graphical.VisibleAccessor, org.refcodes.graphical.VisibleAccessor.VisibleBuilder<Term>, org.refcodes.graphical.VisibleAccessor.VisibleMutator, org.refcodes.graphical.VisibleAccessor.VisibleProperty
All Known Implementing Classes:
AbstractPropertyOption, BooleanProperty, CharProperty, ConfigProperty, DoubleProperty, EnumProperty, FileProperty, FloatProperty, IntProperty, LongProperty, StringProperty

public interface PropertyOption<T> extends Option<T>
An PropertyOption represents a command line property with the according porperty's key and value. A PropertyOption can be seen as a key=value pair and is passed in a single argument as such (e.g. "--file=simeFile"). A PropertyOption has a state which changes with each invocation of the Term.parseArgs(String[], String[], CliContext) method.