- All Implemented Interfaces:
Cloneable,Comparable<Operand<?>>,ArgsAccessor,Constituent,Operand<Boolean>,Option<Boolean>,Synopsisable,org.refcodes.mixin.AliasAccessor,org.refcodes.mixin.Clonable,org.refcodes.mixin.DescriptionAccessor,org.refcodes.mixin.EnabledAccessor,org.refcodes.mixin.Resetable,org.refcodes.mixin.Schemable<CliSchema>,org.refcodes.mixin.TypeAccessor<Boolean>,org.refcodes.mixin.ValueAccessor<Boolean>
A predefined "be quiet"
Flag: A predefined Flag gives its
SHORT_OPTION, its LONG_OPTION as well as its ALIAS
an according semantics regarded by other subsystems.-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.mixin.AliasAccessor
org.refcodes.mixin.AliasAccessor.AliasBuilder<B extends org.refcodes.mixin.AliasAccessor.AliasBuilder<B>>, org.refcodes.mixin.AliasAccessor.AliasMutator, org.refcodes.mixin.AliasAccessor.AliasPropertyNested classes/interfaces inherited from interface org.refcodes.cli.ArgsAccessor
ArgsAccessor.ArgsMutator, ArgsAccessor.ArgsPropertyNested classes/interfaces inherited from interface org.refcodes.mixin.DescriptionAccessor
org.refcodes.mixin.DescriptionAccessor.DescriptionBuilder<B extends org.refcodes.mixin.DescriptionAccessor.DescriptionBuilder<B>>, org.refcodes.mixin.DescriptionAccessor.DescriptionMutator, org.refcodes.mixin.DescriptionAccessor.DescriptionPropertyNested classes/interfaces inherited from interface org.refcodes.mixin.EnabledAccessor
org.refcodes.mixin.EnabledAccessor.EnabledBuilder<B extends org.refcodes.mixin.EnabledAccessor.EnabledBuilder<B>>, org.refcodes.mixin.EnabledAccessor.EnabledMutator, org.refcodes.mixin.EnabledAccessor.EnabledPropertyNested classes/interfaces inherited from interface org.refcodes.mixin.TypeAccessor
org.refcodes.mixin.TypeAccessor.TypeBuilder<T extends Object,B extends org.refcodes.mixin.TypeAccessor.TypeBuilder<T, B>>, org.refcodes.mixin.TypeAccessor.TypeMutator<T extends Object>, org.refcodes.mixin.TypeAccessor.TypeProperty<T extends Object> Nested classes/interfaces inherited from interface org.refcodes.mixin.ValueAccessor
org.refcodes.mixin.ValueAccessor.ValueBuilder<V extends Object,B extends org.refcodes.mixin.ValueAccessor.ValueBuilder<V, B>>, org.refcodes.mixin.ValueAccessor.ValueMutator<V extends Object>, org.refcodes.mixin.ValueAccessor.ValueProperty<V extends Object> -
Field Summary
FieldsModifier and TypeFieldDescriptionprotected Stringstatic final Stringstatic final Stringstatic final CharacterFields inherited from class org.refcodes.cli.AbstractOperand
_value -
Constructor Summary
Constructors -
Method Summary
Methods inherited from class org.refcodes.cli.AbstractOption
clone, contains, getLongOption, getShortOption, setParsedArgs, setValue, toOptionArgument, toOptionArgument, toSchemaMethods inherited from class org.refcodes.cli.AbstractOperand
compareTo, getAlias, getType, getValue, toParsedArgs, toStringMethods inherited from class java.lang.Object
equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface org.refcodes.mixin.Clonable
cloneMethods inherited from interface java.lang.Comparable
compareToMethods inherited from interface org.refcodes.cli.Constituent
parseArgs, toSynopsis, toSyntax, toSyntax, toSyntax, toSyntaxMethods inherited from interface org.refcodes.mixin.DescriptionAccessor
getDescriptionMethods inherited from interface org.refcodes.cli.Operand
getAlias, getValue, hasValue, toParsedArgs, toSpec, toValueMethods inherited from interface org.refcodes.cli.Option
getLongOption, getShortOptionMethods inherited from interface org.refcodes.mixin.Schemable
toSchemaMethods inherited from interface org.refcodes.cli.Synopsisable
toSynopsis, toSynopsis, toSynopsis, toSynopsisMethods inherited from interface org.refcodes.mixin.TypeAccessor
getTypeMethods inherited from interface org.refcodes.mixin.ValueAccessor
getValueOr
-
Field Details
-
ALIAS
- See Also:
-
LONG_OPTION
- See Also:
-
SHORT_OPTION
-
_description
-
-
Constructor Details
-
QuietFlag
Constructs the predefined quietFlag.- Parameters:
aDescription- The description to be used (without any line breaks).
-
QuietFlag
Constructs the predefined quietFlag.- Parameters:
aDescription- The description to be used (without any line breaks).hasShortOption- True in case to also enable the short option, else only the long option takes effect.
-
QuietFlag
public QuietFlag()Constructs the predefined quietFlag. -
QuietFlag
public QuietFlag(boolean hasShortOption) Constructs the predefined quietFlag.- Parameters:
hasShortOption- True in case to also enable the short option, else only the long option takes effect.
-
-
Method Details
-
getDescription
- Specified by:
getDescriptionin interfaceorg.refcodes.mixin.DescriptionAccessor
-