Interface RootConditionAccessor.RootConditionBuilder<B extends RootConditionAccessor.RootConditionBuilder<B>>

Type Parameters:
B - The builder to return in order to be able to apply multiple build operations.
Enclosing interface:
RootConditionAccessor

public static interface RootConditionAccessor.RootConditionBuilder<B extends RootConditionAccessor.RootConditionBuilder<B>>
Provides a builder method for a root condition property returning the builder for applying multiple build operations.
  • Method Summary

    Modifier and Type Method Description
    B withRootCondition​(Condition aRootCondition)
    Sets the root condition for the root condition property.
    default B withRootOption​(Option<?> aRootOption)
    Sets the root option for the root condition property.
  • Method Details

    • withRootCondition

      B withRootCondition​(Condition aRootCondition)
      Sets the root condition for the root condition property.
      Parameters:
      aRootCondition - The root condition to be stored by the root condition property.
      Returns:
      The builder for applying multiple build operations.
    • withRootOption

      default B withRootOption​(Option<?> aRootOption)
      Sets the root option for the root condition property. Convenience method wrapping an Option into a OptionConditionFacade and passing it to the withRootCondition(Condition) method.
      Parameters:
      aRootOption - The root condition to be stored by the root condition property.
      Returns:
      The builder for applying multiple build operations.