Module org.refcodes.cli
Package org.refcodes.cli
Interface RootConditionAccessor.RootConditionBuilder<B extends RootConditionAccessor.RootConditionBuilder<B>>
- Type Parameters:
B- The builder to return in order to be able to apply multiple build operations.
- Enclosing interface:
- RootConditionAccessor
public static interface RootConditionAccessor.RootConditionBuilder<B extends RootConditionAccessor.RootConditionBuilder<B>>
Provides a builder method for a root condition property returning the
builder for applying multiple build operations.
-
Method Summary
Modifier and Type Method Description BwithRootCondition(Condition aRootCondition)Sets the root condition for the root condition property.default BwithRootOption(Option<?> aRootOption)Sets the root option for the root condition property.
-
Method Details
-
withRootCondition
Sets the root condition for the root condition property.- Parameters:
aRootCondition- The root condition to be stored by the root condition property.- Returns:
- The builder for applying multiple build operations.
-
withRootOption
Sets the root option for the root condition property. Convenience method wrapping anOptioninto aOptionConditionFacadeand passing it to thewithRootCondition(Condition)method.- Parameters:
aRootOption- The root condition to be stored by the root condition property.- Returns:
- The builder for applying multiple build operations.
-