Interface RootConditionAccessor.RootConditionMutator

All Known Subinterfaces:
RootConditionAccessor.RootConditionProperty
Enclosing interface:
RootConditionAccessor

public static interface RootConditionAccessor.RootConditionMutator
Provides a mutator for a root condition property.
  • Method Summary

    Modifier and Type Method Description
    void setRootCondition​(Condition aRootCondition)
    Sets the root condition for the root condition property.
    default void setRootOption​(Option<?> aRootOption)
    Sets the root option for the root condition property.
  • Method Details

    • setRootCondition

      void setRootCondition​(Condition aRootCondition)
      Sets the root condition for the root condition property.
      Parameters:
      aRootCondition - The root condition to be stored by the root condition property.
    • setRootOption

      default void setRootOption​(Option<?> aRootOption)
      Sets the root option for the root condition property. Convenience method wrapping an Option into a OptionConditionFacade and passing it to the setRootCondition(Condition) method.
      Parameters:
      aRootOption - The root option to be stored by the root condition property.