- java.lang.Object
-
- org.refcodes.cli.AbstractOperand<String>
-
- org.refcodes.cli.StringOperand
-
- All Implemented Interfaces:
Cloneable,Comparable<Operand<?>>,ArgsAccessor,Operand<String>,Syntaxable,SyntaxUsage,org.refcodes.component.Resetable,org.refcodes.mixin.AliasAccessor,org.refcodes.mixin.Clonable,org.refcodes.mixin.DescriptionAccessor,org.refcodes.mixin.TypeAccessor<String>,org.refcodes.mixin.ValueAccessor<String>
public class StringOperand extends AbstractOperand<String>
-
-
Nested Class Summary
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.AliasAccessor
org.refcodes.mixin.AliasAccessor.AliasBuilder<B extends org.refcodes.mixin.AliasAccessor.AliasBuilder<B>>, org.refcodes.mixin.AliasAccessor.AliasMutator, org.refcodes.mixin.AliasAccessor.AliasProperty
-
Nested classes/interfaces inherited from interface org.refcodes.cli.ArgsAccessor
ArgsAccessor.ArgsMutator, ArgsAccessor.ArgsProperty
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.DescriptionAccessor
org.refcodes.mixin.DescriptionAccessor.DescriptionBuilder<B extends org.refcodes.mixin.DescriptionAccessor.DescriptionBuilder<B>>, org.refcodes.mixin.DescriptionAccessor.DescriptionMutator, org.refcodes.mixin.DescriptionAccessor.DescriptionProperty
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.TypeAccessor
org.refcodes.mixin.TypeAccessor.TypeBuilder<T extends Object,B extends org.refcodes.mixin.TypeAccessor.TypeBuilder<T,B>>, org.refcodes.mixin.TypeAccessor.TypeMutator<T extends Object>, org.refcodes.mixin.TypeAccessor.TypeProperty<T extends Object>
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.ValueAccessor
org.refcodes.mixin.ValueAccessor.ValueBuilder<V extends Object,B extends org.refcodes.mixin.ValueAccessor.ValueBuilder<V,B>>, org.refcodes.mixin.ValueAccessor.ValueMutator<V extends Object>, org.refcodes.mixin.ValueAccessor.ValueProperty<V extends Object>
-
-
Field Summary
-
Fields inherited from class org.refcodes.cli.AbstractOperand
_value
-
-
Constructor Summary
Constructors Constructor Description StringOperand(String aAlias, String aDescription)Instantiates a new string operand impl.StringOperand(org.refcodes.struct.Relation<String,String> aProperty)Instantiates a new string operand impl.
-
Method Summary
All Methods Instance Methods Concrete Methods Modifier and Type Method Description protected StringtoType(String aArg)To value.StringtoUsage(SyntaxNotation aSyntaxNotation, String aOptionEscCode, String aResetEscCode)Returns the human readable (verbose) syntax of implementing class ATTENTION: As of different parenthesis settings for some notations regarding the rootSyntaxableand the childSyntaxables, the methodSyntaxable.toSyntax(SyntaxNotation, String, String)is called from inside aSyntaxablehierarchy.-
Methods inherited from class org.refcodes.cli.AbstractOperand
clone, compareTo, getAlias, getArgs, getDescription, getType, getValue, parseArgs, reset, setArgs, setValue, toState, toString, toSyntax
-
Methods inherited from class java.lang.Object
equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, wait
-
Methods inherited from interface org.refcodes.cli.Syntaxable
parseArgs, toSyntax, toSyntax, toSyntax
-
Methods inherited from interface org.refcodes.cli.SyntaxUsage
toUsage, toUsage, toUsage, toUsage
-
-
-
-
Constructor Detail
-
StringOperand
public StringOperand(String aAlias, String aDescription)
Instantiates a new string operand impl.- Parameters:
aAlias- The identifier to be used when printing the syntax via theAbstractOperand.toSyntax(SyntaxNotation, String, String)method.aDescription- A description without any line breaks.
-
-
Method Detail
-
toType
protected String toType(String aArg)
To value.- Specified by:
toTypein classAbstractOperand<String>- Parameters:
aArg- the arg- Returns:
- the string
-
toUsage
public String toUsage(SyntaxNotation aSyntaxNotation, String aOptionEscCode, String aResetEscCode)
Returns the human readable (verbose) syntax of implementing class ATTENTION: As of different parenthesis settings for some notations regarding the rootSyntaxableand the childSyntaxables, the methodSyntaxable.toSyntax(SyntaxNotation, String, String)is called from inside aSyntaxablehierarchy. In case the syntax is to be retrieved from the rootSyntaxableor an encapsulating and different type, then the applicable method to be called isSyntaxUsage.toUsage(SyntaxNotation), as for some notations it will for example not create the most outer braces.- Specified by:
toUsagein interfaceSyntaxUsage- Parameters:
aSyntaxNotation- The syntax notation used for generating the command line arguments syntax.aOptionEscCode- The escape code to be used when processing an option, e.g. this can be an ANSI Escape-Code to highlight the option parameters (for example "--help", "-q" and so on).aResetEscCode- The escape code to close (reset) any Escape-Code being set before.- Returns:
- The human readable (verbose) command line arguments syntax.
-
-