- All Known Subinterfaces:
Condition,Operand<T>,Option<T>,PropertyOption<T>,Term
- All Known Implementing Classes:
AbstractCondition,AbstractOperand,AbstractOption,AbstractPropertyOption,AllCondition,AndCondition,AnyCondition,ArrayOperand,ArrayOption,BooleanOption,BooleanProperty,CasesCondition,CharOption,CharProperty,CleanFlag,ConfigOption,ConfigProperty,DaemonFlag,DebugFlag,DoubleOption,DoubleProperty,EnumOption,EnumProperty,FileOption,FileProperty,Flag,FloatOption,FloatProperty,ForceFlag,HelpFlag,InitFlag,IntOption,IntProperty,LongOption,LongProperty,NoneOperand,Operation,OrCondition,QuietFlag,StringOperand,StringOption,StringProperty,SysInfoFlag,VerboseFlag,XorCondition
public interface Synopsisable
The
Synopsisable interface defines those methods required to create a
human readable usage String similar to a manpage's synopsis from the
implementing instance.-
Method Summary
Modifier and TypeMethodDescriptiondefault StringReturns the human readable (verbose) syntax of implementing class ATTENTION: As of different parenthesis settings for some notations regarding the rootTermand the childTerms, the methodTerm.toSyntax(CliContext)is called from inside aTermhierarchy.default StringtoSynopsis(String aOptEscCode, String aParamEscCode, String aResetEscCode) Returns the human readable (verbose) syntax of implementing class ATTENTION: As of different parenthesis settings for some notations regarding the rootTermand the childTerms, the methodTerm.toSyntax(CliContext)is called from inside aTermhierarchy.toSynopsis(CliContext aCliCtx) Returns the human readable (verbose) syntax of the implementing class ATTENTION: As of different parenthesis settings for some notations regarding the rootTermand the childTerms, the methodTerm.toSyntax(CliContext)is called from inside aTermhierarchy.default StringtoSynopsis(SyntaxNotation aSyntaxNotation) Returns the human readable (verbose) syntax of implementing class ATTENTION: As of different parenthesis settings for some notations regarding the rootTermand the childTerms, the methodTerm.toSyntax(CliContext)is called from inside aTermhierarchy.default StringtoSynopsis(SyntaxNotation aSyntaxNotation, String aOptEscCode, String aParamEscCode, String aResetEscCode) Returns the human readable (verbose) syntax of implementing class ATTENTION: As of different parenthesis settings for some notations regarding the rootTermand the childTerms, the methodTerm.toSyntax(CliContext)is called from inside aTermhierarchy.
-
Method Details
-
toSynopsis
Returns the human readable (verbose) syntax of implementing class ATTENTION: As of different parenthesis settings for some notations regarding the rootTermand the childTerms, the methodTerm.toSyntax(CliContext)is called from inside aTermhierarchy. In case the syntax is to be retrieved from the rootTermor an encapsulating and different type, then the applicable method to be called istoSynopsis(SyntaxNotation), as for some notations it will for example not create the most outer braces. This method uses theSyntaxNotation.LOGICALbe default!- Returns:
- The human readable (verbose) command line arguments syntax.
-
toSynopsis
Returns the human readable (verbose) syntax of the implementing class ATTENTION: As of different parenthesis settings for some notations regarding the rootTermand the childTerms, the methodTerm.toSyntax(CliContext)is called from inside aTermhierarchy. In case the syntax is to be retrieved from the rootTermor an encapsulating and different type, then the applicable method to be called istoSynopsis(SyntaxNotation), as for some notations it will for example not create the most outer braces.- Parameters:
aCliCtx- TheCliContextfor which the syntax is being generated.- Returns:
- The human readable (verbose) command line arguments syntax.
-
toSynopsis
Returns the human readable (verbose) syntax of implementing class ATTENTION: As of different parenthesis settings for some notations regarding the rootTermand the childTerms, the methodTerm.toSyntax(CliContext)is called from inside aTermhierarchy. In case the syntax is to be retrieved from the rootTermor an encapsulating and different type, then the applicable method to be called istoSynopsis(SyntaxNotation), as for some notations it will for example not create the most outer braces. This method uses theSyntaxNotation.LOGICALbe default!- Parameters:
aOptEscCode- The escape code to be used when processing an option, e.g. this can be an ANSI Escape-Code to highlight the option.aParamEscCode- The escape code to be used when processing am argument, e.g. this can be an ANSI Escape-Code to highlight the option.aResetEscCode- The escape code to close (reset) any Escape-Code being set before.- Returns:
- The human readable (verbose) command line arguments syntax.
-
toSynopsis
Returns the human readable (verbose) syntax of implementing class ATTENTION: As of different parenthesis settings for some notations regarding the rootTermand the childTerms, the methodTerm.toSyntax(CliContext)is called from inside aTermhierarchy. In case the syntax is to be retrieved from the rootTermor an encapsulating and different type, then the applicable method to be called istoSynopsis(SyntaxNotation), as for some notations it will for example not create the most outer braces.- Parameters:
aSyntaxNotation- The syntax notation used for generating the command line arguments syntax.- Returns:
- The human readable (verbose) command line arguments syntax.
-
toSynopsis
default String toSynopsis(SyntaxNotation aSyntaxNotation, String aOptEscCode, String aParamEscCode, String aResetEscCode) Returns the human readable (verbose) syntax of implementing class ATTENTION: As of different parenthesis settings for some notations regarding the rootTermand the childTerms, the methodTerm.toSyntax(CliContext)is called from inside aTermhierarchy. In case the syntax is to be retrieved from the rootTermor an encapsulating and different type, then the applicable method to be called istoSynopsis(SyntaxNotation), as for some notations it will for example not create the most outer braces.- Parameters:
aSyntaxNotation- The syntax notation used for generating the command line arguments syntax.aOptEscCode- The escape code to be used when processing an option, e.g. this can be an ANSI Escape-Code to highlight the option.aParamEscCode- The escape code to be used when processing am argument, e.g. this can be an ANSI Escape-Code to highlight the option.aResetEscCode- The escape code to close (reset) any Escape-Code being set before.- Returns:
- The human readable (verbose) command line arguments syntax.
-