- All Implemented Interfaces:
Serializable,Comparable<SyntaxNotation>,Constable
The
SyntaxNotation is used by a the
Syntaxable.toSyntax(SyntaxNotation, String, String, String) method to
determine which notation to be used for the generated syntax.-
Nested Class Summary
Nested classes/interfaces inherited from class java.lang.Enum
Enum.EnumDesc<E extends Enum<E>> -
Enum Constant Summary
Enum ConstantsEnum ConstantDescriptionA syntax notation derived from GNU and POSIX utility conventions and utility argument syntax.A notation which the author of this code believes to unambiguously describe a command line utility's argument syntax; as defined by the means of thisrefcodes-cliartifact. -
Method Summary
Modifier and TypeMethodDescriptionstatic SyntaxNotationReturns the enum constant of this class with the specified name.static SyntaxNotation[]values()Returns an array containing the constants of this enum class, in the order they are declared.
-
Enum Constant Details
-
REFCODES
A notation which the author of this code believes to unambiguously describe a command line utility's argument syntax; as defined by the means of thisrefcodes-cliartifact. -
GNU_POSIX
A syntax notation derived from GNU and POSIX utility conventions and utility argument syntax.- See Also:
-
- "http://www.gnu.org/software/libc/manual/html_node/Argument-Syntax.html"
- "http://pubs.opengroup.org/onlinepubs/009695399/basedefs/xbd_chap12.html"
-
-
Method Details
-
values
Returns an array containing the constants of this enum class, in the order they are declared.- Returns:
- an array containing the constants of this enum class, in the order they are declared
-
valueOf
Returns the enum constant of this class with the specified name. The string must match exactly an identifier used to declare an enum constant in this class. (Extraneous whitespace characters are not permitted.)- Parameters:
name- the name of the enum constant to be returned.- Returns:
- the enum constant with the specified name
- Throws:
IllegalArgumentException- if this enum class has no constant with the specified nameNullPointerException- if the argument is null
-