Interface SyntaxUsage

All Known Subinterfaces:
Condition, Operand<T>, Option<T>, Syntaxable
All Known Implementing Classes:
AbstractCondition, AbstractOperand, AbstractOption, AndCondition, ArrayOperand, ArrayOption, CharOption, DebugFlag, DoubleOption, EnumOption, FileOption, Flag, FloatOption, ForceFlag, HelpFlag, IntOption, LongOption, Operation, OptionalCondition, OptionConditionFacade, OrCondition, QuietFlag, StringOperand, StringOption, SysInfoFlag, VerboseFlag, XorCondition

public interface SyntaxUsage
The SyntaxUsage interface defines those methods required to create a human readable usage String from the implementing instance.
  • Method Details

    • toUsage

      default String toUsage()
    • toUsage

      default String toUsage​(SyntaxNotation aSyntaxNotation)
      Returns the human readable (verbose) syntax of implementing class ATTENTION: As of different parenthesis settings for some notations regarding the root Syntaxable and the child Syntaxables, the method Syntaxable.toSyntax(SyntaxNotation, String, String) is called from inside a Syntaxable hierarchy. In case the syntax is to be retrieved from the root Syntaxable or an encapsulating and different type, then the applicable method to be called is toUsage(SyntaxNotation), as for some notations it will for example not create the most outer braces.
      Parameters:
      aSyntaxNotation - The syntax notation used for generating the command line arguments syntax.
      Returns:
      The human readable (verbose) command line arguments syntax.
    • toUsage

      String toUsage​(SyntaxNotation aSyntaxNotation, String aOptionEscCode, String aResetEscCode)
      Returns the human readable (verbose) syntax of implementing class ATTENTION: As of different parenthesis settings for some notations regarding the root Syntaxable and the child Syntaxables, the method Syntaxable.toSyntax(SyntaxNotation, String, String) is called from inside a Syntaxable hierarchy. In case the syntax is to be retrieved from the root Syntaxable or an encapsulating and different type, then the applicable method to be called is toUsage(SyntaxNotation), as for some notations it will for example not create the most outer braces.
      Parameters:
      aSyntaxNotation - The syntax notation used for generating the command line arguments syntax.
      aOptionEscCode - The escape code to be used when processing an option, e.g. this can be an ANSI Escape-Code to highlight the option parameters (for example "--help", "-q" and so on).
      aResetEscCode - The escape code to close (reset) any Escape-Code being set before.
      Returns:
      The human readable (verbose) command line arguments syntax.