- All Known Subinterfaces:
Condition,Operand<T>,Option<T>,Syntaxable
- All Known Implementing Classes:
AbstractCondition,AbstractOperand,AbstractOption,AndCondition,ArrayOperand,ArrayOption,CharOption,DebugFlag,DoubleOption,EnumOption,FileOption,Flag,FloatOption,ForceFlag,HelpFlag,IntOption,LongOption,Operation,OptionalCondition,OptionConditionFacade,OrCondition,QuietFlag,StringOperand,StringOption,SysInfoFlag,VerboseFlag,XorCondition
public interface SyntaxUsage
The
SyntaxUsage interface defines those methods required to create a
human readable usage String from the implementing instance.-
Method Summary
Modifier and Type Method Description default StringtoUsage()default StringtoUsage(SyntaxNotation aSyntaxNotation)Returns the human readable (verbose) syntax of implementing class ATTENTION: As of different parenthesis settings for some notations regarding the rootSyntaxableand the childSyntaxables, the methodSyntaxable.toSyntax(SyntaxNotation, String, String)is called from inside aSyntaxablehierarchy.StringtoUsage(SyntaxNotation aSyntaxNotation, String aOptionEscCode, String aResetEscCode)Returns the human readable (verbose) syntax of implementing class ATTENTION: As of different parenthesis settings for some notations regarding the rootSyntaxableand the childSyntaxables, the methodSyntaxable.toSyntax(SyntaxNotation, String, String)is called from inside aSyntaxablehierarchy.
-
Method Details
-
toUsage
-
toUsage
Returns the human readable (verbose) syntax of implementing class ATTENTION: As of different parenthesis settings for some notations regarding the rootSyntaxableand the childSyntaxables, the methodSyntaxable.toSyntax(SyntaxNotation, String, String)is called from inside aSyntaxablehierarchy. In case the syntax is to be retrieved from the rootSyntaxableor an encapsulating and different type, then the applicable method to be called istoUsage(SyntaxNotation), as for some notations it will for example not create the most outer braces.- Parameters:
aSyntaxNotation- The syntax notation used for generating the command line arguments syntax.- Returns:
- The human readable (verbose) command line arguments syntax.
-
toUsage
Returns the human readable (verbose) syntax of implementing class ATTENTION: As of different parenthesis settings for some notations regarding the rootSyntaxableand the childSyntaxables, the methodSyntaxable.toSyntax(SyntaxNotation, String, String)is called from inside aSyntaxablehierarchy. In case the syntax is to be retrieved from the rootSyntaxableor an encapsulating and different type, then the applicable method to be called istoUsage(SyntaxNotation), as for some notations it will for example not create the most outer braces.- Parameters:
aSyntaxNotation- The syntax notation used for generating the command line arguments syntax.aOptionEscCode- The escape code to be used when processing an option, e.g. this can be an ANSI Escape-Code to highlight the option parameters (for example "--help", "-q" and so on).aResetEscCode- The escape code to close (reset) any Escape-Code being set before.- Returns:
- The human readable (verbose) command line arguments syntax.
-