- All Implemented Interfaces:
Cloneable,Comparable<Operand<?>>,ArgsAccessor,Operand<Boolean>,Option<Boolean>,Syntaxable,SyntaxUsage,org.refcodes.component.Resetable,org.refcodes.mixin.AliasAccessor,org.refcodes.mixin.Clonable,org.refcodes.mixin.DescriptionAccessor,org.refcodes.mixin.EnabledAccessor,org.refcodes.mixin.TypeAccessor<Boolean>,org.refcodes.mixin.ValueAccessor<Boolean>
public class SysInfoFlag extends Flag
A predefined system information switch.
-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.mixin.AliasAccessor
org.refcodes.mixin.AliasAccessor.AliasBuilder<B extends org.refcodes.mixin.AliasAccessor.AliasBuilder<B>>, org.refcodes.mixin.AliasAccessor.AliasMutator, org.refcodes.mixin.AliasAccessor.AliasPropertyNested classes/interfaces inherited from interface org.refcodes.cli.ArgsAccessor
ArgsAccessor.ArgsMutator, ArgsAccessor.ArgsPropertyNested classes/interfaces inherited from interface org.refcodes.mixin.DescriptionAccessor
org.refcodes.mixin.DescriptionAccessor.DescriptionBuilder<B extends org.refcodes.mixin.DescriptionAccessor.DescriptionBuilder<B>>, org.refcodes.mixin.DescriptionAccessor.DescriptionMutator, org.refcodes.mixin.DescriptionAccessor.DescriptionPropertyNested classes/interfaces inherited from interface org.refcodes.mixin.EnabledAccessor
org.refcodes.mixin.EnabledAccessor.EnabledBuilder<B extends org.refcodes.mixin.EnabledAccessor.EnabledBuilder<B>>, org.refcodes.mixin.EnabledAccessor.EnabledMutator, org.refcodes.mixin.EnabledAccessor.EnabledPropertyNested classes/interfaces inherited from interface org.refcodes.mixin.TypeAccessor
org.refcodes.mixin.TypeAccessor.TypeBuilder<T extends Object,B extends org.refcodes.mixin.TypeAccessor.TypeBuilder<T,B>>, org.refcodes.mixin.TypeAccessor.TypeMutator<T extends Object>, org.refcodes.mixin.TypeAccessor.TypeProperty<T extends Object>Nested classes/interfaces inherited from interface org.refcodes.mixin.ValueAccessor
org.refcodes.mixin.ValueAccessor.ValueBuilder<V extends Object,B extends org.refcodes.mixin.ValueAccessor.ValueBuilder<V,B>>, org.refcodes.mixin.ValueAccessor.ValueMutator<V extends Object>, org.refcodes.mixin.ValueAccessor.ValueProperty<V extends Object> -
Field Summary
Fields Modifier and Type Field Description static StringLONG_OPTIONstatic StringSHORT_OPTIONstatic StringSYSINFOFields inherited from class org.refcodes.cli.AbstractOperand
_value -
Constructor Summary
Constructors Constructor Description SysInfoFlag()Constructs the predefined system information switch.SysInfoFlag(String aDescription)Constructs the predefined system information switch. -
Method Summary
Modifier and Type Method Description StringtoUsage(SyntaxNotation aSyntaxNotation, String aOptionEscCode, String aResetEscCode)Returns the human readable (verbose) syntax of implementing class ATTENTION: As of different parenthesis settings for some notations regarding the rootSyntaxableand the childSyntaxables, the methodSyntaxable.toSyntax(SyntaxNotation, String, String)is called from inside aSyntaxablehierarchy.Methods inherited from class org.refcodes.cli.AbstractOption
clone, getLongOption, getOptionPrefixes, getShortOption, setArgs, setValue, toState, toSyntaxMethods inherited from class org.refcodes.cli.AbstractOperand
compareTo, getAlias, getArgs, getDescription, getType, getValue, toStringMethods inherited from class java.lang.Object
equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface org.refcodes.mixin.Clonable
cloneMethods inherited from interface java.lang.Comparable
compareToMethods inherited from interface org.refcodes.mixin.DescriptionAccessor
getDescriptionMethods inherited from interface org.refcodes.cli.Operand
get, getAlias, getArgs, getValue, hasValueMethods inherited from interface org.refcodes.cli.Option
getLongOption, getOptions, getShortOptionMethods inherited from interface org.refcodes.cli.Syntaxable
parseArgs, toState, toSyntax, toSyntaxMethods inherited from interface org.refcodes.cli.SyntaxUsage
toUsage, toUsage, toUsageMethods inherited from interface org.refcodes.mixin.TypeAccessor
getTypeMethods inherited from interface org.refcodes.mixin.ValueAccessor
getValueOr
-
Field Details
-
SYSINFO
- See Also:
- Constant Field Values
-
LONG_OPTION
- See Also:
- Constant Field Values
-
SHORT_OPTION
-
-
Constructor Details
-
SysInfoFlag
Constructs the predefined system information switch.- Parameters:
aDescription- A description without any line breaks.
-
SysInfoFlag
public SysInfoFlag()Constructs the predefined system information switch.
-
-
Method Details
-
toUsage
Returns the human readable (verbose) syntax of implementing class ATTENTION: As of different parenthesis settings for some notations regarding the rootSyntaxableand the childSyntaxables, the methodSyntaxable.toSyntax(SyntaxNotation, String, String)is called from inside aSyntaxablehierarchy. In case the syntax is to be retrieved from the rootSyntaxableor an encapsulating and different type, then the applicable method to be called isSyntaxUsage.toUsage(SyntaxNotation), as for some notations it will for example not create the most outer braces.- Specified by:
toUsagein interfaceSyntaxUsage- Parameters:
aSyntaxNotation- The syntax notation used for generating the command line arguments syntax.aOptionEscCode- The escape code to be used when processing an option, e.g. this can be an ANSI Escape-Code to highlight the option parameters (for example "--help", "-q" and so on).aResetEscCode- The escape code to close (reset) any Escape-Code being set before.- Returns:
- The human readable (verbose) command line arguments syntax.
-