Interface Term

All Superinterfaces:
org.refcodes.mixin.DescriptionAccessor, org.refcodes.exception.ExceptionAccessor<ArgsSyntaxException>, MatchCountAccessor, org.refcodes.mixin.Resetable, org.refcodes.schema.Schemable, Synopsisable, org.refcodes.graphical.VisibleAccessor, org.refcodes.graphical.VisibleAccessor.VisibleBuilder<Term>, org.refcodes.graphical.VisibleAccessor.VisibleMutator, org.refcodes.graphical.VisibleAccessor.VisibleProperty
All Known Subinterfaces:
Condition, Operand<T>, Option<T>, PropertyOption<T>
All Known Implementing Classes:
AbstractCondition, AbstractOperand, AbstractOption, AbstractPropertyOption, AllCondition, AndCondition, AnyCondition, ArrayOperand, ArrayOption, BooleanOption, BooleanProperty, CasesCondition, CharOption, CharProperty, CleanFlag, ConfigOption, ConfigProperty, DaemonFlag, DebugFlag, DoubleOption, DoubleProperty, EnumOption, EnumProperty, FileOption, FileProperty, Flag, FloatOption, FloatProperty, ForceFlag, HelpFlag, InitFlag, IntOption, IntProperty, LongOption, LongProperty, NoneOperand, Operation, OrCondition, QuietFlag, StringOperand, StringOption, StringProperty, SysInfoFlag, VerboseFlag, XorCondition

public interface Term extends org.refcodes.mixin.Resetable, Synopsisable, org.refcodes.mixin.DescriptionAccessor, org.refcodes.schema.Schemable, org.refcodes.exception.ExceptionAccessor<ArgsSyntaxException>, MatchCountAccessor, org.refcodes.graphical.VisibleAccessor.VisibleProperty, org.refcodes.graphical.VisibleAccessor.VisibleBuilder<Term>
A Term defines the methods at least required when building a command line arguments syntax tree for traversing the syntax tree; either for parsing command line arguments or for constructing the command line arguments syntax. By providing various implementations of the Term's subclasses such as Operand, Option or Condition, a command line arguments syntax tree can be constructed. This syntax tree can be use to create a human readable (verbose) command line arguments syntax and to parse an array of command line arguments for determining the Operands', the Flages' or the Options' values.