Class UnknownArgsException
java.lang.Object
java.lang.Throwable
java.lang.Exception
org.refcodes.exception.AbstractException
org.refcodes.cli.CliException
org.refcodes.cli.CliException.CliArgsException
org.refcodes.cli.ArgsSyntaxException
org.refcodes.cli.UnknownArgsException
- All Implemented Interfaces:
Serializable,ArgsAccessor,MatchCountAccessor,org.refcodes.exception.ErrorCodeAccessor,org.refcodes.exception.Trap,org.refcodes.mixin.SourceAccessor<Term>
- Direct Known Subclasses:
UnknownOperationArgsException,UnknownOptionArgsException
Thrown in case command line arguments were not processed (did not match the
expected arguments), e.g. the arguments were rejected as them did not work
for the according syntax.
- See Also:
-
Nested Class Summary
Nested classes/interfaces inherited from class org.refcodes.cli.CliException
CliException.CliArgsExceptionNested classes/interfaces inherited from interface org.refcodes.cli.ArgsAccessor
ArgsAccessor.ArgsMutator, ArgsAccessor.ArgsPropertyNested classes/interfaces inherited from interface org.refcodes.exception.ErrorCodeAccessor
org.refcodes.exception.ErrorCodeAccessor.ErrorCodeBuilder<B extends org.refcodes.exception.ErrorCodeAccessor.ErrorCodeBuilder<B>>, org.refcodes.exception.ErrorCodeAccessor.ErrorCodeMutator, org.refcodes.exception.ErrorCodeAccessor.ErrorCodePropertyNested classes/interfaces inherited from interface org.refcodes.cli.MatchCountAccessor
MatchCountAccessor.MatchCountBuilder<B extends MatchCountAccessor.MatchCountBuilder<B>>, MatchCountAccessor.MatchCountMutator, MatchCountAccessor.MatchCountPropertyNested classes/interfaces inherited from interface org.refcodes.mixin.SourceAccessor
org.refcodes.mixin.SourceAccessor.SourceBuilder<SRC,B extends org.refcodes.mixin.SourceAccessor.SourceBuilder<SRC, B>>, org.refcodes.mixin.SourceAccessor.SourceMutator<SRC>, org.refcodes.mixin.SourceAccessor.SourceProperty<SRC> -
Field Summary
Fields inherited from class org.refcodes.cli.ArgsSyntaxException
_matchCount, _sourceFields inherited from class org.refcodes.cli.CliException.CliArgsException
_args -
Constructor Summary
ConstructorsConstructorDescriptionUnknownArgsException(String[] aArgs, Throwable aCause) Instantiates the classUnknownArgsException.UnknownArgsException(String[] aArgs, Throwable aCause, String aErrorCode) Instantiates the classUnknownArgsException.UnknownArgsException(String[] aArgs, Term aSource, Throwable aCause) Instantiates the classUnknownArgsException.UnknownArgsException(String[] aArgs, Term aSource, Throwable aCause, String aErrorCode) Instantiates the classUnknownArgsException.UnknownArgsException(String aMessage, String[] aArgs) Instantiates the classUnknownArgsException.UnknownArgsException(String aMessage, String[] aArgs, String aErrorCode) Instantiates the classUnknownArgsException.UnknownArgsException(String aMessage, String[] aArgs, Throwable aCause) Instantiates the classUnknownArgsException.UnknownArgsException(String aMessage, String[] aArgs, Throwable aCause, String aErrorCode) Instantiates the classUnknownArgsException.UnknownArgsException(String aMessage, String[] aArgs, Term aSource) Instantiates the classUnknownArgsException.UnknownArgsException(String aMessage, String[] aArgs, Term aSource, String aErrorCode) Instantiates the classUnknownArgsException.UnknownArgsException(String aMessage, String[] aArgs, Term aSource, Throwable aCause) Instantiates the classUnknownArgsException.UnknownArgsException(String aMessage, String[] aArgs, Term aSource, Throwable aCause, String aErrorCode) Instantiates the classUnknownArgsException. -
Method Summary
Methods inherited from class org.refcodes.cli.ArgsSyntaxException
getMatchCount, getPatternArguments, getSource, toHeuristicMessage, toRootMatchCauseMethods inherited from class org.refcodes.cli.CliException.CliArgsException
getArgsMethods inherited from class org.refcodes.exception.AbstractException
getErrorCode, getMessageMethods inherited from class java.lang.Throwable
addSuppressed, fillInStackTrace, getCause, getLocalizedMessage, getStackTrace, getSuppressed, initCause, printStackTrace, printStackTrace, printStackTrace, setStackTrace, toStringMethods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface org.refcodes.exception.Trap
toLocalizedMessage, toMessage, toMessage, toMessage, toShortLocalizedMessage, toShortMessage
-
Constructor Details
-
UnknownArgsException
Instantiates the classUnknownArgsException.- See Also:
-
UnknownArgsException
Instantiates the classUnknownArgsException.- See Also:
-
UnknownArgsException
Instantiates the classUnknownArgsException.- See Also:
-
UnknownArgsException
-
UnknownArgsException
Instantiates the classUnknownArgsException.- See Also:
-
UnknownArgsException
Instantiates the classUnknownArgsException.- See Also:
-
UnknownArgsException
Instantiates the classUnknownArgsException.- See Also:
-
UnknownArgsException
Instantiates the classUnknownArgsException.- See Also:
-
UnknownArgsException
Instantiates the classUnknownArgsException.- See Also:
-
UnknownArgsException
Instantiates the classUnknownArgsException.- See Also:
-
UnknownArgsException
Instantiates the classUnknownArgsException.- See Also:
-
UnknownArgsException
Instantiates the classUnknownArgsException.- See Also:
-