java.lang.Object
java.lang.Throwable
java.lang.Exception
org.refcodes.exception.AbstractException
org.refcodes.cli.CliException
org.refcodes.cli.CliException.ConsoleArgsException
org.refcodes.cli.ArgsSyntaxException
org.refcodes.cli.UnknownArgsException
- All Implemented Interfaces:
Serializable,ArgsAccessor,MatchCountAccessor,org.refcodes.exception.ErrorCodeAccessor,org.refcodes.exception.Trap,org.refcodes.mixin.SourceAccessor<Term>
Thrown in case command line arguments were not processed (did not match the
expected arguments), e.g. the arguments were rejected as them did not work
for the according syntax.
- See Also:
-
Nested Class Summary
Nested classes/interfaces inherited from class org.refcodes.cli.CliException
CliException.ConsoleArgsException, CliException.ConsoleCliExceptionNested classes/interfaces inherited from interface org.refcodes.cli.ArgsAccessor
ArgsAccessor.ArgsMutator, ArgsAccessor.ArgsPropertyNested classes/interfaces inherited from interface org.refcodes.exception.ErrorCodeAccessor
org.refcodes.exception.ErrorCodeAccessor.ErrorCodeBuilder<B extends org.refcodes.exception.ErrorCodeAccessor.ErrorCodeBuilder<B>>, org.refcodes.exception.ErrorCodeAccessor.ErrorCodeMutator, org.refcodes.exception.ErrorCodeAccessor.ErrorCodePropertyNested classes/interfaces inherited from interface org.refcodes.cli.MatchCountAccessor
MatchCountAccessor.MatchCountBuilder<B extends MatchCountAccessor.MatchCountBuilder<B>>, MatchCountAccessor.MatchCountMutator, MatchCountAccessor.MatchCountProperty -
Constructor Summary
ConstructorsConstructorDescriptionUnknownArgsException(String[] aArgs, String aMessage) Instantiates a newUnknownArgsExceptionexception.UnknownArgsException(String[] aArgs, String aMessage, String aErrorCode) Instantiates a newUnknownArgsExceptionexception.UnknownArgsException(String[] aArgs, String aMessage, String aErrorCode, Term aSource) Instantiates a newUnknownArgsExceptionexception.UnknownArgsException(String[] aArgs, String aMessage, Throwable aCause) Instantiates a newUnknownArgsExceptionexception.UnknownArgsException(String[] aArgs, String aMessage, Throwable aCause, String aErrorCode) Instantiates a newUnknownArgsExceptionexception.UnknownArgsException(String[] aArgs, String aMessage, Throwable aCause, String aErrorCode, Term aSource) Instantiates a newUnknownArgsExceptionexception.UnknownArgsException(String[] aArgs, String aMessage, Throwable aCause, Term aSource) Instantiates a newUnknownArgsExceptionexception.UnknownArgsException(String[] aArgs, String aMessage, Term aSource) Instantiates a newUnknownArgsExceptionexception.UnknownArgsException(String[] aArgs, Throwable aCause) Instantiates a newUnknownArgsExceptionexception.UnknownArgsException(String[] aArgs, Throwable aCause, String aErrorCode) Instantiates a newUnknownArgsExceptionexception.UnknownArgsException(String[] aArgs, Throwable aCause, String aErrorCode, Term aSource) Instantiates a newUnknownArgsExceptionexception.UnknownArgsException(String[] aArgs, Throwable aCause, Term aSource) Instantiates a newUnknownArgsExceptionexception. -
Method Summary
Methods inherited from class org.refcodes.cli.ArgsSyntaxException
getMatchCount, getSource, toHeuristicMessage, toRootMatchCauseMethods inherited from class org.refcodes.cli.CliException.ConsoleArgsException
getArgsMethods inherited from class org.refcodes.exception.AbstractException
getErrorCodeMethods inherited from class java.lang.Throwable
addSuppressed, fillInStackTrace, getCause, getLocalizedMessage, getMessage, getStackTrace, getSuppressed, initCause, printStackTrace, printStackTrace, printStackTrace, setStackTrace, toStringMethods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface org.refcodes.exception.Trap
toLocalizedMessage, toMessage, toShortLocalizedMessage, toShortMessage
-
Constructor Details
-
UnknownArgsException
Instantiates a newUnknownArgsExceptionexception.- Parameters:
aArgs- The arguments participating in the exception.aMessage- The aMessage describing this exception.aSource- TheTermresponsible for this exception (source).
-
UnknownArgsException
Instantiates a newUnknownArgsExceptionexception.- Parameters:
aArgs- The arguments participating in the exception.aMessage- The aMessage describing this exception.aErrorCode- The error code identifying this exception.aSource- TheTermresponsible for this exception (source).
-
UnknownArgsException
Instantiates a newUnknownArgsExceptionexception. -
UnknownArgsException
public UnknownArgsException(String[] aArgs, String aMessage, Throwable aCause, String aErrorCode, Term aSource) Instantiates a newUnknownArgsExceptionexception. -
UnknownArgsException
Instantiates a newUnknownArgsExceptionexception. -
UnknownArgsException
Instantiates a newUnknownArgsExceptionexception. -
UnknownArgsException
Instantiates a newUnknownArgsExceptionexception.- Parameters:
aArgs- The arguments participating in the exception.aMessage- The aMessage describing this exception.
-
UnknownArgsException
Instantiates a newUnknownArgsExceptionexception.- Parameters:
aArgs- The arguments participating in the exception.aMessage- The aMessage describing this exception.aErrorCode- The error code identifying this exception.
-
UnknownArgsException
Instantiates a newUnknownArgsExceptionexception. -
UnknownArgsException
Instantiates a newUnknownArgsExceptionexception. -
UnknownArgsException
Instantiates a newUnknownArgsExceptionexception. -
UnknownArgsException
Instantiates a newUnknownArgsExceptionexception.
-