java.lang.Object
java.lang.Throwable
java.lang.Exception
org.refcodes.exception.AbstractException
org.refcodes.cli.CliException
org.refcodes.cli.CliException.ConsoleArgsException
org.refcodes.cli.ArgsSyntaxException
org.refcodes.cli.UnknownArgsException
- All Implemented Interfaces:
Serializable,ArgsAccessor,org.refcodes.exception.ErrorCodeAccessor,org.refcodes.exception.Trap
Thrown in case command line arguments were not processed (did not match the
expected arguments), e.g. the arguments were rejected as them did not work
for the according syntax.
- See Also:
-
Nested Class Summary
Nested classes/interfaces inherited from class org.refcodes.cli.CliException
CliException.ConsoleArgsException, CliException.ConsoleCliExceptionNested classes/interfaces inherited from interface org.refcodes.cli.ArgsAccessor
ArgsAccessor.ArgsMutator, ArgsAccessor.ArgsPropertyNested classes/interfaces inherited from interface org.refcodes.exception.ErrorCodeAccessor
org.refcodes.exception.ErrorCodeAccessor.ErrorCodeBuilder<B extends org.refcodes.exception.ErrorCodeAccessor.ErrorCodeBuilder<B>>, org.refcodes.exception.ErrorCodeAccessor.ErrorCodeMutator, org.refcodes.exception.ErrorCodeAccessor.ErrorCodeProperty -
Constructor Summary
ConstructorsConstructorDescriptionUnknownArgsException(String[] aArgs, String message) Instantiates a new unknown args exception.UnknownArgsException(String[] aArgs, String aMessage, String aErrorCode) Instantiates a new unknown args exception.UnknownArgsException(String[] aArgs, String message, Throwable cause) Instantiates a new unknown args exception.UnknownArgsException(String[] aArgs, String aMessage, Throwable aCause, String aErrorCode) Instantiates a new unknown args exception.UnknownArgsException(String[] aArgs, Throwable cause) Instantiates a new unknown args exception.UnknownArgsException(String[] aArgs, Throwable aCause, String aErrorCode) Instantiates a new unknown args exception. -
Method Summary
Methods inherited from class org.refcodes.cli.CliException.ConsoleArgsException
getArgsMethods inherited from class org.refcodes.exception.AbstractException
getErrorCodeMethods inherited from class java.lang.Throwable
addSuppressed, fillInStackTrace, getCause, getLocalizedMessage, getMessage, getStackTrace, getSuppressed, initCause, printStackTrace, printStackTrace, printStackTrace, setStackTrace, toString
-
Constructor Details
-
UnknownArgsException
Instantiates a new unknown args exception.- Parameters:
aArgs- the argsaMessage- the messageaErrorCode- the error code
-
UnknownArgsException
Instantiates a new unknown args exception.- Parameters:
aArgs- the argsaMessage- the messageaCause- the causeaErrorCode- the error code
-
UnknownArgsException
Instantiates a new unknown args exception.- Parameters:
aArgs- the argsmessage- the messagecause- the cause
-
UnknownArgsException
Instantiates a new unknown args exception.- Parameters:
aArgs- the argsmessage- the message
-
UnknownArgsException
Instantiates a new unknown args exception.- Parameters:
aArgs- the argsaCause- the causeaErrorCode- the error code
-
UnknownArgsException
Instantiates a new unknown args exception.- Parameters:
aArgs- the argscause- the cause
-