Class UnknownOperationArgsException

All Implemented Interfaces:
Serializable, ArgsAccessor, MatchCountAccessor, OperationAccessor, org.refcodes.exception.ErrorCodeAccessor, org.refcodes.exception.Trap, org.refcodes.mixin.SourceAccessor<Term>

public class UnknownOperationArgsException extends UnknownArgsException implements OperationAccessor
Thrown in case command line arguments were not processed (did not match the expected arguments) by an Option (having a short- and/or a long-option), e.g. the arguments were rejected as them did not work for the according syntax.
See Also: