Class UnknownOperationArgsException
java.lang.Object
java.lang.Throwable
java.lang.Exception
org.refcodes.exception.AbstractException
org.refcodes.cli.CliException
org.refcodes.cli.CliException.CliArgsException
org.refcodes.cli.ArgsSyntaxException
org.refcodes.cli.UnknownArgsException
org.refcodes.cli.UnknownOperationArgsException
- All Implemented Interfaces:
Serializable,ArgsAccessor,MatchCountAccessor,OperationAccessor,org.refcodes.exception.ErrorCodeAccessor,org.refcodes.exception.Trap,org.refcodes.mixin.SourceAccessor<Term>
public class UnknownOperationArgsException
extends UnknownArgsException
implements OperationAccessor
Thrown in case command line arguments were not processed (did not match the
expected arguments) by an
Option (having a short- and/or a
long-option), e.g. the arguments were rejected as them did not work for the
according syntax.- See Also:
-
Nested Class Summary
Nested classes/interfaces inherited from class org.refcodes.cli.CliException
CliException.CliArgsExceptionNested classes/interfaces inherited from interface org.refcodes.cli.ArgsAccessor
ArgsAccessor.ArgsMutator, ArgsAccessor.ArgsPropertyNested classes/interfaces inherited from interface org.refcodes.exception.ErrorCodeAccessor
org.refcodes.exception.ErrorCodeAccessor.ErrorCodeBuilder<B extends org.refcodes.exception.ErrorCodeAccessor.ErrorCodeBuilder<B>>, org.refcodes.exception.ErrorCodeAccessor.ErrorCodeMutator, org.refcodes.exception.ErrorCodeAccessor.ErrorCodePropertyNested classes/interfaces inherited from interface org.refcodes.cli.MatchCountAccessor
MatchCountAccessor.MatchCountBuilder<B extends MatchCountAccessor.MatchCountBuilder<B>>, MatchCountAccessor.MatchCountMutator, MatchCountAccessor.MatchCountPropertyNested classes/interfaces inherited from interface org.refcodes.cli.OperationAccessor
OperationAccessor.OperationBuilder<B extends OperationAccessor.OperationBuilder<B>>, OperationAccessor.OperationMutator, OperationAccessor.OperationPropertyNested classes/interfaces inherited from interface org.refcodes.mixin.SourceAccessor
org.refcodes.mixin.SourceAccessor.SourceBuilder<SRC,B extends org.refcodes.mixin.SourceAccessor.SourceBuilder<SRC, B>>, org.refcodes.mixin.SourceAccessor.SourceMutator<SRC>, org.refcodes.mixin.SourceAccessor.SourceProperty<SRC> -
Field Summary
Fields inherited from class org.refcodes.cli.ArgsSyntaxException
_matchCount, _sourceFields inherited from class org.refcodes.cli.CliException.CliArgsException
_args -
Constructor Summary
ConstructorsConstructorDescriptionUnknownOperationArgsException(String aMessage, String[] aArgs, String aOperation) Instantiates the classUnknownOperationArgsException.UnknownOperationArgsException(String aMessage, String[] aArgs, String aOperation, String aErrorCode) Instantiates the classUnknownOperationArgsException.UnknownOperationArgsException(String aMessage, String[] aArgs, String aOperation, Throwable aCause) Instantiates the classUnknownOperationArgsException.UnknownOperationArgsException(String aMessage, String[] aArgs, String aOperation, Throwable aCause, String aErrorCode) Instantiates the classUnknownOperationArgsException.UnknownOperationArgsException(String aMessage, String[] aArgs, String aOperation, Throwable aCause, Term aSource) Instantiates the classUnknownOperationArgsException.UnknownOperationArgsException(String aMessage, String[] aArgs, String aOperation, Throwable aCause, Term aSource, String aErrorCode) Instantiates the classUnknownOperationArgsException.UnknownOperationArgsException(String aMessage, String[] aArgs, String aOperation, Term aSource) Instantiates the classUnknownOperationArgsException.UnknownOperationArgsException(String aMessage, String[] aArgs, String aOperation, Term aSource, String aErrorCode) Instantiates the classUnknownOperationArgsException.UnknownOperationArgsException(String aShortOption, String aOperation, String[] aArgs, Throwable aCause) Instantiates the classUnknownOperationArgsException.UnknownOperationArgsException(String aShortOption, String aOperation, String[] aArgs, Throwable aCause, String aErrorCode) Instantiates the classUnknownOperationArgsException.UnknownOperationArgsException(String aShortOption, String aOperation, String[] aArgs, Throwable aCause, Term aSource) Instantiates the classUnknownOperationArgsException.UnknownOperationArgsException(String aShortOption, String aOperation, String[] aArgs, Throwable aCause, Term aSource, String aErrorCode) Instantiates the classUnknownOperationArgsException. -
Method Summary
Methods inherited from class org.refcodes.cli.ArgsSyntaxException
getMatchCount, getSource, toHeuristicMessage, toRootMatchCauseMethods inherited from class org.refcodes.cli.CliException.CliArgsException
getArgsMethods inherited from class org.refcodes.exception.AbstractException
getErrorCode, getMessageMethods inherited from class java.lang.Throwable
addSuppressed, fillInStackTrace, getCause, getLocalizedMessage, getStackTrace, getSuppressed, initCause, printStackTrace, printStackTrace, printStackTrace, setStackTrace, toStringMethods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface org.refcodes.exception.Trap
toLocalizedMessage, toMessage, toMessage, toMessage, toShortLocalizedMessage, toShortMessage
-
Constructor Details
-
UnknownOperationArgsException
public UnknownOperationArgsException(String aMessage, String[] aArgs, String aOperation, Term aSource) Instantiates the classUnknownOperationArgsException.- Parameters:
aOperation- The operation for which the arguments did not apply.- See Also:
-
UnknownOperationArgsException
-
UnknownOperationArgsException
-
UnknownOperationArgsException
-
UnknownOperationArgsException
-
UnknownOperationArgsException
-
UnknownOperationArgsException
Instantiates the classUnknownOperationArgsException.- Parameters:
aOperation- The operation for which the arguments did not apply.- See Also:
-
UnknownOperationArgsException
public UnknownOperationArgsException(String aMessage, String[] aArgs, String aOperation, String aErrorCode) Instantiates the classUnknownOperationArgsException.- Parameters:
aOperation- The operation for which the arguments did not apply.- See Also:
-
UnknownOperationArgsException
public UnknownOperationArgsException(String aMessage, String[] aArgs, String aOperation, Throwable aCause) Instantiates the classUnknownOperationArgsException.- Parameters:
aOperation- The operation for which the arguments did not apply.- See Also:
-
UnknownOperationArgsException
-
UnknownOperationArgsException
public UnknownOperationArgsException(String aShortOption, String aOperation, String[] aArgs, Throwable aCause) Instantiates the classUnknownOperationArgsException.- Parameters:
aOperation- The operation for which the arguments did not apply.- See Also:
-
UnknownOperationArgsException
-
-
Method Details
-
getOperation
Retrieves the operation from the operation property.- Specified by:
getOperationin interfaceOperationAccessor- Returns:
- The operation stored by the operation property.
-
getPatternArguments
- Specified by:
getPatternArgumentsin interfaceorg.refcodes.exception.Trap- Overrides:
getPatternArgumentsin classArgsSyntaxException
-