java.lang.Object
org.refcodes.cli.AbstractCondition
org.refcodes.cli.XorCondition
- All Implemented Interfaces:
Condition,Constituent,Synopsisable,org.refcodes.mixin.DescriptionAccessor,org.refcodes.mixin.Resetable,org.refcodes.mixin.Schemable<CliSchema>
- Direct Known Subclasses:
CasesCondition
An
XorCondition represents a list of Condition
(Constituent) instances of which only one is allowed to be parsed
successfully when the
Constituent.parseArgs(String[], String[], CliContext) methods are
invoked. The command line arguments syntax { -a ^ -b ^ -c }
specifies that only "-a", only "-b" or only "-c" must be set. In case more
then one is set or none, then the XorCondition will terminate the
parseArgs(String[], String[], CliContext) method with an exception.-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.mixin.DescriptionAccessor
org.refcodes.mixin.DescriptionAccessor.DescriptionBuilder<B extends org.refcodes.mixin.DescriptionAccessor.DescriptionBuilder<B>>, org.refcodes.mixin.DescriptionAccessor.DescriptionMutator, org.refcodes.mixin.DescriptionAccessor.DescriptionProperty -
Field Summary
Fields -
Constructor Summary
ConstructorsModifierConstructorDescriptionprotectedXorCondition(String aDescription, Constituent... aArgs) XorCondition(Constituent... aArgs) -
Method Summary
Modifier and TypeMethodDescriptionparseArgs(String[] aArgs, String[] aOptions, CliContext aCliCtx) Parses the provided command line arguments and determines the according values by evaluating thisConstituentinstance or, in case of being a node in the syntax tree (such as aCondition, traversing the childConstituentinstances'Constituent.parseArgs(String[], String[], CliContext)methods.toSynopsis(CliContext aCliCtx) Returns the human readable (verbose) syntax of implementing class ATTENTION: As of different parenthesis settings for some notations regarding the rootConstituentand the childConstituents, the methodConstituent.toSyntax(CliContext)is called from inside aConstituenthierarchy.Methods inherited from class org.refcodes.cli.AbstractCondition
addChild, getChildren, getFirst, reset, toOperand, toOperands, toSchema, toString, toSyntax, toValueMethods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface org.refcodes.cli.Condition
toOperand, toOperand, toOperand, toOperandsMethods inherited from interface org.refcodes.cli.Constituent
parseArgs, toSyntax, toSyntax, toSyntax, toSyntax, toSyntax, toValueMethods inherited from interface org.refcodes.mixin.DescriptionAccessor
getDescriptionMethods inherited from interface org.refcodes.mixin.Resetable
resetMethods inherited from interface org.refcodes.mixin.Schemable
toSchemaMethods inherited from interface org.refcodes.cli.Synopsisable
toSynopsis, toSynopsis, toSynopsis, toSynopsis
-
Field Details
-
_description
-
-
Constructor Details
-
XorCondition
- Parameters:
aArgs- TheConstituent(Condition) instances to be nested
-
XorCondition
- Parameters:
aDescription- The description of thisCondition.aArgs- TheConstituent(Condition) instances to be nested
-
-
Method Details
-
parseArgs
public List<? extends Operand<?>> parseArgs(String[] aArgs, String[] aOptions, CliContext aCliCtx) throws ArgsSyntaxException Parses the provided command line arguments and determines the according values by evaluating thisConstituentinstance or, in case of being a node in the syntax tree (such as aCondition, traversing the childConstituentinstances'Constituent.parseArgs(String[], String[], CliContext)methods. In case of successfully parsing thisConstituentand / or the childConstituentinstances, the evaluated command line arguments are returned: Depending on theConstituentsubclasses representing the evaluated command line arguments, instances ofFlagclasses,Optionclasses orOperandclasses may be found in the result. In case of parsing failure, an according exception is thrown. ATTENTION: This method does not test for superfluous command line arguments being passed; e.g. command line arguments not being evaluated by any of theConstituentinstance being traversed. This method is commonly used by a rootConstituent'sArgsParser.evalArgs(String[])method, which delegates to theConstituent.parseArgs(String[], String[], CliContext)method and after which it determines whether there are superfluous arguments to be taken care of (by throwing an according exception). Business logic therefore should invoke the root node'sConstituent.parseArgs(String[], String[], CliContext)method as ignoring superfluous command line arguments will cause unexpected behavior from the point of view of the invoker.- Specified by:
parseArgsin interfaceConstituent- Parameters:
aArgs- The command line arguments to be parsed.aOptions- The list of options (short and as well as long) which are reserved and cannot be used as value.aCliCtx- the cli context- Returns:
- The list of evaluated command line arguments being instances of
the
Operandinterfaces or its sub-types. - Throws:
ArgsSyntaxException- thrown in case of a command line arguments mismatch regarding provided and expected args.
-
toSynopsis
Returns the human readable (verbose) syntax of implementing class ATTENTION: As of different parenthesis settings for some notations regarding the rootConstituentand the childConstituents, the methodConstituent.toSyntax(CliContext)is called from inside aConstituenthierarchy. In case the syntax is to be retrieved from the rootConstituentor an encapsulating and different type, then the applicable method to be called isSynopsisable.toSynopsis(SyntaxNotation), as for some notations it will for example not create the most outer braces.- Specified by:
toSynopsisin interfaceConstituent- Specified by:
toSynopsisin interfaceSynopsisable- Parameters:
aCliCtx- TheCliContextfor which the syntax is being generated.- Returns:
- The human readable (verbose) command line arguments syntax.
-
getDescription
- Specified by:
getDescriptionin interfaceorg.refcodes.mixin.DescriptionAccessor
-