java.lang.Object
org.refcodes.cli.AbstractCondition
org.refcodes.cli.XorCondition
- All Implemented Interfaces:
ArgsSyntax,Condition,Synopsisable,Syntaxable,org.refcodes.mixin.Resetable,org.refcodes.mixin.Schemable<CliSchema>
- Direct Known Subclasses:
CasesCondition
An
XorCondition represents a list of ArgsSyntax
(Syntaxable) instances of which only one is allowed to be parsed
successfully when the Syntaxable.parseArgs(String[], String[])
methods are invoked. The command line arguments syntax
{ -a ^ -b ^ -c } specifies that only "-a", only "-b" or only
"-c" must be set. In case more then one is set or none, then the
XorCondition will terminate the
parseArgs(String[], String[]) method with an exception.-
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionParses the provided command line arguments and determines the according values by evaluating thisSyntaxableinstance or, in case of being a node in the syntax tree (such as aArgsSyntax, traversing the childSyntaxableinstances'Syntaxable.parseArgs(String[], String[])methods.toState()TheSyntaxable.toState()method might be used by theObject.toString()method and prints out the state of the syntaxable and (if any) its children.toSynopsis(SyntaxNotation aSyntaxNotation, String aOptEscCode, String aParamEscCode, String aResetEscCode) Returns the human readable (verbose) syntax of implementing class ATTENTION: As of different parenthesis settings for some notations regarding the rootSyntaxableand the childSyntaxables, the methodSyntaxable.toSyntax(SyntaxNotation, String, String, String)is called from inside aSyntaxablehierarchy.toSyntax(SyntaxNotation aSyntaxNotation, String aOptEscCode, String aParamEscCode, String aResetEscCode) This method is to be called from inside theSyntaxablehierarchy; use the methodSynopsisable.toSynopsis(SyntaxNotation)in case you invoke syntax retrieval from the rootSyntaxable.Methods inherited from class org.refcodes.cli.AbstractCondition
addChild, getChildren, getFirst, reset, toOperand, toOperands, toSchema, toString, toValueMethods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface org.refcodes.cli.ArgsSyntax
toOperand, toOperand, toOperand, toOperandsMethods inherited from interface org.refcodes.mixin.Resetable
resetMethods inherited from interface org.refcodes.mixin.Schemable
toSchemaMethods inherited from interface org.refcodes.cli.Synopsisable
toSynopsis, toSynopsis, toSynopsis
-
Constructor Details
-
XorCondition
- Parameters:
aArgs- TheSyntaxable(ArgsSyntax) instances to be nested
-
-
Method Details
-
parseArgs
public List<? extends Operand<?>> parseArgs(String[] aArgs, String[] aOptions) throws ArgsSyntaxException Parses the provided command line arguments and determines the according values by evaluating thisSyntaxableinstance or, in case of being a node in the syntax tree (such as aArgsSyntax, traversing the childSyntaxableinstances'Syntaxable.parseArgs(String[], String[])methods. In case of successfully parsing thisSyntaxableand / or the childSyntaxableinstances, the evaluated command line arguments are returned: Depending on theSyntaxablesubclasses representing the evaluated command line arguments, instances ofFlagclasses,Optionclasses orOperandclasses may be found in the result. In case of parsing failure, an according exception is thrown. ATTENTION: This method does not test for superfluous command line arguments being passed; e.g. command line arguments not being evaluated by any of theSyntaxableinstance being traversed. This method is commonly used by a rootSyntaxable'sArgsParser.evalArgs(String[])method, which delegates to theSyntaxable.parseArgs(String[], String[])method and after which it determines whether there are superfluous arguments to be taken care of (by throwing an according exception). Business logic therefore should invoke the root node'sSyntaxable.parseArgs(String[], String[])method as ignoring superfluous command line arguments will cause unexpected behavior from the point of view of the invoker.- Specified by:
parseArgsin interfaceSyntaxable- Parameters:
aArgs- The command line arguments to be parsed.aOptions- The list of options (short and as well as long) which are reserved and cannot be used as value.- Returns:
- The list of evaluated command line arguments being instances of
the
Operandinterfaces or its sub-types. - Throws:
ArgsSyntaxException- thrown in case of a command line arguments mismatch regarding provided and expected args.
-
toSyntax
public String toSyntax(SyntaxNotation aSyntaxNotation, String aOptEscCode, String aParamEscCode, String aResetEscCode) This method is to be called from inside theSyntaxablehierarchy; use the methodSynopsisable.toSynopsis(SyntaxNotation)in case you invoke syntax retrieval from the rootSyntaxable. Returns the human readable (verbose) syntax of thisSyntaxableinstance including, in case of being a node in the syntax tree (such as aArgsSyntax, the syntax of the childSyntaxableinstances. ATTENTION: As of different parenthesis settings for some notations regarding the rootSyntaxableand the childSyntaxables, the methodSyntaxable.toSyntax(SyntaxNotation, String, String, String)is called from inside theSyntaxablehierarchy. In case the syntax is to be retrieved from the rootSyntaxable, then the applicable method to be called isSynopsisable.toSynopsis(SyntaxNotation), as for some notations it will for example not create the most outer braces.- Specified by:
toSyntaxin interfaceSyntaxable- Overrides:
toSyntaxin classAbstractCondition- Parameters:
aSyntaxNotation- The syntax notation used for generating the command line arguments syntax.aOptEscCode- The escape code to be used when processing an option, e.g. this can be an ANSI Escape-Code to highlight the option.aParamEscCode- The escape code to be used when processing a keyword, e.g. this can be an ANSI Escape-Code to highlight the option and/or parameters.aResetEscCode- The escape code to close (reset) any Escape-Code being set before.- Returns:
- The human readable (verbose) command line arguments syntax.
-
toSynopsis
public String toSynopsis(SyntaxNotation aSyntaxNotation, String aOptEscCode, String aParamEscCode, String aResetEscCode) Returns the human readable (verbose) syntax of implementing class ATTENTION: As of different parenthesis settings for some notations regarding the rootSyntaxableand the childSyntaxables, the methodSyntaxable.toSyntax(SyntaxNotation, String, String, String)is called from inside aSyntaxablehierarchy. In case the syntax is to be retrieved from the rootSyntaxableor an encapsulating and different type, then the applicable method to be called isSynopsisable.toSynopsis(SyntaxNotation), as for some notations it will for example not create the most outer braces.- Specified by:
toSynopsisin interfaceSynopsisable- Parameters:
aSyntaxNotation- The syntax notation used for generating the command line arguments syntax.aOptEscCode- The escape code to be used when processing an option, e.g. this can be an ANSI Escape-Code to highlight the option.aParamEscCode- The escape code to be used when processing am argument, e.g. this can be an ANSI Escape-Code to highlight the option.aResetEscCode- The escape code to close (reset) any Escape-Code being set before.- Returns:
- The human readable (verbose) command line arguments syntax.
-
toState
TheSyntaxable.toState()method might be used by theObject.toString()method and prints out the state of the syntaxable and (if any) its children. Even in case parsing command line arguments failed, the state till failure can be inspected with this method.- Specified by:
toStatein interfaceSyntaxable- Returns:
- The state of this
Syntaxableinstance and (if any) its children.
-