Uses of Class
org.refcodes.cli.AbstractCondition
-
Uses of AbstractCondition in org.refcodes.cli
Subclasses of AbstractCondition in org.refcodes.cliModifier and TypeClassDescriptionclassTheAllConditionenforces that the encapsulatedConstituentconsumes all arguments passed via invoking itsConstituent.parseArgs(String[], CliContext), else aSuperfluousArgsExceptionis thrown.classAnAndConditioncontains (represents) a list ofCondition(Constituent) instances (nested by theAndCondition) of which all are to be parsed successfully as of invoking theConstituent.parseArgs(String[], String[], CliContext)methods.classAny of the nestedConditionconditions may match for theAnyConditionto match, e.g. all of the nested conditions are optional.classTheCasesConditionis anXorConditionmaking sure that all possible cases inside theXorConditionmust(!)classAnOrConditionrepresents a list ofCondition(Constituent) instances of which at least one must be parsed successfully when theConstituents'Constituent.parseArgs(String[], String[], CliContext)methods are invoked.classAnXorConditionrepresents a list ofCondition(Constituent) instances of which only one is allowed to be parsed successfully when theConstituent.parseArgs(String[], String[], CliContext)methods are invoked.