Uses of Class
org.refcodes.cli.AbstractCondition
-
Uses of AbstractCondition in org.refcodes.cli
Subclasses of AbstractCondition in org.refcodes.cliModifier and TypeClassDescriptionclassTheAllConditionenforces that the encapsulatedSyntaxableconsumes all arguments passed via invoking itsSyntaxable.parseArgs(String[]), else aSuperfluousArgsExceptionis thrown.classAnAndConditioncontains (represents) a list ofArgsSyntax(Syntaxable) instances (nested by theAndCondition) of which all are to be parsed successfully as of invoking theSyntaxable.parseArgs(String[], String[])methods.classAny of the nestedArgsSyntaxconditions may match for theAnyConditionto match, e.g. all of the nested conditions are optional.classTheCasesConditionis anXorConditionmaking sure that all possible cases inside theXorConditionmust(!)classclassAnOrConditionrepresents a list ofArgsSyntax(Syntaxable) instances of which at least one must be parsed successfully when theSyntaxables'Syntaxable.parseArgs(String[], String[])methods are invoked.classAnXorConditionrepresents a list ofArgsSyntax(Syntaxable) instances of which only one is allowed to be parsed successfully when theSyntaxable.parseArgs(String[], String[])methods are invoked.