Uses of Class
org.refcodes.cli.AbstractCondition
-
-
Uses of AbstractCondition in org.refcodes.cli
Subclasses of AbstractCondition in org.refcodes.cli Modifier and Type Class Description classAllConditionTheAllConditionenforces that the encapsulatedSyntaxableconsumes all arguments passed via invoking itsSyntaxable.parseArgs(String[]), else aSuperfluousArgsExceptionis thrown.classAndConditionAnAndConditioncontains (represents) a list ofArgsSyntax(Syntaxable) instances (nested by theAndCondition) of which all are to be parsed successfully as of invoking theSyntaxable.parseArgs(String[], String[])methods.classAnyConditionAny of the nestedArgsSyntaxconditions may match for theAnyConditionto match, e.g. all of the nested conditions are optional.classCasesConditionTheCasesConditionis anXorConditionmaking sure that all possible cases inside theXorConditionmust(!)classOptionConditionclassOrConditionAnOrConditionrepresents a list ofArgsSyntax(Syntaxable) instances of which at least one must be parsed successfully when theSyntaxables'Syntaxable.parseArgs(String[], String[])methods are invoked.classXorConditionAnXorConditionrepresents a list ofArgsSyntax(Syntaxable) instances of which only one is allowed to be parsed successfully when theSyntaxable.parseArgs(String[], String[])methods are invoked.
-