Uses of Class
org.refcodes.cli.AbstractCondition
-
Uses of AbstractCondition in org.refcodes.cli
Subclasses of AbstractCondition in org.refcodes.cli Modifier and Type Class Description classAndConditionAnAndConditioncontains (represents) a list ofCondition(Syntaxable) instances (nested by theAndCondition) of which all are to be parsed successfully as of invoking theSyntaxable.parseArgs(String[], String[])methods.classOptionalConditionTheOptionalConditioncan nested by anAndConditionand encapsulates aConditionwhich may be provided but does not necessarily needs to be provided in order for theAndConditionto successfully parse the nestedConditionitems including theOptionalCondition.classOptionConditionFacadeclassOrConditionAnOrConditionrepresents a list ofCondition(Syntaxable) instances of which at least one must be parsed successfully when theSyntaxables'Syntaxable.parseArgs(String[], String[])methods are invoked.classXorConditionAnXorConditionrepresents a list ofCondition(Syntaxable) instances of which only one is allowed to be parsed successfully when theSyntaxable.parseArgs(String[], String[])methods are invoked.