Uses of Class
org.refcodes.cli.AbstractOperand
-
Uses of AbstractOperand in org.refcodes.cli
Subclasses of AbstractOperand in org.refcodes.cli Modifier and Type Class Description classAbstractOption<T>TheAbstractOptionis an abstract implementation of anOptionproviding the boiler plate when implementing theOptioninterface.classCharOptionclassDebugFlagA predefined debug switch.classDoubleOptionclassEnumOption<T extends Enum<T>>The Class EnumOption.classFileOptionclassFlagTheFlagclass implements theOptioninterface for representing either atrueor afalsestate: When a flag is provided to your command line arguments, then it is considered to betrue, when it is omitted, then it is considered to befalseas ofFlag.isEnabled().classFloatOptionclassForceFlagA predefined force switch.classHelpFlagA predefined help switch.classIntOptionclassLongOptionclassOperationTheOperationis an argument representing a function or a method and is either provided or not provided as ofOperation.isEnabled().classQuietFlagA predefined "be quiet" switch.classStringOperandclassStringOptionclassSysInfoFlagA predefined system information switch.classVerboseFlagA predefined verbose switch.