Uses of Interface
org.refcodes.cli.ArgsAccessor
-
-
Uses of ArgsAccessor in org.refcodes.cli
Subinterfaces of ArgsAccessor in org.refcodes.cli Modifier and Type Interface Description static interfaceArgsAccessor.ArgsPropertyProvides a args property.interfaceOperand<T>AnOperandrepresents a value parsed from command line arguments.interfaceOption<T>AnOptionrepresents a command line option with the according option's value.Classes in org.refcodes.cli that implement ArgsAccessor Modifier and Type Class Description classAbstractOperand<T>TheAbstractOperandis an abstract implementation of anOperandproviding the boiler plate when implementing theOperandinterface.classAbstractOption<T>TheAbstractOptionis an abstract implementation of anOptionproviding the boiler plate when implementing theOptioninterface.classAmbiguousArgsExceptionThrown in case the command line arguments do not match the required syntax.classArgsSyntaxExceptionThrown in case of a command line arguments mismatch regarding provided and expected args.classArrayOperand<T>Creates an array representation facade for the encapsulatedOperand.classArrayOption<T>Creates an array representation facade for the encapsulatedOption.classCharOptionclassCleanFlagA predefined cleanFlag: A predefinedFlaggives itsCleanFlag.SHORT_OPTION, itsCleanFlag.LONG_OPTIONas well as itsCleanFlag.ALIASan according semantics regarded by other subsystems.static classCliException.ConsoleArgsExceptionThis abstract exception is the base exception for all command line argument related exceptions.classConfigOptionTheConfigOptionrepresents anOptionholding a value specifying a configuration resource (file).classDaemonFlagA predefined daemonFlag: A predefinedFlaggives itsDaemonFlag.SHORT_OPTION, itsDaemonFlag.LONG_OPTIONas well as itsDaemonFlag.ALIASan according semantics regarded by other subsystems.classDebugFlagA predefined debugFlag: A predefinedFlaggives itsDebugFlag.SHORT_OPTION, itsDebugFlag.LONG_OPTIONas well as itsDebugFlag.ALIASan according semantics regarded by other subsystems.classDoubleOptionclassEnumOption<T extends Enum<T>>The Class EnumOption.classFileOptionclassFlagTheFlagclass implements theOptioninterface for representing either atrueor afalsestate: When a flag is provided to your command line arguments, then it is considered to betrue, when it is omitted, then it is considered to befalseas ofFlag.isEnabled().classFloatOptionclassForceFlagA predefined forceFlag: A predefinedFlaggives itsForceFlag.SHORT_OPTION, itsForceFlag.LONG_OPTIONas well as itsForceFlag.ALIASan according semantics regarded by other subsystems.classHelpFlagA predefined helpFlag: A predefinedFlaggives itsHelpFlag.SHORT_OPTION, itsHelpFlag.LONG_OPTIONas well as itsHelpFlag.ALIASan according semantics regarded by other subsystems.classInitFlagA predefined initFlag: A predefinedFlaggives itsInitFlag.SHORT_OPTION, itsInitFlag.LONG_OPTIONas well as itsInitFlag.ALIASan according semantics regarded by other subsystems.classIntOptionclassLongOptionclassNoneOperandTheNoneOperandrepresents an empty set of arguments, e.g. no command line argument is being passed.classOperationTheOperationis an argument representing a function or a method ("command") and is either provided or not provided as ofOperation.isEnabled().classParseArgsExceptionThrown in case the provided command line arguments do not respect the required semantics or cannot be converted to the required type.classQuietFlagA predefined "be quiet"Flag: A predefinedFlaggives itsQuietFlag.SHORT_OPTION, itsQuietFlag.LONG_OPTIONas well as itsQuietFlag.ALIASan according semantics regarded by other subsystems.classStringOperandclassStringOptionclassSuperfluousArgsExceptionThrown in case there were arguments found not being used (superfluous arguments).classSysInfoFlagA predefined system informationFlag: A predefinedFlaggives itsSysInfoFlag.SHORT_OPTION, itsSysInfoFlag.LONG_OPTIONas well as itsSysInfoFlag.ALIASan according semantics regarded by other subsystems..classUnknownArgsExceptionThrown in case command line arguments were not processed (did not match the expected arguments), e.g. the arguments were rejected as them did not work for the according syntax.classVerboseFlagA predefined verboseFlag: A predefinedFlaggives itsVerboseFlag.SHORT_OPTION, itsVerboseFlag.LONG_OPTIONas well as itsVerboseFlag.ALIASan according semantics regarded by other subsystems.
-