-
Subclasses of ArgsMismatchException in org.refcodes.cli
| Modifier and Type |
Class |
Description |
class |
AmbiguousArgsException |
Thrown in case at least one command line argument is ambiguous regarding
expected args vs. provided args.
|
class |
ParseArgsException |
Thrown in case the provided command line arguments do not respect the
required syntax or cannot be converted to the required type.
|
class |
SuperfluousArgsException |
Thrown in case there were arguments found not being used (superfluous
arguments).
|
class |
UnknownArgsException |
Thrown in case not one command line argument matched regarding the provided
args vs. the expected args.
|