Uses of Interface
org.refcodes.cli.ArgsParser
-
Uses of ArgsParser in org.refcodes.cli
Classes in org.refcodes.cli that implement ArgsParserModifier and TypeClassDescriptionclassA straightforward implementation of theArgsParserinterface.Methods in org.refcodes.cli that return ArgsParserModifier and TypeMethodDescriptionArgsParserAccessor.getArgsParser()Retrieves the args-parser from theArgsParserproperty.default ArgsParserArgsParserAccessor.ArgsParserProperty.letArgsParser(ArgsParser aArgsParser) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenArgsParser(setter) as ofArgsParserAccessor.ArgsParserMutator.setArgsParser(ArgsParser)and returns the very same value (getter).default ArgsParserArgsParser.withBannerBorderEscapeCode(String aBannerBorderEscCode) Sets the banner's border Escape-Code for the banner border Escape-Code property.default ArgsParserArgsParser.withBannerEscapeCode(String aBannerEscCode) Sets the banner's content Escape-Code for the banner Escape-Code property.default ArgsParserArgsParser.withBannerFont(org.refcodes.textual.Font aBannerFont) With banner font.default ArgsParserArgsParser.withBannerFontPalette(char[] aColorPalette) With banner font palette.default ArgsParserArgsParser.withCommandEscapeCode(String aCommandEscCode) Sets the command name's (CLI executable) Escape-Code for the command name Escape-Code property.default ArgsParserArgsParser.withConsoleWidth(int aConsoleWidth) Set the console with.default ArgsParserArgsParser.withCopyrightNote(String aCopyrightNote) Set the copyright note used by theprintHelp()method when writing out the copyright claim and make other adjustments with the result (with regards to the Builder-Pattern).default ArgsParserArgsParser.withDescription(String aDescription) With description.default ArgsParserArgsParser.withDescriptionEscapeCode(String aDescriptionEscCode) Sets the description Escape-Code for the description Escape-Code property.default ArgsParserArgsParser.withErrorOut(PrintStream aErrorOut) Set the error outPrintStreamand make other adjustments with the result (with regards to the Builder-Pattern).default ArgsParserArgsParser.withEscapeCodesEnabled(boolean isEscCodeEnabled) default ArgsParserArgsParser.withEvalArgs(String[] aArgs) Same asevalArgs(String[])with the difference that this class's instance being invoked is returned as of the builder pattern.default ArgsParserArgsParser.withEvalArgs(List<String> aArgs) Same asevalArgs(List)with the difference that this class's instance being invoked is returned as of the builder pattern.default ArgsParserArgsParser.withExample(String aDescription, Operand<?>... aOperands) Adds a usage example by providing a description of the example and the command line arguments required by the example.default ArgsParserArgsParser.withExample(Example aExample) Adds a usage example.default ArgsParserArgsParser.withExamples(Collection<Example> aExamples) Adds all the bunch ofExampleelements provided.default ArgsParserArgsParser.withExamples(Example[] aExamples) Adds all the bunch ofExampleelements provided.default ArgsParserArgsParser.withLicenseNote(String aLicenseNote) Set the license note used by theprintHelp()method when writing out the licensing conditions and make other adjustments with the result (with regards to the Builder-Pattern).default ArgsParserArgsParser.withLineBreak(String aLineBreak) Set the console's line break.default ArgsParserArgsParser.withLineSeparatorEscapeCode(String aLineSeparatorEscCode) Sets the line separator Escape-Code for the line separator Escape-Code property.default ArgsParserArgsParser.withMaxConsoleWidth(int aMaxConsoleWidth) Set the maximum console width to use in case the console width is greater than the maximum you want.default ArgsParserWith name.default ArgsParserArgsParser.withOptionEscapeCode(String aOptEscCode) Sets the option Escape-Code for the option Escape-Code property.default ArgsParserArgsParser.withParamEscapeCode(String aParamEscCode) Sets the parameter Escape-Code for the parameter Escape-Code property.default ArgsParserArgsParser.withResetEscapeCode(String aResetEscCode) default ArgsParserArgsParser.withSeparatorLnChar(char aSeparatorLnChar) Set the character to be used when printing a separator line with theprintSeparatorLn()method.default ArgsParserArgsParser.withStandardOut(PrintStream aStandardOut) Set the standard outPrintStreamand make other adjustments with the result (with regards to the Builder-Pattern).default ArgsParserArgsParser.withSyntaxNotation(SyntaxNotation aSyntaxNotation) Set theSyntaxNotationand make other adjustments with the result (with regards to the Builder-Pattern).default ArgsParserArgsParser.withTextBoxGrid(org.refcodes.textual.TextBoxGrid aTextBoxGrid) default ArgsParserWith title.Methods in org.refcodes.cli with parameters of type ArgsParserModifier and TypeMethodDescriptiondefault ArgsParserArgsParserAccessor.ArgsParserProperty.letArgsParser(ArgsParser aArgsParser) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenArgsParser(setter) as ofArgsParserAccessor.ArgsParserMutator.setArgsParser(ArgsParser)and returns the very same value (getter).voidArgsParserAccessor.ArgsParserMutator.setArgsParser(ArgsParser aProperties) Sets the args-parser for theArgsParserproperty.ArgsParserAccessor.ArgsParserBuilder.withArgsParser(ArgsParser aProperties) Sets the args-parser for theArgsParserproperty.