Uses of Interface
org.refcodes.cli.ArgsParserMixin
-
Uses of ArgsParserMixin in org.refcodes.cli
Classes in org.refcodes.cli with type parameters of type ArgsParserMixin Modifier and Type Interface Description interfaceArgsParserMixin<B extends ArgsParserMixin<B>>This mixin provides builder additions (as of the builder pattern for chained configuring method calls) for parsing command line arguments.Subinterfaces of ArgsParserMixin in org.refcodes.cli Modifier and Type Interface Description interfaceArgsParserTheArgsParserprovides means for parsing command line arguments and constructing a command line utility's help output.Classes in org.refcodes.cli that implement ArgsParserMixin Modifier and Type Class Description classArgsParserImplA straightforward implementation of theArgsParserinterface.