Uses of Interface
org.refcodes.cli.ArgsSyntaxAccessor.ArgsSyntaxBuilder
-
Uses of ArgsSyntaxAccessor.ArgsSyntaxBuilder in org.refcodes.cli
Classes in org.refcodes.cli with type parameters of type ArgsSyntaxAccessor.ArgsSyntaxBuilderModifier and TypeInterfaceDescriptionstatic interfaceProvides a builder method for a root condition property returning the builder for applying multiple build operations.