Uses of Class
org.refcodes.cli.ArgsSyntaxException
-
Uses of ArgsSyntaxException in org.refcodes.cli
Subclasses of ArgsSyntaxException in org.refcodes.cliModifier and TypeClassDescriptionclassThrown in case the command line arguments do not match the required syntax.classThrown in case the provided command line arguments do not respect the required semantics or cannot be converted to the required type.classThrown in case the provided command line arguments do not respect the required semantics or cannot be converted to the required type by anOption(having a short- and/or a long-option), e.g. the arguments were rejected as them did not work for the according syntax.classThrown in case there were arguments found not being used (superfluous arguments).classThrown in case command line arguments were not processed (did not match the expected arguments), e.g. the arguments were rejected as them did not work for the according syntax.classThrown in case command line arguments were not processed (did not match the expected arguments) by anOption(having a short- and/or a long-option), e.g. the arguments were rejected as them did not work for the according syntax.Fields in org.refcodes.cli declared as ArgsSyntaxExceptionModifier and TypeFieldDescriptionprotected ArgsSyntaxExceptionAbstractTerm._exceptionprotected ArgsSyntaxExceptionAbstractTerm._exceptionprotected ArgsSyntaxExceptionAbstractTerm._exceptionprotected ArgsSyntaxExceptionAbstractTerm._exceptionprotected ArgsSyntaxExceptionAbstractTerm._exceptionprotected ArgsSyntaxExceptionAbstractTerm._exceptionprotected ArgsSyntaxExceptionAbstractTerm._exceptionprotected ArgsSyntaxExceptionAbstractTerm._exceptionprotected ArgsSyntaxExceptionAbstractTerm._exceptionprotected ArgsSyntaxExceptionAbstractTerm._exceptionprotected ArgsSyntaxExceptionAbstractTerm._exceptionprotected ArgsSyntaxExceptionAbstractTerm._exceptionprotected ArgsSyntaxExceptionAbstractTerm._exceptionprotected ArgsSyntaxExceptionAbstractTerm._exceptionprotected ArgsSyntaxExceptionAbstractTerm._exceptionprotected ArgsSyntaxExceptionAbstractTerm._exceptionprotected ArgsSyntaxExceptionAbstractTerm._exceptionprotected ArgsSyntaxExceptionAbstractTerm._exceptionprotected ArgsSyntaxExceptionAbstractTerm._exceptionprotected ArgsSyntaxExceptionAbstractTerm._exceptionprotected ArgsSyntaxExceptionAbstractTerm._exceptionprotected ArgsSyntaxExceptionAbstractTerm._exceptionprotected ArgsSyntaxExceptionAbstractTerm._exceptionprotected ArgsSyntaxExceptionAbstractTerm._exceptionprotected ArgsSyntaxExceptionAbstractTerm._exceptionprotected ArgsSyntaxExceptionAbstractTerm._exceptionprotected ArgsSyntaxExceptionAbstractTerm._exceptionprotected ArgsSyntaxExceptionAbstractTerm._exceptionprotected ArgsSyntaxExceptionAbstractTerm._exceptionprotected ArgsSyntaxExceptionAbstractTerm._exceptionprotected ArgsSyntaxExceptionAbstractTerm._exceptionprotected ArgsSyntaxExceptionAbstractTerm._exceptionprotected ArgsSyntaxExceptionAbstractTerm._exceptionprotected ArgsSyntaxExceptionAbstractTerm._exceptionprotected ArgsSyntaxExceptionAbstractTerm._exceptionprotected ArgsSyntaxExceptionAbstractTerm._exceptionprotected ArgsSyntaxExceptionAbstractTerm._exceptionprotected ArgsSyntaxExceptionAbstractTerm._exceptionprotected ArgsSyntaxExceptionAbstractTerm._exceptionprotected ArgsSyntaxExceptionAbstractTerm._exceptionprotected ArgsSyntaxExceptionAbstractTerm._exceptionprotected ArgsSyntaxExceptionAbstractTerm._exceptionprotected ArgsSyntaxExceptionAbstractTerm._exceptionprotected ArgsSyntaxExceptionAbstractTerm._exceptionprotected ArgsSyntaxExceptionAbstractTerm._exceptionMethods in org.refcodes.cli that return ArgsSyntaxExceptionModifier and TypeMethodDescriptionAnyCondition.getException()Retrieves theArgsSyntaxExceptionexception caught while invoking theTerm.parseArgs(String[], CliContext)method.Term.getException()Retrieves theArgsSyntaxExceptionexception in case invokingTerm.parseArgs(String[], CliContext)failed.ArgsSyntaxException.toRootMatchCause()Determines the root cause of this exception with the same match count (getMatchCount()) as this exception.Methods in org.refcodes.cli that throw ArgsSyntaxExceptionModifier and TypeMethodDescriptionOperand<?>[]Evaluates the provided command line arguments and determines the according values by evaluating the rootCondition.Operand<?>[]Evaluates the provided command line arguments and determines the according values by evaluating the rootCondition.default Operand<?>[]Evaluates the provided command line arguments as ofParseArgs.evalArgs(String[]), additionally filtering (excluding) the arguments matching the providedPattern.default Operand<?>[]ParseArgs.evalArgs(String[] aArgs, ArgsFilter aArgsFilter) Evaluates the provided command line arguments as ofParseArgs.evalArgs(String[]), additionally filtering (excluding) the arguments matching the providedArgsFilter.default Operand<?>[]Same asParseArgs.evalArgs(String[])with the difference that the elements representing the arguments are passed as a list instead of an array.default Operand<?>[]Evaluates the provided command line arguments as ofParseArgs.evalArgs(String[]), additionally filtering (excluding) the arguments matching the providedPattern.default Operand<?>[]ParseArgs.evalArgs(List<String> aArgs, ArgsFilter aArgsFilter) Evaluates the provided command line arguments as ofParseArgs.evalArgs(String[]), additionally filtering (excluding) the arguments matching the providedArgsFilter.Operand<?>[]AbstractOperand.parseArgs(String[] aArgs, String[] aOptions, CliContext aCliContext) Parses the provided command line arguments and determines the according values by evaluating thisTerminstance or, in case of being a node in the syntax tree (such as aCondition, traversing the childTerminstances'Term.parseArgs(String[], String[], CliContext)methods.Operand<?>[]AbstractOption.parseArgs(String[] aArgs, String[] aOptions, CliContext aCliCtx) Parses the provided command line arguments and determines the according values by evaluating thisTerminstance or, in case of being a node in the syntax tree (such as aCondition, traversing the childTerminstances'Term.parseArgs(String[], String[], CliContext)methods.Operand<?>[]AbstractPropertyOption.parseArgs(String[] aArgs, String[] aOptions, CliContext aCliCtx) Parses the provided command line arguments and determines the according values by evaluating thisTerminstance or, in case of being a node in the syntax tree (such as aCondition, traversing the childTerminstances'Term.parseArgs(String[], String[], CliContext)methods.Operand<?>[]AllCondition.parseArgs(String[] aArgs, String[] aOptions, CliContext aCliCtx) Parses the provided command line arguments and determines the according values by evaluating thisTerminstance or, in case of being a node in the syntax tree (such as aCondition, traversing the childTerminstances'Term.parseArgs(String[], String[], CliContext)methods.Operand<?>[]AndCondition.parseArgs(String[] aArgs, String[] aOptions, CliContext aCliCtx) Parses the provided command line arguments and determines the according values by evaluating thisTerminstance or, in case of being a node in the syntax tree (such as aCondition, traversing the childTerminstances'Term.parseArgs(String[], String[], CliContext)methods.Operand<?>[]AnyCondition.parseArgs(String[] aArgs, String[] aOptions, CliContext aCliCtx) Parses the provided command line arguments and determines the according values by evaluating thisTerminstance or, in case of being a node in the syntax tree (such as aCondition, traversing the childTerminstances'Term.parseArgs(String[], String[], CliContext)methods.Operand<?>[]ArrayOperand.parseArgs(String[] aArgs, String[] aOperands, CliContext aCliCtx) Parses the provided command line arguments and determines the according values by evaluating thisTerminstance or, in case of being a node in the syntax tree (such as aCondition, traversing the childTerminstances'Term.parseArgs(String[], String[], CliContext)methods.Flag.parseArgs(String[] aArgs, String[] aOptions, CliContext aCliCtx) Parses the provided command line arguments and determines the according values by evaluating thisTerminstance or, in case of being a node in the syntax tree (such as aCondition, traversing the childTerminstances'Term.parseArgs(String[], String[], CliContext)methods.Operand<?>[]NoneOperand.parseArgs(String[] aArgs, String[] aOptions, CliContext aCliContext) Parses the provided command line arguments and determines the according values by evaluating thisTerminstance or, in case of being a node in the syntax tree (such as aCondition, traversing the childTerminstances'Term.parseArgs(String[], String[], CliContext)methods.Operation.parseArgs(String[] aArgs, String[] aOptions, CliContext aCliContext) Parses the provided command line arguments and determines the according values by evaluating thisTerminstance or, in case of being a node in the syntax tree (such as aCondition, traversing the childTerminstances'Term.parseArgs(String[], String[], CliContext)methods.Operand<?>[]OrCondition.parseArgs(String[] aArgs, String[] aOptions, CliContext aCliCtx) Parses the provided command line arguments and determines the according values by evaluating thisTerminstance or, in case of being a node in the syntax tree (such as aCondition, traversing the childTerminstances'Term.parseArgs(String[], String[], CliContext)methods.Operand<?>[]Term.parseArgs(String[] aArgs, String[] aOptions, CliContext aCliContext) Parses the provided command line arguments and determines the according values by evaluating thisTerminstance or, in case of being a node in the syntax tree (such as aCondition, traversing the childTerminstances'Term.parseArgs(String[], String[], CliContext)methods.default Operand<?>[]Term.parseArgs(String[] aArgs, CliContext aCliCtx) Parses the provided command line arguments and determines the according values by evaluating thisTerminstance or, in case of being a node in the syntax tree (such as aCondition, traversing the childTerminstances'Term.parseArgs(String[], String[], CliContext)methods.Operand<?>[]XorCondition.parseArgs(String[] aArgs, String[] aOptions, CliContext aCliCtx) Parses the provided command line arguments and determines the according values by evaluating thisTerminstance or, in case of being a node in the syntax tree (such as aCondition, traversing the childTerminstances'Term.parseArgs(String[], String[], CliContext)methods.ArgsParser.withEvalArgs(String[] aArgs) Evaluates the provided command line arguments.ArgsParser.withEvalArgs(String[] aArgs, Pattern aFilterExp) Evaluates the provided command line arguments, filtering (excluding) the arguments matching the providedPattern.ArgsParser.withEvalArgs(String[] aArgs, ArgsFilter aArgsFilter) Evaluates the provided command line arguments, filtering (excluding) the arguments matching the providedArgsFilter.ArgsParser.withEvalArgs(List<String> aArgs) Evaluates the provided command line arguments .ArgsParser.withEvalArgs(List<String> aArgs, Pattern aFilterExp) Evaluates the provided command line arguments, filtering (excluding) the arguments matching the providedPattern.ArgsParser.withEvalArgs(List<String> aArgs, ArgsFilter aArgsFilter) Evaluates the provided command line arguments, filtering (excluding) the arguments matching the providedArgsFilter.ArgsParserBuilder.withEvalArgs(String[] aArgs) Evaluates the provided command line arguments.default BArgsParserBuilder.withEvalArgs(String[] aArgs, Pattern aFilterExp) Evaluates the provided command line arguments, filtering (excluding) the arguments matching the providedPattern.default BArgsParserBuilder.withEvalArgs(String[] aArgs, ArgsFilter aArgsFilter) Evaluates the provided command line arguments, filtering (excluding) the arguments matching the providedArgsFilter.default BArgsParserBuilder.withEvalArgs(List<String> aArgs) Evaluates the provided command line arguments .default BArgsParserBuilder.withEvalArgs(List<String> aArgs, Pattern aFilterExp) Evaluates the provided command line arguments, filtering (excluding) the arguments matching the providedPattern.default BArgsParserBuilder.withEvalArgs(List<String> aArgs, ArgsFilter aArgsFilter) Evaluates the provided command line arguments, filtering (excluding) the arguments matching the providedArgsFilter.default ParseArgsParseArgs.withEvalArgs(String[] aArgs) Evaluates the provided command line arguments.default ParseArgsParseArgs.withEvalArgs(List<String> aArgs) Evaluates the provided command line arguments .