Uses of Class
org.refcodes.cli.ArgsSyntaxException
-
-
Uses of ArgsSyntaxException in org.refcodes.cli
Subclasses of ArgsSyntaxException in org.refcodes.cli Modifier and Type Class Description classAmbiguousArgsExceptionThrown in case the command line arguments do not match the required syntax.classParseArgsExceptionThrown in case the provided command line arguments do not respect the required semantics or cannot be converted to the required type.classSuperfluousArgsExceptionThrown in case there were arguments found not being used (superfluous arguments).classUnknownArgsExceptionThrown in case command line arguments were not processed (did not match the expected arguments), e.g. the arguments were rejected as them did not work for the according syntax.Methods in org.refcodes.cli that throw ArgsSyntaxException Modifier and Type Method Description List<? extends Operand<?>>ArgsParser. evalArgs(String[] aArgs)Evaluates the provided command line arguments and determines the according values by evaluating the rootArgsSyntax.default List<? extends Operand<?>>ArgsParser. evalArgs(List<String> aArgs)Same asArgsParser.evalArgs(String[])with the difference that the elements representing the arguments are passed as a list instead of an array.List<? extends Operand<?>>ArgsParserImpl. evalArgs(String[] aArgs)Evaluates the provided command line arguments and determines the according values by evaluating the rootArgsSyntax.List<Operand<T>>AbstractOperand. parseArgs(String[] aArgs, String[] aOptions)Parses the provided command line arguments and determines the according values by evaluating thisSyntaxableinstance or, in case of being a node in the syntax tree (such as aArgsSyntax, traversing the childSyntaxableinstances'Syntaxable.parseArgs(String[], String[])methods.List<Operand<T>>AbstractOption. parseArgs(String[] aArgs, String[] aOptions)Parses the provided command line arguments and determines the according values by evaluating thisSyntaxableinstance or, in case of being a node in the syntax tree (such as aArgsSyntax, traversing the childSyntaxableinstances'Syntaxable.parseArgs(String[], String[])methods.List<? extends Operand<?>>AllCondition. parseArgs(String[] aArgs, String[] aOptions)Parses the provided command line arguments and determines the according values by evaluating thisSyntaxableinstance or, in case of being a node in the syntax tree (such as aArgsSyntax, traversing the childSyntaxableinstances'Syntaxable.parseArgs(String[], String[])methods.List<? extends Operand<?>>AndCondition. parseArgs(String[] aArgs, String[] aOptions)Parses the provided command line arguments and determines the according values by evaluating thisSyntaxableinstance or, in case of being a node in the syntax tree (such as aArgsSyntax, traversing the childSyntaxableinstances'Syntaxable.parseArgs(String[], String[])methods.List<? extends Operand<?>>AnyCondition. parseArgs(String[] aArgs, String[] aOptions)Parses the provided command line arguments and determines the according values by evaluating thisSyntaxableinstance or, in case of being a node in the syntax tree (such as aArgsSyntax, traversing the childSyntaxableinstances'Syntaxable.parseArgs(String[], String[])methods.List<Operand<?>>ArrayOperand. parseArgs(String[] aArgs, String[] aOperands)Parses the provided command line arguments and determines the according values by evaluating thisSyntaxableinstance or, in case of being a node in the syntax tree (such as aArgsSyntax, traversing the childSyntaxableinstances'Syntaxable.parseArgs(String[], String[])methods.List<Operand<Boolean>>Flag. parseArgs(String[] aArgs, String[] aOptions)Parses the provided command line arguments and determines the according values by evaluating thisSyntaxableinstance or, in case of being a node in the syntax tree (such as aArgsSyntax, traversing the childSyntaxableinstances'Syntaxable.parseArgs(String[], String[])methods.List<Operand<Boolean>>NoneOperand. parseArgs(String[] aArgs, String[] aOptions)Parses the provided command line arguments and determines the according values by evaluating thisSyntaxableinstance or, in case of being a node in the syntax tree (such as aArgsSyntax, traversing the childSyntaxableinstances'Syntaxable.parseArgs(String[], String[])methods.List<Operand<Boolean>>Operation. parseArgs(String[] aArgs, String[] aOptions)Parses the provided command line arguments and determines the according values by evaluating thisSyntaxableinstance or, in case of being a node in the syntax tree (such as aArgsSyntax, traversing the childSyntaxableinstances'Syntaxable.parseArgs(String[], String[])methods.List<? extends Operand<?>>OptionCondition. parseArgs(String[] aArgs, String[] aOptions)Parses the provided command line arguments and determines the according values by evaluating thisSyntaxableinstance or, in case of being a node in the syntax tree (such as aArgsSyntax, traversing the childSyntaxableinstances'Syntaxable.parseArgs(String[], String[])methods.List<? extends Operand<?>>OrCondition. parseArgs(String[] aArgs, String[] aOptions)Parses the provided command line arguments and determines the according values by evaluating thisSyntaxableinstance or, in case of being a node in the syntax tree (such as aArgsSyntax, traversing the childSyntaxableinstances'Syntaxable.parseArgs(String[], String[])methods.default List<? extends Operand<?>>Syntaxable. parseArgs(String[] aArgs)Parses the provided command line arguments and determines the according values by evaluating thisSyntaxableinstance or, in case of being a node in the syntax tree (such as aArgsSyntax, traversing the childSyntaxableinstances'Syntaxable.parseArgs(String[], String[])methods.List<? extends Operand<?>>Syntaxable. parseArgs(String[] aArgs, String[] aOptions)Parses the provided command line arguments and determines the according values by evaluating thisSyntaxableinstance or, in case of being a node in the syntax tree (such as aArgsSyntax, traversing the childSyntaxableinstances'Syntaxable.parseArgs(String[], String[])methods.List<? extends Operand<?>>XorCondition. parseArgs(String[] aArgs, String[] aOptions)Parses the provided command line arguments and determines the according values by evaluating thisSyntaxableinstance or, in case of being a node in the syntax tree (such as aArgsSyntax, traversing the childSyntaxableinstances'Syntaxable.parseArgs(String[], String[])methods.default ArgsParserArgsParser. withEvalArgs(String[] aArgs)Same asArgsParser.evalArgs(String[])with the difference that this class's instance being invoked is returned as of the builder pattern.default ArgsParserArgsParser. withEvalArgs(List<String> aArgs)Same asArgsParser.evalArgs(List)with the difference that this class's instance being invoked is returned as of the builder pattern.BArgsParserMixin. withEvalArgs(String[] aArgs)Evaluates the provided command line arguments.default BArgsParserMixin. withEvalArgs(List<String> aArgs)Evaluates the provided command line arguments .
-