Uses of Interface
org.refcodes.cli.Condition
-
Uses of Condition in org.refcodes.cli
Classes in org.refcodes.cli that implement ConditionModifier and TypeClassDescriptionclassTheAbstractConditionis an abstract implementation of theConditioninterface providing the boiler plate when implementing theConditioninterface as done by theAbstractCondition's sub-classes.classTheAllConditionenforces that the encapsulatedConstituentconsumes all arguments passed via invoking itsConstituent.parseArgs(String[], CliContext), else aSuperfluousArgsExceptionis thrown.classAnAndConditioncontains (represents) a list ofCondition(Constituent) instances (nested by theAndCondition) of which all are to be parsed successfully as of invoking theConstituent.parseArgs(String[], String[], CliContext)methods.classAny of the nestedConditionconditions may match for theAnyConditionto match, e.g. all of the nested conditions are optional.classTheCasesConditionis anXorConditionmaking sure that all possible cases inside theXorConditionmust(!)classAnOrConditionrepresents a list ofCondition(Constituent) instances of which at least one must be parsed successfully when theConstituents'Constituent.parseArgs(String[], String[], CliContext)methods are invoked.classAnXorConditionrepresents a list ofCondition(Constituent) instances of which only one is allowed to be parsed successfully when theConstituent.parseArgs(String[], String[], CliContext)methods are invoked.Methods in org.refcodes.cli that return ConditionModifier and TypeMethodDescriptionstatic ConditionCliSugar.all(Constituent aArg) static ConditionCliSugar.and(Constituent... aArgs) static ConditionCliSugar.any(Constituent... aArgs) static ConditionCliSugar.cases(Constituent... aArgs) static ConditionCliSugar.optional(Constituent... aArgs) Semantically identical synonym for theCliSugar.optional(Constituent...)declaration.static ConditionCliSugar.or(Constituent... aArgs) static ConditionCliSugar.xor(Constituent... aArgs)