Uses of Interface
org.refcodes.cli.Condition
-
Uses of Condition in org.refcodes.cli
Classes in org.refcodes.cli that implement Condition Modifier and Type Class Description classAbstractConditionTheAbstractConditionis an abstract implementation of anConditionproviding the boiler plate when implementing theConditioninterface.classAndConditionAnAndConditioncontains (represents) a list ofCondition(Syntaxable) instances (nested by theAndCondition) of which all are to be parsed successfully as of invoking theSyntaxable.parseArgs(String[], String[])methods.classOptionalConditionTheOptionalConditioncan nested by anAndConditionand encapsulates aConditionwhich may be provided but does not necessarily needs to be provided in order for theAndConditionto successfully parse the nestedConditionitems including theOptionalCondition.classOptionConditionFacadeclassOrConditionAnOrConditionrepresents a list ofCondition(Syntaxable) instances of which at least one must be parsed successfully when theSyntaxables'Syntaxable.parseArgs(String[], String[])methods are invoked.classXorConditionAnXorConditionrepresents a list ofCondition(Syntaxable) instances of which only one is allowed to be parsed successfully when theSyntaxable.parseArgs(String[], String[])methods are invoked.Methods in org.refcodes.cli that return Condition Modifier and Type Method Description static ConditionCliSugar. and(Syntaxable... aArgs)ConditionArgsParser. getRootCondition()The root condition is the starting point node of aSyntaxablehierarchy to be traversed when determining the syntax for command line arguments or when evaluating the command line arguments.ConditionArgsParserImpl. getRootCondition()The root condition is the starting point node of aSyntaxablehierarchy to be traversed when determining the syntax for command line arguments or when evaluating the command line arguments.ConditionRootConditionAccessor. getRootCondition()Retrieves the root condition from the root condition property.default ConditionRootConditionAccessor.RootConditionProperty. letRootCondition(Condition aRootCondition)This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenCondition(setter) as ofRootConditionAccessor.RootConditionMutator.setRootCondition(Condition)and returns the very same value (getter).static ConditionCliSugar. optional(Syntaxable... aArgs)static ConditionCliSugar. or(Syntaxable... aArgs)static ConditionCliSugar. xor(Syntaxable... aArgs)Methods in org.refcodes.cli with parameters of type Condition Modifier and Type Method Description default ConditionRootConditionAccessor.RootConditionProperty. letRootCondition(Condition aRootCondition)This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenCondition(setter) as ofRootConditionAccessor.RootConditionMutator.setRootCondition(Condition)and returns the very same value (getter).voidRootConditionAccessor.RootConditionMutator. setRootCondition(Condition aRootCondition)Sets the root condition for the root condition property.BRootConditionAccessor.RootConditionBuilder. withRootCondition(Condition aRootCondition)Sets the root condition for the root condition property.Constructors in org.refcodes.cli with parameters of type Condition Constructor Description ArgsParserImpl(Condition aRootCondition)Constructs theArgsParserinstance with the given rootConditionand the defaultSyntaxNotation.REFCODES.