Uses of Class
org.refcodes.cli.Example
-
Uses of Example in org.refcodes.cli
Methods in org.refcodes.cli that return ExampleModifier and TypeMethodDescriptionstatic Examplestatic Example[]Sugar for creating anExamplearray from a varargs argument.Methods in org.refcodes.cli that return types with arguments of type ExampleModifier and TypeMethodDescriptionArgsParser.getExamples()Retrieves theExampleinstances as added usingArgsParser.addExample(String, Operand...).ArgsParserImpl.getExamples()Retrieves theExampleinstances as added usingArgsParser.addExample(String, Operand...).Methods in org.refcodes.cli with parameters of type ExampleModifier and TypeMethodDescriptionvoidArgsParser.addExample(Example aExample) Adds a usage example by providing a description of the example and the command line arguments required by the example.voidArgsParserImpl.addExample(Example aExampleUsage) Adds a usage example by providing a description of the example and the command line arguments required by the example.static Example[]Sugar for creating anExamplearray from a varargs argument.default ArgsParserArgsParser.withExample(Example aExample) Adds a usage example.default ArgsParserArgsParser.withExamples(Example[] aExamples) Adds all the bunch ofExampleelements provided.Method parameters in org.refcodes.cli with type arguments of type ExampleModifier and TypeMethodDescriptiondefault ArgsParserArgsParser.withExamples(Collection<Example> aExamples) Adds all the bunch ofExampleelements provided.