Uses of Class
org.refcodes.cli.Example
-
-
Uses of Example in org.refcodes.cli
Methods in org.refcodes.cli that return Example Modifier and Type Method Description static ExampleCliSugar. example(String aDescription, Operand<?>... aOperands)static Example[]CliSugar. examples(Example... aExamples)Sugar for creating anExamplearray from a varargs argument.Methods in org.refcodes.cli that return types with arguments of type Example Modifier and Type Method Description List<Example>ArgsParser. getExamples()Retrieves theExampleinstances as added usingArgsParser.addExample(String, Operand...).List<Example>ArgsParserImpl. getExamples()Retrieves theExampleinstances as added usingArgsParser.addExample(String, Operand...).Methods in org.refcodes.cli with parameters of type Example Modifier and Type Method Description voidArgsParser. addExample(Example aExample)Adds a usage example by providing a description of the example and the command line arguments required by the example.voidArgsParserImpl. addExample(Example aExampleUsage)Adds a usage example by providing a description of the example and the command line arguments required by the example.static Example[]CliSugar. examples(Example... aExamples)Sugar for creating anExamplearray from a varargs argument.default ArgsParserArgsParser. withExample(Example aExample)Adds a usage example.default ArgsParserArgsParser. withExamples(Example[] aExamples)Adds all the bunch ofExampleelements provided.Method parameters in org.refcodes.cli with type arguments of type Example Modifier and Type Method Description default ArgsParserArgsParser. withExamples(Collection<Example> aExamples)Adds all the bunch ofExampleelements provided.
-