Uses of Interface
org.refcodes.cli.Operand
-
Uses of Operand in org.refcodes.cli
Subinterfaces of Operand in org.refcodes.cliModifier and TypeInterfaceDescriptioninterfaceOption<T>AnOptionrepresents a command line option with the according option's value.interfaceAnPropertyOptionrepresents a command line property with the according porperty's key and value.Classes in org.refcodes.cli that implement OperandModifier and TypeClassDescriptionclassTheAbstractOperandis an abstract implementation of anOperandproviding the boiler plate when implementing theOperandinterface.classTheAbstractOptionis an abstract implementation of anOptionproviding the boiler plate when implementing theOptioninterface.classTheAbstractPropertyOptionis an abstract implementation of aPropertyOptionproviding the boiler plate when implementing thePropertyOptioninterface.classArrayOperand<T>Creates an array representation facade for the encapsulatedOperand.classArrayOption<T>Creates an array representation facade for the encapsulatedOption.classclassclassclassclassA predefined cleanFlag: A predefinedFlaggives itsCleanFlag.SHORT_OPTION, itsCleanFlag.LONG_OPTIONas well as itsCleanFlag.ALIASan according semantics regarded by other subsystems.classTheConfigOptionrepresents anOptionholding a value specifying a configuration resource (file).classTheConfigPropertyrepresents anPropertyOptionholding a value specifying a configuration resource (file).classA predefined daemonFlag: A predefinedFlaggives itsDaemonFlag.SHORT_OPTION, itsDaemonFlag.LONG_OPTIONas well as itsDaemonFlag.ALIASan according semantics regarded by other subsystems.classA predefined debugFlag: A predefinedFlaggives itsDebugFlag.SHORT_OPTION, itsDebugFlag.LONG_OPTIONas well as itsDebugFlag.ALIASan according semantics regarded by other subsystems.classclassclassEnumOption<T extends Enum<T>>TheEnumOptionrepresents anOptionof enumeration types.classEnumProperty<T extends Enum<T>>TheEnumPropertyrepresents anPropertyOptionof enumeration types.classclassclassTheFlagclass implements theOptioninterface for representing either atrueor afalsestate: When a flag is provided to your command line arguments, then it is considered to betrue, when it is omitted, then it is considered to befalseas ofFlag.isEnabled().classclassclassA predefined forceFlag: A predefinedFlaggives itsForceFlag.SHORT_OPTION, itsForceFlag.LONG_OPTIONas well as itsForceFlag.ALIASan according semantics regarded by other subsystems.classA predefined helpFlag: A predefinedFlaggives itsHelpFlag.SHORT_OPTION, itsHelpFlag.LONG_OPTIONas well as itsHelpFlag.ALIASan according semantics regarded by other subsystems.classA predefined initFlag: A predefinedFlaggives itsInitFlag.SHORT_OPTION, itsInitFlag.LONG_OPTIONas well as itsInitFlag.ALIASan according semantics regarded by other subsystems.classclassclassclassclassTheNoneOperandrepresents an empty set of arguments, e.g. no command line argument is being passed.classTheOperationis an argument representing a function or a method ("command") and is either provided or not provided as ofOperation.isEnabled().classA predefined "be quiet"Flag: A predefinedFlaggives itsQuietFlag.SHORT_OPTION, itsQuietFlag.LONG_OPTIONas well as itsQuietFlag.ALIASan according semantics regarded by other subsystems.classclassclassclassA predefined system informationFlag: A predefinedFlaggives itsSysInfoFlag.SHORT_OPTION, itsSysInfoFlag.LONG_OPTIONas well as itsSysInfoFlag.ALIASan according semantics regarded by other subsystems..classA predefined verboseFlag: A predefinedFlaggives itsVerboseFlag.SHORT_OPTION, itsVerboseFlag.LONG_OPTIONas well as itsVerboseFlag.ALIASan according semantics regarded by other subsystems.Methods in org.refcodes.cli with type parameters of type OperandModifier and TypeMethodDescription<T extends Operand<?>>
TTraverses the hierarchy ofConditiontree and returns the (first) operand matching the given alias and type.default <T extends Operand<?>>
TTraverses the hierarchy ofConditiontree and returns the (first) operand matching the given type.<T extends Operand<?>>
TTraverses the hierarchy ofConditiontree and returns the (first) operand matching the given alias and type.Methods in org.refcodes.cli that return OperandModifier and TypeMethodDescriptionOperand<?>[]Evaluates the provided command line arguments and determines the according values by evaluating the rootCondition.Operand<?>[]Evaluates the provided command line arguments and determines the according values by evaluating the rootCondition.default Operand<?>[]Evaluates the provided command line arguments as ofParseArgs.evalArgs(String[]), additionally filtering (excluding) the arguments matching the providedPattern.default Operand<?>[]ParseArgs.evalArgs(String[] aArgs, ArgsFilter aArgsFilter) Evaluates the provided command line arguments as ofParseArgs.evalArgs(String[]), additionally filtering (excluding) the arguments matching the providedArgsFilter.default Operand<?>[]Same asParseArgs.evalArgs(String[])with the difference that the elements representing the arguments are passed as a list instead of an array.default Operand<?>[]Evaluates the provided command line arguments as ofParseArgs.evalArgs(String[]), additionally filtering (excluding) the arguments matching the providedPattern.default Operand<?>[]ParseArgs.evalArgs(List<String> aArgs, ArgsFilter aArgsFilter) Evaluates the provided command line arguments as ofParseArgs.evalArgs(String[]), additionally filtering (excluding) the arguments matching the providedArgsFilter.ArrayOperand.getOperand()Hook for accessing the encapsulatedOperand.Operand<?>[]Example.getOperands()Retrieves the command line arguments required by the example.Operand<?>[]AbstractOperand.parseArgs(String[] aArgs, String[] aOptions, CliContext aCliContext) Parses the provided command line arguments and determines the according values by evaluating thisTerminstance or, in case of being a node in the syntax tree (such as aCondition, traversing the childTerminstances'Term.parseArgs(String[], String[], CliContext)methods.Operand<?>[]AbstractOption.parseArgs(String[] aArgs, String[] aOptions, CliContext aCliCtx) Parses the provided command line arguments and determines the according values by evaluating thisTerminstance or, in case of being a node in the syntax tree (such as aCondition, traversing the childTerminstances'Term.parseArgs(String[], String[], CliContext)methods.Operand<?>[]AbstractPropertyOption.parseArgs(String[] aArgs, String[] aOptions, CliContext aCliCtx) Parses the provided command line arguments and determines the according values by evaluating thisTerminstance or, in case of being a node in the syntax tree (such as aCondition, traversing the childTerminstances'Term.parseArgs(String[], String[], CliContext)methods.Operand<?>[]AllCondition.parseArgs(String[] aArgs, String[] aOptions, CliContext aCliCtx) Parses the provided command line arguments and determines the according values by evaluating thisTerminstance or, in case of being a node in the syntax tree (such as aCondition, traversing the childTerminstances'Term.parseArgs(String[], String[], CliContext)methods.Operand<?>[]AndCondition.parseArgs(String[] aArgs, String[] aOptions, CliContext aCliCtx) Parses the provided command line arguments and determines the according values by evaluating thisTerminstance or, in case of being a node in the syntax tree (such as aCondition, traversing the childTerminstances'Term.parseArgs(String[], String[], CliContext)methods.Operand<?>[]AnyCondition.parseArgs(String[] aArgs, String[] aOptions, CliContext aCliCtx) Parses the provided command line arguments and determines the according values by evaluating thisTerminstance or, in case of being a node in the syntax tree (such as aCondition, traversing the childTerminstances'Term.parseArgs(String[], String[], CliContext)methods.Operand<?>[]ArrayOperand.parseArgs(String[] aArgs, String[] aOperands, CliContext aCliCtx) Parses the provided command line arguments and determines the according values by evaluating thisTerminstance or, in case of being a node in the syntax tree (such as aCondition, traversing the childTerminstances'Term.parseArgs(String[], String[], CliContext)methods.Flag.parseArgs(String[] aArgs, String[] aOptions, CliContext aCliCtx) Parses the provided command line arguments and determines the according values by evaluating thisTerminstance or, in case of being a node in the syntax tree (such as aCondition, traversing the childTerminstances'Term.parseArgs(String[], String[], CliContext)methods.Operand<?>[]NoneOperand.parseArgs(String[] aArgs, String[] aOptions, CliContext aCliContext) Parses the provided command line arguments and determines the according values by evaluating thisTerminstance or, in case of being a node in the syntax tree (such as aCondition, traversing the childTerminstances'Term.parseArgs(String[], String[], CliContext)methods.Operation.parseArgs(String[] aArgs, String[] aOptions, CliContext aCliContext) Parses the provided command line arguments and determines the according values by evaluating thisTerminstance or, in case of being a node in the syntax tree (such as aCondition, traversing the childTerminstances'Term.parseArgs(String[], String[], CliContext)methods.Operand<?>[]OrCondition.parseArgs(String[] aArgs, String[] aOptions, CliContext aCliCtx) Parses the provided command line arguments and determines the according values by evaluating thisTerminstance or, in case of being a node in the syntax tree (such as aCondition, traversing the childTerminstances'Term.parseArgs(String[], String[], CliContext)methods.Operand<?>[]Term.parseArgs(String[] aArgs, String[] aOptions, CliContext aCliContext) Parses the provided command line arguments and determines the according values by evaluating thisTerminstance or, in case of being a node in the syntax tree (such as aCondition, traversing the childTerminstances'Term.parseArgs(String[], String[], CliContext)methods.default Operand<?>[]Term.parseArgs(String[] aArgs, CliContext aCliCtx) Parses the provided command line arguments and determines the according values by evaluating thisTerminstance or, in case of being a node in the syntax tree (such as aCondition, traversing the childTerminstances'Term.parseArgs(String[], String[], CliContext)methods.Operand<?>[]XorCondition.parseArgs(String[] aArgs, String[] aOptions, CliContext aCliCtx) Parses the provided command line arguments and determines the according values by evaluating thisTerminstance or, in case of being a node in the syntax tree (such as aCondition, traversing the childTerminstances'Term.parseArgs(String[], String[], CliContext)methods.default Operand<?>Traverses the hierarchy ofConditiontree and returns the (first) operand matching the given alias.Operand<?>[]AbstractCondition.toOperands()Operand<?>[]Condition.toOperands()default Operand<?>[]Condition.toOperands(String[] aArgs) Methods in org.refcodes.cli with parameters of type OperandModifier and TypeMethodDescriptiondefault voidParseArgs.addExample(String aDescription, Operand<?>... aOperands) Adds a usage example by providing a description of the example and the command line arguments required by the example.static <T> ArrayOperand<T>Creates an array representation facade for the encapsulatedOperand.static <T> ArrayOperand<T>Creates an array representation facade for the encapsulatedOperand.static <T> ArrayOperand<T>Creates an array representation facade for the encapsulatedOperand.intintstatic ExampleCliContext.toArgumentSpec(Operand<?> aOperand) Creates the argument specification from the providedOperand.CliContext.toArgumentSpec(Operand<?> aOperand, int aMin, int aMax) Creates the argument specification from the providedOperand.ArgsParser.withAddExample(String aDescription, Operand<?>... aOperands) Builder method adding an application'sExampleelement.ArgsProcessorBuilder.withAddExample(String aDescription, Operand<?>... aOperands) Builder method adding an application'sExampleelement.default ParseArgsParseArgs.withAddExample(String aDescription, Operand<?>... aOperands) Builder method adding an application'sExampleelement.Constructors in org.refcodes.cli with parameters of type OperandModifierConstructorDescriptionArrayOperand(Operand<T> aOperand) Constructs theArrayOperandby encapsulating the givenOperandand providing its definition as array definition to the CLI.ArrayOperand(Operand<T> aOperand, int aLength) Constructs theArrayOperandby encapsulating the givenOperandand providing its definition as array definition to the CLI.ArrayOperand(Operand<T> aOperand, int aMinLength, int aMaxLength) Constructs theArrayOperandby encapsulating the givenOperandand providing its definition as array definition to the CLI.Constructs an example usage.Constructor parameters in org.refcodes.cli with type arguments of type OperandModifierConstructorDescriptionAbstractOperand(Class<T> aType, String aAlias, String aDescription, Consumer<? extends Operand<T>> aConsumer) Constructs anOperandwith the given arguments.AbstractOperand(org.refcodes.struct.Relation<String, T> aProperty, Class<T> aType, Consumer<? extends Operand<T>> aConsumer) Constructs anOperandwith the given arguments.AbstractOption(Character aShortOption, String aLongOption, Class<T> aType, String aAlias, String aDescription, Consumer<? extends Operand<T>> aConsumer) Constructs anAbstractOptionwith the given arguments.protectedAbstractOption(Character aShortOption, String aLongOption, Class<T> aType, String aDescription, Consumer<? extends Operand<T>> aConsumer) Constructs anAbstractOptionwith the given arguments.AbstractOption(String aLongOption, Class<T> aType, String aAlias, String aDescription, Consumer<? extends Operand<T>> aConsumer) Constructs anAbstractOptionwith the given arguments.AbstractOption(String aLongOption, Class<T> aType, String aDescription, Consumer<? extends Operand<T>> aConsumer) Constructs anAbstractOptionwith the given arguments.AbstractOption(org.refcodes.struct.Relation<String, T> aProperty, Class<T> aType, Consumer<? extends Operand<T>> aConsumer) Constructs anAbstractOptionwith the given arguments.AbstractPropertyOption(Character aShortProperty, String aLongProperty, Class<T> aType, String aAlias, String aDescription, Consumer<? extends Operand<T>> aConsumer) Constructs anAbstractPropertyOptionwith the given arguments.protectedAbstractPropertyOption(Character aShortProperty, String aLongProperty, Class<T> aType, String aDescription, Consumer<? extends Operand<T>> aConsumer) Constructs anAbstractPropertyOptionwith the given arguments.AbstractPropertyOption(String aLongProperty, Class<T> aType, String aAlias, String aDescription, Consumer<? extends Operand<T>> aConsumer) Constructs anAbstractPropertyOptionwith the given arguments.AbstractPropertyOption(String aLongProperty, Class<T> aType, String aDescription, Consumer<? extends Operand<T>> aConsumer) Constructs anAbstractPropertyOptionwith the given arguments.AbstractPropertyOption(org.refcodes.struct.Relation<String, T> aProperty, Class<T> aType, Consumer<? extends Operand<T>> aConsumer) Constructs anAbstractPropertyOptionwith the given arguments.