Uses of Interface
org.refcodes.cli.Operand
-
Uses of Operand in org.refcodes.cli
Subinterfaces of Operand in org.refcodes.cliModifier and TypeInterfaceDescriptioninterfaceOption<T>AnOptionrepresents a command line option with the according option's value.Classes in org.refcodes.cli that implement OperandModifier and TypeClassDescriptionclassTheAbstractOperandis an abstract implementation of anOperandproviding the boiler plate when implementing theOperandinterface.classTheAbstractOptionis an abstract implementation of anOptionproviding the boiler plate when implementing theOptioninterface.classArrayOperand<T>Creates an array representation facade for the encapsulatedOperand.classArrayOption<T>Creates an array representation facade for the encapsulatedOption.classclassA predefined cleanFlag: A predefinedFlaggives itsCleanFlag.SHORT_OPTION, itsCleanFlag.LONG_OPTIONas well as itsCleanFlag.ALIASan according semantics regarded by other subsystems.classTheConfigOptionrepresents anOptionholding a value specifying a configuration resource (file).classA predefined daemonFlag: A predefinedFlaggives itsDaemonFlag.SHORT_OPTION, itsDaemonFlag.LONG_OPTIONas well as itsDaemonFlag.ALIASan according semantics regarded by other subsystems.classA predefined debugFlag: A predefinedFlaggives itsDebugFlag.SHORT_OPTION, itsDebugFlag.LONG_OPTIONas well as itsDebugFlag.ALIASan according semantics regarded by other subsystems.classclassEnumOption<T extends Enum<T>>The Class EnumOption.classclassTheFlagclass implements theOptioninterface for representing either atrueor afalsestate: When a flag is provided to your command line arguments, then it is considered to betrue, when it is omitted, then it is considered to befalseas ofFlag.isEnabled().classclassA predefined forceFlag: A predefinedFlaggives itsForceFlag.SHORT_OPTION, itsForceFlag.LONG_OPTIONas well as itsForceFlag.ALIASan according semantics regarded by other subsystems.classA predefined helpFlag: A predefinedFlaggives itsHelpFlag.SHORT_OPTION, itsHelpFlag.LONG_OPTIONas well as itsHelpFlag.ALIASan according semantics regarded by other subsystems.classA predefined initFlag: A predefinedFlaggives itsInitFlag.SHORT_OPTION, itsInitFlag.LONG_OPTIONas well as itsInitFlag.ALIASan according semantics regarded by other subsystems.classclassclassTheNoneOperandrepresents an empty set of arguments, e.g. no command line argument is being passed.classTheOperationis an argument representing a function or a method ("command") and is either provided or not provided as ofOperation.isEnabled().classA predefined "be quiet"Flag: A predefinedFlaggives itsQuietFlag.SHORT_OPTION, itsQuietFlag.LONG_OPTIONas well as itsQuietFlag.ALIASan according semantics regarded by other subsystems.classclassclassA predefined system informationFlag: A predefinedFlaggives itsSysInfoFlag.SHORT_OPTION, itsSysInfoFlag.LONG_OPTIONas well as itsSysInfoFlag.ALIASan according semantics regarded by other subsystems..classA predefined verboseFlag: A predefinedFlaggives itsVerboseFlag.SHORT_OPTION, itsVerboseFlag.LONG_OPTIONas well as itsVerboseFlag.ALIASan according semantics regarded by other subsystems.Methods in org.refcodes.cli with type parameters of type OperandModifier and TypeMethodDescription<T extends Operand<?>>
TTraverses the hierarchy ofArgsSyntaxtree and returns the (first) operand matching the given alias and type.default <T extends Operand<?>>
TTraverses the hierarchy ofArgsSyntaxtree and returns the (first) operand matching the given type.<T extends Operand<?>>
TTraverses the hierarchy ofArgsSyntaxtree and returns the (first) operand matching the given alias and type.Methods in org.refcodes.cli that return OperandModifier and TypeMethodDescriptionArrayOperand.getOperand()Hook for accessing the encapsulatedOperand.Operand<?>[]Example.getOperands()Retrieves the command line arguments required by the example.default Operand<?>Traverses the hierarchy ofArgsSyntaxtree and returns the (first) operand matching the given alias.Methods in org.refcodes.cli that return types with arguments of type OperandModifier and TypeMethodDescriptionEvaluates the provided command line arguments and determines the according values by evaluating the rootArgsSyntax.Same asArgsParser.evalArgs(String[])with the difference that the elements representing the arguments are passed as a list instead of an array.Evaluates the provided command line arguments and determines the according values by evaluating the rootArgsSyntax.Heuristically loads the arguments without any syntax required, e.g.Parses the provided command line arguments and determines the according values by evaluating thisSyntaxableinstance or, in case of being a node in the syntax tree (such as aArgsSyntax, traversing the childSyntaxableinstances'Syntaxable.parseArgs(String[], String[])methods.Parses the provided command line arguments and determines the according values by evaluating thisSyntaxableinstance or, in case of being a node in the syntax tree (such as aArgsSyntax, traversing the childSyntaxableinstances'Syntaxable.parseArgs(String[], String[])methods.Parses the provided command line arguments and determines the according values by evaluating thisSyntaxableinstance or, in case of being a node in the syntax tree (such as aArgsSyntax, traversing the childSyntaxableinstances'Syntaxable.parseArgs(String[], String[])methods.Parses the provided command line arguments and determines the according values by evaluating thisSyntaxableinstance or, in case of being a node in the syntax tree (such as aArgsSyntax, traversing the childSyntaxableinstances'Syntaxable.parseArgs(String[], String[])methods.Parses the provided command line arguments and determines the according values by evaluating thisSyntaxableinstance or, in case of being a node in the syntax tree (such as aArgsSyntax, traversing the childSyntaxableinstances'Syntaxable.parseArgs(String[], String[])methods.Parses the provided command line arguments and determines the according values by evaluating thisSyntaxableinstance or, in case of being a node in the syntax tree (such as aArgsSyntax, traversing the childSyntaxableinstances'Syntaxable.parseArgs(String[], String[])methods.Parses the provided command line arguments and determines the according values by evaluating thisSyntaxableinstance or, in case of being a node in the syntax tree (such as aArgsSyntax, traversing the childSyntaxableinstances'Syntaxable.parseArgs(String[], String[])methods.Parses the provided command line arguments and determines the according values by evaluating thisSyntaxableinstance or, in case of being a node in the syntax tree (such as aArgsSyntax, traversing the childSyntaxableinstances'Syntaxable.parseArgs(String[], String[])methods.Parses the provided command line arguments and determines the according values by evaluating thisSyntaxableinstance or, in case of being a node in the syntax tree (such as aArgsSyntax, traversing the childSyntaxableinstances'Syntaxable.parseArgs(String[], String[])methods.Parses the provided command line arguments and determines the according values by evaluating thisSyntaxableinstance or, in case of being a node in the syntax tree (such as aArgsSyntax, traversing the childSyntaxableinstances'Syntaxable.parseArgs(String[], String[])methods.Parses the provided command line arguments and determines the according values by evaluating thisSyntaxableinstance or, in case of being a node in the syntax tree (such as aArgsSyntax, traversing the childSyntaxableinstances'Syntaxable.parseArgs(String[], String[])methods.Parses the provided command line arguments and determines the according values by evaluating thisSyntaxableinstance or, in case of being a node in the syntax tree (such as aArgsSyntax, traversing the childSyntaxableinstances'Syntaxable.parseArgs(String[], String[])methods.Parses the provided command line arguments and determines the according values by evaluating thisSyntaxableinstance or, in case of being a node in the syntax tree (such as aArgsSyntax, traversing the childSyntaxableinstances'Syntaxable.parseArgs(String[], String[])methods.Parses the provided command line arguments and determines the according values by evaluating thisSyntaxableinstance or, in case of being a node in the syntax tree (such as aArgsSyntax, traversing the childSyntaxableinstances'Syntaxable.parseArgs(String[], String[])methods.AbstractCondition.toOperands()Traverses the hierarchy ofArgsSyntaxs and collects all therein foundOperands and sub-types such as theFlagor theOption.ArgsSyntax.toOperands()Traverses the hierarchy ofArgsSyntaxs and collects all therein foundOperands and sub-types such as theFlagor theOption.Methods in org.refcodes.cli with parameters of type OperandModifier and TypeMethodDescriptiondefault voidArgsParser.addExample(String aDescription, Operand<?>... aOperands) Adds a usage example by providing a description of the example and the command line arguments required by the example.static <T> ArrayOperand<T>Creates an array representation facade for the encapsulatedOperand.static <T> ArrayOperand<T>Creates an array representation facade for the encapsulatedOperand.static <T> ArrayOperand<T>Creates an array representation facade for the encapsulatedOperand.intintstatic Examplestatic StringCliUtility.toOptionsSpec(Operand<?> aOperand) Creates the options specification containing the short option (if any) and the long option (if any) from the providedOperand.static StringCliUtility.toOptionsSpec(Operand<?> aOperand, String aOptEscCode, String aResetEscCode) Creates the options specification containing the short option (if any) and the long option (if any) from the providedOperand.static StringCliUtility.toParameterSpec(Operand<?> aOperand) Creates the parameter specification from the providedOperand.static StringCliUtility.toParameterSpec(Operand<?> aOperand, int aMin, int aMax) Creates the parameter specification from the providedOperand.static StringCliUtility.toParameterSpec(Operand<?> aOperand, int aMin, int aMax, String aParamEscCode, String aResetEscCode) Creates the parameter specification from the providedOperand.static StringCliUtility.toParameterSpec(Operand<?> aOperand, String aParamEscCode, String aResetEscCode) Creates the parameter specification from the providedOperand.static StringCliUtility.toShortOptionsSpec(Operand<?> aOperand) Creates the options specification containing the short option only (if any) or(!)static StringCliUtility.toShortOptionsSpec(Operand<?> aOperand, String aOptEscCode, String aResetEscCode) Creates the options specification containing the short option only (if any) or(!)static StringCliUtility.toShortSpec(Operand<?> aOperand) Creates a specification for the givenOperandconsisting of the short option specification (if any) or the long option specification(if any) and the parameter specification (if any) as ofCliUtility.toParameterSpec(Operand).static StringCliUtility.toShortSpec(Operand<?> aOperand, String aOptEscCode, String aParamEscCode, String aResetEscCode) Creates a specification for the givenOperandconsisting of the short option specification (if any) or the long option specification(if any) and the parameter specification (if any) as ofCliUtility.toParameterSpec(Operand).static StringCreates a specification for the givenOperandconsisting of the options specification (if any) as ofCliUtility.toOptionsSpec(Operand)and the parameter specification (if any) as ofCliUtility.toParameterSpec(Operand).static StringCliUtility.toSpec(Operand<?> aOperand, String aOptEscCode, String aParamEscCode, String aResetEscCode) Creates a specification for the givenOperandconsisting of the options specification (if any) as ofCliUtility.toOptionsSpec(Operand)and the parameter specification (if any) as ofCliUtility.toParameterSpec(Operand).default ArgsParserArgsParser.withExample(String aDescription, Operand<?>... aOperands) Adds a usage example by providing a description of the example and the command line arguments required by the example.Method parameters in org.refcodes.cli with type arguments of type OperandConstructors in org.refcodes.cli with parameters of type OperandModifierConstructorDescriptionArrayOperand(Operand<T> aOperand) Constructs theArrayOperandby encapsulating the givenOperandand providing its definition as array definition to the CLI.ArrayOperand(Operand<T> aOperand, int aLength) Constructs theArrayOperandby encapsulating the givenOperandand providing its definition as array definition to the CLI.ArrayOperand(Operand<T> aOperand, int aMinLength, int aMaxLength) Constructs theArrayOperandby encapsulating the givenOperandand providing its definition as array definition to the CLI.Constructs an example usage.