Uses of Interface
org.refcodes.cli.Operand
-
-
Uses of Operand in org.refcodes.cli
Subinterfaces of Operand in org.refcodes.cli Modifier and Type Interface Description interfaceOption<T>AnOptionrepresents a command line option with the according option's value.Classes in org.refcodes.cli that implement Operand Modifier and Type Class Description classAbstractOperand<T>TheAbstractOperandis an abstract implementation of anOperandproviding the boiler plate when implementing theOperandinterface.classAbstractOption<T>TheAbstractOptionis an abstract implementation of anOptionproviding the boiler plate when implementing theOptioninterface.classArrayOperand<T>Creates an array representation facade for the encapsulatedOperand.classArrayOption<T>Creates an array representation facade for the encapsulatedOption.classCharOptionclassCleanFlagA predefined cleanFlag: A predefinedFlaggives itsCleanFlag.SHORT_OPTION, itsCleanFlag.LONG_OPTIONas well as itsCleanFlag.ALIASan according semantics regarded by other subsystems.classConfigOptionTheConfigOptionrepresents anOptionholding a value specifying a configuration resource (file).classDaemonFlagA predefined daemonFlag: A predefinedFlaggives itsDaemonFlag.SHORT_OPTION, itsDaemonFlag.LONG_OPTIONas well as itsDaemonFlag.ALIASan according semantics regarded by other subsystems.classDebugFlagA predefined debugFlag: A predefinedFlaggives itsDebugFlag.SHORT_OPTION, itsDebugFlag.LONG_OPTIONas well as itsDebugFlag.ALIASan according semantics regarded by other subsystems.classDoubleOptionclassEnumOption<T extends Enum<T>>The Class EnumOption.classFileOptionclassFlagTheFlagclass implements theOptioninterface for representing either atrueor afalsestate: When a flag is provided to your command line arguments, then it is considered to betrue, when it is omitted, then it is considered to befalseas ofFlag.isEnabled().classFloatOptionclassForceFlagA predefined forceFlag: A predefinedFlaggives itsForceFlag.SHORT_OPTION, itsForceFlag.LONG_OPTIONas well as itsForceFlag.ALIASan according semantics regarded by other subsystems.classHelpFlagA predefined helpFlag: A predefinedFlaggives itsHelpFlag.SHORT_OPTION, itsHelpFlag.LONG_OPTIONas well as itsHelpFlag.ALIASan according semantics regarded by other subsystems.classInitFlagA predefined initFlag: A predefinedFlaggives itsInitFlag.SHORT_OPTION, itsInitFlag.LONG_OPTIONas well as itsInitFlag.ALIASan according semantics regarded by other subsystems.classIntOptionclassLongOptionclassNoneOperandTheNoneOperandrepresents an empty set of arguments, e.g. no command line argument is being passed.classOperationTheOperationis an argument representing a function or a method ("command") and is either provided or not provided as ofOperation.isEnabled().classQuietFlagA predefined "be quiet"Flag: A predefinedFlaggives itsQuietFlag.SHORT_OPTION, itsQuietFlag.LONG_OPTIONas well as itsQuietFlag.ALIASan according semantics regarded by other subsystems.classStringOperandclassStringOptionclassSysInfoFlagA predefined system informationFlag: A predefinedFlaggives itsSysInfoFlag.SHORT_OPTION, itsSysInfoFlag.LONG_OPTIONas well as itsSysInfoFlag.ALIASan according semantics regarded by other subsystems..classVerboseFlagA predefined verboseFlag: A predefinedFlaggives itsVerboseFlag.SHORT_OPTION, itsVerboseFlag.LONG_OPTIONas well as itsVerboseFlag.ALIASan according semantics regarded by other subsystems.Methods in org.refcodes.cli with type parameters of type Operand Modifier and Type Method Description <T extends Operand<?>>
TAbstractCondition. toOperand(String aAlias, Class<T> aType)Traverses the hierarchy ofArgsSyntaxtree and returns the (first) operand matching the given alias and type.default <T extends Operand<?>>
TArgsSyntax. toOperand(Class<T> aType)Traverses the hierarchy ofArgsSyntaxtree and returns the (first) operand matching the given type.<T extends Operand<?>>
TArgsSyntax. toOperand(String aAlias, Class<T> aType)Traverses the hierarchy ofArgsSyntaxtree and returns the (first) operand matching the given alias and type.Methods in org.refcodes.cli that return Operand Modifier and Type Method Description protected Operand<T>ArrayOperand. getOperand()Hook for accessing the encapsulatedOperand.Operand<?>[]Example. getOperands()Retrieves the command line arguments required by the example.default Operand<?>ArgsSyntax. toOperand(String aAlias)Traverses the hierarchy ofArgsSyntaxtree and returns the (first) operand matching the given alias.Methods in org.refcodes.cli that return types with arguments of type Operand Modifier and Type Method Description List<? extends Operand<?>>ArgsParser. evalArgs(String[] aArgs)Evaluates the provided command line arguments and determines the according values by evaluating the rootArgsSyntax.default List<? extends Operand<?>>ArgsParser. evalArgs(List<String> aArgs)Same asArgsParser.evalArgs(String[])with the difference that the elements representing the arguments are passed as a list instead of an array.List<? extends Operand<?>>ArgsParserImpl. evalArgs(String[] aArgs)Evaluates the provided command line arguments and determines the according values by evaluating the rootArgsSyntax.protected static List<? extends Operand<?>>ArgsParserImpl. fromArgs(String[] aArgs, char aDelimiter)Heuristically loads the arguments without any syntax required, e.g.List<Operand<T>>AbstractOperand. parseArgs(String[] aArgs, String[] aOptions)Parses the provided command line arguments and determines the according values by evaluating thisSyntaxableinstance or, in case of being a node in the syntax tree (such as aArgsSyntax, traversing the childSyntaxableinstances'Syntaxable.parseArgs(String[], String[])methods.List<Operand<T>>AbstractOption. parseArgs(String[] aArgs, String[] aOptions)Parses the provided command line arguments and determines the according values by evaluating thisSyntaxableinstance or, in case of being a node in the syntax tree (such as aArgsSyntax, traversing the childSyntaxableinstances'Syntaxable.parseArgs(String[], String[])methods.List<? extends Operand<?>>AllCondition. parseArgs(String[] aArgs, String[] aOptions)Parses the provided command line arguments and determines the according values by evaluating thisSyntaxableinstance or, in case of being a node in the syntax tree (such as aArgsSyntax, traversing the childSyntaxableinstances'Syntaxable.parseArgs(String[], String[])methods.List<? extends Operand<?>>AndCondition. parseArgs(String[] aArgs, String[] aOptions)Parses the provided command line arguments and determines the according values by evaluating thisSyntaxableinstance or, in case of being a node in the syntax tree (such as aArgsSyntax, traversing the childSyntaxableinstances'Syntaxable.parseArgs(String[], String[])methods.List<? extends Operand<?>>AnyCondition. parseArgs(String[] aArgs, String[] aOptions)Parses the provided command line arguments and determines the according values by evaluating thisSyntaxableinstance or, in case of being a node in the syntax tree (such as aArgsSyntax, traversing the childSyntaxableinstances'Syntaxable.parseArgs(String[], String[])methods.List<Operand<?>>ArrayOperand. parseArgs(String[] aArgs, String[] aOperands)Parses the provided command line arguments and determines the according values by evaluating thisSyntaxableinstance or, in case of being a node in the syntax tree (such as aArgsSyntax, traversing the childSyntaxableinstances'Syntaxable.parseArgs(String[], String[])methods.List<Operand<Boolean>>Flag. parseArgs(String[] aArgs, String[] aOptions)Parses the provided command line arguments and determines the according values by evaluating thisSyntaxableinstance or, in case of being a node in the syntax tree (such as aArgsSyntax, traversing the childSyntaxableinstances'Syntaxable.parseArgs(String[], String[])methods.List<Operand<Boolean>>NoneOperand. parseArgs(String[] aArgs, String[] aOptions)Parses the provided command line arguments and determines the according values by evaluating thisSyntaxableinstance or, in case of being a node in the syntax tree (such as aArgsSyntax, traversing the childSyntaxableinstances'Syntaxable.parseArgs(String[], String[])methods.List<Operand<Boolean>>Operation. parseArgs(String[] aArgs, String[] aOptions)Parses the provided command line arguments and determines the according values by evaluating thisSyntaxableinstance or, in case of being a node in the syntax tree (such as aArgsSyntax, traversing the childSyntaxableinstances'Syntaxable.parseArgs(String[], String[])methods.List<? extends Operand<?>>OptionCondition. parseArgs(String[] aArgs, String[] aOptions)Parses the provided command line arguments and determines the according values by evaluating thisSyntaxableinstance or, in case of being a node in the syntax tree (such as aArgsSyntax, traversing the childSyntaxableinstances'Syntaxable.parseArgs(String[], String[])methods.List<? extends Operand<?>>OrCondition. parseArgs(String[] aArgs, String[] aOptions)Parses the provided command line arguments and determines the according values by evaluating thisSyntaxableinstance or, in case of being a node in the syntax tree (such as aArgsSyntax, traversing the childSyntaxableinstances'Syntaxable.parseArgs(String[], String[])methods.default List<? extends Operand<?>>Syntaxable. parseArgs(String[] aArgs)Parses the provided command line arguments and determines the according values by evaluating thisSyntaxableinstance or, in case of being a node in the syntax tree (such as aArgsSyntax, traversing the childSyntaxableinstances'Syntaxable.parseArgs(String[], String[])methods.List<? extends Operand<?>>Syntaxable. parseArgs(String[] aArgs, String[] aOptions)Parses the provided command line arguments and determines the according values by evaluating thisSyntaxableinstance or, in case of being a node in the syntax tree (such as aArgsSyntax, traversing the childSyntaxableinstances'Syntaxable.parseArgs(String[], String[])methods.List<? extends Operand<?>>XorCondition. parseArgs(String[] aArgs, String[] aOptions)Parses the provided command line arguments and determines the according values by evaluating thisSyntaxableinstance or, in case of being a node in the syntax tree (such as aArgsSyntax, traversing the childSyntaxableinstances'Syntaxable.parseArgs(String[], String[])methods.List<Operand<?>>AbstractCondition. toOperands()Traverses the hierarchy ofArgsSyntaxs and collects all therein foundOperands and sub-types such as theFlagor theOption.List<? extends Operand<?>>ArgsSyntax. toOperands()Traverses the hierarchy ofArgsSyntaxs and collects all therein foundOperands and sub-types such as theFlagor theOption.Methods in org.refcodes.cli with parameters of type Operand Modifier and Type Method Description default voidArgsParser. addExample(String aDescription, Operand<?>... aOperands)Adds a usage example by providing a description of the example and the command line arguments required by the example.static <T> ArrayOperand<T>CliSugar. asArray(Operand<T> aOperand)Creates an array representation facade for the encapsulatedOperand.static <T> ArrayOperand<T>CliSugar. asArray(Operand<T> aOperand, int aLength)Creates an array representation facade for the encapsulatedOperand.static <T> ArrayOperand<T>CliSugar. asArray(Operand<T> aOperand, int aMinLength, int aMaxLength)Creates an array representation facade for the encapsulatedOperand.intAbstractOperand. compareTo(Operand<?> obj)intArrayOperand. compareTo(Operand<?> o)static ExampleCliSugar. example(String aDescription, Operand<?>... aOperands)static StringCliUtility. toOptionsSpec(Operand<?> aOperand)Creates the options specification containing the short option (if any) and the long option (if any) from the providedOperand.static StringCliUtility. toOptionsSpec(Operand<?> aOperand, String aOptEscCode, String aResetEscCode)Creates the options specification containing the short option (if any) and the long option (if any) from the providedOperand.static StringCliUtility. toParameterSpec(Operand<?> aOperand)Creates the parameter specification from the providedOperand.static StringCliUtility. toParameterSpec(Operand<?> aOperand, int aMin, int aMax)Creates the parameter specification from the providedOperand.static StringCliUtility. toParameterSpec(Operand<?> aOperand, int aMin, int aMax, String aParamEscCode, String aResetEscCode)Creates the parameter specification from the providedOperand.static StringCliUtility. toParameterSpec(Operand<?> aOperand, String aParamEscCode, String aResetEscCode)Creates the parameter specification from the providedOperand.static StringCliUtility. toShortOptionsSpec(Operand<?> aOperand)Creates the options specification containing the short option only (if any) or(!)static StringCliUtility. toShortOptionsSpec(Operand<?> aOperand, String aOptEscCode, String aResetEscCode)Creates the options specification containing the short option only (if any) or(!)static StringCliUtility. toShortSpec(Operand<?> aOperand)Creates a specification for the givenOperandconsisting of the short option specification (if any) or the long option specification(if any) and the parameter specification (if any) as ofCliUtility.toParameterSpec(Operand).static StringCliUtility. toShortSpec(Operand<?> aOperand, String aOptEscCode, String aParamEscCode, String aResetEscCode)Creates a specification for the givenOperandconsisting of the short option specification (if any) or the long option specification(if any) and the parameter specification (if any) as ofCliUtility.toParameterSpec(Operand).static StringCliUtility. toSpec(Operand<?> aOperand)Creates a specification for the givenOperandconsisting of the options specification (if any) as ofCliUtility.toOptionsSpec(Operand)and the parameter specification (if any) as ofCliUtility.toParameterSpec(Operand).static StringCliUtility. toSpec(Operand<?> aOperand, String aOptEscCode, String aParamEscCode, String aResetEscCode)Creates a specification for the givenOperandconsisting of the options specification (if any) as ofCliUtility.toOptionsSpec(Operand)and the parameter specification (if any) as ofCliUtility.toParameterSpec(Operand).default ArgsParserArgsParser. withExample(String aDescription, Operand<?>... aOperands)Adds a usage example by providing a description of the example and the command line arguments required by the example.Method parameters in org.refcodes.cli with type arguments of type Operand Modifier and Type Method Description static String[]CliUtility. toDiff(String[] aSet, List<? extends Operand<?>> aSubset)Constructors in org.refcodes.cli with parameters of type Operand Constructor Description ArrayOperand(Operand<T> aOperand)Constructs theArrayOperandby encapsulating the givenOperandand providing its definition as array definition to the CLI.ArrayOperand(Operand<T> aOperand, int aLength)Constructs theArrayOperandby encapsulating the givenOperandand providing its definition as array definition to the CLI.ArrayOperand(Operand<T> aOperand, int aMinLength, int aMaxLength)Constructs theArrayOperandby encapsulating the givenOperandand providing its definition as array definition to the CLI.Example(String aDescription, Operand<?>... aOperands)Constructs an example usage.
-