Uses of Interface
org.refcodes.cli.Operand
-
Uses of Operand in org.refcodes.cli
Subinterfaces of Operand in org.refcodes.cli Modifier and Type Interface Description interfaceOption<T>AnOptionrepresents a command line option with the according option's value.Classes in org.refcodes.cli that implement Operand Modifier and Type Class Description classAbstractOperand<T>TheAbstractOperandis an abstract implementation of anOperandproviding the boiler plate when implementing theOperandinterface.classAbstractOption<T>TheAbstractOptionis an abstract implementation of anOptionproviding the boiler plate when implementing theOptioninterface.classArrayOperand<T>Creates an array representation facade for the encapsulatedOperand.classArrayOption<T>Creates an array representation facade for the encapsulatedOption.classCharOptionclassDebugFlagA predefined debug switch.classDoubleOptionclassEnumOption<T extends Enum<T>>The Class EnumOption.classFileOptionclassFlagTheFlagclass implements theOptioninterface for representing either atrueor afalsestate: When a flag is provided to your command line arguments, then it is considered to betrue, when it is omitted, then it is considered to befalseas ofFlag.isEnabled().classFloatOptionclassForceFlagA predefined force switch.classHelpFlagA predefined help switch.classIntOptionclassLongOptionclassOperationTheOperationis an argument representing a function or a method and is either provided or not provided as ofOperation.isEnabled().classQuietFlagA predefined "be quiet" switch.classStringOperandclassStringOptionclassSysInfoFlagA predefined system information switch.classVerboseFlagA predefined verbose switch.Methods in org.refcodes.cli that return Operand Modifier and Type Method Description protected Operand<T>ArrayOperand. getOperand()Hook for accessing the encapsulatedOperand.Operand<?>[]ExampleUsage. getOperands()Retrieves the command line arguments required by the example.Methods in org.refcodes.cli that return types with arguments of type Operand Modifier and Type Method Description List<? extends Operand<?>>ArgsParser. evalArgs(String[] aArgs)Evaluates the provided command line arguments and determines the according values by evaluating the rootCondition.default List<? extends Operand<?>>ArgsParser. evalArgs(List<String> aArgs)Same asArgsParser.evalArgs(String[])with the difference that the elements representing the arguments are passed as a list instead of an array.List<? extends Operand<?>>ArgsParserImpl. evalArgs(String[] aArgs)Evaluates the provided command line arguments and determines the according values by evaluating the rootCondition.protected static List<? extends Operand<?>>ArgsParserImpl. fromArgs(String[] aArgs, char aDelimiter)Heuristically loads the arguments without any syntax required, e.g.List<Operand<T>>AbstractOperand. parseArgs(String[] aArgs, String[] aOptions)Parses the provided command line arguments and determines the according values by evaluating thisSyntaxableinstance or, in case of being a node in the syntax tree (such as aCondition, traversing the childSyntaxableinstances'Syntaxable.parseArgs(String[], String[])methods.List<Operand<T>>AbstractOption. parseArgs(String[] aArgs, String[] aOptions)Parses the provided command line arguments and determines the according values by evaluating thisSyntaxableinstance or, in case of being a node in the syntax tree (such as aCondition, traversing the childSyntaxableinstances'Syntaxable.parseArgs(String[], String[])methods.List<? extends Operand<?>>AndCondition. parseArgs(String[] aArgs, String[] aOptions)List<Operand<?>>ArrayOperand. parseArgs(String[] aArgs, String[] aOperands)Parses the provided command line arguments and determines the according values by evaluating thisSyntaxableinstance or, in case of being a node in the syntax tree (such as aCondition, traversing the childSyntaxableinstances'Syntaxable.parseArgs(String[], String[])methods.List<Operand<Boolean>>Flag. parseArgs(String[] aArgs, String[] aOptions)Parses the provided command line arguments and determines the according values by evaluating thisSyntaxableinstance or, in case of being a node in the syntax tree (such as aCondition, traversing the childSyntaxableinstances'Syntaxable.parseArgs(String[], String[])methods.List<Operand<Boolean>>Operation. parseArgs(String[] aArgs, String[] aOptions)Parses the provided command line arguments and determines the according values by evaluating thisSyntaxableinstance or, in case of being a node in the syntax tree (such as aCondition, traversing the childSyntaxableinstances'Syntaxable.parseArgs(String[], String[])methods.List<? extends Operand<?>>OptionalCondition. parseArgs(String[] aArgs, String[] aOptions)List<? extends Operand<?>>OptionConditionFacade. parseArgs(String[] aArgs, String[] aOptions)List<? extends Operand<?>>OrCondition. parseArgs(String[] aArgs, String[] aOptions)default List<? extends Operand<?>>Syntaxable. parseArgs(String[] aArgs)Parses the provided command line arguments and determines the according values by evaluating thisSyntaxableinstance or, in case of being a node in the syntax tree (such as aCondition, traversing the childSyntaxableinstances'Syntaxable.parseArgs(String[], String[])methods.List<? extends Operand<?>>Syntaxable. parseArgs(String[] aArgs, String[] aOptions)Parses the provided command line arguments and determines the according values by evaluating thisSyntaxableinstance or, in case of being a node in the syntax tree (such as aCondition, traversing the childSyntaxableinstances'Syntaxable.parseArgs(String[], String[])methods.List<? extends Operand<?>>XorCondition. parseArgs(String[] aArgs, String[] aOptions)List<Operand<?>>AbstractCondition. toOperands()List<? extends Operand<?>>Condition. toOperands()Methods in org.refcodes.cli with parameters of type Operand Modifier and Type Method Description voidArgsParser. addExampleUsage(String aDescription, Operand<?>... aOperands)Adds a usage example by providing a description of the example and the command line arguments required by the example.voidArgsParserImpl. addExampleUsage(String aDescription, Operand<?>... aOperands)Adds a usage example by providing a description of the example and the command line arguments required by the example.static <T> ArrayOperand<T>CliSugar. asArray(Operand<T> aOperand)Creates an array representation facade for the encapsulatedOperand.static <T> ArrayOperand<T>CliSugar. asArray(Operand<T> aOperand, int aLength)Creates an array representation facade for the encapsulatedOperand.static <T> ArrayOperand<T>CliSugar. asArray(Operand<T> aOperand, int aMinLength, int aMaxLength)Creates an array representation facade for the encapsulatedOperand.intAbstractOperand. compareTo(Operand<?> obj)intArrayOperand. compareTo(Operand<?> o)static StringCliUtility. toOptionsSpec(Operand<?> aOperand)Creates the options specification containing the short option (if any) and the long option ( if any) from the providedOperand;.static StringCliUtility. toParameterSpec(Operand<?> aOperand)Creates the parameter specification from the providedOperand.static StringCliUtility. toParameterSpec(Operand<?> aOperand, int aMin, int aMax)Creates the parameter specification from the providedOperand.static StringCliUtility. toSpec(Operand<?> aOperand)Creates a specification for the givenOperandconsisting of the options specification (if any) as ofCliUtility.toOptionsSpec(Operand)and the parameter specification (if any) as ofCliUtility.toParameterSpec(Operand).default ArgsParserArgsParser. withExampleUsage(String aDescription, Operand<?>... aOperands)Adds a usage example by providing a description of the example and the command line arguments required by the example.Method parameters in org.refcodes.cli with type arguments of type Operand Modifier and Type Method Description static String[]CliUtility. toDiff(String[] aSet, List<? extends Operand<?>> aSubset)Constructors in org.refcodes.cli with parameters of type Operand Constructor Description ArrayOperand(Operand<T> aOperand)Constructs theArrayOperandby encapsulating the givenOperandand providing its definition as array definition to the CLI.ArrayOperand(Operand<T> aOperand, int aLength)Constructs theArrayOperandby encapsulating the givenOperandand providing its definition as array definition to the CLI.ArrayOperand(Operand<T> aOperand, int aMinLength, int aMaxLength)Constructs theArrayOperandby encapsulating the givenOperandand providing its definition as array definition to the CLI.ExampleUsage(String aDescription, Operand<?>... aOperands)Constructs an example usage.