Uses of Interface
org.refcodes.cli.Option
-
Uses of Option in org.refcodes.cli
Subinterfaces of Option in org.refcodes.cliModifier and TypeInterfaceDescriptioninterfaceAnPropertyOptionrepresents a command line property with the according porperty's key and value.Classes in org.refcodes.cli that implement OptionModifier and TypeClassDescriptionclassTheAbstractOptionis an abstract implementation of anOptionproviding the boiler plate when implementing theOptioninterface.classTheAbstractPropertyOptionis an abstract implementation of aPropertyOptionproviding the boiler plate when implementing thePropertyOptioninterface.classArrayOption<T>Creates an array representation facade for the encapsulatedOption.classclassclassclassclassA predefined cleanFlag: A predefinedFlaggives itsCleanFlag.SHORT_OPTION, itsCleanFlag.LONG_OPTIONas well as itsCleanFlag.ALIASan according semantics regarded by other subsystems.classTheConfigOptionrepresents anOptionholding a value specifying a configuration resource (file).classTheConfigPropertyrepresents anPropertyOptionholding a value specifying a configuration resource (file).classA predefined daemonFlag: A predefinedFlaggives itsDaemonFlag.SHORT_OPTION, itsDaemonFlag.LONG_OPTIONas well as itsDaemonFlag.ALIASan according semantics regarded by other subsystems.classA predefined debugFlag: A predefinedFlaggives itsDebugFlag.SHORT_OPTION, itsDebugFlag.LONG_OPTIONas well as itsDebugFlag.ALIASan according semantics regarded by other subsystems.classclassclassEnumOption<T extends Enum<T>>TheEnumOptionrepresents anOptionof enumeration types.classEnumProperty<T extends Enum<T>>TheEnumPropertyrepresents anPropertyOptionof enumeration types.classclassclassTheFlagclass implements theOptioninterface for representing either atrueor afalsestate: When a flag is provided to your command line arguments, then it is considered to betrue, when it is omitted, then it is considered to befalseas ofFlag.isEnabled().classclassclassA predefined forceFlag: A predefinedFlaggives itsForceFlag.SHORT_OPTION, itsForceFlag.LONG_OPTIONas well as itsForceFlag.ALIASan according semantics regarded by other subsystems.classA predefined helpFlag: A predefinedFlaggives itsHelpFlag.SHORT_OPTION, itsHelpFlag.LONG_OPTIONas well as itsHelpFlag.ALIASan according semantics regarded by other subsystems.classA predefined initFlag: A predefinedFlaggives itsInitFlag.SHORT_OPTION, itsInitFlag.LONG_OPTIONas well as itsInitFlag.ALIASan according semantics regarded by other subsystems.classclassclassclassclassA predefined "be quiet"Flag: A predefinedFlaggives itsQuietFlag.SHORT_OPTION, itsQuietFlag.LONG_OPTIONas well as itsQuietFlag.ALIASan according semantics regarded by other subsystems.classclassclassA predefined system informationFlag: A predefinedFlaggives itsSysInfoFlag.SHORT_OPTION, itsSysInfoFlag.LONG_OPTIONas well as itsSysInfoFlag.ALIASan according semantics regarded by other subsystems..classA predefined verboseFlag: A predefinedFlaggives itsVerboseFlag.SHORT_OPTION, itsVerboseFlag.LONG_OPTIONas well as itsVerboseFlag.ALIASan according semantics regarded by other subsystems.Methods in org.refcodes.cli with parameters of type OptionModifier and TypeMethodDescriptionstatic <T> ArrayOption<T>Creates an array representation facade for the encapsulatedOption.static <T> ArrayOption<T>Creates an array representation facade for the encapsulatedOption.static <T> ArrayOption<T>Creates an array representation facade for the encapsulatedOption.CliContext.toLongOption(Option<?> aOption) Creates theCliContextinstance specific prefixed long optionStringfrom the providedOptionby prefixing theOption's long option (as ofgetLongOption()) with the long option prefix (as ofLongOptionPrefixAccessor.getLongOptionPrefix()).String[]Retrieves an array of the context specific options being configured for the givenOptioninstance, being the long option (when set) and the short option (when set), by prepending the according runtime specific short option and long option prefix (if applicable).String[]Retrieves an array of the context specific options being configured for the givenOptioninstance, being the long option (when set) and the short option (when set), by prepending the according runtime specific short option and long option prefix (if applicable).default String[]Retrieves an array of the context specific options being configured for the givenOptioninstance, being the long option (when set) and the short option (when set), by prepending the according runtime specific short option and long option prefix (if applicable).CliContext.toOptionSpec(Option<?> aOption) Creates theCliContextinstance specific option notationString(without any arguments), consisting of the short option (as ofCliContext.toShortOption(Option)) and(!)CliContext.toOptionUsage(Option<?> aOption) Creates theCliContextinstance specific preferred prefixed optionString, being the short option (as ofCliContext.toShortOption(Option)) or, in case of the short option beingnull, the long option (as ofCliContext.toLongOption(Option)).CliContext.toShortOption(Option<?> aOption) Creates theCliContextinstance specific prefixed short optionStringfrom the providedOptionby prefixing theOption's short option (as ofgetShortOption()) with the short option prefix (as ofShortOptionPrefixAccessor.getShortOptionPrefix()).Constructors in org.refcodes.cli with parameters of type OptionModifierConstructorDescriptionArrayOption(Option<T> aOption) Constructs theArrayOptionby encapsulating the givenOptionand providing its definition as array definition to the CLI.ArrayOption(Option<T> aOption, int aLength) Constructs theArrayOptionby encapsulating the givenOptionand providing its definition as array definition to the CLI.ArrayOption(Option<T> aOption, int aMinLength, int aMaxLength) Constructs theArrayOptionby encapsulating the givenOptionand providing its definition as array definition to the CLI.