Uses of Interface
org.refcodes.cli.Option
-
Uses of Option in org.refcodes.cli
Classes in org.refcodes.cli that implement OptionModifier and TypeClassDescriptionclassTheAbstractOptionis an abstract implementation of anOptionproviding the boiler plate when implementing theOptioninterface.classArrayOption<T>Creates an array representation facade for the encapsulatedOption.classclassA predefined cleanFlag: A predefinedFlaggives itsCleanFlag.SHORT_OPTION, itsCleanFlag.LONG_OPTIONas well as itsCleanFlag.ALIASan according semantics regarded by other subsystems.classTheConfigOptionrepresents anOptionholding a value specifying a configuration resource (file).classA predefined daemonFlag: A predefinedFlaggives itsDaemonFlag.SHORT_OPTION, itsDaemonFlag.LONG_OPTIONas well as itsDaemonFlag.ALIASan according semantics regarded by other subsystems.classA predefined debugFlag: A predefinedFlaggives itsDebugFlag.SHORT_OPTION, itsDebugFlag.LONG_OPTIONas well as itsDebugFlag.ALIASan according semantics regarded by other subsystems.classclassEnumOption<T extends Enum<T>>The Class EnumOption.classclassTheFlagclass implements theOptioninterface for representing either atrueor afalsestate: When a flag is provided to your command line arguments, then it is considered to betrue, when it is omitted, then it is considered to befalseas ofFlag.isEnabled().classclassA predefined forceFlag: A predefinedFlaggives itsForceFlag.SHORT_OPTION, itsForceFlag.LONG_OPTIONas well as itsForceFlag.ALIASan according semantics regarded by other subsystems.classA predefined helpFlag: A predefinedFlaggives itsHelpFlag.SHORT_OPTION, itsHelpFlag.LONG_OPTIONas well as itsHelpFlag.ALIASan according semantics regarded by other subsystems.classA predefined initFlag: A predefinedFlaggives itsInitFlag.SHORT_OPTION, itsInitFlag.LONG_OPTIONas well as itsInitFlag.ALIASan according semantics regarded by other subsystems.classclassclassA predefined "be quiet"Flag: A predefinedFlaggives itsQuietFlag.SHORT_OPTION, itsQuietFlag.LONG_OPTIONas well as itsQuietFlag.ALIASan according semantics regarded by other subsystems.classclassA predefined system informationFlag: A predefinedFlaggives itsSysInfoFlag.SHORT_OPTION, itsSysInfoFlag.LONG_OPTIONas well as itsSysInfoFlag.ALIASan according semantics regarded by other subsystems..classA predefined verboseFlag: A predefinedFlaggives itsVerboseFlag.SHORT_OPTION, itsVerboseFlag.LONG_OPTIONas well as itsVerboseFlag.ALIASan according semantics regarded by other subsystems.Methods in org.refcodes.cli with parameters of type OptionModifier and TypeMethodDescriptionstatic <T> ArrayOption<T>Creates an array representation facade for the encapsulatedOption.static <T> ArrayOption<T>Creates an array representation facade for the encapsulatedOption.static <T> ArrayOption<T>Creates an array representation facade for the encapsulatedOption.CliUtility.getOptionArgument(Option<?> aOption, String[] aArgs, String[] aOptions) default voidRootConditionAccessor.RootConditionMutator.setRootOption(Option<?> aRootOption) Sets the root option for the root condition property.default BRootConditionAccessor.RootConditionBuilder.withRootOption(Option<?> aRootOption) Sets the root option for the root condition property.Constructors in org.refcodes.cli with parameters of type OptionModifierConstructorDescriptionArgsParserImpl(Option<?> aRootOption) Constructs theArgsParserinstance with the given rootOptionand the defaultSyntaxNotation.REFCODES.ArrayOption(Option<T> aOption) Constructs theArrayOptionby encapsulating the givenOptionand providing its definition as array definition to the CLI.ArrayOption(Option<T> aOption, int aLength) Constructs theArrayOptionby encapsulating the givenOptionand providing its definition as array definition to the CLI.ArrayOption(Option<T> aOption, int aMinLength, int aMaxLength) Constructs theArrayOptionby encapsulating the givenOptionand providing its definition as array definition to the CLI.OptionCondition(Option<?> aArg)