Uses of Interface
org.refcodes.cli.Option
-
-
Uses of Option in org.refcodes.cli
Classes in org.refcodes.cli that implement Option Modifier and Type Class Description classAbstractOption<T>TheAbstractOptionis an abstract implementation of anOptionproviding the boiler plate when implementing theOptioninterface.classArrayOption<T>Creates an array representation facade for the encapsulatedOption.classCharOptionclassCleanFlagA predefined cleanFlag: A predefinedFlaggives itsCleanFlag.SHORT_OPTION, itsCleanFlag.LONG_OPTIONas well as itsCleanFlag.ALIASan according semantics regarded by other subsystems.classConfigOptionTheConfigOptionrepresents anOptionholding a value specifying a configuration resource (file).classDaemonFlagA predefined daemonFlag: A predefinedFlaggives itsDaemonFlag.SHORT_OPTION, itsDaemonFlag.LONG_OPTIONas well as itsDaemonFlag.ALIASan according semantics regarded by other subsystems.classDebugFlagA predefined debugFlag: A predefinedFlaggives itsDebugFlag.SHORT_OPTION, itsDebugFlag.LONG_OPTIONas well as itsDebugFlag.ALIASan according semantics regarded by other subsystems.classDoubleOptionclassEnumOption<T extends Enum<T>>The Class EnumOption.classFileOptionclassFlagTheFlagclass implements theOptioninterface for representing either atrueor afalsestate: When a flag is provided to your command line arguments, then it is considered to betrue, when it is omitted, then it is considered to befalseas ofFlag.isEnabled().classFloatOptionclassForceFlagA predefined forceFlag: A predefinedFlaggives itsForceFlag.SHORT_OPTION, itsForceFlag.LONG_OPTIONas well as itsForceFlag.ALIASan according semantics regarded by other subsystems.classHelpFlagA predefined helpFlag: A predefinedFlaggives itsHelpFlag.SHORT_OPTION, itsHelpFlag.LONG_OPTIONas well as itsHelpFlag.ALIASan according semantics regarded by other subsystems.classInitFlagA predefined initFlag: A predefinedFlaggives itsInitFlag.SHORT_OPTION, itsInitFlag.LONG_OPTIONas well as itsInitFlag.ALIASan according semantics regarded by other subsystems.classIntOptionclassLongOptionclassQuietFlagA predefined "be quiet"Flag: A predefinedFlaggives itsQuietFlag.SHORT_OPTION, itsQuietFlag.LONG_OPTIONas well as itsQuietFlag.ALIASan according semantics regarded by other subsystems.classStringOptionclassSysInfoFlagA predefined system informationFlag: A predefinedFlaggives itsSysInfoFlag.SHORT_OPTION, itsSysInfoFlag.LONG_OPTIONas well as itsSysInfoFlag.ALIASan according semantics regarded by other subsystems..classVerboseFlagA predefined verboseFlag: A predefinedFlaggives itsVerboseFlag.SHORT_OPTION, itsVerboseFlag.LONG_OPTIONas well as itsVerboseFlag.ALIASan according semantics regarded by other subsystems.Methods in org.refcodes.cli with parameters of type Option Modifier and Type Method Description static <T> ArrayOption<T>CliSugar. asArray(Option<T> aOption)Creates an array representation facade for the encapsulatedOption.static <T> ArrayOption<T>CliSugar. asArray(Option<T> aOption, int aLength)Creates an array representation facade for the encapsulatedOption.static <T> ArrayOption<T>CliSugar. asArray(Option<T> aOption, int aMinLength, int aMaxLength)Creates an array representation facade for the encapsulatedOption.static org.refcodes.struct.Relation<String,String>CliUtility. getOptionArgument(Option<?> aOption, String[] aArgs, String[] aOptions)default voidRootConditionAccessor.RootConditionMutator. setRootOption(Option<?> aRootOption)Sets the root option for the root condition property.default BRootConditionAccessor.RootConditionBuilder. withRootOption(Option<?> aRootOption)Sets the root option for the root condition property.Constructors in org.refcodes.cli with parameters of type Option Constructor Description ArgsParserImpl(Option<?> aRootOption)Constructs theArgsParserinstance with the given rootOptionand the defaultSyntaxNotation.REFCODES.ArrayOption(Option<T> aOption)Constructs theArrayOptionby encapsulating the givenOptionand providing its definition as array definition to the CLI.ArrayOption(Option<T> aOption, int aLength)Constructs theArrayOptionby encapsulating the givenOptionand providing its definition as array definition to the CLI.ArrayOption(Option<T> aOption, int aMinLength, int aMaxLength)Constructs theArrayOptionby encapsulating the givenOptionand providing its definition as array definition to the CLI.OptionCondition(Option<?> aArg)
-