Uses of Interface
org.refcodes.cli.Option
-
Uses of Option in org.refcodes.cli
Classes in org.refcodes.cli that implement Option Modifier and Type Class Description classAbstractOption<T>TheAbstractOptionis an abstract implementation of anOptionproviding the boiler plate when implementing theOptioninterface.classArrayOption<T>Creates an array representation facade for the encapsulatedOption.classCharOptionclassDebugFlagA predefined debug switch.classDoubleOptionclassEnumOption<T extends Enum<T>>The Class EnumOption.classFileOptionclassFlagTheFlagclass implements theOptioninterface for representing either atrueor afalsestate: When a flag is provided to your command line arguments, then it is considered to betrue, when it is omitted, then it is considered to befalseas ofFlag.isEnabled().classFloatOptionclassForceFlagA predefined force switch.classHelpFlagA predefined help switch.classIntOptionclassLongOptionclassQuietFlagA predefined "be quiet" switch.classStringOptionclassSysInfoFlagA predefined system information switch.classVerboseFlagA predefined verbose switch.Methods in org.refcodes.cli with parameters of type Option Modifier and Type Method Description static <T> ArrayOption<T>CliSugar. asArray(Option<T> aOption)Creates an array representation facade for the encapsulatedOption.static <T> ArrayOption<T>CliSugar. asArray(Option<T> aOption, int aLength)Creates an array representation facade for the encapsulatedOption.static <T> ArrayOption<T>CliSugar. asArray(Option<T> aOption, int aMinLength, int aMaxLength)Creates an array representation facade for the encapsulatedOption.static org.refcodes.struct.Relation<String,String>CliUtility. getOptionArgument(Option<?> aOption, String[] aArgs, String[] aOptions)default voidRootConditionAccessor.RootConditionMutator. setRootOption(Option<?> aRootOption)Sets the root option for the root condition property.default BRootConditionAccessor.RootConditionBuilder. withRootOption(Option<?> aRootOption)Sets the root option for the root condition property.Constructors in org.refcodes.cli with parameters of type Option Constructor Description ArgsParserImpl(Option<?> aRootOption)Constructs theArgsParserinstance with the given rootOptionand the defaultSyntaxNotation.REFCODES.ArrayOption(Option<T> aOption)Constructs theArrayOptionby encapsulating the givenOptionand providing its definition as array definition to the CLI.ArrayOption(Option<T> aOption, int aLength)Constructs theArrayOptionby encapsulating the givenOptionand providing its definition as array definition to the CLI.ArrayOption(Option<T> aOption, int aMinLength, int aMaxLength)Constructs theArrayOptionby encapsulating the givenOptionand providing its definition as array definition to the CLI.