-
class
Thrown in case the provided command line arguments do not respect the
required semantics or cannot be converted to the required type by an
Option (having a short- and/or a long-option), e.g. the arguments
were rejected as them did not work for the according syntax.
Double dispatch hook to be implemented by subclasses of the
AbstractOperand for converting a command line argument to the
required
Operand's type.
Double dispatch hook to be implemented by subclasses of the
AbstractOperand for converting a command line argument to the
required
Operand's type.
Double dispatch hook to be implemented by subclasses of the
AbstractOperand for converting a command line argument to the
required
Operand's type.
Double dispatch hook to be implemented by subclasses of the
AbstractOperand for converting a command line argument to the
required
Operand's type.
Double dispatch hook to be implemented by subclasses of the
AbstractOperand for converting a command line argument to the
required
Operand's type.
Double dispatch hook to be implemented by subclasses of the
AbstractOperand for converting a command line argument to the
required
Operand's type.
Double dispatch hook to be implemented by subclasses of the
AbstractOperand for converting a command line argument to the
required
Operand's type.
Double dispatch hook to be implemented by subclasses of the
AbstractOperand for converting a command line argument to the
required
Operand's type.
Double dispatch hook to be implemented by subclasses of the
AbstractOperand for converting a command line argument to the
required
Operand's type.
Double dispatch hook to be implemented by subclasses of the
AbstractOperand for converting a command line argument to the
required
Operand's type.
Double dispatch hook to be implemented by subclasses of the
AbstractOperand for converting a command line argument to the
required
Operand's type.
Double dispatch hook to be implemented by subclasses of the
AbstractOperand for converting a command line argument to the
required
Operand's type.
Double dispatch hook to be implemented by subclasses of the
AbstractOperand for converting a command line argument to the
required
Operand's type.
Double dispatch hook to be implemented by subclasses of the
AbstractOperand for converting a command line argument to the
required
Operand's type.
Double dispatch hook to be implemented by subclasses of the
AbstractOperand for converting a command line argument to the
required
Operand's type.
Double dispatch hook to be implemented by subclasses of the
AbstractOperand for converting a command line argument to the
required
Operand's type.
Double dispatch hook to be implemented by subclasses of the
AbstractOperand for converting a command line argument to the
required
Operand's type.
Double dispatch hook to be implemented by subclasses of the
AbstractOperand for converting a command line argument to the
required
Operand's type.
Double dispatch hook to be implemented by subclasses of the
AbstractOperand for converting a command line argument to the
required
Operand's type.
Double dispatch hook to be implemented by subclasses of the
AbstractOperand for converting a command line argument to the
required
Operand's type.
Double dispatch hook to be implemented by subclasses of the
AbstractOperand for converting a command line argument to the
required
Operand's type.