Uses of Interface
org.refcodes.cli.Synopsisable
-
Uses of Synopsisable in org.refcodes.cli
Subinterfaces of Synopsisable in org.refcodes.cliModifier and TypeInterfaceDescriptioninterfaceTheConditioninterface represents a node (and therewith the syntax for the arguments) in the command line arguments syntax tree; simply extending theConstituentinterface and adding the functionality of providing access to the addedOperands (leafs).interfaceAConstituentdefines the methods at least required when building a command line arguments syntax tree for traversing the syntax tree; either for parsing command line arguments or for constructing the command line arguments syntax.interfaceOperand<T>AnOperandrepresents a value parsed from command line arguments.interfaceOption<T>AnOptionrepresents a command line option with the according option's value.Classes in org.refcodes.cli that implement SynopsisableModifier and TypeClassDescriptionclassTheAbstractConditionis an abstract implementation of theConditioninterface providing the boiler plate when implementing theConditioninterface as done by theAbstractCondition's sub-classes.classTheAbstractOperandis an abstract implementation of anOperandproviding the boiler plate when implementing theOperandinterface.classTheAbstractOptionis an abstract implementation of anOptionproviding the boiler plate when implementing theOptioninterface.classTheAllConditionenforces that the encapsulatedConstituentconsumes all arguments passed via invoking itsConstituent.parseArgs(String[], CliContext), else aSuperfluousArgsExceptionis thrown.classAnAndConditioncontains (represents) a list ofCondition(Constituent) instances (nested by theAndCondition) of which all are to be parsed successfully as of invoking theConstituent.parseArgs(String[], String[], CliContext)methods.classAny of the nestedConditionconditions may match for theAnyConditionto match, e.g. all of the nested conditions are optional.classArrayOperand<T>Creates an array representation facade for the encapsulatedOperand.classArrayOption<T>Creates an array representation facade for the encapsulatedOption.classTheCasesConditionis anXorConditionmaking sure that all possible cases inside theXorConditionmust(!)classclassA predefined cleanFlag: A predefinedFlaggives itsCleanFlag.SHORT_OPTION, itsCleanFlag.LONG_OPTIONas well as itsCleanFlag.ALIASan according semantics regarded by other subsystems.classTheConfigOptionrepresents anOptionholding a value specifying a configuration resource (file).classA predefined daemonFlag: A predefinedFlaggives itsDaemonFlag.SHORT_OPTION, itsDaemonFlag.LONG_OPTIONas well as itsDaemonFlag.ALIASan according semantics regarded by other subsystems.classA predefined debugFlag: A predefinedFlaggives itsDebugFlag.SHORT_OPTION, itsDebugFlag.LONG_OPTIONas well as itsDebugFlag.ALIASan according semantics regarded by other subsystems.classclassEnumOption<T extends Enum<T>>TheEnumOptionrepresents anOptionof enumeration types.classclassTheFlagclass implements theOptioninterface for representing either atrueor afalsestate: When a flag is provided to your command line arguments, then it is considered to betrue, when it is omitted, then it is considered to befalseas ofFlag.isEnabled().classclassA predefined forceFlag: A predefinedFlaggives itsForceFlag.SHORT_OPTION, itsForceFlag.LONG_OPTIONas well as itsForceFlag.ALIASan according semantics regarded by other subsystems.classA predefined helpFlag: A predefinedFlaggives itsHelpFlag.SHORT_OPTION, itsHelpFlag.LONG_OPTIONas well as itsHelpFlag.ALIASan according semantics regarded by other subsystems.classA predefined initFlag: A predefinedFlaggives itsInitFlag.SHORT_OPTION, itsInitFlag.LONG_OPTIONas well as itsInitFlag.ALIASan according semantics regarded by other subsystems.classclassclassTheNoneOperandrepresents an empty set of arguments, e.g. no command line argument is being passed.classTheOperationis an argument representing a function or a method ("command") and is either provided or not provided as ofOperation.isEnabled().classAnOrConditionrepresents a list ofCondition(Constituent) instances of which at least one must be parsed successfully when theConstituents'Constituent.parseArgs(String[], String[], CliContext)methods are invoked.classA predefined "be quiet"Flag: A predefinedFlaggives itsQuietFlag.SHORT_OPTION, itsQuietFlag.LONG_OPTIONas well as itsQuietFlag.ALIASan according semantics regarded by other subsystems.classclassclassA predefined system informationFlag: A predefinedFlaggives itsSysInfoFlag.SHORT_OPTION, itsSysInfoFlag.LONG_OPTIONas well as itsSysInfoFlag.ALIASan according semantics regarded by other subsystems..classA predefined verboseFlag: A predefinedFlaggives itsVerboseFlag.SHORT_OPTION, itsVerboseFlag.LONG_OPTIONas well as itsVerboseFlag.ALIASan according semantics regarded by other subsystems.classAnXorConditionrepresents a list ofCondition(Constituent) instances of which only one is allowed to be parsed successfully when theConstituent.parseArgs(String[], String[], CliContext)methods are invoked.