Uses of Interface
org.refcodes.cli.SyntaxMetrics
-
Uses of SyntaxMetrics in org.refcodes.cli
Classes in org.refcodes.cli that implement SyntaxMetricsModifier and TypeClassDescriptionclassTheSyntaxMetricsImplclass implements theSyntaxMetricsinterface for building customSyntaxMetricsinstances.enumTheSyntaxNotationis used by a theConstituent.toSyntax(CliContext)method to determine which notation to be used for the generated syntax.Methods in org.refcodes.cli that return SyntaxMetricsModifier and TypeMethodDescriptionSyntaxMetricsImpl.Builder.build()SyntaxMetricsImpl.Builderfor fluently building aSyntaxMetricsinstances.ArgsParserImpl.getSyntaxMetrics()Retrieves theSyntaxMetricsfrom theSyntaxMetricsproperty.CliContext.getSyntaxMetrics()Retrieves theSyntaxMetricsfrom theSyntaxMetricsproperty.SyntaxMetricsAccessor.getSyntaxMetrics()Retrieves theSyntaxMetricsfrom theSyntaxMetricsproperty.default SyntaxMetricsSyntaxMetricsAccessor.SyntaxMetricsProperty.letSyntaxMetrics(SyntaxMetrics aSyntaxMetrics) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenSyntaxMetrics(setter) as ofSyntaxMetricsAccessor.SyntaxMetricsMutator.setSyntaxMetrics(SyntaxMetrics)and returns the very same value (getter).Methods in org.refcodes.cli with parameters of type SyntaxMetricsModifier and TypeMethodDescriptiondefault SyntaxMetricsSyntaxMetricsAccessor.SyntaxMetricsProperty.letSyntaxMetrics(SyntaxMetrics aSyntaxMetrics) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenSyntaxMetrics(setter) as ofSyntaxMetricsAccessor.SyntaxMetricsMutator.setSyntaxMetrics(SyntaxMetrics)and returns the very same value (getter).voidArgsParser.setSyntaxMetrics(SyntaxMetrics aSyntaxMetrics) Set theSyntaxNotation.voidArgsParserImpl.setSyntaxMetrics(SyntaxMetrics aSyntaxMetrics) Set theSyntaxNotation.voidSyntaxMetricsAccessor.SyntaxMetricsMutator.setSyntaxMetrics(SyntaxMetrics aSyntaxMetrics) Sets theSyntaxMetricsfor theSyntaxMetricsproperty.default ArgsParserArgsParser.withSyntaxMetrics(SyntaxMetrics aSyntaxMetrics) Set theSyntaxNotationand make other adjustments with the result (with regards to the Builder-Pattern).CliContext.Builder.withSyntaxMetrics(SyntaxMetrics aSyntaxMetrics) Sets theSyntaxMetricsfor theSyntaxMetricsproperty.SyntaxMetricsAccessor.SyntaxMetricsBuilder.withSyntaxMetrics(SyntaxMetrics aSyntaxMetrics) Sets theSyntaxMetricsfor theSyntaxMetricsproperty.Constructors in org.refcodes.cli with parameters of type SyntaxMetricsModifierConstructorDescriptionCliContext(CliMetrics aCliMetrics, SyntaxMetrics aSyntaxMetrics) Constructs an accordingly configuredCliContextinstance.CliContext(SyntaxMetrics aSyntaxMetrics) Constructs an accordingly configuredCliContextinstance.CliContext(SyntaxMetrics aSyntaxMetrics, boolean isEscapeCodesEnabled) Constructs an accordingly configuredCliContextinstance.CliContext(SyntaxMetrics aSyntaxMetrics, Character aShortOptionPrefix, String aLongOptionPrefix, boolean isEscapeCodesEnabled, String aArgumentEscapeCode, String aOptionEscapeCode, String aResetEscapeCode) Constructs an accordingly configuredCliContextinstance.CliContext(SyntaxMetrics aSyntaxMetrics, String aArgumentEscapeCode, String aOptionEscapeCode, String aResetEscapeCode) Constructs an accordingly configuredCliContextinstance.