Uses of Class
org.refcodes.cli.SyntaxMetricsImpl.Builder
-
Uses of SyntaxMetricsImpl.Builder in org.refcodes.cli
Methods in org.refcodes.cli that return SyntaxMetricsImpl.BuilderModifier and TypeMethodDescriptionstatic SyntaxMetricsImpl.BuilderSyntaxMetricsImpl.builder()Creates aSyntaxMetricsImpl.Builderused to fluently constructSyntaxMetricsinstances.SyntaxMetricsImpl.Builder.withAllSymbol(String aAllSymbol) Sets the symbol for representing an ALL notation.SyntaxMetricsImpl.Builder.withAndSymbol(String aAndSymbol) Sets the symbol for representing an AND notation.SyntaxMetricsImpl.Builder.withAnySymbol(String aAnySymbol) Sets the symbol for representing an ANY notation.SyntaxMetricsImpl.Builder.withArgumentPrefix(String aArgNotationPrefix) Sets the argument prefix for the argument prefix property.SyntaxMetricsImpl.Builder.withArgumentSuffix(String aArgNotationSuffix) Sets the argument suffix for the argument suffix property.SyntaxMetricsImpl.Builder.withBeginArraySymbol(String aBeginArraySymbol) Sets the symbol representing the beginning of an array, e.g. an opening square brace.SyntaxMetricsImpl.Builder.withBeginListSymbol(String aBeginListSymbol) Sets the symbol representing the beginning of a list, e.g. an opening brace.SyntaxMetricsImpl.Builder.withBeginOptionalSymbol(String aBeginOptionalSymbol) Sets the symbol representing the beginning optional elements, e.g. an opening square brace.SyntaxMetricsImpl.Builder.withBeginRangeSymbol(String aBeginRangeSymbol) Sets the symbol representing the beginning of a range, e.g. an opening square brace.SyntaxMetricsImpl.Builder.withEMptySymbol(String aEmptySymbol) Sets the symbol for representing an EMPTY notation.SyntaxMetricsImpl.Builder.withEndArraySymbol(String aEndArraySymbol) Sets the symbol representing the end of an array, e.g. a closing square brace.SyntaxMetricsImpl.Builder.withEndListSymbol(String aEndListSymbol) Sets the symbol representing the end of a list, e.g. a closing brace.SyntaxMetricsImpl.Builder.withEndOptionalSymbol(String aEndOptionalSymbol) Sets the symbol representing the end of optional elements, e.g. a closing square brace.SyntaxMetricsImpl.Builder.withEndRangeSymbol(String aEndRangeSymbol) Sets the symbol representing the end of a range, e.g. a closing square brace.SyntaxMetricsImpl.Builder.withIntervalSymbol(String aIntervalSymbol) Sets the symbol representing an interval, e.g. "..." or "-".SyntaxMetricsImpl.Builder.withLongOptionPrefix(String aLongOptionPrefix) Sets the long option prefix for the long option prefix property.SyntaxMetricsImpl.Builder.withOrSymbol(String aOrSymbol) Sets the symbol for representing an OR notation.SyntaxMetricsImpl.Builder.withShortOptionPrefix(Character aShortOptionPrefix) Sets the short option prefix for the short option prefix property.SyntaxMetricsImpl.Builder.withXorSymbol(String aXorSymbol) Sets the symbol for representing an XOR notation.