Uses of Enum Class
org.refcodes.cli.SyntaxNotation
-
Uses of SyntaxNotation in org.refcodes.cli
Fields in org.refcodes.cli declared as SyntaxNotationMethods in org.refcodes.cli that return SyntaxNotationModifier and TypeMethodDescriptiondefault SyntaxNotationSyntaxMetricsAccessor.SyntaxMetricsProperty.letSyntaxMetrics(SyntaxNotation aSyntaxNotation) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenSyntaxNotation(setter) as ofSyntaxMetricsAccessor.SyntaxMetricsMutator.setSyntaxMetrics(SyntaxNotation)and returns the very same value (getter).static SyntaxNotationSyntaxNotation.toSyntaxNotation(String aValue) Retrieves aSyntaxNotationdepending on the given string, ignoring the case as well as being graceful regarding "-" and "_",.static SyntaxNotationReturns the enum constant of this class with the specified name.static SyntaxNotation[]SyntaxNotation.values()Returns an array containing the constants of this enum class, in the order they are declared.Methods in org.refcodes.cli with parameters of type SyntaxNotationModifier and TypeMethodDescriptiondefault SyntaxNotationSyntaxMetricsAccessor.SyntaxMetricsProperty.letSyntaxMetrics(SyntaxNotation aSyntaxNotation) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenSyntaxNotation(setter) as ofSyntaxMetricsAccessor.SyntaxMetricsMutator.setSyntaxMetrics(SyntaxNotation)and returns the very same value (getter).default voidSyntaxMetricsAccessor.SyntaxMetricsMutator.setSyntaxMetrics(SyntaxNotation aSyntaxNotation) Sets theSyntaxNotationfor theSyntaxNotationproperty.default StringSynopsisable.toSynopsis(SyntaxNotation aSyntaxNotation) Returns the human readable (verbose) syntax of implementing class ATTENTION: As of different parenthesis settings for some notations regarding the rootTermand the childTerms, the methodTerm.toSyntax(CliContext)is called from inside aTermhierarchy.default StringSynopsisable.toSynopsis(SyntaxNotation aSyntaxNotation, String aOptEscCode, String aParamEscCode, String aResetEscCode) Returns the human readable (verbose) syntax of implementing class ATTENTION: As of different parenthesis settings for some notations regarding the rootTermand the childTerms, the methodTerm.toSyntax(CliContext)is called from inside aTermhierarchy.default StringTerm.toSyntax(SyntaxNotation aSyntaxNotation) This method is to be called from inside theTermhierarchy; use the methodSynopsisable.toSynopsis(SyntaxNotation)in case you invoke syntax retrieval from the rootTerm.default StringTerm.toSyntax(SyntaxNotation aSyntaxNotation, String aOptEscCode, String aParamEscCode, String aResetEscCode) This method is to be called from inside theTermhierarchy; use the methodSynopsisable.toSynopsis(SyntaxNotation)in case you invoke syntax retrieval from the rootTerm.ArgsParser.withSyntaxMetrics(SyntaxNotation aSyntaxNotation) Sets theSyntaxNotationfor theSyntaxNotationproperty.default BSyntaxMetricsAccessor.SyntaxMetricsBuilder.withSyntaxMetrics(SyntaxNotation aSyntaxNotation) Sets theSyntaxNotationfor theSyntaxNotationproperty.