Uses of Enum Class
org.refcodes.cli.SyntaxNotation
-
Uses of SyntaxNotation in org.refcodes.cli
Methods in org.refcodes.cli that return SyntaxNotationModifier and TypeMethodDescriptionstatic SyntaxNotationSyntaxNotation.toSyntaxNotation(String aValue) Retrieves aSyntaxNotationdepending on the given string, ignoring the case as well as being graceful regarding "-" and "_",.static SyntaxNotationReturns the enum constant of this class with the specified name.static SyntaxNotation[]SyntaxNotation.values()Returns an array containing the constants of this enum class, in the order they are declared.Methods in org.refcodes.cli with parameters of type SyntaxNotationModifier and TypeMethodDescriptiondefault StringSynopsisable.toSynopsis(SyntaxNotation aSyntaxNotation) Returns the human readable (verbose) syntax of implementing class ATTENTION: As of different parenthesis settings for some notations regarding the rootConstituentand the childConstituents, the methodConstituent.toSyntax(CliContext)is called from inside aConstituenthierarchy.default StringSynopsisable.toSynopsis(SyntaxNotation aSyntaxNotation, String aOptEscCode, String aParamEscCode, String aResetEscCode) Returns the human readable (verbose) syntax of implementing class ATTENTION: As of different parenthesis settings for some notations regarding the rootConstituentand the childConstituents, the methodConstituent.toSyntax(CliContext)is called from inside aConstituenthierarchy.default StringConstituent.toSyntax(SyntaxNotation aSyntaxNotation) This method is to be called from inside theConstituenthierarchy; use the methodSynopsisable.toSynopsis(SyntaxNotation)in case you invoke syntax retrieval from the rootConstituent.default StringConstituent.toSyntax(SyntaxNotation aSyntaxNotation, String aOptEscCode, String aParamEscCode, String aResetEscCode) This method is to be called from inside theConstituenthierarchy; use the methodSynopsisable.toSynopsis(SyntaxNotation)in case you invoke syntax retrieval from the rootConstituent.