Uses of Class
org.refcodes.cli.SyntaxNotation
-
Uses of SyntaxNotation in org.refcodes.cli
Methods in org.refcodes.cli that return SyntaxNotation Modifier and Type Method Description static SyntaxNotationSyntaxNotation. valueOf(String name)Returns the enum constant of this type with the specified name.static SyntaxNotation[]SyntaxNotation. values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in org.refcodes.cli with parameters of type SyntaxNotation Modifier and Type Method Description voidArgsParser. setSyntaxNotation(SyntaxNotation aSyntaxNotation)Set theSyntaxNotation.voidArgsParserImpl. setSyntaxNotation(SyntaxNotation aSyntaxNotation)Set theSyntaxNotation.StringAbstractCondition. toSyntax(SyntaxNotation aSyntaxNotation, String aOptionEscCode, String aResetEscCode)This method is to be called from inside theSyntaxablehierarchy; use the methodSyntaxUsage.toUsage(SyntaxNotation)in case you invoke syntax retrieval from the rootSyntaxable.StringAbstractOperand. toSyntax(SyntaxNotation aSyntaxNotation, String aOptionEscCode, String aResetEscCode)This method is to be called from inside theSyntaxablehierarchy; use the methodSyntaxUsage.toUsage(SyntaxNotation)in case you invoke syntax retrieval from the rootSyntaxable.StringAbstractOption. toSyntax(SyntaxNotation aSyntaxNotation, String aOptionEscCode, String aResetEscCode)This method is to be called from inside theSyntaxablehierarchy; use the methodSyntaxUsage.toUsage(SyntaxNotation)in case you invoke syntax retrieval from the rootSyntaxable.StringArrayOperand. toSyntax(SyntaxNotation aSyntaxNotation, String aOptionEscCode, String aResetEscCode)This method is to be called from inside theSyntaxablehierarchy; use the methodSyntaxUsage.toUsage(SyntaxNotation)in case you invoke syntax retrieval from the rootSyntaxable.StringArrayOption. toSyntax(SyntaxNotation aSyntaxNotation, String aOptionEscCode, String aResetEscCode)This method is to be called from inside theSyntaxablehierarchy; use the methodSyntaxUsage.toUsage(SyntaxNotation)in case you invoke syntax retrieval from the rootSyntaxable.StringOperation. toSyntax(SyntaxNotation aSyntaxNotation, String aOptionEscCode, String aResetEscCode)This method is to be called from inside theSyntaxablehierarchy; use the methodSyntaxUsage.toUsage(SyntaxNotation)in case you invoke syntax retrieval from the rootSyntaxable.default StringSyntaxable. toSyntax(SyntaxNotation aSyntaxNotation)This method is to be called from inside theSyntaxablehierarchy; use the methodSyntaxUsage.toUsage(SyntaxNotation)in case you invoke syntax retrieval from the rootSyntaxable.StringSyntaxable. toSyntax(SyntaxNotation aSyntaxNotation, String aOptionEscCode, String aResetEscCode)This method is to be called from inside theSyntaxablehierarchy; use the methodSyntaxUsage.toUsage(SyntaxNotation)in case you invoke syntax retrieval from the rootSyntaxable.StringXorCondition. toSyntax(SyntaxNotation aSyntaxNotation, String aOptionEscCode, String aResetEscCode)This method is to be called from inside theSyntaxablehierarchy; use the methodSyntaxUsage.toUsage(SyntaxNotation)in case you invoke syntax retrieval from the rootSyntaxable.StringAndCondition. toUsage(SyntaxNotation aSyntaxNotation, String aOptionEscCode, String aResetEscCode)Returns the human readable (verbose) syntax of implementing class ATTENTION: As of different parenthesis settings for some notations regarding the rootSyntaxableand the childSyntaxables, the methodSyntaxable.toSyntax(SyntaxNotation, String, String)is called from inside aSyntaxablehierarchy.StringOptionalCondition. toUsage(SyntaxNotation aSyntaxNotation, String aOptionEscCode, String aResetEscCode)Returns the human readable (verbose) syntax of implementing class ATTENTION: As of different parenthesis settings for some notations regarding the rootSyntaxableand the childSyntaxables, the methodSyntaxable.toSyntax(SyntaxNotation, String, String)is called from inside aSyntaxablehierarchy.StringOptionConditionFacade. toUsage(SyntaxNotation aSyntaxNotation, String aOptionEscCode, String aResetEscCode)Returns the human readable (verbose) syntax of implementing class ATTENTION: As of different parenthesis settings for some notations regarding the rootSyntaxableand the childSyntaxables, the methodSyntaxable.toSyntax(SyntaxNotation, String, String)is called from inside aSyntaxablehierarchy.StringOrCondition. toUsage(SyntaxNotation aSyntaxNotation, String aOptionEscCode, String aResetEscCode)Returns the human readable (verbose) syntax of implementing class ATTENTION: As of different parenthesis settings for some notations regarding the rootSyntaxableand the childSyntaxables, the methodSyntaxable.toSyntax(SyntaxNotation, String, String)is called from inside aSyntaxablehierarchy.default StringSyntaxUsage. toUsage(SyntaxNotation aSyntaxNotation)Returns the human readable (verbose) syntax of implementing class ATTENTION: As of different parenthesis settings for some notations regarding the rootSyntaxableand the childSyntaxables, the methodSyntaxable.toSyntax(SyntaxNotation, String, String)is called from inside aSyntaxablehierarchy.StringSyntaxUsage. toUsage(SyntaxNotation aSyntaxNotation, String aOptionEscCode, String aResetEscCode)Returns the human readable (verbose) syntax of implementing class ATTENTION: As of different parenthesis settings for some notations regarding the rootSyntaxableand the childSyntaxables, the methodSyntaxable.toSyntax(SyntaxNotation, String, String)is called from inside aSyntaxablehierarchy.StringXorCondition. toUsage(SyntaxNotation aSyntaxNotation, String aOptionEscCode, String aResetEscCode)Returns the human readable (verbose) syntax of implementing class ATTENTION: As of different parenthesis settings for some notations regarding the rootSyntaxableand the childSyntaxables, the methodSyntaxable.toSyntax(SyntaxNotation, String, String)is called from inside aSyntaxablehierarchy.default ArgsParserArgsParser. withSyntaxNotation(SyntaxNotation aSyntaxNotation)Set theSyntaxNotationand make other adjustments with the result (with regards to the Builder-Pattern).