Uses of Interface
org.refcodes.cli.SyntaxUsage
-
Uses of SyntaxUsage in org.refcodes.cli
Subinterfaces of SyntaxUsage in org.refcodes.cli Modifier and Type Interface Description interfaceConditionTheConditioninterface represents a node in the command line arguments syntax tree; simply extending theSyntaxableinterface and adding the functionality of providing access to the addedOperands (leafs).interfaceOperand<T>AnOperandrepresents a value parsed from command line arguments.interfaceOption<T>AnOptionrepresents a command line option with the according option's value.interfaceSyntaxableASyntaxabledefines the methods at least required when building a command line arguments syntax tree for traversing the syntax tree; either for parsing command line arguments or for constructing the command line arguments syntax.Classes in org.refcodes.cli that implement SyntaxUsage Modifier and Type Class Description classAbstractConditionTheAbstractConditionis an abstract implementation of anConditionproviding the boiler plate when implementing theConditioninterface.classAbstractOperand<T>TheAbstractOperandis an abstract implementation of anOperandproviding the boiler plate when implementing theOperandinterface.classAbstractOption<T>TheAbstractOptionis an abstract implementation of anOptionproviding the boiler plate when implementing theOptioninterface.classAndConditionAnAndConditioncontains (represents) a list ofCondition(Syntaxable) instances (nested by theAndCondition) of which all are to be parsed successfully as of invoking theSyntaxable.parseArgs(String[], String[])methods.classArrayOperand<T>Creates an array representation facade for the encapsulatedOperand.classArrayOption<T>Creates an array representation facade for the encapsulatedOption.classCharOptionclassDebugFlagA predefined debug switch.classDoubleOptionclassEnumOption<T extends Enum<T>>The Class EnumOption.classFileOptionclassFlagTheFlagclass implements theOptioninterface for representing either atrueor afalsestate: When a flag is provided to your command line arguments, then it is considered to betrue, when it is omitted, then it is considered to befalseas ofFlag.isEnabled().classFloatOptionclassForceFlagA predefined force switch.classHelpFlagA predefined help switch.classIntOptionclassLongOptionclassOperationTheOperationis an argument representing a function or a method and is either provided or not provided as ofOperation.isEnabled().classOptionalConditionTheOptionalConditioncan nested by anAndConditionand encapsulates aConditionwhich may be provided but does not necessarily needs to be provided in order for theAndConditionto successfully parse the nestedConditionitems including theOptionalCondition.classOptionConditionFacadeclassOrConditionAnOrConditionrepresents a list ofCondition(Syntaxable) instances of which at least one must be parsed successfully when theSyntaxables'Syntaxable.parseArgs(String[], String[])methods are invoked.classQuietFlagA predefined "be quiet" switch.classStringOperandclassStringOptionclassSysInfoFlagA predefined system information switch.classVerboseFlagA predefined verbose switch.classXorConditionAnXorConditionrepresents a list ofCondition(Syntaxable) instances of which only one is allowed to be parsed successfully when theSyntaxable.parseArgs(String[], String[])methods are invoked.