Uses of Interface
org.refcodes.cli.Syntaxable
-
-
Uses of Syntaxable in org.refcodes.cli
Subinterfaces of Syntaxable in org.refcodes.cli Modifier and Type Interface Description interfaceArgsSyntaxTheArgsSyntaxinterface represents a node (and therewith the syntax for the arguments) in the command line arguments syntax tree; simply extending theSyntaxableinterface and adding the functionality of providing access to the addedOperands (leafs).interfaceConditionInterface indicating that theArgsSyntaxsemantically represents a condition.interfaceOperand<T>AnOperandrepresents a value parsed from command line arguments.interfaceOption<T>AnOptionrepresents a command line option with the according option's value.Classes in org.refcodes.cli that implement Syntaxable Modifier and Type Class Description classAbstractConditionTheAbstractConditionis an abstract implementation of theArgsSyntaxinterface providing the boiler plate when implementing theArgsSyntaxinterface as done by theAbstractCondition's sub-classes.classAbstractOperand<T>TheAbstractOperandis an abstract implementation of anOperandproviding the boiler plate when implementing theOperandinterface.classAbstractOption<T>TheAbstractOptionis an abstract implementation of anOptionproviding the boiler plate when implementing theOptioninterface.classAllConditionTheAllConditionenforces that the encapsulatedSyntaxableconsumes all arguments passed via invoking itsparseArgs(String[]), else aSuperfluousArgsExceptionis thrown.classAndConditionAnAndConditioncontains (represents) a list ofArgsSyntax(Syntaxable) instances (nested by theAndCondition) of which all are to be parsed successfully as of invoking theparseArgs(String[], String[])methods.classAnyConditionAny of the nestedArgsSyntaxconditions may match for theAnyConditionto match, e.g. all of the nested conditions are optional.classArrayOperand<T>Creates an array representation facade for the encapsulatedOperand.classArrayOption<T>Creates an array representation facade for the encapsulatedOption.classCasesConditionTheCasesConditionis anXorConditionmaking sure that all possible cases inside theXorConditionmust(!)classCharOptionclassConfigOptionTheConfigOptionrepresents anOptionholding a value specifying a configuration file or identifying a configuration in general.classDaemonFlagA predefined daemonFlag: A predefinedFlaggives itsDaemonFlag.SHORT_OPTION, itsDaemonFlag.LONG_OPTIONas well as itsDaemonFlag.ALIASan according semantics regarded by other subsystems.classDebugFlagA predefined debugFlag: A predefinedFlaggives itsDebugFlag.SHORT_OPTION, itsDebugFlag.LONG_OPTIONas well as itsDebugFlag.ALIASan according semantics regarded by other subsystems.classDoubleOptionclassEnumOption<T extends Enum<T>>The Class EnumOption.classFileOptionclassFlagTheFlagclass implements theOptioninterface for representing either atrueor afalsestate: When a flag is provided to your command line arguments, then it is considered to betrue, when it is omitted, then it is considered to befalseas ofFlag.isEnabled().classFloatOptionclassForceFlagA predefined forceFlag: A predefinedFlaggives itsForceFlag.SHORT_OPTION, itsForceFlag.LONG_OPTIONas well as itsForceFlag.ALIASan according semantics regarded by other subsystems.classHelpFlagA predefined helpFlag: A predefinedFlaggives itsHelpFlag.SHORT_OPTION, itsHelpFlag.LONG_OPTIONas well as itsHelpFlag.ALIASan according semantics regarded by other subsystems.classInitFlagA predefined initFlag: A predefinedFlaggives itsInitFlag.SHORT_OPTION, itsInitFlag.LONG_OPTIONas well as itsInitFlag.ALIASan according semantics regarded by other subsystems.classIntOptionclassLongOptionclassNoneOperandTheNoneOperandrepresents an empty set of arguments, e.g. no command line argument is being passed.classOperationTheOperationis an argument representing a function or a method ("command") and is either provided or not provided as ofOperation.isEnabled().classOptionConditionclassOrConditionAnOrConditionrepresents a list ofArgsSyntax(Syntaxable) instances of which at least one must be parsed successfully when theSyntaxables'parseArgs(String[], String[])methods are invoked.classQuietFlagA predefined "be quiet"Flag: A predefinedFlaggives itsQuietFlag.SHORT_OPTION, itsQuietFlag.LONG_OPTIONas well as itsQuietFlag.ALIASan according semantics regarded by other subsystems.classStringOperandclassStringOptionclassSysInfoFlagA predefined system informationFlag: A predefinedFlaggives itsSysInfoFlag.SHORT_OPTION, itsSysInfoFlag.LONG_OPTIONas well as itsSysInfoFlag.ALIASan according semantics regarded by other subsystems..classVerboseFlagA predefined verboseFlag: A predefinedFlaggives itsVerboseFlag.SHORT_OPTION, itsVerboseFlag.LONG_OPTIONas well as itsVerboseFlag.ALIASan according semantics regarded by other subsystems.classXorConditionAnXorConditionrepresents a list ofArgsSyntax(Syntaxable) instances of which only one is allowed to be parsed successfully when theparseArgs(String[], String[])methods are invoked.Methods in org.refcodes.cli that return Syntaxable Modifier and Type Method Description protected SyntaxableAbstractCondition. getFirst()Gets the first child.Methods in org.refcodes.cli that return types with arguments of type Syntaxable Modifier and Type Method Description protected List<Syntaxable>AbstractCondition. getChildren()Gets the children.Methods in org.refcodes.cli with parameters of type Syntaxable Modifier and Type Method Description protected voidAbstractCondition. addChild(Syntaxable aArgumentizer)Adds the child.static ArgsSyntaxCliSugar. all(Syntaxable aArg)static ArgsSyntaxCliSugar. and(Syntaxable... aArgs)static ArgsSyntaxCliSugar. any(Syntaxable... aArgs)static ArgsSyntaxCliSugar. cases(Syntaxable... aArgs)static ArgsSyntaxCliSugar. optional(Syntaxable... aArgs)Semantically identical synonym for theCliSugar.optional(Syntaxable...)declaration.static ArgsSyntaxCliSugar. or(Syntaxable... aArgs)static ArgsSyntaxCliSugar. xor(Syntaxable... aArgs)Constructors in org.refcodes.cli with parameters of type Syntaxable Constructor Description AbstractCondition(Syntaxable... aElements)Instantiates a new abstract condition.AllCondition(Syntaxable aArg)AndCondition(Syntaxable... aArgs)AnyCondition(Syntaxable... aArgs)CasesCondition(Syntaxable... aArgs)OrCondition(Syntaxable... aArgs)XorCondition(Syntaxable... aArgs)
-