Uses of Interface
org.refcodes.cli.Term
-
Uses of Term in org.refcodes.cli
Subinterfaces of Term in org.refcodes.cliModifier and TypeInterfaceDescriptioninterfaceinterfaceOperand<T>AnOperandrepresents a value parsed from command line arguments.interfaceOption<T>AnOptionrepresents a command line option with the according option's value.interfaceAnPropertyOptionrepresents a command line property with the according porperty's key and value.Classes in org.refcodes.cli that implement TermModifier and TypeClassDescriptionclassTheAbstractConditionis an abstract implementation of theConditioninterface providing the boiler plate when implementing theConditioninterface as done by theAbstractCondition's sub-classes.classTheAbstractOperandis an abstract implementation of anOperandproviding the boiler plate when implementing theOperandinterface.classTheAbstractOptionis an abstract implementation of anOptionproviding the boiler plate when implementing theOptioninterface.classTheAbstractPropertyOptionis an abstract implementation of aPropertyOptionproviding the boiler plate when implementing thePropertyOptioninterface.classTheAllConditionenforces that the encapsulatedTermconsumes all arguments passed via invoking itsparseArgs(String[], CliContext), else aSuperfluousArgsExceptionis thrown.classAnAndConditioncontains (represents) a list ofCondition(Term) instances (nested by theAndCondition) of which all are to be parsed successfully as of invoking theparseArgs(String[], String[], CliContext)methods.classAny of the nestedConditionconditions may match for theAnyConditionto match, e.g. all of the nested conditions are optional.classArrayOperand<T>Creates an array representation facade for the encapsulatedOperand.classArrayOption<T>Creates an array representation facade for the encapsulatedOption.classclassclassTheCasesConditionis anXorConditionmaking sure that all possible cases inside theXorConditionmust(!)classclassclassA predefined cleanFlag: A predefinedFlaggives itsCleanFlag.SHORT_OPTION, itsCleanFlag.LONG_OPTIONas well as itsCleanFlag.ALIASan according semantics regarded by other subsystems.classTheConfigOptionrepresents anOptionholding a value specifying a configuration resource (file).classTheConfigPropertyrepresents anPropertyOptionholding a value specifying a configuration resource (file).classA predefined daemonFlag: A predefinedFlaggives itsDaemonFlag.SHORT_OPTION, itsDaemonFlag.LONG_OPTIONas well as itsDaemonFlag.ALIASan according semantics regarded by other subsystems.classA predefined debugFlag: A predefinedFlaggives itsDebugFlag.SHORT_OPTION, itsDebugFlag.LONG_OPTIONas well as itsDebugFlag.ALIASan according semantics regarded by other subsystems.classclassclassEnumOption<T extends Enum<T>>TheEnumOptionrepresents anOptionof enumeration types.classEnumProperty<T extends Enum<T>>TheEnumPropertyrepresents anPropertyOptionof enumeration types.classclassclassTheFlagclass implements theOptioninterface for representing either atrueor afalsestate: When a flag is provided to your command line arguments, then it is considered to betrue, when it is omitted, then it is considered to befalseas ofFlag.isEnabled().classclassclassA predefined forceFlag: A predefinedFlaggives itsForceFlag.SHORT_OPTION, itsForceFlag.LONG_OPTIONas well as itsForceFlag.ALIASan according semantics regarded by other subsystems.classA predefined helpFlag: A predefinedFlaggives itsHelpFlag.SHORT_OPTION, itsHelpFlag.LONG_OPTIONas well as itsHelpFlag.ALIASan according semantics regarded by other subsystems.classA predefined initFlag: A predefinedFlaggives itsInitFlag.SHORT_OPTION, itsInitFlag.LONG_OPTIONas well as itsInitFlag.ALIASan according semantics regarded by other subsystems.classclassclassclassclassTheNoneOperandrepresents an empty set of arguments, e.g. no command line argument is being passed.classTheOperationis an argument representing a function or a method ("command") and is either provided or not provided as ofOperation.isEnabled().classAnOrConditionrepresents a list ofCondition(Term) instances of which at least one must be parsed successfully when theTerms'parseArgs(String[], String[], CliContext)methods are invoked.classA predefined "be quiet"Flag: A predefinedFlaggives itsQuietFlag.SHORT_OPTION, itsQuietFlag.LONG_OPTIONas well as itsQuietFlag.ALIASan according semantics regarded by other subsystems.classclassclassclassA predefined system informationFlag: A predefinedFlaggives itsSysInfoFlag.SHORT_OPTION, itsSysInfoFlag.LONG_OPTIONas well as itsSysInfoFlag.ALIASan according semantics regarded by other subsystems..classA predefined verboseFlag: A predefinedFlaggives itsVerboseFlag.SHORT_OPTION, itsVerboseFlag.LONG_OPTIONas well as itsVerboseFlag.ALIASan according semantics regarded by other subsystems.classAnXorConditionrepresents a list ofCondition(Term) instances of which only one is allowed to be parsed successfully when theparseArgs(String[], String[], CliContext)methods are invoked.Fields in org.refcodes.cli declared as TermModifier and TypeFieldDescriptionprotected Term[]AbstractCondition._childrenprotected TermArgsSyntaxException._sourceMethods in org.refcodes.cli that return TermModifier and TypeMethodDescriptionArgsParser.getArgsSyntax()ArgsSyntaxAccessor.getArgsSyntax()ParseArgs.getArgsSyntax()protected TermAllCondition.getChild()Returns the one and only child of thisTerm.Term[]AbstractCondition.getChildren()ArgsSyntaxException.getSource()Returns theTermresponsible for this exception.default TermArgsSyntaxAccessor.ArgsSyntaxProperty.letArgsSyntax(Term aArgsSyntax) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenCondition(setter) as ofArgsSyntaxAccessor.ArgsSyntaxMutator.setArgsSyntax(Term)and returns the very same value (getter).Methods in org.refcodes.cli with parameters of type TermModifier and TypeMethodDescriptionstatic AllConditionstatic AndConditionstatic AnyConditionstatic CasesConditiondefault booleandefault booleandefault TermArgsSyntaxAccessor.ArgsSyntaxProperty.letArgsSyntax(Term aArgsSyntax) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenCondition(setter) as ofArgsSyntaxAccessor.ArgsSyntaxMutator.setArgsSyntax(Term)and returns the very same value (getter).static AnyConditionSemantically identical synonym for theCliSugar.optional(Term...)declaration.static OrConditionvoidArgsParser.setArgsSyntax(Term aArgsSyntax) voidArgsSyntaxAccessor.ArgsSyntaxMutator.setArgsSyntax(Term aArgsSyntax) String[]CliContext.toAllOptions(Term aConstituent) Determines all options (short and long) found in the providedTermnode and its children.ArgsParser.withArgsSyntax(Term aArgsSyntax) ArgsSyntaxAccessor.ArgsSyntaxBuilder.withArgsSyntax(Term aArgsSyntax) static XorConditionConstructors in org.refcodes.cli with parameters of type TermModifierConstructorDescriptionAbstractCondition(String aDescription, Term... aElements) Instantiates anAbstractCondition' s sub-class with the according arguments.AllCondition(Term aArg) AmbiguousArgsException(String[] aArgs, Term aSource, Throwable aCause) AmbiguousArgsException(String[] aArgs, Term aSource, Throwable aCause, String aErrorCode) AmbiguousArgsException(String aMessage, String[] aArgs, Term aSource) AmbiguousArgsException(String aMessage, String[] aArgs, Term aSource, String aErrorCode) AmbiguousArgsException(String aMessage, String[] aArgs, Term aSource, Throwable aCause) AmbiguousArgsException(String aMessage, String[] aArgs, Term aSource, Throwable aCause, String aErrorCode) AndCondition(Term... aArgs) AnyCondition(Term... aArgs) ArgsParser(Term aArgsSyntax) Constructs theParseArgsinstance with the given rootConditionand the defaultSyntaxNotation.LOGICAL.ArgsParser(Term aArgsSyntax, CliContext aCliCtx) Constructs theParseArgsinstance with the given rootConditionand the defaultSyntaxNotation.LOGICAL.ArgsSyntaxException(String[] aArgs, Term aSource, Throwable aCause) ArgsSyntaxException(String[] aArgs, Term aSource, Throwable aCause, String aErrorCode) ArgsSyntaxException(String aMessage, String[] aArgs, Term aSource) ArgsSyntaxException(String aMessage, String[] aArgs, Term aSource, String aErrorCode) ArgsSyntaxException(String aMessage, String[] aArgs, Term aSource, Throwable aCause) ArgsSyntaxException(String aMessage, String[] aArgs, Term aSource, Throwable aCause, String aErrorCode) CasesCondition(Term... aArgs) OrCondition(Term... aArgs) ParseArgsException(String[] aArgs, Term aSource, Throwable aCause) ParseArgsException(String[] aArgs, Term aSource, Throwable aCause, String aErrorCode) ParseArgsException(String aMessage, String[] aArgs, Term aSource) ParseArgsException(String aMessage, String[] aArgs, Term aSource, String aErrorCode) ParseArgsException(String aMessage, String[] aArgs, Term aSource, Throwable aCause) ParseArgsException(String aMessage, String[] aArgs, Term aSource, Throwable aCause, String aErrorCode) ParseOptionArgsException(String[] aArgs, String aShortOption, String aLongOption, Throwable aCause, Term aSource) ParseOptionArgsException(String[] aArgs, String aShortOption, String aLongOption, Throwable aCause, Term aSource, String aErrorCode) ParseOptionArgsException(String aMessage, String[] aArgs, String aShortOption, String aLongOption, Throwable aCause, Term aSource) ParseOptionArgsException(String aMessage, String[] aArgs, String aShortOption, String aLongOption, Throwable aCause, Term aSource, String aErrorCode) ParseOptionArgsException(String aMessage, String[] aArgs, String aShortOption, String aLongOption, Term aSource) ParseOptionArgsException(String aMessage, String[] aArgs, String aShortOption, String aLongOption, Term aSource, String aErrorCode) SuperfluousArgsException(String[] aArgs, Term aSource, Throwable aCause) SuperfluousArgsException(String[] aArgs, Term aSource, Throwable aCause, String aErrorCode) SuperfluousArgsException(String aMessage, String[] aArgs, Term aSource) SuperfluousArgsException(String aMessage, String[] aArgs, Term aSource, String aErrorCode) SuperfluousArgsException(String aMessage, String[] aArgs, Term aSource, Throwable aCause) SuperfluousArgsException(String aMessage, String[] aArgs, Term aSource, Throwable aCause, String aErrorCode) UnknownArgsException(String[] aArgs, Term aSource, Throwable aCause) UnknownArgsException(String[] aArgs, Term aSource, Throwable aCause, String aErrorCode) UnknownArgsException(String aMessage, String[] aArgs, Term aSource) UnknownArgsException(String aMessage, String[] aArgs, Term aSource, String aErrorCode) UnknownArgsException(String aMessage, String[] aArgs, Term aSource, Throwable aCause) UnknownArgsException(String aMessage, String[] aArgs, Term aSource, Throwable aCause, String aErrorCode) UnknownOptionArgsException(String aMessage, String[] aArgs, String aShortOption, String aLongOption, Throwable aCause, Term aSource) UnknownOptionArgsException(String aMessage, String[] aArgs, String aShortOption, String aLongOption, Throwable aCause, Term aSource, String aErrorCode) UnknownOptionArgsException(String aMessage, String[] aArgs, String aShortOption, String aLongOption, Term aSource) UnknownOptionArgsException(String aMessage, String[] aArgs, String aShortOption, String aLongOption, Term aSource, String aErrorCode) UnknownOptionArgsException(String aShortOption, String aLongOption, String[] aArgs, Throwable aCause, Term aSource) UnknownOptionArgsException(String aShortOption, String aLongOption, String[] aArgs, Throwable aCause, Term aSource, String aErrorCode) protectedXorCondition(String aDescription, Term... aArgs) XorCondition(Term... aArgs)