Uses of Class
org.refcodes.cli.UnknownArgsException
-
Uses of UnknownArgsException in org.refcodes.cli
Subclasses of UnknownArgsException in org.refcodes.cliModifier and TypeClassDescriptionclassThrown in case command line arguments were not processed (did not match the expected arguments) by anOption(having a short- and/or a long-option), e.g. the arguments were rejected as them did not work for the according syntax.Methods in org.refcodes.cli that return UnknownArgsExceptionModifier and TypeMethodDescriptionprotected UnknownArgsExceptionAbstractOption.toException(String[] aArgs, CliContext aCliCtx) Convenience method to create anUnknownArgsException.