Provides an accessor for a command line arguments (short "args") array.
Provides a mutator for a args property.
Enumeration declaring command line argument filter.
The
ArgsParser provides means for parsing command line arguments and
constructing a command line utility's help output.
Provides a builder method for a
ArgsParser property returning the
builder for applying multiple build operations.
This mixin provides builder additions (as of the builder pattern for chained
configuring method calls) for parsing command line arguments.
Provides an accessor for a root condition property.
Provides a builder method for a root condition property returning the
builder for applying multiple build operations.
Provides a mutator for a root condition property.
Thrown in case of a command line arguments mismatch regarding provided and
expected args.
Provides an accessor for a argument Escape-Code property.
Provides a builder method for a argument Escape-Code property returning
the builder for applying multiple build operations.
Provides a mutator for a argument Escape-Code property.
Provides a argument Escape-Code property.
Provides an accessor for an argument prefix property.
Provides a builder method for an argument prefix property returning the
builder for applying multiple build operations.
Provides a mutator for an argument prefix property.
Provides an accessor for an argument suffix property.
Provides a builder method for an argument suffix property returning the
builder for applying multiple build operations.
Provides a mutator for an argument suffix property.
Creates an array representation facade for the encapsulated
Operand.
Creates an array representation facade for the encapsulated
Option.
Provides a builder method for a
CliContext property returning the
builder for applying multiple build operations.
Base exception for the console artifact.
This abstract exception is the base exception for all command line
argument related exceptions.
The
Condition interface represents a node (and therewith the syntax
for the arguments) in the command line arguments syntax tree; simply
extending the
Constituent interface and adding the functionality of
providing access to the added
Operands (leafs).
The
ConfigOption represents an
Option holding a value
specifying a configuration resource (file).
A
Constituent defines the methods at least required when building a
command line arguments syntax tree for traversing the syntax tree; either for
parsing command line arguments or for constructing the command line arguments
syntax.
An example usage item describing a usage scenario.
The
Flag class implements the
Option interface for
representing either a
true or a
false state: When a
flag is provided to your command line arguments, then it is considered to be
true, when it is omitted, then it is considered to be
false as of
Flag.isEnabled().
Provides an accessor for a long option prefix property.
Provides a builder method for a long option prefix property returning the
builder for applying multiple build operations.
Provides a mutator for a long option prefix property.
Provides a long option prefix property.
The
NoneOperand represents an empty set of arguments, e.g. no command
line argument is being passed.
An
Operand represents a value parsed from command line arguments.
An
Option represents a command line option with the according
option's value.
Provides means to determine context specific information on
Option
instances.
Provides an accessor for a option Escape-Code property.
Provides a builder method for a option Escape-Code property returning the
builder for applying multiple build operations.
Provides a mutator for a option Escape-Code property.
Provides a option Escape-Code property.
Thrown in case the provided command line arguments do not respect the
required semantics or cannot be converted to the required type.
Provides an accessor for a short option prefix property.
Provides a builder method for a short option prefix property returning
the builder for applying multiple build operations.
Provides a mutator for a short option prefix property.
Provides a short option prefix property.
An
Operand (neither a short option nor a long option prepended nor
being a switch) being s
String.
The
Synopsisable interface defines those methods required to create a
human readable usage
String similar to a manpage's synopsis from the
implementing instance.
The
SyntaxMetrics provides properties specific to a specific command
line syntax notation.
Provides a builder method for a
SyntaxMetrics property returning
the builder for applying multiple build operations.