Uses of Package
org.refcodes.cli
-
Classes in org.refcodes.cli used by org.refcodes.cliClassDescriptionThe
AbstractConditionis an abstract implementation of theArgsSyntaxinterface providing the boiler plate when implementing theArgsSyntaxinterface as done by theAbstractCondition's sub-classes.TheAbstractOperandis an abstract implementation of anOperandproviding the boiler plate when implementing theOperandinterface.TheAbstractOptionis an abstract implementation of anOptionproviding the boiler plate when implementing theOptioninterface.Provides an accessor for a command line arguments (short "args") array.Provides a mutator for a args property.TheArgsParserprovides means for parsing command line arguments and constructing a command line utility's help output.Provides an accessor for aArgsParserproperty.Provides a builder method for aArgsParserproperty returning the builder for applying multiple build operations.Provides a mutator for aArgsParserproperty.This mixin provides builder additions (as of the builder pattern for chained configuring method calls) for parsing command line arguments.TheArgsSyntaxinterface represents a node (and therewith the syntax for the arguments) in the command line arguments syntax tree; simply extending theSyntaxableinterface and adding the functionality of providing access to the addedOperands (leafs).Thrown in case of a command line arguments mismatch regarding provided and expected args.Creates an array representation facade for the encapsulatedOperand.Creates an array representation facade for the encapsulatedOption.A predefined cleanFlag: A predefinedFlaggives itsCleanFlag.SHORT_OPTION, itsCleanFlag.LONG_OPTIONas well as itsCleanFlag.ALIASan according semantics regarded by other subsystems.Base exception for the console artifact.This abstract exception is the base exception for all command line argument related exceptions.The purpose of aCliSchemais automatically generate documentation ofSyntaxablestructures.Interface indicating that theArgsSyntaxsemantically represents a condition which usally encapsulates otherSyntaxablechildren.TheConfigOptionrepresents anOptionholding a value specifying a configuration resource (file).A predefined daemonFlag: A predefinedFlaggives itsDaemonFlag.SHORT_OPTION, itsDaemonFlag.LONG_OPTIONas well as itsDaemonFlag.ALIASan according semantics regarded by other subsystems.A predefined debugFlag: A predefinedFlaggives itsDebugFlag.SHORT_OPTION, itsDebugFlag.LONG_OPTIONas well as itsDebugFlag.ALIASan according semantics regarded by other subsystems.The Class EnumOption.An example usage item describing a usage scenario.TheFlagclass implements theOptioninterface for representing either atrueor afalsestate: When a flag is provided to your command line arguments, then it is considered to betrue, when it is omitted, then it is considered to befalseas ofFlag.isEnabled().A predefined forceFlag: A predefinedFlaggives itsSHORT_OPTION, itsLONG_OPTIONas well as itsALIASan according semantics regarded by other subsystems.A predefined helpFlag: A predefinedFlaggives itsHelpFlag.SHORT_OPTION, itsHelpFlag.LONG_OPTIONas well as itsHelpFlag.ALIASan according semantics regarded by other subsystems.A predefined initFlag: A predefinedFlaggives itsInitFlag.SHORT_OPTION, itsInitFlag.LONG_OPTIONas well as itsInitFlag.ALIASan according semantics regarded by other subsystems.TheNoneOperandrepresents an empty set of arguments, e.g. no command line argument is being passed.AnOperandrepresents a value parsed from command line arguments.TheOperationis an argument representing a function or a method ("command") and is either provided or not provided as ofOperation.isEnabled().AnOptionrepresents a command line option with the according option's value.Thrown in case the provided command line arguments do not respect the required semantics or cannot be converted to the required type.A predefined "be quiet"Flag: A predefinedFlaggives itsQuietFlag.SHORT_OPTION, itsQuietFlag.LONG_OPTIONas well as itsQuietFlag.ALIASan according semantics regarded by other subsystems.Provides an accessor for a root condition property.Provides a builder method for a root condition property returning the builder for applying multiple build operations.Provides a mutator for a root condition property.TheSynopsisableinterface defines those methods required to create a human readable usageStringsimilar to a manpage's synopsis from the implementing instance.ASyntaxabledefines the methods at least required when building a command line arguments syntax tree for traversing the syntax tree; either for parsing command line arguments or for constructing the command line arguments syntax.TheSyntaxNotationis used by a theSyntaxable.toSyntax(SyntaxNotation, String, String, String)method to determine which notation to be used for the generated syntax.A predefined system informationFlag: A predefinedFlaggives itsSysInfoFlag.SHORT_OPTION, itsSysInfoFlag.LONG_OPTIONas well as itsSysInfoFlag.ALIASan according semantics regarded by other subsystems..A predefined verboseFlag: A predefinedFlaggives itsVerboseFlag.SHORT_OPTION, itsVerboseFlag.LONG_OPTIONas well as itsVerboseFlag.ALIASan according semantics regarded by other subsystems.AnXorConditionrepresents a list ofArgsSyntax(Syntaxable) instances of which only one is allowed to be parsed successfully when theSyntaxable.parseArgs(String[], String[])methods are invoked.