| AbstractCondition |
|
| AbstractOperand |
|
| AbstractOption |
|
| ArgsAccessor |
Provides an accessor for a command line arguments (short "args") array.
|
| ArgsAccessor.ArgsMutator |
Provides a mutator for a args property.
|
| ArgsParser |
The ArgsParser provides means for parsing command line arguments and
constructing a command line utility's help output.
|
| ArgsParserAccessor |
|
| ArgsParserAccessor.ArgsParserBuilder |
Provides a builder method for a ArgsParser property returning the
builder for applying multiple build operations.
|
| ArgsParserAccessor.ArgsParserMutator |
|
| ArgsParserMixin |
This mixin provides builder additions (as of the builder pattern for chained
configuring method calls) for parsing command line arguments.
|
| ArgsSyntax |
The ArgsSyntax interface represents a node (and therewith the syntax
for the arguments) in the command line arguments syntax tree; simply
extending the Syntaxable interface and adding the functionality of
providing access to the added Operands (leafs).
|
| ArgsSyntaxException |
Thrown in case of a command line arguments mismatch regarding provided and
expected args.
|
| ArrayOperand |
Creates an array representation facade for the encapsulated Operand.
|
| ArrayOption |
Creates an array representation facade for the encapsulated Option.
|
| CharOption |
|
| CleanFlag |
|
| CliException |
Base exception for the console artifact.
|
| CliException.ConsoleArgsException |
This abstract exception is the base exception for all command line
argument related exceptions.
|
| Condition |
Interface indicating that the ArgsSyntax semantically represents a
condition which usally encapsulates other Syntaxable children.
|
| ConfigOption |
The ConfigOption represents an Option holding a value
specifying a configuration resource (file).
|
| DaemonFlag |
|
| DebugFlag |
|
| DoubleOption |
|
| EnumOption |
The Class EnumOption.
|
| Example |
An example usage item describing a usage scenario.
|
| FileOption |
|
| Flag |
The Flag class implements the Option interface for
representing either a true or a false state: When a
flag is provided to your command line arguments, then it is considered to be
true, when it is omitted, then it is considered to be
false as of Flag.isEnabled().
|
| FloatOption |
|
| ForceFlag |
|
| HelpFlag |
|
| InitFlag |
|
| IntOption |
|
| LongOption |
|
| NoneOperand |
The NoneOperand represents an empty set of arguments, e.g. no command
line argument is being passed.
|
| Operand |
An Operand represents a value parsed from command line arguments.
|
| Operation |
|
| Option |
An Option represents a command line option with the according
option's value.
|
| ParseArgsException |
Thrown in case the provided command line arguments do not respect the
required semantics or cannot be converted to the required type.
|
| QuietFlag |
|
| RootConditionAccessor |
Provides an accessor for a root condition property.
|
| RootConditionAccessor.RootConditionBuilder |
Provides a builder method for a root condition property returning the
builder for applying multiple build operations.
|
| RootConditionAccessor.RootConditionMutator |
Provides a mutator for a root condition property.
|
| StringOperand |
An Operand (neither a short option nor a long option prepended nor
being a switch) being s String.
|
| StringOption |
|
| Synopsis |
The Synopsis interface defines those methods required to create a
human readable usage String from the implementing instance.
|
| Syntaxable |
A Syntaxable defines the methods at least required when building a
command line arguments syntax tree for traversing the syntax tree; either for
parsing command line arguments or for constructing the command line arguments
syntax.
|
| SyntaxNotation |
|
| SysInfoFlag |
|
| VerboseFlag |
|
| XorCondition |
|